
      ***************************************************************
      * File:      IF4105.CBL
      * Author:    Mike Ray
      * Date:      05/20/96
      * Purpose:   Calculates guarantee per acre and dollar amt of
      *            protection per acre as ranges based upon a minimum
      *            and maximum coverage level percent.  This is required
      *            because the reinsured companies are not required to
      *            report coverage level percent for IP crops.
      ***************************************************************

       4105-CALC-IP-DOLLAR-AMT.

      $IF DEBUG-SW DEFINED
           DISPLAY '4105-CALCULATING IP DOLLAR AMT OF INSURANCE'
           UPON CONSOLE
      $END

      *****************************************************
      *    INITIALIZE LOCAL AND OUTPUT VARIABLES          *
      *****************************************************
           INITIALIZE WS-4105-LOCAL
           INITIALIZE WS-4105-OUTPUT
           MOVE 50 TO WS-4105-MIN-CVG-LVL-PERCENT
           MOVE 75 TO WS-4105-MAX-CVG-LVL-PERCENT

      *****************************************************
      *    SET UP DISPLAY FIELDS                          *
      *****************************************************
           MOVE WS-4105-YIELD TO WS-4105-YIELD-X
           MOVE WS-4105-PRICE-ELECTION TO WS-4105-PRICE-ELECTION-X
           MOVE WS-4105-GUAR-REDUCTION-FCTR
             TO WS-4105-GUAR-REDUCTION-FCTR-X

      $IF DEBUG-SW DEFINED
           DISPLAY 'YIELD         = ', WS-4105-YIELD-X
           UPON CONSOLE
           DISPLAY 'PRICE ELECT   = ', WS-4105-PRICE-ELECTION-X
           UPON CONSOLE
           DISPLAY 'CVG LEVEL %   = ', WS-4105-CVG-LVL-PERCENT
           UPON CONSOLE
           DISPLAY 'GUAR RED FCTR = ', WS-4105-GUAR-REDUCTION-FCTR-X
           UPON CONSOLE
      $END

      *****************************************************
      *    CHECK PRE-CONDITIONS                           *
      *****************************************************
           IF WS-4105-YIELD = ZEROS
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-4105-CALC-ERROR
              MOVE 'WS-4105-YIELD' TO WS-8000-FIELD-NAME1
              MOVE ZERO TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 4105 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-4105-PRICE-ELECTION = ZEROS
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-4105-CALC-ERROR
              MOVE 'WS-4105-PRICE-ELECTION' TO WS-8000-FIELD-NAME1
              MOVE ZERO TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 4105 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-4105-CVG-LVL-PERCENT < ZEROS
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-4105-CALC-ERROR
              MOVE 'WS-4105-CVG-LVL-PCT' TO WS-8000-FIELD-NAME1
              MOVE ZERO TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 4105 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-4105-CROP-UNIT-OF-MEASURE = ZEROS
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-4105-CALC-ERROR
              MOVE 'WS-4105-CROP-UM' TO WS-8000-FIELD-NAME1
              MOVE ZERO TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 4105 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-4105-CALC-ERROR = WS-LITERAL-YES
              GO TO 4105-CALC-IP-DOLLAR-AMT-EXIT
           END-IF

      *    *** WS-4105-GUAR-REDUCTION-FCTR CAN = ZEROS
      *    *** IF ZEROS DEFAULT TO 1.00 FOR CALCULATION
           IF WS-4105-GUAR-REDUCTION-FCTR = ZEROS
              MOVE 1.00 TO WS-4105-GUAR-REDUCTION-FCTR
           END-IF

      *****************************************************
      *             PERFORM CALCULATIONS                  *
      *****************************************************
           IF WS-4105-CROP-UNIT-OF-MEASURE = WS-LITERAL-DOLLARS OR
              WS-4105-CROP-UNIT-OF-MEASURE = WS-LITERAL-LBS

      ***************************************************************
      *  FOR CROPS WHICH USE DOLLARS OR POUNDS AS A COMMODITY UNIT  *
      *  OF MEASURE, ROUND THE GUARANTEE PER ACRE TO THE NEAREST    *
      *  DOLLAR OR POUND.                                           *
      ***************************************************************

              COMPUTE WS-4105-MIN-GPA-LBS ROUNDED =
                 WS-4105-YIELD * (WS-4105-MIN-CVG-LVL-PERCENT / 100)
                 ON SIZE ERROR
                    MOVE 4105 TO WS-8020-PARAGRAPH-NO
                    MOVE 90017 TO WS-8020-INT-ERROR-NO
                    MOVE 'Yield * CVG LVL %' TO WS-8020-FIELD-NAME
                    MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                    PERFORM 8020-RECORD-INT-ERROR
                       THRU 8020-RECORD-INT-ERROR-EXIT
              END-COMPUTE

              COMPUTE WS-4105-MAX-GPA-LBS ROUNDED =
                 WS-4105-YIELD * (WS-4105-MAX-CVG-LVL-PERCENT / 100)
                 ON SIZE ERROR
                    MOVE 4105 TO WS-8020-PARAGRAPH-NO
                    MOVE 90017 TO WS-8020-INT-ERROR-NO
                    MOVE 'Yield * CVG LVL %' TO WS-8020-FIELD-NAME
                    MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                    PERFORM 8020-RECORD-INT-ERROR
                       THRU 8020-RECORD-INT-ERROR-EXIT
              END-COMPUTE

      *       *** AFTER ROUNDING, MOVE THE ROUNDED FIELDS TO THE
      *       *** MORE PRECISE FIELDS FOR THE NEXT SET OF CALCULATIONS.
              MOVE WS-4105-MIN-GPA-LBS
                TO WS-4105-MIN-GUARANTEE-PER-ACRE
              MOVE WS-4105-MAX-GPA-LBS
                TO WS-4105-MAX-GUARANTEE-PER-ACRE
           ELSE
      ***************************************************************
      *  FOR CROPS WHICH DO NOT USE DOLLARS OR POUNDS AS A COMMODITY*
      *  UNIT OF MEASURE, ROUND THE GUARANTEE PER ACRE TO THE       *
      *  NEAREST TENTH OF A UNIT.                                   *
      ***************************************************************
              COMPUTE WS-4105-MIN-GUARANTEE-PER-ACRE ROUNDED =
                 WS-4105-YIELD * (WS-4105-MIN-CVG-LVL-PERCENT / 100)
                 ON SIZE ERROR
                    MOVE 4105 TO WS-8020-PARAGRAPH-NO
                    MOVE 90017 TO WS-8020-INT-ERROR-NO
                    MOVE 'Yield * CVG LVL %' TO WS-8020-FIELD-NAME
                    MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                    PERFORM 8020-RECORD-INT-ERROR
                       THRU 8020-RECORD-INT-ERROR-EXIT
              END-COMPUTE

              COMPUTE WS-4105-MAX-GUARANTEE-PER-ACRE ROUNDED =
                 WS-4105-YIELD * (WS-4105-MAX-CVG-LVL-PERCENT / 100)
                 ON SIZE ERROR
                    MOVE 4105 TO WS-8020-PARAGRAPH-NO
                    MOVE 90017 TO WS-8020-INT-ERROR-NO
                    MOVE 'Yield * CVG LVL %' TO WS-8020-FIELD-NAME
                    MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                    PERFORM 8020-RECORD-INT-ERROR
                       THRU 8020-RECORD-INT-ERROR-EXIT
              END-COMPUTE
           END-IF

      ***************************************************************
      *            DISPLAY GUARANTEE PER ACRE RESULTS               *
      ***************************************************************

      $IF DEBUG-SW DEFINED
           MOVE WS-4105-MIN-GUARANTEE-PER-ACRE
             TO WS-4105-MIN-GPA-X
           DISPLAY 'MINIMUM GPA        = ',
           WS-4105-MIN-GPA-X
           UPON CONSOLE
           MOVE WS-4105-MAX-GUARANTEE-PER-ACRE
             TO WS-4105-MAX-GPA-X
           DISPLAY 'MAXIMUM GPA        = ',
           WS-4105-MAX-GPA-X
           UPON CONSOLE
      $END

      ***************************************************************
      *            COMPUTE TOTAL AND PREMIUM GUARANTEES             *
      ***************************************************************

           COMPUTE WS-4105-MIN-PROT-ACRE ROUNDED =
              WS-4105-MIN-GUARANTEE-PER-ACRE * WS-4105-PRICE-ELECTION
              * WS-4105-GUAR-REDUCTION-FCTR
              ON SIZE ERROR
                 MOVE 4105 TO WS-8020-PARAGRAPH-NO
                 MOVE 90017 TO WS-8020-INT-ERROR-NO
                 MOVE 'GPA*PRICE*LPO/PP' TO WS-8020-FIELD-NAME
                 MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                 PERFORM 8020-RECORD-INT-ERROR
                    THRU 8020-RECORD-INT-ERROR-EXIT
           END-COMPUTE

           COMPUTE WS-4105-MAX-PROT-ACRE ROUNDED =
              WS-4105-MAX-GUARANTEE-PER-ACRE * WS-4105-PRICE-ELECTION
              * WS-4105-GUAR-REDUCTION-FCTR
              ON SIZE ERROR
                 MOVE 4105 TO WS-8020-PARAGRAPH-NO
                 MOVE 90017 TO WS-8020-INT-ERROR-NO
                 MOVE 'GPA*PRICE*LPO/PP' TO WS-8020-FIELD-NAME
                 MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                 PERFORM 8020-RECORD-INT-ERROR
                    THRU 8020-RECORD-INT-ERROR-EXIT
           END-COMPUTE

           MOVE WS-4105-MIN-PROT-ACRE
             TO WS-4105-MIN-PROT-ACRE-X
           MOVE WS-4105-MAX-PROT-ACRE
             TO WS-4105-MAX-PROT-ACRE-X.

      ***************************************************************
      *            DISPLAY TOTAL GUARANTEE RESULTS                  *
      ***************************************************************

      $IF DEBUG-SW DEFINED
           DISPLAY 'MIN $AMT PROTECTION PER ACRE = ',
           WS-4105-MIN-PROT-ACRE-X
           UPON CONSOLE
           DISPLAY 'MAX $AMT PROTECTION PER ACRE = ',
           WS-4105-MAX-PROT-ACRE-X
           UPON CONSOLE.
      $END

       4105-CALC-IP-DOLLAR-AMT-EXIT.
           EXIT.

