
      ***************************************************************
      * File:      IF4115.CBL
      * Author:    Mike Ray
      * Date:      03/04/97
      * Purpose:   Calculates dollar amount of protection per acre
      *            for a Revenue Assurance Enterprise unit.
      ***************************************************************

      *****************************************************
      *  BECAUSE THIS MODULE IS CALLED BY AN INTER-RECORD *
      *  EDIT AND CANNOT BE TIED BACK TO A PARTICULAR     *
      *  TRANSACTION WE WILL RECORD THESE ERRORS AS IR AND*
      *  REJECT THE WHOLE POLICY.  ANY ERROR WILL BE      *
      *  ASSOCIATED WITH THE TYPE 10 001 TRANSACTION.     *
      *****************************************************

       4115-CALC-RA-EU-DOL-AMT.

      $IF DEBUG-SW DEFINED
           DISPLAY '4115-CALCULATING RA ENTERPRISE DOLLAR AMT OF INS'
           UPON CONSOLE
      $END


      *****************************************************
      *    INITIALIZE LOCAL AND OUTPUT VARIABLES          *
      *****************************************************
           INITIALIZE WS-4115-LOCAL
           INITIALIZE WS-4115-OUTPUT

      *****************************************************
      *    SET UP DISPLAY FIELDS                          *
      *****************************************************
           MOVE WS-4115-ACRES TO WS-4115-ACRES-X
           MOVE WS-4115-PRICE-ELECTION TO WS-4115-PRICE-ELECTION-X
           MOVE WS-4115-YIELD-X-ACRES TO WS-4115-YIELD-X-ACRES-X
           MOVE WS-4115-RA-COVERAGE-LEVEL
             TO WS-4115-RA-COVERAGE-LEVEL-X

      $IF DEBUG-SW DEFINED
           DISPLAY 'SUM OF ACRES       = ', WS-4115-ACRES-X
           UPON CONSOLE
           DISPLAY 'PRICE ELECTION     = ', WS-4115-PRICE-ELECTION-X
           UPON CONSOLE
           DISPLAY 'SUM OF YLD x ACRES = ', WS-4115-YIELD-X-ACRES-X
           UPON CONSOLE
           DISPLAY 'RA CVG LEVEL %     = ',
           WS-4115-RA-COVERAGE-LEVEL-X
           UPON CONSOLE
      $END

      *****************************************************
      *    CHECK PRE-CONDITIONS                           *
      *****************************************************
           IF WS-4115-ACRES = ZEROS
              MOVE 10 TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-IR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-4115-CALC-ERROR
              MOVE 'WS-4115-DOLLAR-AMT-INS' TO WS-8000-FIELD-NAME1
              MOVE ZERO TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 4115 TO WS-8000-PARAGRAPH-NO
              MOVE WS-0005-TRAN-SEQ-NO TO WS-8000-TRAN-SEQ-NO
              MOVE WS-0005-CURRENT-POLICY-NO TO WS-8000-POLICY-NO
              MOVE WS-LITERAL-YES TO WS-0005-REJECT-POLICY-FLAG
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-4115-PRICE-ELECTION = ZEROS
              MOVE 10 TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-IR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-4115-CALC-ERROR
              MOVE 'WS-4115-PRICE-ELECTION' TO WS-8000-FIELD-NAME1
              MOVE ZERO TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 4115 TO WS-8000-PARAGRAPH-NO
              MOVE WS-0005-TRAN-SEQ-NO TO WS-8000-TRAN-SEQ-NO
              MOVE WS-0005-CURRENT-POLICY-NO TO WS-8000-POLICY-NO
              MOVE WS-LITERAL-YES TO WS-0005-REJECT-POLICY-FLAG
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-4115-YIELD-X-ACRES = ZEROS
              MOVE 10 TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-IR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-4115-CALC-ERROR
              MOVE 'WS-4115-YLD-X-ACRES' TO WS-8000-FIELD-NAME1
              MOVE ZERO TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 4115 TO WS-8000-PARAGRAPH-NO
              MOVE WS-0005-TRAN-SEQ-NO TO WS-8000-TRAN-SEQ-NO
              MOVE WS-0005-CURRENT-POLICY-NO TO WS-8000-POLICY-NO
              MOVE WS-LITERAL-YES TO WS-0005-REJECT-POLICY-FLAG
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-4115-RA-COVERAGE-LEVEL = ZEROS
              MOVE 10 TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-IR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-4115-CALC-ERROR
              MOVE 'WS-4115-RA-CVG-LVL' TO WS-8000-FIELD-NAME1
              MOVE ZERO TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 4115 TO WS-8000-PARAGRAPH-NO
              MOVE WS-0005-TRAN-SEQ-NO TO WS-8000-TRAN-SEQ-NO
              MOVE WS-0005-CURRENT-POLICY-NO TO WS-8000-POLICY-NO
              MOVE WS-LITERAL-YES TO WS-0005-REJECT-POLICY-FLAG
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-4115-CALC-ERROR = WS-LITERAL-YES
              GO TO 4115-CALC-RA-EU-DOL-AMT-EXIT
           END-IF


      ***************************************************************
      * COMPUTE MAX AND ACTUAL DOLLAR AMOUNT OF PROTECTION PER ACRE *
      ***************************************************************

           COMPUTE WS-4115-MAX-DOLLAR-AMT-PROT ROUNDED =
              (WS-4115-PRICE-ELECTION * WS-4115-YIELD-X-ACRES)
              / WS-4115-ACRES
              ON SIZE ERROR
                 MOVE 4115 TO WS-8020-PARAGRAPH-NO
                 MOVE 90017 TO WS-8020-INT-ERROR-NO
                 MOVE '(PRICE*(SUM YLD*ACRES))/SUM ACRES'
                   TO WS-8020-FIELD-NAME
                 MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                 PERFORM 8020-RECORD-INT-ERROR
                    THRU 8020-RECORD-INT-ERROR-EXIT
           END-COMPUTE

           COMPUTE WS-4115-DOLLAR-AMT-PROT ROUNDED =
              ((WS-4115-PRICE-ELECTION * WS-4115-YIELD-X-ACRES)
              / WS-4115-ACRES) * WS-4115-RA-COVERAGE-LEVEL
              ON SIZE ERROR
                 MOVE 4115 TO WS-8020-PARAGRAPH-NO
                 MOVE 90017 TO WS-8020-INT-ERROR-NO
                 MOVE 'MAX PROT * RA CVG LVL'
                   TO WS-8020-FIELD-NAME
                 MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                 PERFORM 8020-RECORD-INT-ERROR
                    THRU 8020-RECORD-INT-ERROR-EXIT
           END-COMPUTE.

      ***************************************************************
      *              DISPLAY RESULTS                                *
      ***************************************************************

      $IF DEBUG-SW DEFINED
           MOVE WS-4115-MAX-DOLLAR-AMT-PROT
             TO WS-4115-MAX-DOLLAR-AMT-PROT-X
           MOVE WS-4115-DOLLAR-AMT-PROT
             TO WS-4115-DOLLAR-AMT-PROT-X
           DISPLAY 'MAX $AMT PROTECTION PER ACRE = ',
           WS-4115-MAX-DOLLAR-AMT-PROT-X
           UPON CONSOLE
           DISPLAY 'ELECTED PROTECTION PER ACRE = ',
           WS-4115-DOLLAR-AMT-PROT-X
           UPON CONSOLE.
      $END


       4115-CALC-RA-EU-DOL-AMT-EXIT.
           EXIT.


