
      ***************************************************************
      * File:      IF4210.CBL
      * Author:    Mike Ray
      * Date:      05/20/96
      * Purpose:   Calculates Total Guarantee, Premium Guarantee,
      *            and Guarantee per Acre
      ***************************************************************

       4210-CALC-QUOTA-PNUT-GUAR.

      $IF DEBUG-SW DEFINED
           DISPLAY '4210-CALCULATING QUOTA PEANUT GUARANTEE'
           UPON CONSOLE
      $END

      *****************************************************
      *    INITIALIZE LOCAL AND OUTPUT VARIABLES          *
      *****************************************************
           INITIALIZE WS-4210-LOCAL
           INITIALIZE WS-4210-OUTPUT

      *****************************************************
      *    SET UP DISPLAY FIELDS                          *
      *****************************************************
           MOVE WS-4210-YIELD TO WS-4210-YIELD-X
           MOVE WS-4210-ACRES TO WS-4210-ACRES-X
           MOVE WS-4210-GUAR-REDUCTION-FCTR
             TO WS-4210-GUAR-REDUCTION-FCTR-X

      $IF DEBUG-SW DEFINED
           DISPLAY 'YIELD         = ', WS-4210-YIELD-X
           UPON CONSOLE
           DISPLAY 'GUAR RED FCTR = ', WS-4210-GUAR-REDUCTION-FCTR-X
           UPON CONSOLE
           DISPLAY 'ACRES         = ', WS-4210-ACRES-X
           UPON CONSOLE
      $END

      *****************************************************
      *    CHECK PRE-CONDITIONS                           *
      *****************************************************
           IF WS-4210-YIELD = ZEROS
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-4210-CALC-ERROR
              MOVE 'WS-4210-YIELD' TO WS-8000-FIELD-NAME1
              MOVE ZERO TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 4210 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-4210-ACRES = ZEROS
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-4210-CALC-ERROR
              MOVE 'WS-4210-ACRES' TO WS-8000-FIELD-NAME1
              MOVE ZERO TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 4210 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-4210-CROP-UNIT-OF-MEASURE = ZEROS
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-4210-CALC-ERROR
              MOVE 'WS-4210-CROP-UM' TO WS-8000-FIELD-NAME1
              MOVE ZERO TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 4210 TO WS-8000-PARAGRAPH-NO
              MOVE WS-LITERAL-YES TO ERROR-TOTAL-GUARANTEE
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-4210-CALC-ERROR = WS-LITERAL-YES
              MOVE WS-LITERAL-YES TO ERROR-TOTAL-GUARANTEE
              GO TO 4210-CALC-QUOTA-PNUT-GUAR-EXIT
           END-IF

      *    *** WS-4210-GUAR-REDUCTION-FCTR CAN = ZEROS
      *    *** IF ZEROS DEFAULT TO 1.00 FOR CALCULATION
            IF WS-4210-GUAR-REDUCTION-FCTR = ZEROS
               MOVE 1.00 TO WS-4210-GUAR-REDUCTION-FCTR
            END-IF

      *****************************************************
      *              PERFORM CALCULATIONS                 *
      *****************************************************

      ***************************************************************
      *  ROUND THE GUARANTEE PER ACRE TO THE NEAREST WHOLE UNIT     *
      ***************************************************************

           COMPUTE WS-4210-GUARANTEE-PER-ACRE ROUNDED =
              WS-4210-yield * (WS-4210-CVG-LVL-PERCENT / 100)
              ON SIZE ERROR
                 MOVE 4210 TO WS-8020-PARAGRAPH-NO
                 MOVE 90017 TO WS-8020-INT-ERROR-NO
                 MOVE 'Yld * CVG%' TO WS-8020-FIELD-NAME
                 MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                 PERFORM 8020-RECORD-INT-ERROR
                    THRU 8020-RECORD-INT-ERROR-EXIT
                 GO TO 4210-CALC-QUOTA-PNUT-GUAR-EXIT
           END-COMPUTE
           COMPUTE WS-4210-GUARANTEE-PER-ACRE ROUNDED =
               WS-4210-GUARANTEE-PER-ACRE * WS-4210-GUAR-REDUCTION-FCTR
              ON SIZE ERROR
                 MOVE 4210 TO WS-8020-PARAGRAPH-NO
                 MOVE 90017 TO WS-8020-INT-ERROR-NO
                 MOVE 'GPA*LPO' TO WS-8020-FIELD-NAME
                 MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                 PERFORM 8020-RECORD-INT-ERROR
                    THRU 8020-RECORD-INT-ERROR-EXIT
                 GO TO 4210-CALC-QUOTA-PNUT-GUAR-EXIT
           END-COMPUTE

      ***************************************************************
      *            DISPLAY GUARANTEE PER ACRE RESULTS               *
      ***************************************************************

      $IF DEBUG-SW DEFINED
           MOVE WS-4210-GUARANTEE-PER-ACRE
             TO WS-4210-GUARANTEE-PER-ACRE-X
           DISPLAY 'GUARANTEE PER ACRE = ',
           WS-4210-GUARANTEE-PER-ACRE-X
           UPON CONSOLE
      $END

      ***************************************************************
      *            COMPUTE TOTAL AND PREMIUM GUARANTEES             *
      ***************************************************************

           COMPUTE WS-4210-PREMIUM-GUARANTEE ROUNDED =
              WS-4210-yield * (WS-4210-CVG-LVL-PERCENT / 100)
              ON SIZE ERROR
                 MOVE 4210 TO WS-8020-PARAGRAPH-NO
                 MOVE 90017 TO WS-8020-INT-ERROR-NO
                 MOVE 'YIELD * Acres' TO WS-8020-FIELD-NAME
                 MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                 PERFORM 8020-RECORD-INT-ERROR
                    THRU 8020-RECORD-INT-ERROR-EXIT
           END-COMPUTE

           COMPUTE WS-4210-PREMIUM-GUARANTEE ROUNDED =
               WS-4210-PREMIUM-GUARANTEE * WS-4210-ACRES
              ON SIZE ERROR
                 MOVE 4210 TO WS-8020-PARAGRAPH-NO
                 MOVE 90017 TO WS-8020-INT-ERROR-NO
                 MOVE 'yield * Acres' TO WS-8020-FIELD-NAME
                 PERFORM 8020-RECORD-INT-ERROR
                    THRU 8020-RECORD-INT-ERROR-EXIT
           END-COMPUTE

           COMPUTE WS-4210-TOTAL-GUARANTEE ROUNDED =
              WS-4210-GUARANTEE-PER-ACRE * WS-4210-ACRES
              ON SIZE ERROR
                 MOVE 4210 TO WS-8020-PARAGRAPH-NO
                 MOVE 90017 TO WS-8020-INT-ERROR-NO
                 MOVE 'GPA * Acres' TO WS-8020-FIELD-NAME
                 MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                 PERFORM 8020-RECORD-INT-ERROR
                    THRU 8020-RECORD-INT-ERROR-EXIT
           END-COMPUTE.

      ***************************************************************
      *            DISPLAY TOTAL GUARANTEE RESULTS                  *
      ***************************************************************

      $IF DEBUG-SW DEFINED
           MOVE WS-4210-PREMIUM-GUARANTEE
             TO WS-4210-PREMIUM-GUARANTEE-X
           DISPLAY 'PREMIUM GUARANTEE  = ',
           WS-4210-PREMIUM-GUARANTEE-X
           UPON CONSOLE
           MOVE WS-4210-TOTAL-GUARANTEE
             TO WS-4210-TOTAL-GUARANTEE-X
           DISPLAY 'TOTAL GUARANTEE    = ',
           WS-4210-TOTAL-GUARANTEE-X
           UPON CONSOLE.
      $END

       4210-CALC-QUOTA-PNUT-GUAR-EXIT.
           EXIT.

