
      ***************************************************************
      * File:      IF4215.CBL
      * Author:    Mike Ray
      * Date:      05/20/96
      * Purpose:   Calculates Total Guarantee, Premium Guarantee,
      *            and Guarantee per Acre
      ***************************************************************

       4215-CALC-DOLLAR-GUAR.

      $IF DEBUG-SW DEFINED
           DISPLAY '4215-CALCULATING DOLLAR CROP GUARANTEE'
           UPON CONSOLE
      $END

      *****************************************************
      *    INITIALIZE LOCAL AND OUTPUT VARIABLES          *
      *****************************************************
           INITIALIZE WS-4215-LOCAL
           INITIALIZE WS-4215-OUTPUT

      *****************************************************
      *    SET UP DISPLAY FIELDS                          *
      *****************************************************
           MOVE WS-4215-ACRES TO WS-4215-ACRES-X
           MOVE WS-4215-GUAR-REDUCTION-FCTR
             TO WS-4215-GUAR-REDUCTION-FCTR-X
           MOVE WS-4215-DOLLAR-AMT-INS TO WS-4215-DOLLAR-AMT-INS-X

      $IF DEBUG-SW DEFINED
           DISPLAY '$AMT INS      = ', WS-4215-DOLLAR-AMT-INS-X
           UPON CONSOLE
           DISPLAY 'GUAR RED FCTR = ', WS-4215-GUAR-REDUCTION-FCTR-X
           UPON CONSOLE
           DISPLAY 'ACRES         = ', WS-4215-ACRES-X
           UPON CONSOLE
      $END

      *****************************************************
      *    CHECK PRE-CONDITIONS                           *
      *****************************************************
           IF WS-4215-ACRES = ZEROS
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-4215-CALC-ERROR
              MOVE 'WS-4215-ACRES' TO WS-8000-FIELD-NAME1
              MOVE ZERO TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 4215 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-4215-DOLLAR-AMT-INS = ZEROS
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-4215-CALC-ERROR
              MOVE 'WS-4215-DOLLAR-AMT-INS' TO WS-8000-FIELD-NAME1
              MOVE ZERO TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 4215 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-4215-CROP-UNIT-OF-MEASURE = ZEROS
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-4215-CALC-ERROR
              MOVE 'WS-4215-CROP-UM' TO WS-8000-FIELD-NAME1
              MOVE ZERO TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 4215 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-4215-CALC-ERROR = WS-LITERAL-YES
              GO TO 4215-CALC-DOLLAR-GUAR-EXIT
           END-IF

      *    *** WS-4215-GUAR-REDUCTION-FCTR CAN = ZEROS
      *    *** IF ZEROS DEFAULT TO 1.00 FOR CALCULATION
           IF WS-4215-GUAR-REDUCTION-FCTR = ZEROS
              MOVE 1.00 TO WS-4215-GUAR-REDUCTION-FCTR
           END-IF

      *****************************************************
      *              PERFORM CALCULATIONS                 *
      *****************************************************

           IF WS-4215-CROP-UNIT-OF-MEASURE = WS-LITERAL-DOLLARS
              OR WS-4215-CROP-UNIT-OF-MEASURE = WS-LITERAL-LBS

      ***************************************************************
      *  FOR CROPS WHICH USE DOLLARS OR POUNDS AS A COMMODITY UNIT  *
      *  OF MEASURE, ROUND THE GUARANTEE PER ACRE TO THE NEAREST    *
      *  DOLLAR OR POUND.                                           *
      ***************************************************************

              COMPUTE WS-4215-GUARANTEE-PER-ACRE-LBS ROUNDED =
                 WS-4215-DOLLAR-AMT-INS * WS-4215-GUAR-REDUCTION-FCTR
                 ON SIZE ERROR
                 MOVE 4215 TO WS-8020-PARAGRAPH-NO
                 MOVE 90017 TO WS-8020-INT-ERROR-NO
                 MOVE 'AMT INS*(1-GRF)' TO WS-8020-FIELD-NAME
                 MOVE WS-4215-GUARANTEE-PER-ACRE-LBS
                   TO WS-8020-BAD-DATA
                 MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                 PERFORM 8020-RECORD-INT-ERROR
                    THRU 8020-RECORD-INT-ERROR-EXIT
              END-COMPUTE

              MOVE WS-4215-DOLLAR-AMT-INS
                TO WS-4215-PREMIUM-GPA-LBS

      *       *** AFTER ROUNDING, MOVE THE ROUNDED FIELDS TO THE
      *       *** MORE PRECISE FIELDS FOR THE NEXT SET OF CALCULATIONS.

              MOVE WS-4215-GUARANTEE-PER-ACRE-LBS
                TO WS-4215-GUARANTEE-PER-ACRE
           ELSE
      ***************************************************************
      *  FOR CROPS WHICH DO NOT USE DOLLARS OR POUNDS AS A COMMODITY*
      *  UNIT OF MEASURE, ROUND THE GUARANTEE PER ACRE TO THE       *
      *  NEAREST TENTH OF A UNIT.                                   *
      *                                                             *
      *  GUARANTEE PER ACRE = $AMT INS * GUAR RED FCTR              *
      *  PREM GPA           = $AMT INS                              *
      ***************************************************************

              COMPUTE WS-4215-GUARANTEE-PER-ACRE ROUNDED =
                 WS-4215-DOLLAR-AMT-INS * WS-4215-GUAR-REDUCTION-FCTR
                 ON SIZE ERROR
                    MOVE 4215 TO WS-8020-PARAGRAPH-NO
                    MOVE 90017 TO WS-8020-INT-ERROR-NO
                    MOVE 'AMT INS * (1-GRF)' TO WS-8020-FIELD-NAME
                    MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                    PERFORM 8020-RECORD-INT-ERROR
                       THRU 8020-RECORD-INT-ERROR-EXIT
              END-COMPUTE
           END-IF

           MOVE WS-4215-DOLLAR-AMT-INS TO WS-4215-PREMIUM-GPA

      ***************************************************************
      *            DISPLAY GUARANTEE PER ACRE RESULTS               *
      ***************************************************************

      $IF DEBUG-SW DEFINED
           MOVE WS-4215-PREMIUM-GPA TO WS-4215-PREMIUM-GPA-X
           DISPLAY 'PREMIUM GPA        = ', WS-4215-PREMIUM-GPA-X
           UPON CONSOLE
           MOVE WS-4215-GUARANTEE-PER-ACRE
             TO WS-4215-GUARANTEE-PER-ACRE-X
           DISPLAY 'GUARANTEE PER ACRE = ',
           WS-4215-GUARANTEE-PER-ACRE-X
           UPON CONSOLE
      $END

      ***************************************************************
      *            COMPUTE TOTAL AND PREMIUM GUARANTEES             *
      ***************************************************************

           IF WS-4215-CROP-UNIT-OF-MEASURE = WS-LITERAL-BARRELS OR
              WS-4215-CROP-UNIT-OF-MEASURE = WS-LITERAL-TONS

      ***************************************************************
      *  FOR CROPS WHICH USE TONS OR BARRELS AS A COMMODITY UNIT OF *
      *  MEASURE, ROUND THE TOTAL GUARANTEE TO THE NEAREST TENTH OF *
      *  A UNIT.                                                    *
      *                                                             *
      *  GUARANTEE = GUARANTEE PER ACRE * ACRES                     *
      *  PREMIUM GUARANTEE = PREM GPA * ACRES                       *
      ***************************************************************

              COMPUTE WS-4215-PREMIUM-GUARANTEE ROUNDED =
                 WS-4215-PREMIUM-GPA * WS-4215-ACRES
                 ON SIZE ERROR
                    MOVE 4215 TO WS-8020-PARAGRAPH-NO
                    MOVE 90017 TO WS-8020-INT-ERROR-NO
                    MOVE 'Amt Ins * Acres' TO WS-8020-FIELD-NAME
                    MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                    PERFORM 8020-RECORD-INT-ERROR
                       THRU 8020-RECORD-INT-ERROR-EXIT
              END-COMPUTE

              COMPUTE WS-4215-TOTAL-GUARANTEE ROUNDED =
                 WS-4215-GUARANTEE-PER-ACRE * WS-4215-ACRES
                 ON SIZE ERROR
                    MOVE 4215 TO WS-8020-PARAGRAPH-NO
                    MOVE 90017 TO WS-8020-INT-ERROR-NO
                    MOVE 'GPA * Acres' TO WS-8020-FIELD-NAME
                    MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                    PERFORM 8020-RECORD-INT-ERROR
                       THRU 8020-RECORD-INT-ERROR-EXIT
              END-COMPUTE

           ELSE
      ***************************************************************
      *  FOR CROPS WHICH DO NOT USE TONS OR BARRELS AS A COMMODITY  *
      *  UNIT OF MEASURE, ROUND THE TOTAL GUARANTEE TO THE NEAREST  *
      *  WHOLE UNIT.                                                *
      *                                                             *
      *  GUARANTEE = GUARANTEE PER ACRE * ACRES                     *
      *  PREMIUM GUARANTEE = PREM GPA * ACRES                       *
      ***************************************************************

              COMPUTE WS-4215-PREMIUM-GUARANTEE-LBS ROUNDED =
                 WS-4215-DOLLAR-AMT-INS * WS-4215-ACRES
                 ON SIZE ERROR
                    MOVE 4215 TO WS-8020-PARAGRAPH-NO
                    MOVE 90017 TO WS-8020-INT-ERROR-NO
                    MOVE 'Amt Ins * Acres' TO WS-8020-FIELD-NAME
                    MOVE WS-4215-PREMIUM-GUARANTEE-LBS
                      TO WS-8020-BAD-DATA
                    MOVE WS-LITERAL-YES
                      TO WS-8020-ABORT-PROGRAM
                    PERFORM 8020-RECORD-INT-ERROR
                       THRU 8020-RECORD-INT-ERROR-EXIT
              END-COMPUTE

              COMPUTE WS-4215-TOTAL-GUARANTEE-LBS ROUNDED =
                 WS-4215-GUARANTEE-PER-ACRE * WS-4215-ACRES
                 ON SIZE ERROR
                    MOVE 4215 TO WS-8020-PARAGRAPH-NO
                    MOVE 90017 TO WS-8020-INT-ERROR-NO
                    MOVE 'GPA * Acres' TO WS-8020-FIELD-NAME
                    MOVE WS-4215-TOTAL-GUARANTEE-LBS
                      TO WS-8020-BAD-DATA
                    MOVE WS-LITERAL-YES
                      TO WS-8020-ABORT-PROGRAM
                    PERFORM 8020-RECORD-INT-ERROR
                       THRU 8020-RECORD-INT-ERROR-EXIT
              END-COMPUTE

      *       *** AFTER ROUNDING, MOVE THE ROUNDED FIELDS TO THE
      *       *** MORE PRECISE FIELDS FOR THE NEXT SET OF CALCULATIONS.

              MOVE WS-4215-PREMIUM-GUARANTEE-LBS
                TO WS-4215-PREMIUM-GUARANTEE
              MOVE WS-4215-TOTAL-GUARANTEE-LBS
                TO WS-4215-TOTAL-GUARANTEE
           END-IF.

      ***************************************************************
      *            DISPLAY TOTAL GUARANTEE RESULTS                  *
      ***************************************************************

      $IF DEBUG-SW DEFINED
           MOVE WS-4215-PREMIUM-GUARANTEE
             TO WS-4215-PREMIUM-GUARANTEE-X
           DISPLAY 'PREMIUM GUARANTEE  = ',
           WS-4215-PREMIUM-GUARANTEE-X
           UPON CONSOLE
           MOVE WS-4215-TOTAL-GUARANTEE
             TO WS-4215-TOTAL-GUARANTEE-X
           DISPLAY 'TOTAL GUARANTEE    = ',
           WS-4215-TOTAL-GUARANTEE-X
           UPON CONSOLE.
      $END

       4215-CALC-DOLLAR-GUAR-EXIT.
           EXIT.

