
      ***************************************************************
      * File:      IF4240.CBL
      * Author:    Mike Ray
      * Date:      05/20/96
      * Purpose:   Calculates Total Guarantee, Premium Guarantee,
      *            and Guarantee per Acre
      ***************************************************************

       4240-CALC-QTOBACCO-GUAR.

      $IF DEBUG-SW DEFINED
           DISPLAY '4240-CALCULATING QUOTA TOBACCO GUARANTEE'
           UPON CONSOLE
      $END

      *****************************************************
      *    INITIALIZE LOCAL AND OUTPUT VARIABLES          *
      *****************************************************
           INITIALIZE WS-4240-LOCAL
           INITIALIZE WS-4240-OUTPUT

      *****************************************************
      *            SET UP DISPLAY FIELDS                  *
      *****************************************************
           MOVE WS-4240-QUOTA TO WS-4240-QUOTA-X
           MOVE WS-4240-PRICE-ELECTION TO WS-4240-PRICE-ELECTION-X
           MOVE WS-4240-GUAR-REDUCTION-FCTR
             TO WS-4240-GUAR-REDUCTION-FCTR-X

      $IF DEBUG-SW DEFINED
           DISPLAY 'QUOTA         = ', WS-4240-QUOTA-X
           UPON CONSOLE
           DISPLAY 'CVG LVL %     = ', WS-4240-CVG-LVL-PERCENT
           UPON CONSOLE
           DISPLAY 'GUAR RED FCTR = ', WS-4240-GUAR-REDUCTION-FCTR-X
           UPON CONSOLE
           DISPLAY 'PRICE ELECT   = ', WS-4240-PRICE-ELECTION-X
           UPON CONSOLE
      $END

      *****************************************************
      *    CHECK PRE-CONDITIONS                           *
      *****************************************************
           IF WS-4240-QUOTA = ZEROS
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-4240-CALC-ERROR
              MOVE 'WS-4240-QUOTA' TO WS-8000-FIELD-NAME1
              MOVE ZERO TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 4240 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-4240-PRICE-ELECTION = ZEROS
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-4240-CALC-ERROR
              MOVE 'WS-4240-PRICE-EL' TO WS-8000-FIELD-NAME1
              MOVE ZERO TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 4240 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-4240-CVG-LVL-PERCENT = ZEROS
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-4240-CALC-ERROR
              MOVE 'WS-4240-CVG-LVL-PCT' TO WS-8000-FIELD-NAME1
              MOVE ZERO TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 4240 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-4240-CROP-UNIT-OF-MEASURE = ZEROS
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-4240-CALC-ERROR
              MOVE 'WS-4240-CROP-UM' TO WS-8000-FIELD-NAME1
              MOVE ZERO TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 4240 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-4240-CALC-ERROR = WS-LITERAL-YES
              GO TO 4240-CALC-QTOBACCO-GUAR-EXIT
           END-IF

      *    *** WS-4240-GUAR-REDUCTION-FCTR CAN = ZEROS
      *    *** IF ZEROS DEFAULT TO 1.00 FOR CALCULATION
           IF WS-4240-GUAR-REDUCTION-FCTR = ZEROS
              MOVE 1.00 TO WS-4240-GUAR-REDUCTION-FCTR
           END-IF

      ***************************************************************
      *            COMPUTE TOTAL AND PREMIUM GUARANTEES             *
      ***************************************************************

           IF WS-4240-CROP-UNIT-OF-MEASURE = WS-LITERAL-BARRELS
              OR WS-4240-CROP-UNIT-OF-MEASURE = WS-LITERAL-TONS

      ***************************************************************
      *  FOR CROPS WHICH USE TONS OR BARRELS AS A COMMODITY UNIT OF *
      *  MEASURE, ROUND THE TOTAL GUARANTEE TO THE NEAREST TENTH OF *
      *  A UNIT.                                                    *
      ***************************************************************

              COMPUTE WS-4240-PREMIUM-GUARANTEE ROUNDED =
                 WS-4240-QUOTA * (WS-4240-CVG-LVL-PERCENT / 100)
                 * WS-4240-PRICE-ELECTION
                 ON SIZE ERROR
                    MOVE 4240 TO WS-8020-PARAGRAPH-NO
                    MOVE 90017 TO WS-8020-INT-ERROR-NO
                    MOVE 'Quota*Cvg%*Price' TO WS-8020-FIELD-NAME
                    MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                    PERFORM 8020-RECORD-INT-ERROR
                       THRU 8020-RECORD-INT-ERROR-EXIT
              END-COMPUTE

              COMPUTE WS-4240-TOTAL-GUARANTEE ROUNDED =
                 WS-4240-PREMIUM-GUARANTEE * WS-4240-GUAR-REDUCTION-FCTR
                 ON SIZE ERROR
                    MOVE 4240 TO WS-8020-PARAGRAPH-NO
                    MOVE 90017 TO WS-8020-INT-ERROR-NO
                    MOVE 'PREM GPA*(1-GRF)' TO WS-8020-FIELD-NAME
                    MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                    PERFORM 8020-RECORD-INT-ERROR
                       THRU 8020-RECORD-INT-ERROR-EXIT
              END-COMPUTE

           ELSE
      ***************************************************************
      *  FOR CROPS WHICH DO NOT USE TONS OR BARRELS AS A COMMODITY  *
      *  UNIT OF MEASURE, ROUND THE TOTAL GUARANTEE TO THE NEAREST  *
      *  WHOLE UNIT.                                                *
      ***************************************************************

              COMPUTE WS-4240-PREMIUM-GUARANTEE-LBS ROUNDED =
                 WS-4240-QUOTA * (WS-4240-CVG-LVL-PERCENT / 100)
                 * WS-4240-PRICE-ELECTION
                 ON SIZE ERROR
                    MOVE 4240 TO WS-8020-PARAGRAPH-NO
                    MOVE 90017 TO WS-8020-INT-ERROR-NO
                    MOVE 'Quota*Cvg%*Price' TO WS-8020-FIELD-NAME
                    MOVE WS-4240-PREMIUM-GUARANTEE-LBS
                      TO WS-8020-BAD-DATA
                    MOVE WS-LITERAL-YES
                      TO WS-8020-ABORT-PROGRAM
                    PERFORM 8020-RECORD-INT-ERROR
                       THRU 8020-RECORD-INT-ERROR-EXIT
              END-COMPUTE

              COMPUTE WS-4240-TOTAL-GUARANTEE-LBS ROUNDED =
                 WS-4240-PREMIUM-GUARANTEE-LBS *
                 WS-4240-GUAR-REDUCTION-FCTR
                 ON SIZE ERROR
                    MOVE 4240 TO WS-8020-PARAGRAPH-NO
                    MOVE 90017 TO WS-8020-INT-ERROR-NO
                    MOVE 'PREM GPA*(1-GRF)' TO WS-8020-FIELD-NAME
                    MOVE WS-4240-TOTAL-GUARANTEE-LBS
                      TO WS-8020-BAD-DATA
                    MOVE WS-LITERAL-YES
                      TO WS-8020-ABORT-PROGRAM
                    PERFORM 8020-RECORD-INT-ERROR
                       THRU 8020-RECORD-INT-ERROR-EXIT
              END-COMPUTE

      *       *** AFTER ROUNDING, MOVE THE ROUNDED FIELDS TO THE
      *       *** MORE PRECISE FIELDS FOR THE NEXT SET OF CALCULATIONS.

              MOVE WS-4240-PREMIUM-GUARANTEE-LBS
                TO WS-4240-PREMIUM-GUARANTEE
              MOVE WS-4240-TOTAL-GUARANTEE-LBS
                TO WS-4240-TOTAL-GUARANTEE
           END-IF.

      ***************************************************************
      *            DISPLAY TOTAL GUARANTEE RESULTS                  *
      ***************************************************************

      $IF DEBUG-SW DEFINED
           MOVE WS-4240-PREMIUM-GUARANTEE
             TO WS-4240-PREMIUM-GUARANTEE-X
           DISPLAY 'PREMIUM GUARANTEE  = ',
           WS-4240-PREMIUM-GUARANTEE-X
           UPON CONSOLE
           MOVE WS-4240-TOTAL-GUARANTEE
             TO WS-4240-TOTAL-GUARANTEE-X
           DISPLAY 'TOTAL GUARANTEE    = ',
           WS-4240-TOTAL-GUARANTEE-X
           UPON CONSOLE.
      $END

       4240-CALC-QTOBACCO-GUAR-EXIT.
           EXIT.

