
      ***************************************************************
      * File:      IF4255.CBL
      * Author:    Mike Ray
      * Date:      01/27/97
      * Purpose:   Calculates Total Guarantee, Premium Guarantee,
      *            and Guarantee per Acre
      ***************************************************************

       4255-CALC-RA-GUARANTEE.

      $IF DEBUG-SW DEFINED
           DISPLAY '4255-CALCULATING REVENUE ASSURANCE GUARANTEE'
           UPON CONSOLE
      $END

      *****************************************************
      *    INITIALIZE LOCAL AND OUTPUT VARIABLES          *
      *****************************************************
           INITIALIZE WS-4255-LOCAL
           INITIALIZE WS-4255-OUTPUT

      *****************************************************
      *    SET UP DISPLAY FIELDS                          *
      *****************************************************
           MOVE WS-4255-ACRES TO WS-4255-ACRES-X
           MOVE WS-4255-GUAR-REDUCTION-FCTR
             TO WS-4255-GUAR-REDUCTION-FCTR-X
           MOVE WS-4255-DOLLAR-AMT-INS
             TO WS-4255-DOLLAR-AMT-INS-X

      $IF DEBUG-SW DEFINED
           DISPLAY 'DOLLAR AMOUNT OF INS     = ',
           WS-4255-DOLLAR-AMT-INS-X
           UPON CONSOLE
           DISPLAY 'GUARANTEE REDUCTION FCTR = ',
           WS-4255-GUAR-REDUCTION-FCTR-X
           UPON CONSOLE
           DISPLAY 'ACRES                    = ',
           WS-4255-ACRES-X
           UPON CONSOLE
      $END

      *****************************************************
      *    CHECK PRE-CONDITIONS                           *
      *****************************************************
           IF WS-4255-ACRES = ZEROS
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-4255-CALC-ERROR
              MOVE 'WS-4255-ACRES' TO WS-8000-FIELD-NAME1
              MOVE ZERO TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 4255 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-4255-DOLLAR-AMT-INS = ZEROS
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-4255-CALC-ERROR
              MOVE 'WS-4255-DOLLAR-AMT-INS' TO WS-8000-FIELD-NAME1
              MOVE ZERO TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 4255 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-4255-CALC-ERROR = WS-LITERAL-YES
              GO TO 4255-CALC-RA-GUARANTEE-EXIT
           END-IF

      *    *** WS-4255-GUAR-REDUCTION-FCTR CAN = ZEROS
      *    *** IF ZEROS DEFAULT TO 1.00 FOR CALCULATION
           IF WS-4255-GUAR-REDUCTION-FCTR = ZEROS
              MOVE 1.00 TO WS-4255-GUAR-REDUCTION-FCTR
           END-IF

      *****************************************************
      *              PERFORM CALCULATIONS                 *
      *****************************************************

           COMPUTE WS-4255-GUARANTEE-PER-ACRE ROUNDED =
              WS-4255-DOLLAR-AMT-INS * WS-4255-GUAR-REDUCTION-FCTR
              ON SIZE ERROR
                 MOVE 4255 TO WS-8020-PARAGRAPH-NO
                 MOVE 90017 TO WS-8020-INT-ERROR-NO
                 MOVE 'AMT INS * (1-GUAR RED FCTR)'
                   TO WS-8020-FIELD-NAME
                 MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                 PERFORM 8020-RECORD-INT-ERROR
                    THRU 8020-RECORD-INT-ERROR-EXIT
           END-COMPUTE

           MOVE WS-4255-DOLLAR-AMT-INS TO WS-4255-PREMIUM-GPA

      ***************************************************************
      *            DISPLAY GUARANTEE PER ACRE RESULTS               *
      ***************************************************************

      $IF DEBUG-SW DEFINED
           MOVE WS-4255-PREMIUM-GPA TO WS-4255-PREMIUM-GPA-X
           DISPLAY 'PREMIUM GPA        = ', WS-4255-PREMIUM-GPA-X
           UPON CONSOLE
           MOVE WS-4255-GUARANTEE-PER-ACRE
             TO WS-4255-GUARANTEE-PER-ACRE-X
           DISPLAY 'GUARANTEE PER ACRE = ',
           WS-4255-GUARANTEE-PER-ACRE-X
           UPON CONSOLE
      $END

      ***************************************************************
      *            COMPUTE TOTAL AND PREMIUM GUARANTEES             *
      ***************************************************************

           COMPUTE WS-4255-PREMIUM-GUARANTEE ROUNDED =
              WS-4255-PREMIUM-GPA * WS-4255-ACRES
              ON SIZE ERROR
                 MOVE 4255 TO WS-8020-PARAGRAPH-NO
                 MOVE 90017 TO WS-8020-INT-ERROR-NO
                 MOVE 'Amt Ins * Acres' TO WS-8020-FIELD-NAME
                 MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                 PERFORM 8020-RECORD-INT-ERROR
                    THRU 8020-RECORD-INT-ERROR-EXIT
           END-COMPUTE

           COMPUTE WS-4255-TOTAL-GUARANTEE ROUNDED =
              WS-4255-GUARANTEE-PER-ACRE * WS-4255-ACRES
              ON SIZE ERROR
                 MOVE 4255 TO WS-8020-PARAGRAPH-NO
                 MOVE 90017 TO WS-8020-INT-ERROR-NO
                 MOVE 'GPA * Acres' TO WS-8020-FIELD-NAME
                 MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                 PERFORM 8020-RECORD-INT-ERROR
                    THRU 8020-RECORD-INT-ERROR-EXIT
           END-COMPUTE.

      ***************************************************************
      *            DISPLAY TOTAL GUARANTEE RESULTS                  *
      ***************************************************************

      $IF DEBUG-SW DEFINED
           MOVE WS-4255-PREMIUM-GUARANTEE
             TO WS-4255-PREMIUM-GUARANTEE-X
           DISPLAY 'PREMIUM GUARANTEE  = ',
           WS-4255-PREMIUM-GUARANTEE-X
           UPON CONSOLE
           MOVE WS-4255-TOTAL-GUARANTEE
             TO WS-4255-TOTAL-GUARANTEE-X
           DISPLAY 'TOTAL GUARANTEE    = ',
           WS-4255-TOTAL-GUARANTEE-X
           UPON CONSOLE.
      $END

       4255-CALC-RA-GUARANTEE-EXIT.
           EXIT.

