
      ***************************************************************
      * File:      C4320.CBL
      * Author:    Laurie Viles
      * Date:      06/05/96
      * Purpose:   Calculates the citrus/macadamia liability
      *            according to the calculation in M-13.
      ***************************************************************

       4320-CALC-CITMAC-LIAB.

      $IF DEBUG-SW DEFINED
           DISPLAY '4320-CALCULATING CITRUS/MAC LIABILITY'
           UPON CONSOLE
      $END


      *****************************************************
      *    INITIALIZE LOCAL VARIABLES                     *
      *****************************************************
           INITIALIZE WS-4320-WORK
           INITIALIZE WS-4320-OUTPUT

      *****************************************************
      *    SET UP DISPLAY FIELDS                          *
      *****************************************************
           MOVE WS-4320-INSURED-SHARE
             TO WS-4320-INSURED-SHARE-X
           MOVE WS-4320-TOTAL-GUARANTEE
             TO WS-4320-TOTAL-GUARANTEE-X
           MOVE WS-4320-PREMIUM-GUARANTEE
             TO WS-4320-PREMIUM-GUARANTEE-X

      $IF DEBUG-SW DEFINED
           DISPLAY 'INSURED SHARE     = ', WS-4320-INSURED-SHARE-X
           UPON CONSOLE
           DISPLAY 'TOTAL GUARANTEE   = ', WS-4320-TOTAL-GUARANTEE-X
           UPON CONSOLE
           DISPLAY 'PREMIUM GUARANTEE = ', WS-4320-PREMIUM-GUARANTEE-X
           UPON CONSOLE
      $END

      *****************************************************
      *    CHECK INPUT FIELDS                             *
      *****************************************************
           IF WS-4320-INSURED-SHARE = ZEROS
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-4320-CALC-ERROR
              MOVE 'WS-4320-INS-SHARE' TO WS-8000-FIELD-NAME1
              MOVE ZERO TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 4320 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-4320-TOTAL-GUARANTEE = ZEROS
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-4320-CALC-ERROR
              MOVE 'WS-4320-TOTAL-GUAR' TO WS-8000-FIELD-NAME1
              MOVE ZERO TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 4320 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-4320-PREMIUM-GUARANTEE = ZEROS
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-4320-CALC-ERROR
              MOVE 'WS-4320-PREM-GUAR' TO WS-8000-FIELD-NAME1
              MOVE ZERO TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 4320 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-4320-CALC-ERROR = WS-LITERAL-YES
              GO TO 4320-CALC-CITMAC-LIAB-EXIT
           END-IF

      *****************************************************
      *    LIABILITY CALCULATION FOR CITRUS AND           *
      *    MACADAMIA CROPS                                *
      *****************************************************


           COMPUTE WS-4320-PREMIUM-LIABILITY ROUNDED =
              WS-4320-PREMIUM-GUARANTEE * WS-4320-INSURED-SHARE
              ON SIZE ERROR
                 MOVE 4320 TO WS-8020-PARAGRAPH-NO
                 MOVE 90017 TO WS-8020-INT-ERROR-NO
                 MOVE 'PREMG*SHARE'
                   TO WS-8020-FIELD-NAME
                 MOVE WS-4320-PREMIUM-LIABILITY
                   TO WS-8020-BAD-DATA
                 MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                 PERFORM 8020-RECORD-INT-ERROR
                    THRU 8020-RECORD-INT-ERROR-EXIT
           END-COMPUTE

           COMPUTE WS-4320-TOTAL-LIABILITY ROUNDED =
              WS-4320-TOTAL-GUARANTEE * WS-4320-INSURED-SHARE
              ON SIZE ERROR
                 MOVE 4320 TO WS-8020-PARAGRAPH-NO
                 MOVE 90017 TO WS-8020-INT-ERROR-NO
                 MOVE 'TOTLG*SHARE'
                   TO WS-8020-FIELD-NAME
                 MOVE WS-4320-TOTAL-LIABILITY
                   TO WS-8020-BAD-DATA
                 MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                 PERFORM 8020-RECORD-INT-ERROR
                    THRU 8020-RECORD-INT-ERROR-EXIT
           END-COMPUTE.

      $IF DEBUG-SW DEFINED
           DISPLAY 'CITRUS & MAC TREE TOTAL LIABILITY = ',
           WS-4320-TOTAL-LIABILITY
           UPON CONSOLE
           DISPLAY 'CITRUS & MAC TREE PREMIUM LIABILITY = ',
           WS-4320-PREMIUM-LIABILITY
           UPON CONSOLE.
      $END


       4320-CALC-CITMAC-LIAB-EXIT.
           EXIT.
