
      ***************************************************************
      * File:      C4325.CBL
      * Author:    Laurie Viles
      * Date:      06/05/96
      * Purpose:   Calculates the yield base dollar liability
      *            according to the calculation in M-13.
      ***************************************************************

       4325-CALC-YLDDLR-LIAB.

      $IF DEBUG-SW DEFINED
           DISPLAY '4325-CALCULATING YIELD BASE DOLLAR LIABILITY'
           UPON CONSOLE
      $END


      *****************************************************
      *    INITIALIZE LOCAL VARIABLES                     *
      *****************************************************
           INITIALIZE WS-4325-WORK
           INITIALIZE WS-4325-OUTPUT

      *****************************************************
      *    SET UP DISPLAY FIELDS                          *
      *****************************************************
           MOVE WS-4325-INSURED-SHARE
             TO WS-4325-INSURED-SHARE-X
           MOVE WS-4325-TOTAL-GUARANTEE
             TO WS-4325-TOTAL-GUARANTEE-X
           MOVE WS-4325-PREMIUM-GUARANTEE
             TO WS-4325-PREMIUM-GUARANTEE-X

      $IF DEBUG-SW DEFINED
           DISPLAY 'INSURED SHARE     = ', WS-4325-INSURED-SHARE-X
           UPON CONSOLE
           DISPLAY 'TOTAL GUARANTEE   = ', WS-4325-TOTAL-GUARANTEE-X
           UPON CONSOLE
           DISPLAY 'PREMIUM GUARANTEE = ', WS-4325-PREMIUM-GUARANTEE-X
           UPON CONSOLE
      $END

      *****************************************************
      *    CHECK INPUT FIELDS                             *
      *****************************************************

           IF WS-4325-INSURED-SHARE = ZEROS
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-4325-CALC-ERROR
              MOVE 'WS-4325-INS-SHARE' TO WS-8000-FIELD-NAME1
              MOVE ZERO TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 4325 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-4325-TOTAL-GUARANTEE = ZEROS
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-4325-CALC-ERROR
              MOVE 'WS-4325-TOTAL-GUAR' TO WS-8000-FIELD-NAME1
              MOVE ZERO TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 4325 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-4325-PREMIUM-GUARANTEE = ZEROS
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-4325-CALC-ERROR
              MOVE 'WS-4325-PREM-GUAR' TO WS-8000-FIELD-NAME1
              MOVE ZERO TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 4325 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-4325-CALC-ERROR = WS-LITERAL-YES
              GO TO 4325-CALC-YLDDLR-LIAB-EXIT
           END-IF

      *******************************************************
      *    LIABILITY CALCULATION FOR YIELD BASED DOLLAR     *
      *    CROPS                                            *
      *******************************************************
           COMPUTE WS-4325-PREMIUM-LIABILITY ROUNDED =
              WS-4325-PREMIUM-GUARANTEE * WS-4325-INSURED-SHARE
              ON SIZE ERROR
                 MOVE 4325 TO WS-8020-PARAGRAPH-NO
                 MOVE 90017 TO WS-8020-INT-ERROR-NO
                 MOVE 'PREMG*SHARE'
                   TO WS-8020-FIELD-NAME
                 MOVE WS-4325-PREMIUM-LIABILITY
                   TO WS-8020-BAD-DATA
                 MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                 PERFORM 8020-RECORD-INT-ERROR
                    THRU 8020-RECORD-INT-ERROR-EXIT
           END-COMPUTE

           COMPUTE WS-4325-TOTAL-LIABILITY ROUNDED =
              WS-4325-TOTAL-GUARANTEE * WS-4325-INSURED-SHARE
              ON SIZE ERROR
                 MOVE 4325 TO WS-8020-PARAGRAPH-NO
                 MOVE 90017 TO WS-8020-INT-ERROR-NO
                 MOVE 'TOTLG*SHARE'
                   TO WS-8020-FIELD-NAME
                 MOVE WS-4325-TOTAL-LIABILITY
                   TO WS-8020-BAD-DATA
                 MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                 PERFORM 8020-RECORD-INT-ERROR
                    THRU 8020-RECORD-INT-ERROR-EXIT
           END-COMPUTE.

      ** COMPUTE AN ALTERNATE YLDDLR PREMIUM LIABILITY IN CASE
      ** WE NEED IT DOWN THE LINE
           if ws-4325-lpo-pp-fctr > 0
           COMPUTE WS-4325-alt-PREMIUM-LIABILITY ROUNDED =
              ws-4325-total-liability / WS-4325-LPO-PP-FCTR
              ON SIZE ERROR
                 MOVE 4325 TO WS-8020-PARAGRAPH-NO
                 MOVE 90017 TO WS-8020-INT-ERROR-NO
                 MOVE 'PREMG*PRICE*%ELECT*SHARE'
                   TO WS-8020-FIELD-NAME
                 MOVE WS-4325-PREMIUM-LIABILITY
                   TO WS-8020-BAD-DATA
                 MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                 PERFORM 8020-RECORD-INT-ERROR
                    THRU 8020-RECORD-INT-ERROR-EXIT
           END-COMPUTE
           end-if.


      $IF DEBUG-SW DEFINED
           DISPLAY 'YIELD-BASED $CROP TOTAL LIABILITY = ',
           WS-4325-TOTAL-LIABILITY
           UPON CONSOLE
           DISPLAY 'YIELD-BASED $CROP PREMIUM LIABILITY = ',
           WS-4325-PREMIUM-LIABILITY
           UPON CONSOLE
           DISPLAY 'YIELD-BASED $CROP ALT-PREM LIABILTY = ',
           WS-4325-ALT-PREMIUM-LIABILITY
           UPON CONSOLE.
      $END


       4325-CALC-YLDDLR-LIAB-EXIT.
           EXIT.
