
      ***************************************************************
      * File:      C4335.CBL
      * Author:    Laurie Viles
      * Date:      06/05/96
      * Purpose:   Calculates the guarantee tobacco liability
      *            according to the calculation in M-13.
      ***************************************************************

       4335-CALC-GTOBACCO-LIAB.

      $IF DEBUG-SW DEFINED
           DISPLAY '4335-CALCULATING GUARANTEE TOBACCO LIABILITY'
           UPON CONSOLE
      $END


      *****************************************************
      *    INITIALIZE LOCAL VARIABLES                     *
      *****************************************************
           INITIALIZE WS-4335-WORK
           INITIALIZE WS-4335-OUTPUT

      *****************************************************
      *    SET UP DISPLAY FIELDS                          *
      *****************************************************
           MOVE WS-4335-PRICE-ELECTION
             TO WS-4335-PRICE-ELECTION-X
           MOVE WS-4335-INSURED-SHARE
             TO WS-4335-INSURED-SHARE-X
           MOVE WS-4335-TOTAL-GUARANTEE
             TO WS-4335-TOTAL-GUARANTEE-X
           MOVE WS-4335-PREMIUM-GUARANTEE
             TO WS-4335-PREMIUM-GUARANTEE-X

      $IF DEBUG-SW DEFINED
           DISPLAY 'PRICE ELECTION   = ', WS-4335-PRICE-ELECTION-X
           UPON CONSOLE
           DISPLAY 'INSURED SHARE    = ', WS-4335-INSURED-SHARE-X
           UPON CONSOLE
           DISPLAY 'TOTAL GUARANTEE  = ', WS-4335-TOTAL-GUARANTEE-X
           UPON CONSOLE
           DISPLAY 'PREMIUM GUARANTEE= ', WS-4335-PREMIUM-GUARANTEE-X
           UPON CONSOLE
      $END

      *****************************************************
      *    CHECK INPUT FIELDS                             *
      *****************************************************
           IF WS-4335-PRICE-ELECTION = ZEROS
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-4335-CALC-ERROR
              MOVE 'WS-4335-PRICE-EL' TO WS-8000-FIELD-NAME1
              MOVE ZERO TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 4335 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-4335-INSURED-SHARE = ZEROS
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-4335-CALC-ERROR
              MOVE 'WS-4335-INS-SHARE' TO WS-8000-FIELD-NAME1
              MOVE ZERO TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 4335 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-4335-TOTAL-GUARANTEE = ZEROS
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-4335-CALC-ERROR
              MOVE 'WS-4335-TOTAL-GUAR' TO WS-8000-FIELD-NAME1
              MOVE ZERO TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 4335 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-4335-PREMIUM-GUARANTEE = ZEROS
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-4335-CALC-ERROR
              MOVE 'WS-4335-PREM-GUAR' TO WS-8000-FIELD-NAME1
              MOVE ZERO TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 4335 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-4335-CALC-ERROR = WS-LITERAL-YES
              GO TO 4335-CALC-GTOBACCO-LIAB-EXIT
           END-IF

      *****************************************************
      *    LIABILITY CALCULATION FOR GUARANTEE TOBACCO    *
      *****************************************************
           COMPUTE WS-4335-PREMIUM-LIABILITY ROUNDED =
              WS-4335-PREMIUM-GUARANTEE * WS-4335-PRICE-ELECTION
              * WS-4335-INSURED-SHARE
              ON SIZE ERROR
                 MOVE 4335 TO WS-8020-PARAGRAPH-NO
                 MOVE 90017 TO WS-8020-INT-ERROR-NO
                 MOVE 'PREMG*PRICE*SHARE'
                   TO WS-8020-FIELD-NAME
                 MOVE WS-4335-PREMIUM-LIABILITY
                   TO WS-8020-BAD-DATA
                 MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                 PERFORM 8020-RECORD-INT-ERROR
                    THRU 8020-RECORD-INT-ERROR-EXIT
           END-COMPUTE

           COMPUTE WS-4335-TOTAL-LIABILITY ROUNDED =
              WS-4335-TOTAL-GUARANTEE * WS-4335-PRICE-ELECTION
              * WS-4335-INSURED-SHARE
              ON SIZE ERROR
                 MOVE 4335 TO WS-8020-PARAGRAPH-NO
                 MOVE 90017 TO WS-8020-INT-ERROR-NO
                 MOVE 'TOTLG*PRICE*SHARE'
                   TO WS-8020-FIELD-NAME
                 MOVE WS-4335-TOTAL-LIABILITY
                   TO WS-8020-BAD-DATA
                 MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                 PERFORM 8020-RECORD-INT-ERROR
                    THRU 8020-RECORD-INT-ERROR-EXIT
           END-COMPUTE.

      $IF DEBUG-SW DEFINED
           DISPLAY 'GUARANTEE TOBACCO TOTAL LIABILITY = ',
           WS-4335-TOTAL-LIABILITY
           UPON CONSOLE
           DISPLAY 'GUARANTEE TOBACCO PREMIUM LIABILITY = ',
           WS-4335-PREMIUM-LIABILITY
           UPON CONSOLE.
      $END


       4335-CALC-GTOBACCO-LIAB-EXIT.
           EXIT.
