
      ***************************************************************
      * File:      C4420.CBL
      * Author:    Laurie Viles
      * Date:      06/06/96
      * Purpose:   Calculates the citrus/macadamia premium
      *            according to the calculation in M-13.
      ***************************************************************

       4420-CALC-CITMAC-PREM.

      $IF DEBUG-SW DEFINED
           DISPLAY '4420-CALCULATING CITMAC PREMIUM'
           UPON CONSOLE
      $END


      *****************************************************
      *    INITIALIZE LOCAL VARIABLES                     *
      *****************************************************
           INITIALIZE WS-4420-OUTPUT
           INITIALIZE WS-4420-LOCAL

      *****************************************************
      *    SET UP DISPLAY FIELDS                          *
      *****************************************************
           MOVE WS-4420-PREMIUM-LIABILITY
             TO WS-4420-PREMIUM-LIABILITY-X
           MOVE WS-4420-BASE-PREMIUM-RATE
             TO WS-4420-BASE-PREMIUM-RATE-X
           MOVE WS-4420-RATE-MAP-AREA-FCTR
             TO WS-4420-RATE-MAP-AREA-FCTR-X
           MOVE WS-4420-OPTION-FCTR
             TO WS-4420-OPTION-FCTR-X
           MOVE WS-4420-EXPERIENCE-FCTR
             TO WS-4420-EXPERIENCE-FCTR-X
           MOVE WS-4420-PREM-SURCHARGE-PCT
             TO WS-4420-PREM-SURCHARGE-PCT-X

      $IF DEBUG-SW DEFINED
           DISPLAY 'PREMIUM LIABILITY   = ',
           WS-4420-PREMIUM-LIABILITY-X   UPON CONSOLE
           DISPLAY 'BASE PREMIUM RATE   = ',
           WS-4420-BASE-PREMIUM-RATE-X   UPON CONSOLE
           DISPLAY 'RATE MAP FACTOR     = ',
           WS-4420-RATE-MAP-AREA-FCTR-X  UPON CONSOLE
           DISPLAY 'OPTION FACTOR       = ',
           WS-4420-OPTION-FCTR-X         UPON CONSOLE
           DISPLAY 'EXPERIENCE FACTOR   = ',
           WS-4420-EXPERIENCE-FCTR-X     UPON CONSOLE
           DISPLAY 'PREMIUM RT SURCHG % = ',
           WS-4420-PREM-SURCHARGE-PCT-X  UPON CONSOLE
      $END

      *****************************************************
      *    CHECK INPUT FIELDS                             *
      *****************************************************
           IF WS-4420-PREMIUM-LIABILITY = ZEROS
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-4420-CALC-ERROR
              MOVE 'WS-4420-PREM-LIAB' TO WS-8000-FIELD-NAME1
              MOVE ZERO TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 4420 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-4420-BASE-PREMIUM-RATE = ZEROS
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-4420-CALC-ERROR
              MOVE 'WS-4420-BASE-PREM-RT' TO WS-8000-FIELD-NAME1
              MOVE ZERO TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 4420 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-4420-RATE-MAP-AREA-FCTR = ZEROS
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-4420-CALC-ERROR
              MOVE 'WS-4420-RATE-MAP-FCTR' TO WS-8000-FIELD-NAME1
              MOVE ZERO TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 4420 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-4420-OPTION-FCTR = ZEROS
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-4420-CALC-ERROR
              MOVE 'WS-4420-OPT-FCTR' TO WS-8000-FIELD-NAME1
              MOVE ZERO TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 4420 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
          END-IF

           IF WS-4420-EXPERIENCE-FCTR = ZEROS
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-4420-CALC-ERROR
              MOVE 'WS-4420-EXPER-FCTR' TO WS-8000-FIELD-NAME1
              MOVE ZERO TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 4420 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

      *    WS-4420-PREM-SURCHARGE-PCT CAN EQUAL ZERO

           IF WS-4420-CALC-ERROR = WS-LITERAL-YES
              GO TO 4420-CALC-CITMAC-PREM-EXIT
           END-IF

      *****************************************************************
      *    PREMIUM CALCULATION FOR CITRUS TREES AND MACADAMIA CROPS.  *
      *    THE PREMIUM AMOUNT FOR CITRUS TREES WILL BE INCREASED BY   *
      *    46 PERCENT FOR THE 1998 CROP YEAR ONLY AS A RESULT OF THE  *
      *    ADDITIONAL SIX MONTHS OF COVERAGE.                         *
      *****************************************************************
           IF (WS-2350-CROP-CD = WS-LITERAL-CITRUS-TREES-I   OR
               WS-2350-CROP-CD = WS-LITERAL-CITRUS-TREES-II  OR
               WS-2350-CROP-CD = WS-LITERAL-CITRUS-TREES-III OR
               WS-2350-CROP-CD = WS-LITERAL-CITRUS-TREES-IV  OR
               WS-2350-CROP-CD = WS-LITERAL-CITRUS-TREES-V) AND
               WS-T11-CROP-YEAR = 1998
              COMPUTE WS-4420-TOTAL-PREMIUM ROUNDED =
                      WS-4420-PREMIUM-LIABILITY
                    * WS-4420-BASE-PREMIUM-RATE
                    * WS-4420-RATE-MAP-AREA-FCTR
                    * WS-4420-OPTION-FCTR
                    * WS-4420-EXPERIENCE-FCTR
                    * (1 + WS-4420-PREM-SURCHARGE-PCT)
                    * 1.46
                 ON SIZE ERROR
                    MOVE 4420 TO WS-8020-PARAGRAPH-NO
                    MOVE 90017 TO WS-8020-INT-ERROR-NO
                    MOVE 'PLIAB*BRATE*FACTORS'
                      TO WS-8020-FIELD-NAME
                    MOVE WS-4420-PREMIUM-LIABILITY
                      TO WS-8020-BAD-DATA
                    MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                    PERFORM 8020-RECORD-INT-ERROR
                       THRU 8020-RECORD-INT-ERROR-EXIT
              END-COMPUTE
           ELSE
              COMPUTE WS-4420-TOTAL-PREMIUM ROUNDED =
                      WS-4420-PREMIUM-LIABILITY
                    * WS-4420-BASE-PREMIUM-RATE
                    * WS-4420-RATE-MAP-AREA-FCTR
                    * WS-4420-OPTION-FCTR
                    * WS-4420-EXPERIENCE-FCTR
                    * (1 + WS-4420-PREM-SURCHARGE-PCT)
                 ON SIZE ERROR
                    MOVE 4420 TO WS-8020-PARAGRAPH-NO
                    MOVE 90017 TO WS-8020-INT-ERROR-NO
                    MOVE 'PLIAB*BRATE*FACTORS'
                      TO WS-8020-FIELD-NAME
                    MOVE WS-4420-PREMIUM-LIABILITY
                      TO WS-8020-BAD-DATA
                    MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                    PERFORM 8020-RECORD-INT-ERROR
                       THRU 8020-RECORD-INT-ERROR-EXIT
              END-COMPUTE
           END-IF.

      $IF DEBUG-SW DEFINED
           DISPLAY 'TOTAL PREMIUM = ', WS-4420-TOTAL-PREMIUM
           UPON CONSOLE.
      $END

       4420-CALC-CITMAC-PREM-EXIT.
           EXIT.

