      ***************************************************************
      * File:      IF4720.CBL
      * Author:    Mike Ray
      * Date:      05/19/97
      * Purpose:   Calculates Stage Guarantee per Acre and Loss
      *            Guarantee for both Normal Indemnity and Replant
      *            Payments for Citrus/Macadamia Trees
      ***************************************************************

       4720-CALC-CITMAC-LOSSG.

      $IF DEBUG-SW DEFINED
           DISPLAY '4720-CALCULATING CITRUS/MACADAMIA LOSS GUARANTEE'
           UPON CONSOLE
      $END


      *****************************************************
      *    INITIALIZE LOCAL AND OUTPUT VARIABLES          *
      *****************************************************
           INITIALIZE WS-4720-LOCAL
           INITIALIZE WS-4720-OUTPUT

      *****************************************************
      *            SET UP DISPLAY FIELDS                  *
      *****************************************************
           MOVE WS-4720-DOLLAR-AMT-INS
             TO WS-4720-DOLLAR-AMT-INS-X
           MOVE WS-4720-ACRES TO WS-4720-ACRES-X
           MOVE WS-4720-LIABILITY-ADJ-FCTR
             TO WS-4720-LIABILITY-ADJ-FCTR-X

      $IF DEBUG-SW DEFINED
           DISPLAY 'DOLLAR AMT INS       = ',
           WS-4720-DOLLAR-AMT-INS-X UPON CONSOLE
           DISPLAY 'ACRES                = ',
           WS-4720-ACRES-X UPON CONSOLE
           DISPLAY 'LIABILITY ADJ FCTR   = ',
           WS-4720-LIABILITY-ADJ-FCTR-X UPON CONSOLE
      $END

      *****************************************************
      *    CHECK PRE-CONDITIONS                           *
      *****************************************************
      *    *** REPLANTING NOT AVAILABLE FOR THESE CROPS ***
           IF WS-4720-STAGE-CD = WS-LITERAL-REPLANTED
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 044 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-4720-CALC-ERROR
              MOVE 'WS-4720-STAGE-CD' TO WS-8000-FIELD-NAME1
              MOVE WS-4720-STAGE-CD TO WS-8000-BAD-DATA1
              MOVE 'NOT REPLANT' TO WS-8000-CORR-DATA1
              MOVE 4720 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-4720-DOLLAR-AMT-INS = ZEROS
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-4720-CALC-ERROR
              MOVE 'WS-4720-DOLLAR-AMT-INS' TO WS-8000-FIELD-NAME1
              MOVE ZERO TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 4720 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-4720-CROP-UNIT-OF-MEASURE = ZEROS
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-4720-CALC-ERROR
              MOVE 'WS-4720-CROP-UM' TO WS-8000-FIELD-NAME1
              MOVE ZERO TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 4720 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-4720-ACRES = ZEROS
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-4720-CALC-ERROR
              MOVE 'WS-4720-ACRES' TO WS-8000-FIELD-NAME1
              MOVE ZERO TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 4720 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-4720-LIABILITY-ADJ-FCTR = ZEROS
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-4720-CALC-ERROR
              MOVE 'WS-4720-LIABILITY-ADJ-FCTR'
                TO WS-8000-FIELD-NAME1
              MOVE ZERO TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 4720 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-4720-CALC-ERROR = WS-LITERAL-YES
              GO TO 4720-CALC-CITMAC-LOSSG-EXIT
           END-IF

      *****************************************************
      *    PERFORM CALCULATIONS                           *
      *****************************************************
           PERFORM 4720-CALC-INDEM-LOSSG
              THRU 4720-CALC-INDEM-LOSSG-EXIT.



       4720-CALC-CITMAC-LOSSG-EXIT.
           EXIT.


      *==============================================================*
      *    NORMAL INDEMNITY LOSS GUARANTEE CALCULATION               *
      *==============================================================*

       4720-CALC-INDEM-LOSSG.

      $IF DEBUG-SW DEFINED
           DISPLAY '4720-CALCULATING CITRUS/MACADAMIA LOSS GUARANTEE'
           UPON CONSOLE
      $END

      *****************************************************
      *    CALCULATE GUARANTEE PER ACRE                   *
      *****************************************************
           MOVE WS-4720-DOLLAR-AMT-INS
             TO WS-4720-GUARANTEE-PER-ACRE
           MOVE WS-4720-GUARANTEE-PER-ACRE
             TO WS-4720-STAGE-GPA

      *****************************************************
      *    DISPLAY GUARANTEE PER ACRE RESULTS             *
      *****************************************************
           MOVE WS-4720-GUARANTEE-PER-ACRE
             TO WS-4720-GUARANTEE-PER-ACRE-X
           MOVE WS-4720-STAGE-GPA TO WS-4720-STAGE-GPA-X
      $IF DEBUG-SW DEFINED
           DISPLAY 'GUARANTEE PER ACRE = ',
           WS-4720-GUARANTEE-PER-ACRE-X UPON CONSOLE
           DISPLAY 'STAGE GPA          = ',
           WS-4720-STAGE-GPA-X UPON CONSOLE
      $END

      *****************************************************
      *    CALCULATE INDEMNITY LOSS GUARANTEE             *
      *****************************************************
           COMPUTE WS-4720-LOSS-GUARANTEE ROUNDED =
              WS-4720-STAGE-GPA * WS-4720-ACRES
              * WS-4720-LIABILITY-ADJ-FCTR
              ON SIZE ERROR
                 MOVE 4720 TO WS-8020-PARAGRAPH-NO
                 MOVE 90017 TO WS-8020-INT-ERROR-NO
                 MOVE 'LOSSG' TO WS-8020-FIELD-NAME
                 MOVE WS-4720-LOSS-GUARANTEE TO WS-8020-BAD-DATA
                 MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                 PERFORM 8020-RECORD-INT-ERROR
                    THRU 8020-RECORD-INT-ERROR-EXIT
           END-COMPUTE.

      *****************************************************
      *    DISPLAY INDEMNITY LOSS GUARANTEE RESULTS       *
      *****************************************************
      $IF DEBUG-SW DEFINED
           MOVE WS-4720-LOSS-GUARANTEE
             TO WS-4720-LOSS-GUARANTEE-X
           DISPLAY 'LOSS GUARANTEE = ',
           WS-4720-LOSS-GUARANTEE-X UPON CONSOLE.
      $END

       4720-CALC-INDEM-LOSSG-EXIT.
           EXIT.

