      ***************************************************************
      * File:      IF4725.CBL
      * Author:    Mike Ray
      * Date:      05/15/97
      * Purpose:   Calculates Stage Guarantee per Acre and Loss
      *            Guarantee for both Normal Indemnity and Replant
      *            Payments for APH crops.
      ***************************************************************

       4725-CALC-YLDDLR-LOSSG.

      $IF DEBUG-SW DEFINED
           DISPLAY '4725-CALCULATING APH LOSS GUARANTEE'
           UPON CONSOLE
      $END


      *****************************************************
      *    INITIALIZE LOCAL AND OUTPUT VARIABLES          *
      *****************************************************
           INITIALIZE WS-4725-LOCAL
           INITIALIZE WS-4725-OUTPUT

      *****************************************************
      *            SET UP DISPLAY FIELDS                  *
      *****************************************************
           MOVE WS-4725-YIELD TO WS-4725-YIELD-X
           MOVE WS-4725-PRICE-ELECTION
             TO WS-4725-PRICE-ELECTION-X
           MOVE WS-4725-ACRES TO WS-4725-ACRES-X
           MOVE WS-4725-LIABILITY-ADJ-FCTR
             TO WS-4725-LIABILITY-ADJ-FCTR-X

      $IF DEBUG-SW DEFINED
           DISPLAY 'YIELD                = ',
           WS-4725-YIELD-X UPON CONSOLE
           DISPLAY 'PRICE ELECTION       = ',
           WS-4725-PRICE-ELECTION-X UPON CONSOLE
           DISPLAY 'ACRES                = ',
           WS-4725-ACRES-X UPON CONSOLE
           DISPLAY 'LIABILITY ADJ FCTR   = ',
           WS-4725-LIABILITY-ADJ-FCTR-X UPON CONSOLE
      $END

      *****************************************************
      *    CHECK PRE-CONDITIONS                           *
      *****************************************************
      *    *** REPLANTING NOT AVAILABLE FOR THESE CROPS ***
           IF WS-4725-STAGE-CD = WS-LITERAL-REPLANTED
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 044 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-4725-CALC-ERROR
              MOVE 'WS-4725-STAGE-CD' TO WS-8000-FIELD-NAME1
              MOVE WS-4725-STAGE-CD TO WS-8000-BAD-DATA1
              MOVE 'NOT REPLANT' TO WS-8000-CORR-DATA1
              MOVE 4725 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-4725-YIELD = ZEROS
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-4725-CALC-ERROR
              MOVE 'WS-4725-YIELD' TO WS-8000-FIELD-NAME1
              MOVE ZERO TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 4725 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-4725-CROP-UNIT-OF-MEASURE = ZEROS
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-4725-CALC-ERROR
              MOVE 'WS-4725-CROP-UM' TO WS-8000-FIELD-NAME1
              MOVE ZERO TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 4725 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-4725-ACRES = ZEROS
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-4725-CALC-ERROR
              MOVE 'WS-4725-ACRES' TO WS-8000-FIELD-NAME1
              MOVE ZERO TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 4725 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-4725-LIABILITY-ADJ-FCTR = ZEROS
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-4725-CALC-ERROR
              MOVE 'WS-4725-LIABILITY-ADJ-FCTR'
                TO WS-8000-FIELD-NAME1
              MOVE ZERO TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 4725 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-4725-CALC-ERROR = WS-LITERAL-YES
              GO TO 4725-CALC-YLDDLR-LOSSG-EXIT
           END-IF

      *****************************************************
      *    PERFORM CALCULATIONS                           *
      *****************************************************
           PERFORM 4725-CALC-INDEM-LOSSG
              THRU 4725-CALC-INDEM-LOSSG-EXIT.


       4725-CALC-YLDDLR-LOSSG-EXIT.
           EXIT.



      *==============================================================*
      *    NORMAL INDEMNITY LOSS GUARANTEE CALCULATION               *
      *==============================================================*

       4725-CALC-INDEM-LOSSG.

      $IF DEBUG-SW DEFINED
           DISPLAY '4725-CALCULATING YIELD-BASED $CROP LOSS GUAR'
           UPON CONSOLE
      $END

      *****************************************************
      *    CALCULATE GUARANTEE PER ACRE                   *
      *****************************************************
           COMPUTE WS-4725-GUARANTEE-PER-ACRE ROUNDED =
              WS-4725-YIELD * WS-4725-PRICE-ELECTION
              ON SIZE ERROR
                 MOVE 4725 TO WS-8020-PARAGRAPH-NO
                 MOVE 90017 TO WS-8020-INT-ERROR-NO
                 MOVE 'YLD * PRICE' TO WS-8020-FIELD-NAME
                 MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                 PERFORM 8020-RECORD-INT-ERROR
                    THRU 8020-RECORD-INT-ERROR-EXIT
           END-COMPUTE
           MOVE WS-4725-GUARANTEE-PER-ACRE TO WS-4725-STAGE-GPA

      *****************************************************
      *    DISPLAY GUARANTEE PER ACRE RESULTS             *
      *****************************************************
           MOVE WS-4725-GUARANTEE-PER-ACRE
             TO WS-4725-GUARANTEE-PER-ACRE-X
           MOVE WS-4725-STAGE-GPA TO WS-4725-STAGE-GPA-X
      $IF DEBUG-SW DEFINED
           DISPLAY 'GUARANTEE PER ACRE = ',
           WS-4725-GUARANTEE-PER-ACRE-X UPON CONSOLE
           DISPLAY 'STAGE GPA          = ',
           WS-4725-STAGE-GPA-X UPON CONSOLE
      $END

      *****************************************************
      *    CALCULATE INDEMNITY LOSS GUARANTEE             *
      *****************************************************
           COMPUTE WS-4725-LOSS-GUARANTEE ROUNDED =
              WS-4725-STAGE-GPA * WS-4725-ACRES
              * WS-4725-LIABILITY-ADJ-FCTR
              ON SIZE ERROR
                 MOVE 4725 TO WS-8020-PARAGRAPH-NO
                 MOVE 90017 TO WS-8020-INT-ERROR-NO
                 MOVE 'LOSSG' TO WS-8020-FIELD-NAME
                 MOVE WS-4725-LOSS-GUARANTEE TO WS-8020-BAD-DATA
                 MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                 PERFORM 8020-RECORD-INT-ERROR
                    THRU 8020-RECORD-INT-ERROR-EXIT
           END-COMPUTE.

      *****************************************************
      *    DISPLAY INDEMNITY LOSS GUARANTEE RESULTS       *
      *****************************************************
      $IF DEBUG-SW DEFINED
           MOVE WS-4725-LOSS-GUARANTEE
             TO WS-4725-LOSS-GUARANTEE-X
           DISPLAY 'LOSS GUARANTEE = ',
           WS-4725-LOSS-GUARANTEE-X UPON CONSOLE.
      $END

       4725-CALC-INDEM-LOSSG-EXIT.
           EXIT.

