      ***************************************************************
      * File:      IF4730.CBL
      * Author:    Mike Ray
      * Date:      05/21/97
      * Purpose:   Calculates Stage Guarantee per Acre and Loss
      *            Guarantee for both Normal Indemnity and Replant
      *            Payments for GRP Crops.
      ***************************************************************

       4730-CALC-GRP-LOSSG.

      $IF DEBUG-SW DEFINED
           DISPLAY '4730-CALCULATING GRP LOSS GUARANTEE'
           UPON CONSOLE
      $END


      *****************************************************
      *    INITIALIZE LOCAL AND OUTPUT VARIABLES          *
      *****************************************************
           INITIALIZE WS-4730-LOCAL
           INITIALIZE WS-4730-OUTPUT

      *****************************************************
      *            SET UP DISPLAY FIELDS                  *
      *****************************************************
           MOVE WS-4730-DOLLAR-AMT-INS
             TO WS-4730-DOLLAR-AMT-INS-X
           MOVE WS-4730-INPUT-STAGE-GPA
             TO WS-4730-INPUT-STAGE-GPA-X
           MOVE WS-4730-CROP-MAX-REPLANT-GPA
             TO WS-4730-CROP-MAX-REPLANT-GPA-X
           MOVE WS-4730-PRICE-ELECTION
             TO WS-4730-PRICE-ELECTION-X
           MOVE WS-4730-ACRES TO WS-4730-ACRES-X
           MOVE WS-4730-LIABILITY-ADJ-FCTR
             TO WS-4730-LIABILITY-ADJ-FCTR-X

      $IF DEBUG-SW DEFINED
           DISPLAY 'DOLLAR AMT INS       = ',
           WS-4730-DOLLAR-AMT-INS-X UPON CONSOLE
           DISPLAY 'INPUT STAGE GPA      = ',
           WS-4730-INPUT-STAGE-GPA-X UPON CONSOLE
           DISPLAY 'CROP MAX REPLANT GPA = ',
           WS-4730-CROP-MAX-REPLANT-GPA-X UPON CONSOLE
           DISPLAY 'PRICE ELECTION       = ',
           WS-4730-PRICE-ELECTION-X UPON CONSOLE
           DISPLAY 'ACRES                = ',
           WS-4730-ACRES-X UPON CONSOLE
           DISPLAY 'LIABILITY ADJ FCTR   = ',
           WS-4730-LIABILITY-ADJ-FCTR-X UPON CONSOLE
      $END

      *****************************************************
      *    CHECK PRE-CONDITIONS                           *
      *****************************************************
           IF WS-4730-STAGE-CD = SPACES
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-4730-CALC-ERROR
              MOVE 'WS-4730-STAGE-CD' TO WS-8000-FIELD-NAME1
              MOVE SPACES TO WS-8000-BAD-DATA1
              MOVE 'NOT BLANK' TO WS-8000-CORR-DATA1
              MOVE 4730 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-4730-DOLLAR-AMT-INS = ZEROS
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-4730-CALC-ERROR
              MOVE 'WS-4730-DOLLAR-AMT-INS' TO WS-8000-FIELD-NAME1
              MOVE ZERO TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 4730 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-4730-PRICE-ELECTION = ZEROS
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-4730-CALC-ERROR
              MOVE 'WS-4730-PRICE-ELECTION' TO WS-8000-FIELD-NAME1
              MOVE ZERO TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 4730 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-4730-CROP-UNIT-OF-MEASURE = ZEROS
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-4730-CALC-ERROR
              MOVE 'WS-4730-CROP-UM' TO WS-8000-FIELD-NAME1
              MOVE ZERO TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 4730 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-4730-INPUT-STAGE-GPA = ZEROS
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-4730-CALC-ERROR
              MOVE 'WS-4730-INPUT-STAGE-GPA' TO WS-8000-FIELD-NAME1
              MOVE ZERO TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 4730 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

      *    *** WS-4730-CROP-MAX-REPLANT-GPA CAN = ZERO

           IF WS-4730-ACRES = ZEROS
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-4730-CALC-ERROR
              MOVE 'WS-4730-ACRES' TO WS-8000-FIELD-NAME1
              MOVE ZERO TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 4730 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-4730-LIABILITY-ADJ-FCTR = ZEROS
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-4730-CALC-ERROR
              MOVE 'WS-4730-LIABILITY-ADJ-FCTR'
                TO WS-8000-FIELD-NAME1
              MOVE ZERO TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 4730 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF


           IF WS-4730-CALC-ERROR = WS-LITERAL-YES
              GO TO 4730-CALC-GRP-LOSSG-EXIT
           END-IF

      *****************************************************
      *    PERFORM CALCULATIONS                           *
      *****************************************************
           IF WS-4730-STAGE-CD = WS-LITERAL-REPLANTED
              PERFORM 4730-CALC-REPLANT-LOSSG
                 THRU 4730-CALC-REPLANT-LOSSG-EXIT
           ELSE
              PERFORM 4730-CALC-INDEM-LOSSG
                 THRU 4730-CALC-INDEM-LOSSG-EXIT
           END-IF.



       4730-CALC-GRP-LOSSG-EXIT.
           EXIT.


       4730-CALC-REPLANT-LOSSG.

      $IF DEBUG-SW DEFINED
           DISPLAY '4730-CALCULATING GRP REPLANT GUARANTEE'
           UPON CONSOLE
      $END

      *****************************************************
      *    CALCULATE GUARANTEE PER ACRE                   *
      *****************************************************
           MOVE WS-4730-DOLLAR-AMT-INS
             TO WS-4730-GUARANTEE-PER-ACRE

      *    *** COMPUTE 20% GUARANTEE PER ACRE
           COMPUTE WS-4730-STAGE-GPA ROUNDED =
              WS-4730-GUARANTEE-PER-ACRE * 0.20
              ON SIZE ERROR
                 MOVE 4730 TO WS-8020-PARAGRAPH-NO
                 MOVE 90017 TO WS-8020-INT-ERROR-NO
                 MOVE '0.2 * GPA' TO WS-8020-FIELD-NAME
                 MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                 PERFORM 8020-RECORD-INT-ERROR
                    THRU 8020-RECORD-INT-ERROR-EXIT
           END-COMPUTE

      *    *** COMPUTE CROP MAX GPA IN DOLLARS ***
      *    *** (CROP MAX LIMITS FOR THESE CROPS ARE IN COMMODITY UM **
           COMPUTE WS-4730-CROP-MAX-GPA-DOLLARS ROUNDED =
              WS-4730-CROP-MAX-REPLANT-GPA * WS-4730-PRICE-ELECTION
              ON SIZE ERROR
                 MOVE 4730 TO WS-8020-PARAGRAPH-NO
                 MOVE 90017 TO WS-8020-INT-ERROR-NO
                 MOVE 'MAX * PRICE' TO WS-8020-FIELD-NAME
                 MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                 PERFORM 8020-RECORD-INT-ERROR
                    THRU 8020-RECORD-INT-ERROR-EXIT
           END-COMPUTE

      *****************************************************
      *    DISPLAY GUARANTEE PER ACRE RESULTS             *
      *****************************************************
           MOVE WS-4730-GUARANTEE-PER-ACRE
             TO WS-4730-GUARANTEE-PER-ACRE-X
           MOVE WS-4730-STAGE-GPA TO WS-4730-STAGE-GPA-X
           MOVE WS-4730-CROP-MAX-GPA-DOLLARS
             TO WS-4730-CROP-MAX-REPLANT-GPA-X

      $IF DEBUG-SW DEFINED
           DISPLAY 'GUARANTEE PER ACRE    = ',
           WS-4730-GUARANTEE-PER-ACRE-X UPON CONSOLE
           DISPLAY '20% STAGE GPA         = ',
           WS-4730-STAGE-GPA-X UPON CONSOLE
           DISPLAY 'CROP MAX LIMIT (IN $) = ',
           WS-4730-CROP-MAX-REPLANT-GPA-X UPON CONSOLE
      $END

      *****************************************************
      *    DETERMINE THE CORRECT MAX STAGE GPA            *
      *****************************************************
           IF WS-4730-STAGE-GPA > WS-4730-CROP-MAX-GPA-DOLLARS
              MOVE WS-4730-CROP-MAX-GPA-DOLLARS
                TO WS-4730-STAGE-GPA
              MOVE WS-4730-STAGE-GPA
                TO WS-4730-STAGE-GPA-X
           END-IF

      $IF DEBUG-SW DEFINED
           DISPLAY 'MAX REPLANT STAGE GPA = ',
           WS-4730-STAGE-GPA-X UPON CONSOLE
      $END

      *****************************************************
      *    CALCULATE REPLANT LOSS GUARANTEE               *
      *****************************************************
           COMPUTE WS-4730-LOSS-GUARANTEE ROUNDED =
              WS-4730-INPUT-STAGE-GPA * WS-4730-ACRES
              * WS-4730-LIABILITY-ADJ-FCTR
              ON SIZE ERROR
                 MOVE 4730 TO WS-8020-PARAGRAPH-NO
                 MOVE 90017 TO WS-8020-INT-ERROR-NO
                 MOVE 'REPLANT LOSSG' TO WS-8020-FIELD-NAME
                 MOVE WS-4730-LOSS-GUARANTEE TO WS-8020-BAD-DATA
                 MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                 PERFORM 8020-RECORD-INT-ERROR
                    THRU 8020-RECORD-INT-ERROR-EXIT
           END-COMPUTE.

      *****************************************************
      *    DISPLAY REPLANT LOSS GUARANTEE RESULTS         *
      *****************************************************
      $IF DEBUG-SW DEFINED
           MOVE WS-4730-LOSS-GUARANTEE
             TO WS-4730-LOSS-GUARANTEE-X
           DISPLAY 'REPLANT LOSS GUARANTEE = ',
           WS-4730-LOSS-GUARANTEE-X UPON CONSOLE.
      $END


       4730-CALC-REPLANT-LOSSG-EXIT.
           EXIT.



      *==============================================================*
      *    NORMAL INDEMNITY LOSS GUARANTEE CALCULATION               *
      *==============================================================*

       4730-CALC-INDEM-LOSSG.

      $IF DEBUG-SW DEFINED
           DISPLAY '4730-CALCULATING GRP LOSS GUARANTEE'
           UPON CONSOLE
      $END

      *****************************************************
      *    CALCULATE GUARANTEE PER ACRE                   *
      *****************************************************
           MOVE WS-4730-DOLLAR-AMT-INS
             TO WS-4730-GUARANTEE-PER-ACRE
           MOVE WS-4730-CROP-MAX-GPA-DOLLARS
             TO WS-4730-STAGE-GPA

      *****************************************************
      *    DISPLAY GUARANTEE PER ACRE RESULTS             *
      *****************************************************
           MOVE WS-4730-GUARANTEE-PER-ACRE
             TO WS-4730-GUARANTEE-PER-ACRE-X
           MOVE WS-4730-STAGE-GPA TO WS-4730-STAGE-GPA-X
      $IF DEBUG-SW DEFINED
           DISPLAY 'GUARANTEE PER ACRE = ',
           WS-4730-GUARANTEE-PER-ACRE-X UPON CONSOLE
           DISPLAY 'STAGE GPA          = ',
           WS-4730-STAGE-GPA-X UPON CONSOLE
      $END

      *****************************************************
      *    CALCULATE INDEMNITY LOSS GUARANTEE             *
      *****************************************************
           COMPUTE WS-4730-LOSS-GUARANTEE ROUNDED =
              WS-4730-STAGE-GPA * WS-4730-ACRES
              * WS-4730-LIABILITY-ADJ-FCTR
              ON SIZE ERROR
                 MOVE 4730 TO WS-8020-PARAGRAPH-NO
                 MOVE 90017 TO WS-8020-INT-ERROR-NO
                 MOVE 'LOSSG' TO WS-8020-FIELD-NAME
                 MOVE WS-4730-LOSS-GUARANTEE TO WS-8020-BAD-DATA
                 MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                 PERFORM 8020-RECORD-INT-ERROR
                    THRU 8020-RECORD-INT-ERROR-EXIT
           END-COMPUTE.

      *****************************************************
      *    DISPLAY INDEMNITY LOSS GUARANTEE RESULTS       *
      *****************************************************
      $IF DEBUG-SW DEFINED
           MOVE WS-4730-LOSS-GUARANTEE
             TO WS-4730-LOSS-GUARANTEE-X
           DISPLAY 'LOSS GUARANTEE = ',
           WS-4730-LOSS-GUARANTEE-X UPON CONSOLE.
      $END

       4730-CALC-INDEM-LOSSG-EXIT.
           EXIT.

