      ***************************************************************
      * File:      IF4735.CBL
      * Author:    Mike Ray
      * Date:      05/21/97
      * Purpose:   Calculates Stage Guarantee per Acre and Loss
      *            Guarantee for both Normal Indemnity and Replant
      *            Payments for Guaranteed Production Tobacco.
      ***************************************************************

       4735-CALC-GTOBACCO-LOSSG.

      $IF DEBUG-SW DEFINED
           DISPLAY '4735-CALCULATING GUAR TOBACCO LOSS GUARANTEE'
           UPON CONSOLE
      $END

      *****************************************************
      *    INITIALIZE LOCAL AND OUTPUT VARIABLES          *
      *****************************************************
           INITIALIZE WS-4735-LOCAL
           INITIALIZE WS-4735-OUTPUT

      *****************************************************
      *            SET UP DISPLAY FIELDS                  *
      *****************************************************
           MOVE WS-4735-YIELD TO WS-4735-YIELD-X
           MOVE WS-4735-GUAR-REDUCTION-FCTR
             TO WS-4735-GUAR-REDUCTION-FCTR-X
           MOVE WS-4735-ACRES TO WS-4735-ACRES-X
           MOVE WS-4735-LIABILITY-ADJ-FCTR
             TO WS-4735-LIABILITY-ADJ-FCTR-X

      $IF DEBUG-SW DEFINED
           DISPLAY 'YIELD                = ',
           WS-4735-YIELD-X UPON CONSOLE
           DISPLAY 'COVERAGE LEVEL       = ',
           WS-4735-CVG-LVL-PERCENT UPON CONSOLE
           DISPLAY 'GUARANTEE RED FCTR   = ',
           WS-4735-GUAR-REDUCTION-FCTR-X UPON CONSOLE
           DISPLAY 'ACRES                = ',
           WS-4735-ACRES-X UPON CONSOLE
           DISPLAY 'LIABILITY ADJ FCTR   = ',
           WS-4735-LIABILITY-ADJ-FCTR-X UPON CONSOLE
      $END

      *****************************************************
      *    CHECK PRE-CONDITIONS                           *
      *****************************************************
      *    *** REPLANTING NOT AVAILABLE FOR THESE CROPS ***
           IF WS-4735-STAGE-CD = WS-LITERAL-REPLANTED
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 044 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-4735-CALC-ERROR
              MOVE 'WS-4735-STAGE-CD' TO WS-8000-FIELD-NAME1
              MOVE WS-4735-STAGE-CD TO WS-8000-BAD-DATA1
              MOVE 'NOT REPLANT' TO WS-8000-CORR-DATA1
              MOVE 4735 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-4735-YIELD = ZEROS
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-4735-CALC-ERROR
              MOVE 'WS-4735-YIELD' TO WS-8000-FIELD-NAME1
              MOVE ZERO TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 4735 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-4735-CVG-LVL-PERCENT = ZEROS
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-4735-CALC-ERROR
              MOVE 'WS-4735-CVG-LVL-PERCENT' TO WS-8000-FIELD-NAME1
              MOVE ZERO TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 4735 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-4735-CROP-UNIT-OF-MEASURE = ZEROS
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-4735-CALC-ERROR
              MOVE 'WS-4735-CROP-UM' TO WS-8000-FIELD-NAME1
              MOVE ZERO TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 4735 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-4735-ACRES = ZEROS
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-4735-CALC-ERROR
              MOVE 'WS-4735-ACRES' TO WS-8000-FIELD-NAME1
              MOVE ZERO TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 4735 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-4735-LIABILITY-ADJ-FCTR = ZEROS
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-4735-CALC-ERROR
              MOVE 'WS-4735-LIABILITY-ADJ-FCTR'
                TO WS-8000-FIELD-NAME1
              MOVE ZERO TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 4735 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-4735-CALC-ERROR = WS-LITERAL-YES
              GO TO 4735-CALC-GTOBACCO-LOSSG-EXIT
           END-IF

      *    *** WS-4735-GUAR-REDUCTION-FCTR CAN = ZEROS
      *    *** IF ZEROS DEFAULT TO 1.00 FOR CALCULATION
           IF WS-4735-GUAR-REDUCTION-FCTR = ZEROS
              MOVE 1.00 TO WS-4735-GUAR-REDUCTION-FCTR
           END-IF

      *****************************************************
      *    PERFORM CALCULATIONS                           *
      *****************************************************
           PERFORM 4735-CALC-INDEM-LOSSG
              THRU 4735-CALC-INDEM-LOSSG-EXIT.

       4735-CALC-GTOBACCO-LOSSG-EXIT.
           EXIT.

      *==============================================================*
      *    NORMAL INDEMNITY LOSS GUARANTEE CALCULATION               *
      *==============================================================*

       4735-CALC-INDEM-LOSSG.

      $IF DEBUG-SW DEFINED
           DISPLAY '4735-CALCULATING GUAR TOBACCO LOSS GUARANTEE'
           UPON CONSOLE
      $END

      *****************************************************
      *    CALCULATE GUARANTEE PER ACRE                   *
      *****************************************************
           COMPUTE WS-4735-PREMIUM-GPA ROUNDED =
              WS-4735-YIELD * (WS-4735-CVG-LVL-PERCENT / 100)
              ON SIZE ERROR
                 MOVE 4735 TO WS-8020-PARAGRAPH-NO
                 MOVE 90017 TO WS-8020-INT-ERROR-NO
                 MOVE 'YLD * CVG%' TO WS-8020-FIELD-NAME
                 MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                 PERFORM 8020-RECORD-INT-ERROR
                    THRU 8020-RECORD-INT-ERROR-EXIT
           END-COMPUTE
           COMPUTE WS-4735-GUARANTEE-PER-ACRE ROUNDED =
              WS-4735-PREMIUM-GPA * WS-4735-GUAR-REDUCTION-FCTR
              ON SIZE ERROR
                 MOVE 4735 TO WS-8020-PARAGRAPH-NO
                 MOVE 90017 TO WS-8020-INT-ERROR-NO
                 MOVE 'PGPA * GUAR RED%' TO WS-8020-FIELD-NAME
                 MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                 PERFORM 8020-RECORD-INT-ERROR
                    THRU 8020-RECORD-INT-ERROR-EXIT
           END-COMPUTE
           MOVE WS-4735-GUARANTEE-PER-ACRE TO WS-4735-STAGE-GPA

      *****************************************************
      *    DISPLAY GUARANTEE PER ACRE RESULTS             *
      *****************************************************
           MOVE WS-4735-PREMIUM-GPA
             TO WS-4735-PREMIUM-GPA-X
           MOVE WS-4735-GUARANTEE-PER-ACRE
             TO WS-4735-GUARANTEE-PER-ACRE-X
           MOVE WS-4735-STAGE-GPA TO WS-4735-STAGE-GPA-X
      $IF DEBUG-SW DEFINED
           DISPLAY 'PREMIUM GPA        = ',
           WS-4735-PREMIUM-GPA-X UPON CONSOLE
           DISPLAY 'GUARANTEE PER ACRE = ',
           WS-4735-GUARANTEE-PER-ACRE-X UPON CONSOLE
           DISPLAY 'STAGE GPA          = ',
           WS-4735-STAGE-GPA-X UPON CONSOLE
      $END

      *****************************************************
      *    CALCULATE INDEMNITY LOSS GUARANTEE             *
      *****************************************************
           COMPUTE WS-4735-LOSS-GUARANTEE ROUNDED =
              WS-4735-STAGE-GPA * WS-4735-ACRES
              * WS-4735-LIABILITY-ADJ-FCTR
              ON SIZE ERROR
                 MOVE 4735 TO WS-8020-PARAGRAPH-NO
                 MOVE 90017 TO WS-8020-INT-ERROR-NO
                 MOVE 'LOSSG' TO WS-8020-FIELD-NAME
                 MOVE WS-4735-LOSS-GUARANTEE TO WS-8020-BAD-DATA
                 MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                 PERFORM 8020-RECORD-INT-ERROR
                    THRU 8020-RECORD-INT-ERROR-EXIT
           END-COMPUTE.

      *****************************************************
      *    DISPLAY INDEMNITY LOSS GUARANTEE RESULTS       *
      *****************************************************
      $IF DEBUG-SW DEFINED
           MOVE WS-4735-LOSS-GUARANTEE
             TO WS-4735-LOSS-GUARANTEE-X
           DISPLAY 'LOSS GUARANTEE = ',
           WS-4735-LOSS-GUARANTEE-X UPON CONSOLE.
      $END

       4735-CALC-INDEM-LOSSG-EXIT.
           EXIT.

