      ***************************************************************
      * File:      IF4745.CBL
      * Author:    Mike Ray
      * Date:      05/22/97
      * Purpose:   Calculates Stage Guarantee per Acre and Loss
      *            Guarantee for both Normal Indemnity and Replant
      *            Payments for CRC crops.
      ***************************************************************

       4745-CALC-CRC-LOSSG.

      $IF DEBUG-SW DEFINED
           DISPLAY '4745-CALCULATING CRC LOSS GUARANTEE'
           UPON CONSOLE
      $END

      *****************************************************
      *    INITIALIZE LOCAL AND OUTPUT VARIABLES          *
      *****************************************************
           INITIALIZE WS-4745-LOCAL
           INITIALIZE WS-4745-OUTPUT

      *****************************************************
      *            SET UP DISPLAY FIELDS                  *
      *****************************************************
           MOVE WS-4745-YIELD TO WS-4745-YIELD-X
           MOVE WS-4745-GUAR-REDUCTION-FCTR
             TO WS-4745-GUAR-REDUCTION-FCTR-X
           MOVE WS-4745-INPUT-STAGE-GPA
             TO WS-4745-INPUT-STAGE-GPA-X
           MOVE WS-4745-CROP-MAX-REPLANT-GPA
             TO WS-4745-CROP-MAX-REPLANT-GPA-X
           MOVE WS-4745-ACRES TO WS-4745-ACRES-X
           MOVE WS-4745-PRICE-ELECTION
             TO WS-4745-PRICE-ELECTION-X
           MOVE WS-4745-LIABILITY-ADJ-FCTR
             TO WS-4745-LIABILITY-ADJ-FCTR-X

      $IF DEBUG-SW DEFINED
           DISPLAY 'YIELD                = ',
           WS-4745-YIELD-X UPON CONSOLE
           DISPLAY 'CVG LVL %            = ',
           WS-4745-CVG-LVL-PERCENT UPON CONSOLE
           DISPLAY 'GUAR RED FCTR        = ',
           WS-4745-GUAR-REDUCTION-FCTR-X UPON CONSOLE
           DISPLAY 'INPUT STAGE GPA      = ',
           WS-4745-INPUT-STAGE-GPA-X UPON CONSOLE
           DISPLAY 'CROP MAX REPLANT GPA = ',
           WS-4745-CROP-MAX-REPLANT-GPA-X UPON CONSOLE
           DISPLAY 'ACRES                = ',
           WS-4745-ACRES-X UPON CONSOLE
           DISPLAY 'PRICE ELECTION       = ',
           WS-4745-PRICE-ELECTION-X UPON CONSOLE
           DISPLAY 'LIABILITY ADJ FCTR   = ',
           WS-4745-LIABILITY-ADJ-FCTR-X UPON CONSOLE
      $END

      *****************************************************
      *    CHECK PRE-CONDITIONS                           *
      *****************************************************
           IF WS-4745-STAGE-CD = SPACES
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-4745-CALC-ERROR
              MOVE 'WS-4745-STAGE-CD' TO WS-8000-FIELD-NAME1
              MOVE SPACES TO WS-8000-BAD-DATA1
              MOVE 'NOT BLANK' TO WS-8000-CORR-DATA1
              MOVE 4745 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-4745-YIELD = ZEROS
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-4745-CALC-ERROR
              MOVE 'WS-4745-YIELD' TO WS-8000-FIELD-NAME1
              MOVE ZERO TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 4745 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-4745-CVG-LVL-PERCENT = ZEROS
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-4745-CALC-ERROR
              MOVE 'WS-4745-CVG-LVL-PCT' TO WS-8000-FIELD-NAME1
              MOVE ZERO TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 4745 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-4745-CROP-UNIT-OF-MEASURE = ZEROS
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-4745-CALC-ERROR
              MOVE 'WS-4745-CROP-UM' TO WS-8000-FIELD-NAME1
              MOVE ZERO TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 4745 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-4745-INPUT-STAGE-GPA = ZEROS
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-4745-CALC-ERROR
              MOVE 'WS-4745-INPUT-STAGE-GPA' TO WS-8000-FIELD-NAME1
              MOVE ZERO TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 4745 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

      *    *** WS-4745-CROP-MAX-REPLANT-GPA CAN = ZERO

           IF WS-4745-ACRES = ZEROS
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-4745-CALC-ERROR
              MOVE 'WS-4745-ACRES' TO WS-8000-FIELD-NAME1
              MOVE ZERO TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 4745 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-4745-PRICE-ELECTION = ZEROS
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-4745-CALC-ERROR
              MOVE 'WS-4745-PRICE-ELECTION' TO WS-8000-FIELD-NAME1
              MOVE ZERO TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 4745 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-4745-LIABILITY-ADJ-FCTR = ZEROS
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-4745-CALC-ERROR
              MOVE 'WS-4745-LIABILITY-ADJ-FCTR'
                TO WS-8000-FIELD-NAME1
              MOVE ZERO TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 4745 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-4745-CALC-ERROR = WS-LITERAL-YES
              GO TO 4745-CALC-CRC-LOSSG-EXIT
           END-IF

      *    *** WS-4745-GUAR-REDUCTION-FCTR CAN = ZEROS
      *    *** IF ZEROS DEFAULT TO 1.00 FOR CALCULATION
           IF WS-4745-GUAR-REDUCTION-FCTR = ZEROS
              MOVE 1.00 TO WS-4745-GUAR-REDUCTION-FCTR
           END-IF

      *****************************************************
      *    PERFORM CALCULATIONS                           *
      *****************************************************
           IF WS-4745-STAGE-CD = WS-LITERAL-REPLANTED
              PERFORM 4745-CALC-REPLANT-LOSSG
                 THRU 4745-CALC-REPLANT-LOSSG-EXIT
           ELSE
              PERFORM 4745-CALC-INDEM-LOSSG
                 THRU 4745-CALC-INDEM-LOSSG-EXIT
           END-IF.

       4745-CALC-CRC-LOSSG-EXIT.
           EXIT.

       4745-CALC-REPLANT-LOSSG.

      $IF DEBUG-SW DEFINED
           DISPLAY '4745-CALCULATING CRC REPLANT LOSS GUARANTEE'
           UPON CONSOLE
      $END

      *****************************************************
      *    CALCULATE GUARANTEE PER ACRE                   *
      *****************************************************
           IF WS-4745-CROP-UNIT-OF-MEASURE = WS-LITERAL-DOLLARS OR
              WS-4745-CROP-UNIT-OF-MEASURE = WS-LITERAL-LBS
      *       *** ROUND TO WHOLE
              COMPUTE WS-4745-PREMIUM-GPA-LBS ROUNDED =
                 WS-4745-YIELD * (WS-4745-CVG-LVL-PERCENT / 100)
                 ON SIZE ERROR
                    MOVE 4745 TO WS-8020-PARAGRAPH-NO
                    MOVE 90017 TO WS-8020-INT-ERROR-NO
                    MOVE 'Yield * CVG LVL %' TO WS-8020-FIELD-NAME
                    MOVE WS-4745-PREMIUM-GPA-LBS TO WS-8020-BAD-DATA
                    MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                    PERFORM 8020-RECORD-INT-ERROR
                       THRU 8020-RECORD-INT-ERROR-EXIT
              END-COMPUTE
              COMPUTE WS-4745-GUARANTEE-PER-ACRE-LBS ROUNDED =
                 WS-4745-PREMIUM-GPA-LBS * WS-4745-GUAR-REDUCTION-FCTR
                 ON SIZE ERROR
                    MOVE 4745 TO WS-8020-PARAGRAPH-NO
                    MOVE 90017 TO WS-8020-INT-ERROR-NO
                    MOVE 'PREM GPA*(1-GRF)' TO WS-8020-FIELD-NAME
                    MOVE WS-4745-GUARANTEE-PER-ACRE-LBS
                      TO WS-8020-BAD-DATA
                    MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                    PERFORM 8020-RECORD-INT-ERROR
                       THRU 8020-RECORD-INT-ERROR-EXIT
              END-COMPUTE
      *       *** COMPUTE 20% GUARANTEE PER ACRE
              COMPUTE WS-4745-STAGE-GPA-LBS ROUNDED =
                 WS-4745-GUARANTEE-PER-ACRE-LBS * 0.20
                 ON SIZE ERROR
                    MOVE 4745 TO WS-8020-PARAGRAPH-NO
                    MOVE 90017 TO WS-8020-INT-ERROR-NO
                    MOVE '0.2 * GPA' TO WS-8020-FIELD-NAME
                    MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                    PERFORM 8020-RECORD-INT-ERROR
                       THRU 8020-RECORD-INT-ERROR-EXIT
              END-COMPUTE

      *       *** AFTER ROUNDING, MOVE THE ROUNDED FIELDS TO THE
      *       *** MORE PRECISE FIELDS FOR THE NEXT SET OF CALCULATIONS.
              MOVE WS-4745-PREMIUM-GPA-LBS TO WS-4745-PREMIUM-GPA
              MOVE WS-4745-GUARANTEE-PER-ACRE-LBS
                TO WS-4745-GUARANTEE-PER-ACRE
              MOVE WS-4745-STAGE-GPA-LBS
                TO WS-4745-STAGE-GPA

           ELSE
      *       *** ROUND TO TENTHS
              COMPUTE WS-4745-PREMIUM-GPA ROUNDED =
                 WS-4745-YIELD * (WS-4745-CVG-LVL-PERCENT / 100)
                 ON SIZE ERROR
                    MOVE 4745 TO WS-8020-PARAGRAPH-NO
                    MOVE 90017 TO WS-8020-INT-ERROR-NO
                    MOVE 'Yield * CVG LVL %' TO WS-8020-FIELD-NAME
                    MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                    PERFORM 8020-RECORD-INT-ERROR
                       THRU 8020-RECORD-INT-ERROR-EXIT
              END-COMPUTE
              COMPUTE WS-4745-GUARANTEE-PER-ACRE ROUNDED =
                 WS-4745-PREMIUM-GPA * WS-4745-GUAR-REDUCTION-FCTR
                 ON SIZE ERROR
                    MOVE 4745 TO WS-8020-PARAGRAPH-NO
                    MOVE 90017 TO WS-8020-INT-ERROR-NO
                    MOVE 'PREM GPA*(1-GRF)' TO WS-8020-FIELD-NAME
                    MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                    PERFORM 8020-RECORD-INT-ERROR
                       THRU 8020-RECORD-INT-ERROR-EXIT
              END-COMPUTE
      *       *** COMPUTE 20% GUARANTEE PER ACRE
              COMPUTE WS-4745-STAGE-GPA ROUNDED =
                 WS-4745-GUARANTEE-PER-ACRE * 0.20
                 ON SIZE ERROR
                    MOVE 4745 TO WS-8020-PARAGRAPH-NO
                    MOVE 90017 TO WS-8020-INT-ERROR-NO
                    MOVE '0.2 * GPA' TO WS-8020-FIELD-NAME
                    MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                    PERFORM 8020-RECORD-INT-ERROR
                       THRU 8020-RECORD-INT-ERROR-EXIT
              END-COMPUTE
           END-IF

      *****************************************************
      *    DISPLAY GUARANTEE PER ACRE RESULTS             *
      *****************************************************
           MOVE WS-4745-PREMIUM-GPA TO WS-4745-PREMIUM-GPA-X
           MOVE WS-4745-GUARANTEE-PER-ACRE
             TO WS-4745-GUARANTEE-PER-ACRE-X
           MOVE WS-4745-STAGE-GPA TO WS-4745-STAGE-GPA-X
      $IF DEBUG-SW DEFINED
           DISPLAY 'PREMIUM GPA        = ',
           WS-4745-PREMIUM-GPA-X UPON CONSOLE
           DISPLAY 'GUARANTEE PER ACRE = ',
           WS-4745-GUARANTEE-PER-ACRE-X UPON CONSOLE
           DISPLAY '20% STAGE GPA      = ',
           WS-4745-STAGE-GPA-X UPON CONSOLE
      $END

      *****************************************************
      *    DETERMINE THE CORRECT MAX STAGE GPA            *
      *****************************************************
           IF WS-4745-STAGE-GPA > WS-4745-CROP-MAX-REPLANT-GPA
              MOVE WS-4745-CROP-MAX-REPLANT-GPA
                TO WS-4745-STAGE-GPA
              MOVE WS-4745-STAGE-GPA
                TO WS-4745-STAGE-GPA-X
           END-IF

      $IF DEBUG-SW DEFINED
           DISPLAY 'MAX REPLANT STAGE GPA = ',
           WS-4745-STAGE-GPA-X UPON CONSOLE
      $END

      *****************************************************
      *    CALCULATE REPLANT LOSS GUARANTEE               *
      *****************************************************
           IF WS-4745-CROP-UNIT-OF-MEASURE = WS-LITERAL-DOLLARS OR
              WS-4745-CROP-UNIT-OF-MEASURE = WS-LITERAL-LBS
      *       *** ROUND TO WHOLE
              COMPUTE WS-4745-LOSS-GUARANTEE-LBS ROUNDED =
                 WS-4745-INPUT-STAGE-GPA * WS-4745-ACRES
                 * WS-4745-LIABILITY-ADJ-FCTR
                 ON SIZE ERROR
                    MOVE 4745 TO WS-8020-PARAGRAPH-NO
                    MOVE 90017 TO WS-8020-INT-ERROR-NO
                    MOVE 'REPLANT LOSSG-L' TO WS-8020-FIELD-NAME
                    MOVE WS-4745-PREMIUM-GPA-LBS TO WS-8020-BAD-DATA
                    MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                    PERFORM 8020-RECORD-INT-ERROR
                       THRU 8020-RECORD-INT-ERROR-EXIT
              END-COMPUTE
              MOVE WS-4745-LOSS-GUARANTEE-LBS
                TO WS-4745-LOSS-GUARANTEE
           ELSE
      *       *** ROUND TO TENTHS
              COMPUTE WS-4745-LOSS-GUARANTEE ROUNDED =
                 WS-4745-INPUT-STAGE-GPA * WS-4745-ACRES
                 * WS-4745-LIABILITY-ADJ-FCTR
                 ON SIZE ERROR
                    MOVE 4745 TO WS-8020-PARAGRAPH-NO
                    MOVE 90017 TO WS-8020-INT-ERROR-NO
                    MOVE 'REPLANT LOSSG' TO WS-8020-FIELD-NAME
                    MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                    PERFORM 8020-RECORD-INT-ERROR
                       THRU 8020-RECORD-INT-ERROR-EXIT
              END-COMPUTE
           END-IF.

      *****************************************************
      *    DISPLAY REPLANT LOSS GUARANTEE RESULTS         *
      *****************************************************
      $IF DEBUG-SW DEFINED
           MOVE WS-4745-LOSS-GUARANTEE
             TO WS-4745-LOSS-GUARANTEE-X
           DISPLAY 'REPLANT LOSS GUARANTEE = ',
           WS-4745-LOSS-GUARANTEE-X UPON CONSOLE.
      $END

       4745-CALC-REPLANT-LOSSG-EXIT.
           EXIT.

      *==============================================================*
      *    NORMAL INDEMNITY LOSS GUARANTEE CALCULATION               *
      *==============================================================*

       4745-CALC-INDEM-LOSSG.

      $IF DEBUG-SW DEFINED
           DISPLAY '4745-CALCULATING CRC INDEMNITY LOSS GUARANTEE'
           UPON CONSOLE
      $END

      *****************************************************
      *    CALCULATE GUARANTEE PER ACRE                   *
      *****************************************************
           IF WS-4745-CROP-UNIT-OF-MEASURE = WS-LITERAL-DOLLARS OR
              WS-4745-CROP-UNIT-OF-MEASURE = WS-LITERAL-LBS
      *       *** ROUND TO WHOLE
              COMPUTE WS-4745-PREMIUM-GPA-LBS ROUNDED =
                 WS-4745-YIELD * (WS-4745-CVG-LVL-PERCENT / 100)
                 ON SIZE ERROR
                    MOVE 4745 TO WS-8020-PARAGRAPH-NO
                    MOVE 90017 TO WS-8020-INT-ERROR-NO
                    MOVE 'Yield * CVG LVL %' TO WS-8020-FIELD-NAME
                    MOVE WS-4745-PREMIUM-GPA-LBS TO WS-8020-BAD-DATA
                    MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                    PERFORM 8020-RECORD-INT-ERROR
                       THRU 8020-RECORD-INT-ERROR-EXIT
              END-COMPUTE
              COMPUTE WS-4745-GUARANTEE-PER-ACRE-LBS ROUNDED =
                 WS-4745-PREMIUM-GPA-LBS * WS-4745-GUAR-REDUCTION-FCTR
                 ON SIZE ERROR
                    MOVE 4745 TO WS-8020-PARAGRAPH-NO
                    MOVE 90017 TO WS-8020-INT-ERROR-NO
                    MOVE 'PREM GPA*(1-GRF)' TO WS-8020-FIELD-NAME
                    MOVE WS-4745-GUARANTEE-PER-ACRE-LBS
                      TO WS-8020-BAD-DATA
                    MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                    PERFORM 8020-RECORD-INT-ERROR
                       THRU 8020-RECORD-INT-ERROR-EXIT
              END-COMPUTE
      *       *** COMPUTE STAGE GUARANTEE PER ACRE
              MOVE WS-4745-GUARANTEE-PER-ACRE-LBS
                TO WS-4745-STAGE-GPA-LBS

      *       *** AFTER ROUNDING, MOVE THE ROUNDED FIELDS TO THE
      *       *** MORE PRECISE FIELDS FOR THE NEXT SET OF CALCULATIONS.
              MOVE WS-4745-PREMIUM-GPA-LBS TO WS-4745-PREMIUM-GPA
              MOVE WS-4745-GUARANTEE-PER-ACRE-LBS
                TO WS-4745-GUARANTEE-PER-ACRE
              MOVE WS-4745-STAGE-GPA-LBS
                TO WS-4745-STAGE-GPA

           ELSE
      *       *** ROUND TO TENTHS
              COMPUTE WS-4745-PREMIUM-GPA ROUNDED =
                 WS-4745-YIELD * (WS-4745-CVG-LVL-PERCENT / 100)
                 ON SIZE ERROR
                    MOVE 4745 TO WS-8020-PARAGRAPH-NO
                    MOVE 90017 TO WS-8020-INT-ERROR-NO
                    MOVE 'Yield * CVG LVL %' TO WS-8020-FIELD-NAME
                    MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                    PERFORM 8020-RECORD-INT-ERROR
                       THRU 8020-RECORD-INT-ERROR-EXIT
              END-COMPUTE
              COMPUTE WS-4745-GUARANTEE-PER-ACRE ROUNDED =
                 WS-4745-PREMIUM-GPA * WS-4745-GUAR-REDUCTION-FCTR
                 ON SIZE ERROR
                    MOVE 4745 TO WS-8020-PARAGRAPH-NO
                    MOVE 90017 TO WS-8020-INT-ERROR-NO
                    MOVE 'PREM GPA*(1-GRF)' TO WS-8020-FIELD-NAME
                    MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                    PERFORM 8020-RECORD-INT-ERROR
                       THRU 8020-RECORD-INT-ERROR-EXIT
              END-COMPUTE
      *       *** COMPUTE STAGE GUARANTEE PER ACRE
              MOVE WS-4745-GUARANTEE-PER-ACRE
                TO WS-4745-STAGE-GPA
           END-IF

      *****************************************************
      *    DISPLAY GUARANTEE PER ACRE RESULTS             *
      *****************************************************
           MOVE WS-4745-PREMIUM-GPA TO WS-4745-PREMIUM-GPA-X
           MOVE WS-4745-GUARANTEE-PER-ACRE
             TO WS-4745-GUARANTEE-PER-ACRE-X
           MOVE WS-4745-STAGE-GPA TO WS-4745-STAGE-GPA-X
      $IF DEBUG-SW DEFINED
           DISPLAY 'PREMIUM GPA        = ',
           WS-4745-PREMIUM-GPA-X UPON CONSOLE
           DISPLAY 'GUARANTEE PER ACRE = ',
           WS-4745-GUARANTEE-PER-ACRE-X UPON CONSOLE
           DISPLAY 'STAGE GPA          = ',
           WS-4745-STAGE-GPA-X UPON CONSOLE
      $END

      *****************************************************
      *    CALCULATE INDEMNITY LOSS GUARANTEE             *
      *****************************************************
      *    *** WILL ALWAYS BE IN DOLLARS FOR INDEMNITY LOSS GUARANTEE

      ********* NEW METHOD PER K. BEGLY **********************

      ***  COMPUTE WS-4745-LOSS-GUARANTEE-LBS ROUNDED =
      ***     WS-4745-STAGE-GPA * WS-4745-ACRES *
      ***     WS-4745-PRICE-ELECTION *
      ***     WS-4745-LIABILITY-ADJ-FCTR

           COMPUTE WS-4745-INTERMEDIATE       ROUNDED =
              WS-4745-STAGE-GPA * WS-4745-ACRES

           COMPUTE WS-4745-LOSS-GUARANTEE-LBS ROUNDED =
              WS-4745-INTERMEDIATE *
              WS-4745-PRICE-ELECTION *
              WS-4745-LIABILITY-ADJ-FCTR


      ********* NEW METHOD PER K. BEGLY **********************


              ON SIZE ERROR
                 MOVE 4745 TO WS-8020-PARAGRAPH-NO
                 MOVE 90017 TO WS-8020-INT-ERROR-NO
                 MOVE 'LOSSG-LBS' TO WS-8020-FIELD-NAME
                 MOVE WS-4745-LOSS-GUARANTEE-LBS TO WS-8020-BAD-DATA
                 MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                 PERFORM 8020-RECORD-INT-ERROR
                    THRU 8020-RECORD-INT-ERROR-EXIT
           END-COMPUTE
           MOVE WS-4745-LOSS-GUARANTEE-LBS
             TO WS-4745-LOSS-GUARANTEE.

      *****************************************************
      *    DISPLAY INDEMNITY LOSS GUARANTEE RESULTS       *
      *****************************************************
      $IF DEBUG-SW DEFINED
           MOVE WS-4745-LOSS-GUARANTEE
             TO WS-4745-LOSS-GUARANTEE-X
           DISPLAY 'LOSS GUARANTEE = ',
           WS-4745-LOSS-GUARANTEE-X UPON CONSOLE.
      $END

       4745-CALC-INDEM-LOSSG-EXIT.
           EXIT.

