      ***************************************************************
      * File:      IF4750.CBL
      * Author:    Mike Ray
      * Date:      05/22/97
      * Purpose:   Calculates Stage Guarantee per Acre and Loss
      *            Guarantee for both Normal Indemnity and Replant
      *            Payments for Florida Fruit.
      ***************************************************************

       4750-CALC-FL-FRUIT-LOSSG.

      $IF DEBUG-SW DEFINED
           DISPLAY '4750-CALCULATING FLORIDA FRUIT LOSS GUARANTEE'
           UPON CONSOLE
      $END

      *****************************************************
      *    INITIALIZE LOCAL AND OUTPUT VARIABLES          *
      *****************************************************
           INITIALIZE WS-4750-LOCAL
           INITIALIZE WS-4750-OUTPUT

      *****************************************************
      *            SET UP DISPLAY FIELDS                  *
      *****************************************************
           MOVE WS-4750-QUOTA TO WS-4750-QUOTA-X
           MOVE WS-4750-GUAR-REDUCTION-FCTR
             TO WS-4750-GUAR-REDUCTION-FCTR-X
           MOVE WS-4750-PRICE-ELECTION
             TO WS-4750-PRICE-ELECTION-X
           MOVE WS-4750-LIABILITY-ADJ-FCTR
             TO WS-4750-LIABILITY-ADJ-FCTR-X

      $IF DEBUG-SW DEFINED
           DISPLAY 'QUOTA                = ',
           WS-4750-QUOTA-X UPON CONSOLE
           DISPLAY 'CVG LVL %            = ',
           WS-4750-CVG-LVL-PERCENT UPON CONSOLE
           DISPLAY 'GUAR RED FCTR        = ',
           WS-4750-GUAR-REDUCTION-FCTR-X UPON CONSOLE
           DISPLAY 'PRICE ELECTION       = ',
           WS-4750-PRICE-ELECTION-X UPON CONSOLE
           DISPLAY 'LIABILITY ADJ FCTR   = ',
           WS-4750-LIABILITY-ADJ-FCTR-X UPON CONSOLE
      $END

      *****************************************************
      *    CHECK PRE-CONDITIONS                           *
      *****************************************************
      *    *** REPLANTING NOT AVAILABLE FOR THESE CROPS ***
           IF WS-4750-STAGE-CD = WS-LITERAL-REPLANTED
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 044 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-4750-CALC-ERROR
              MOVE 'WS-4750-STAGE-CD' TO WS-8000-FIELD-NAME1
              MOVE WS-4750-STAGE-CD TO WS-8000-BAD-DATA1
              MOVE 'NOT REPLANT' TO WS-8000-CORR-DATA1
              MOVE 4750 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-4750-QUOTA = ZEROS
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-4750-CALC-ERROR
              MOVE 'WS-4750-QUOTA' TO WS-8000-FIELD-NAME1
              MOVE ZERO TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 4750 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-4750-CVG-LVL-PERCENT = ZEROS
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-4750-CALC-ERROR
              MOVE 'WS-4750-CVG-LVL-PCT' TO WS-8000-FIELD-NAME1
              MOVE ZERO TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 4750 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-4750-PRICE-ELECTION = ZEROS
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-4750-CALC-ERROR
              MOVE 'WS-4750-PRICE-ELECTION' TO WS-8000-FIELD-NAME1
              MOVE ZERO TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 4750 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-4750-CROP-UNIT-OF-MEASURE = ZEROS
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-4750-CALC-ERROR
              MOVE 'WS-4750-CROP-UM' TO WS-8000-FIELD-NAME1
              MOVE ZERO TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 4750 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-4750-LIABILITY-ADJ-FCTR = ZEROS
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-4750-CALC-ERROR
              MOVE 'WS-4750-LIABILITY-ADJ-FCTR'
                TO WS-8000-FIELD-NAME1
              MOVE ZERO TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 4750 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-4750-CALC-ERROR = WS-LITERAL-YES
              GO TO 4750-CALC-FL-FRUIT-LOSSG-EXIT
           END-IF

      *    *** WS-4750-GUAR-REDUCTION-FCTR CAN = ZEROS
      *    *** IF ZEROS DEFAULT TO 1.00 FOR CALCULATION
           IF WS-4750-GUAR-REDUCTION-FCTR = ZEROS
              MOVE 1.00 TO WS-4750-GUAR-REDUCTION-FCTR
           END-IF

      *****************************************************
      *    PERFORM CALCULATIONS                           *
      *****************************************************
           PERFORM 4750-CALC-INDEM-LOSSG
              THRU 4750-CALC-INDEM-LOSSG-EXIT.

       4750-CALC-FL-FRUIT-LOSSG-EXIT.
           EXIT.

      *==============================================================*
      *    NORMAL INDEMNITY LOSS GUARANTEE CALCULATION               *
      *==============================================================*

       4750-CALC-INDEM-LOSSG.

      $IF DEBUG-SW DEFINED
           DISPLAY '4750-CALCULATING FLORIDA FRUIT LOSS GUARANTEE'
           UPON CONSOLE
      $END

      *****************************************************
      *    CALCULATE STAGE GUARANTEE PER ACRE             *
      *****************************************************
           MOVE ZEROS TO WS-4750-STAGE-GPA

      *****************************************************
      *    DISPLAY GUARANTEE PER ACRE RESULTS             *
      *****************************************************
           MOVE WS-4750-STAGE-GPA TO WS-4750-STAGE-GPA-X
      $IF DEBUG-SW DEFINED
           DISPLAY 'STAGE GPA          = ',
           WS-4750-STAGE-GPA-X UPON CONSOLE
      $END

      *****************************************************
      *    CALCULATE INDEMNITY LOSS GUARANTEE             *
      *****************************************************

           COMPUTE WS-4750-PREMIUM-GUARANTEE ROUNDED =
              WS-4750-QUOTA * (WS-4750-CVG-LVL-PERCENT / 100) *
              WS-4750-PRICE-ELECTION
              ON SIZE ERROR
                 MOVE 4750 TO WS-8020-PARAGRAPH-NO
                 MOVE 90017 TO WS-8020-INT-ERROR-NO
                 MOVE 'PREM G' TO WS-8020-FIELD-NAME
                 MOVE WS-4750-QUOTA TO WS-8020-BAD-DATA
                 MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                 PERFORM 8020-RECORD-INT-ERROR
                    THRU 8020-RECORD-INT-ERROR-EXIT
           END-COMPUTE
           COMPUTE WS-4750-TOTAL-GUARANTEE ROUNDED =
              WS-4750-PREMIUM-GUARANTEE * WS-4750-GUAR-REDUCTION-FCTR
              ON SIZE ERROR
                 MOVE 4750 TO WS-8020-PARAGRAPH-NO
                 MOVE 90017 TO WS-8020-INT-ERROR-NO
                 MOVE 'TOTAL G' TO WS-8020-FIELD-NAME
                 MOVE WS-4750-PREMIUM-GUARANTEE TO WS-8020-BAD-DATA
                 MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                 PERFORM 8020-RECORD-INT-ERROR
                    THRU 8020-RECORD-INT-ERROR-EXIT
           END-COMPUTE
           COMPUTE WS-4750-LOSS-GUARANTEE ROUNDED =
              WS-4750-TOTAL-GUARANTEE
              * WS-4750-LIABILITY-ADJ-FCTR
              ON SIZE ERROR
                 MOVE 4750 TO WS-8020-PARAGRAPH-NO
                 MOVE 90017 TO WS-8020-INT-ERROR-NO
                 MOVE 'LOSSG' TO WS-8020-FIELD-NAME
                 MOVE WS-4750-TOTAL-GUARANTEE TO WS-8020-BAD-DATA
                 MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                 PERFORM 8020-RECORD-INT-ERROR
                    THRU 8020-RECORD-INT-ERROR-EXIT
           END-COMPUTE.

      *****************************************************
      *    DISPLAY INDEMNITY LOSS GUARANTEE RESULTS       *
      *****************************************************
      $IF DEBUG-SW DEFINED
           MOVE WS-4750-PREMIUM-GUARANTEE
             TO WS-4750-PREMIUM-GUARANTEE-X
           MOVE WS-4750-TOTAL-GUARANTEE
             TO WS-4750-TOTAL-GUARANTEE-X
           MOVE WS-4750-LOSS-GUARANTEE
             TO WS-4750-LOSS-GUARANTEE-X
           DISPLAY 'PREM GUARANTEE  = ',
           WS-4750-PREMIUM-GUARANTEE-X UPON CONSOLE
           DISPLAY 'TOTAL GUARANTEE = ',
           WS-4750-TOTAL-GUARANTEE-X UPON CONSOLE
           DISPLAY 'LOSS GUARANTEE  = ',
           WS-4750-LOSS-GUARANTEE-X UPON CONSOLE.
      $END

       4750-CALC-INDEM-LOSSG-EXIT.
           EXIT.

