      ***************************************************************
      * File:      IF4755.CBL
      * Author:    Mike Ray
      * Date:      05/22/97
      * Purpose:   Calculates Stage Guarantee per Acre and Loss
      *            Guarantee for both Normal Indemnity and Replant
      *            Payments for Revenue Assurance Crops.
      ***************************************************************

       4755-CALC-RA-LOSSG.

      $IF DEBUG-SW DEFINED
           DISPLAY '4755-CALCULATING REVENUE ASSURANCE LOSS GUARANTEE'
           UPON CONSOLE
      $END

      *****************************************************
      *    INITIALIZE LOCAL AND OUTPUT VARIABLES          *
      *****************************************************
           INITIALIZE WS-4755-LOCAL
           INITIALIZE WS-4755-OUTPUT

      *****************************************************
      *            SET UP DISPLAY FIELDS                  *
      *****************************************************
           MOVE WS-4755-DOLLAR-AMT-INS
             TO WS-4755-DOLLAR-AMT-INS-X
           MOVE WS-4755-GUAR-REDUCTION-FCTR
             TO WS-4755-GUAR-REDUCTION-FCTR-X
           MOVE WS-4755-INS-SHARE
             TO WS-4755-INS-SHARE-X
           MOVE WS-4755-INPUT-STAGE-GPA
             TO WS-4755-INPUT-STAGE-GPA-X
           MOVE WS-4755-CROP-MAX-REPLANT-GPA
             TO WS-4755-CROP-MAX-REPLANT-GPA-X
           MOVE WS-4755-YIELD TO WS-4755-YIELD-X
           MOVE WS-4755-RA-COVERAGE-LEVEL
             TO WS-4755-RA-COVERAGE-LEVEL-X
           MOVE WS-4755-ACRES TO WS-4755-ACRES-X
           MOVE WS-4755-LIABILITY-ADJ-FCTR
             TO WS-4755-LIABILITY-ADJ-FCTR-X

      $IF DEBUG-SW DEFINED
           DISPLAY 'DOLLAR AMT INS       = ',
           WS-4755-DOLLAR-AMT-INS-X UPON CONSOLE
           DISPLAY 'GUARANTEE RED PCT    = ',
           WS-4755-GUAR-REDUCTION-FCTR-X UPON CONSOLE
           DISPLAY 'INSURED SHARE        = ',
           WS-4755-INS-SHARE-X UPON CONSOLE
           DISPLAY 'INPUT STAGE GPA      = ',
           WS-4755-INPUT-STAGE-GPA-X UPON CONSOLE
           DISPLAY 'CROP MAX REPLANT GPA = ',
           WS-4755-CROP-MAX-REPLANT-GPA-X UPON CONSOLE
           DISPLAY 'YIELD                = ',
           WS-4755-YIELD-X UPON CONSOLE
           DISPLAY 'RA COVERAGE LEVEL    = ',
           WS-4755-RA-COVERAGE-LEVEL-X UPON CONSOLE
           DISPLAY 'ACRES                = ',
           WS-4755-ACRES-X UPON CONSOLE
           DISPLAY 'LIABILITY ADJ FCTR   = ',
           WS-4755-LIABILITY-ADJ-FCTR-X UPON CONSOLE
      $END

      *****************************************************
      *    CHECK PRE-CONDITIONS                           *
      *****************************************************
           IF WS-4755-STAGE-CD = SPACES
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-4755-CALC-ERROR
              MOVE 'WS-4755-STAGE-CD' TO WS-8000-FIELD-NAME1
              MOVE SPACES TO WS-8000-BAD-DATA1
              MOVE 'NOT BLANK' TO WS-8000-CORR-DATA1
              MOVE 4755 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-4755-DOLLAR-AMT-INS = ZEROS
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-4755-CALC-ERROR
              MOVE 'WS-4755-DOLLAR-AMT-INS' TO WS-8000-FIELD-NAME1
              MOVE ZERO TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 4755 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-4755-INS-SHARE = ZEROS
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-4755-CALC-ERROR
              MOVE 'WS-4755-INS-SHARE' TO WS-8000-FIELD-NAME1
              MOVE ZERO TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 4755 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-4755-CROP-UNIT-OF-MEASURE = ZERO
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 044 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-4755-CALC-ERROR
              MOVE 'WS-4755-CROP-UM' TO WS-8000-FIELD-NAME1
              MOVE ZERO TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 4755 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-4755-INPUT-STAGE-GPA = ZEROS
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-4755-CALC-ERROR
              MOVE 'WS-4755-INPUT-STAGE-GPA' TO WS-8000-FIELD-NAME1
              MOVE ZERO TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 4755 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

      *    *** WS-4755-CROP-MAX-REPLANT-GPA CAN = ZERO

           IF WS-4755-YIELD = ZEROS
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-4755-CALC-ERROR
              MOVE 'WS-4755-YIELD' TO WS-8000-FIELD-NAME1
              MOVE ZERO TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 4755 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-4755-RA-COVERAGE-LEVEL = ZEROS
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-4755-CALC-ERROR
              MOVE 'WS-4755-RA-COVERAGE-LEVEL'
                TO WS-8000-FIELD-NAME1
              MOVE ZERO TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 4755 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-4755-ACRES = ZEROS
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-4755-CALC-ERROR
              MOVE 'WS-4755-ACRES' TO WS-8000-FIELD-NAME1
              MOVE ZERO TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 4755 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-4755-LIABILITY-ADJ-FCTR = ZEROS
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-4755-CALC-ERROR
              MOVE 'WS-4755-LIABILITY-ADJ-FCTR'
                TO WS-8000-FIELD-NAME1
              MOVE ZERO TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 4755 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-4755-CALC-ERROR = WS-LITERAL-YES
              GO TO 4755-CALC-RA-LOSSG-EXIT
           END-IF

      *    *** WS-4755-GUAR-REDUCTION-FCTR CAN = ZEROS
      *    *** IF ZEROS DEFAULT TO 1.00 FOR CALCULATION
           IF WS-4755-GUAR-REDUCTION-FCTR = ZEROS
              MOVE 1.00 TO WS-4755-GUAR-REDUCTION-FCTR
           END-IF

      *****************************************************
      *    PERFORM CALCULATIONS                           *
      *****************************************************
           IF WS-4755-STAGE-CD = WS-LITERAL-REPLANTED
              PERFORM 4755-CALC-REPLANT-LOSSG
                 THRU 4755-CALC-REPLANT-LOSSG-EXIT
           ELSE
              PERFORM 4755-CALC-INDEM-LOSSG
                 THRU 4755-CALC-INDEM-LOSSG-EXIT
           END-IF.

       4755-CALC-RA-LOSSG-EXIT.
           EXIT.

       4755-CALC-REPLANT-LOSSG.

      $IF DEBUG-SW DEFINED
           DISPLAY '4755-CALCULATING RA REPLANT GUARANTEE'
           UPON CONSOLE
      $END

      *****************************************************
      *    CALCULATE 100% REPLANT GPA                     *
      *****************************************************
           COMPUTE WS-4755-100-PCT-PREMIUM-GPA ROUNDED =
              WS-4755-YIELD * WS-4755-RA-COVERAGE-LEVEL
              ON SIZE ERROR
                 MOVE 4755 TO WS-8020-PARAGRAPH-NO
                 MOVE 90017 TO WS-8020-INT-ERROR-NO
                 MOVE '100% PGPA' TO WS-8020-FIELD-NAME
                 MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                 PERFORM 8020-RECORD-INT-ERROR
                    THRU 8020-RECORD-INT-ERROR-EXIT
           END-COMPUTE

           COMPUTE WS-4755-100-PCT-TOTAL-GPA ROUNDED =
              WS-4755-100-PCT-PREMIUM-GPA * WS-4755-GUAR-REDUCTION-FCTR
              ON SIZE ERROR
                 MOVE 4755 TO WS-8020-PARAGRAPH-NO
                 MOVE 90017 TO WS-8020-INT-ERROR-NO
                 MOVE '100% GPA' TO WS-8020-FIELD-NAME
                 MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                 PERFORM 8020-RECORD-INT-ERROR
                    THRU 8020-RECORD-INT-ERROR-EXIT
           END-COMPUTE

      *    *** COMPUTE 20% GUARANTEE PER ACRE
           COMPUTE WS-4755-MAX-STAGE-GPA ROUNDED =
              WS-4755-100-PCT-TOTAL-GPA * 0.20 * WS-4755-INS-SHARE
              ON SIZE ERROR
                 MOVE 4755 TO WS-8020-PARAGRAPH-NO
                 MOVE 90017 TO WS-8020-INT-ERROR-NO
                 MOVE '0.2 * GPA' TO WS-8020-FIELD-NAME
                 MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                 PERFORM 8020-RECORD-INT-ERROR
                    THRU 8020-RECORD-INT-ERROR-EXIT
           END-COMPUTE

      *****************************************************
      *    DISPLAY GUARANTEE PER ACRE RESULTS             *
      *****************************************************
           MOVE WS-4755-100-PCT-PREMIUM-GPA
             TO WS-4755-100-PCT-PREMIUM-GPA-X
           MOVE WS-4755-100-PCT-TOTAL-GPA
             TO WS-4755-100-PCT-TOTAL-GPA-X
           MOVE WS-4755-MAX-STAGE-GPA
             TO WS-4755-STAGE-GPA
           MOVE WS-4755-STAGE-GPA
             TO WS-4755-STAGE-GPA-X

      $IF DEBUG-SW DEFINED
           DISPLAY '100% PREMIUM GPA      = ',
           WS-4755-100-PCT-PREMIUM-GPA-X UPON CONSOLE
           DISPLAY '100% TOTAL GPA        = ',
           WS-4755-100-PCT-TOTAL-GPA-X UPON CONSOLE
           DISPLAY '20% GPA * INS SHARE   = ',
           WS-4755-STAGE-GPA-X UPON CONSOLE
      $END

      *****************************************************
      *    DETERMINE THE CORRECT MAX STAGE GPA            *
      *****************************************************
           IF (WS-4755-STAGE-GPA >
              (WS-4755-CROP-MAX-REPLANT-GPA * WS-4755-INS-SHARE))
              COMPUTE WS-4755-MAX-STAGE-GPA ROUNDED =
                 WS-4755-CROP-MAX-REPLANT-GPA * WS-4755-INS-SHARE
                 ON SIZE ERROR
                    MOVE 4755 TO WS-8020-PARAGRAPH-NO
                    MOVE 90017 TO WS-8020-INT-ERROR-NO
                    MOVE 'CROP MAX * SHARE' TO WS-8020-FIELD-NAME
                    MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                    PERFORM 8020-RECORD-INT-ERROR
                       THRU 8020-RECORD-INT-ERROR-EXIT
              END-COMPUTE
              MOVE WS-4755-MAX-STAGE-GPA
                TO WS-4755-STAGE-GPA
              MOVE WS-4755-STAGE-GPA
                TO WS-4755-STAGE-GPA-X
           END-IF

      $IF DEBUG-SW DEFINED
           DISPLAY 'MAX REPLANT STAGE GPA = ',
           WS-4755-STAGE-GPA-X UPON CONSOLE
      $END

      *****************************************************
      *    CALCULATE REPLANT LOSS GUARANTEE               *
      *****************************************************
           COMPUTE WS-4755-REPLANT-LOSS-GUAR ROUNDED =
              WS-4755-INPUT-STAGE-GPA * WS-4755-ACRES
              * WS-4755-LIABILITY-ADJ-FCTR
              ON SIZE ERROR
                 MOVE 4755 TO WS-8020-PARAGRAPH-NO
                 MOVE 90017 TO WS-8020-INT-ERROR-NO
                 MOVE 'REPLANT LOSSG' TO WS-8020-FIELD-NAME
                 MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                 PERFORM 8020-RECORD-INT-ERROR
                    THRU 8020-RECORD-INT-ERROR-EXIT
           END-COMPUTE

           MOVE WS-4755-REPLANT-LOSS-GUAR
             TO WS-4755-LOSS-GUARANTEE.

      *****************************************************
      *    DISPLAY REPLANT LOSS GUARANTEE RESULTS         *
      *****************************************************
      $IF DEBUG-SW DEFINED
           MOVE WS-4755-LOSS-GUARANTEE
             TO WS-4755-LOSS-GUARANTEE-X
           DISPLAY 'REPLANT LOSS GUARANTEE = ',
           WS-4755-LOSS-GUARANTEE-X UPON CONSOLE.
      $END

       4755-CALC-REPLANT-LOSSG-EXIT.
           EXIT.

      *==============================================================*
      *    NORMAL INDEMNITY LOSS GUARANTEE CALCULATION               *
      *==============================================================*

       4755-CALC-INDEM-LOSSG.

      $IF DEBUG-SW DEFINED
           DISPLAY '4755-CALCULATING RA INDEMNITY LOSS GUARANTEE'
           UPON CONSOLE
      $END

      *****************************************************
      *    CALCULATE GUARANTEE PER ACRE                   *
      *****************************************************
           COMPUTE WS-4755-PREMIUM-GPA ROUNDED =
              WS-4755-DOLLAR-AMT-INS * WS-4755-INS-SHARE
              ON SIZE ERROR
                 MOVE 4755 TO WS-8020-PARAGRAPH-NO
                 MOVE 90017 TO WS-8020-INT-ERROR-NO
                 MOVE 'PREM GPA' TO WS-8020-FIELD-NAME
                 MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                 PERFORM 8020-RECORD-INT-ERROR
                    THRU 8020-RECORD-INT-ERROR-EXIT
           END-COMPUTE
           COMPUTE WS-4755-GUARANTEE-PER-ACRE ROUNDED =
              WS-4755-PREMIUM-GPA * WS-4755-GUAR-REDUCTION-FCTR
              ON SIZE ERROR
                 MOVE 4755 TO WS-8020-PARAGRAPH-NO
                 MOVE 90017 TO WS-8020-INT-ERROR-NO
                 MOVE 'PREM GPA' TO WS-8020-FIELD-NAME
                 MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                 PERFORM 8020-RECORD-INT-ERROR
                    THRU 8020-RECORD-INT-ERROR-EXIT
           END-COMPUTE
           MOVE WS-4755-GUARANTEE-PER-ACRE
             TO WS-4755-STAGE-GPA

      *****************************************************
      *    DISPLAY GUARANTEE PER ACRE RESULTS             *
      *****************************************************
           MOVE WS-4755-PREMIUM-GPA TO WS-4755-PREMIUM-GPA-X
           MOVE WS-4755-GUARANTEE-PER-ACRE
             TO WS-4755-GUARANTEE-PER-ACRE-X
           MOVE WS-4755-STAGE-GPA TO WS-4755-STAGE-GPA-X
      $IF DEBUG-SW DEFINED
           DISPLAY 'PREMIUM GPA        = ',
           WS-4755-PREMIUM-GPA-X UPON CONSOLE
           DISPLAY 'GUARANTEE PER ACRE = ',
           WS-4755-GUARANTEE-PER-ACRE-X UPON CONSOLE
           DISPLAY 'STAGE GPA          = ',
           WS-4755-STAGE-GPA-X UPON CONSOLE
      $END

      *****************************************************
      *    CALCULATE INDEMNITY LOSS GUARANTEE             *
      *****************************************************
           COMPUTE WS-4755-INDEMNITY-LOSS-GUAR ROUNDED =
              WS-4755-STAGE-GPA * WS-4755-ACRES
              * WS-4755-LIABILITY-ADJ-FCTR
              ON SIZE ERROR
                 MOVE 4755 TO WS-8020-PARAGRAPH-NO
                 MOVE 90017 TO WS-8020-INT-ERROR-NO
                 MOVE 'LOSSG' TO WS-8020-FIELD-NAME
                 MOVE WS-4755-INDEMNITY-LOSS-GUAR
                   TO WS-8020-BAD-DATA
                 MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                 PERFORM 8020-RECORD-INT-ERROR
                    THRU 8020-RECORD-INT-ERROR-EXIT
           END-COMPUTE

           MOVE WS-4755-INDEMNITY-LOSS-GUAR
             TO WS-4755-LOSS-GUARANTEE.

      *****************************************************
      *    DISPLAY INDEMNITY LOSS GUARANTEE RESULTS       *
      *****************************************************
      $IF DEBUG-SW DEFINED
           MOVE WS-4755-LOSS-GUARANTEE
             TO WS-4755-LOSS-GUARANTEE-X
           DISPLAY 'LOSS GUARANTEE = ',
           WS-4755-LOSS-GUARANTEE-X UPON CONSOLE.
      $END

       4755-CALC-INDEM-LOSSG-EXIT.
           EXIT.

