      ***************************************************************
      * File:      IF4835.CBL
      * Author:    Mike Ray
      * Date:      05/23/97
      * Purpose:   Calculates Farm Unit Deficiency and Indemnity
      *            for both Normal Indemnity and Replant Payments
      *            for Guarantee Tobacco.
      ***************************************************************

       4835-CALC-GTOBACCO-INDEM.

      $IF DEBUG-SW DEFINED
           DISPLAY '4835-CALCULATING GUARANTEE TOBACCO INDEMNITY'
           UPON CONSOLE
      $END

      *****************************************************
      *    INITIALIZE LOCAL AND OUTPUT VARIABLES          *
      *****************************************************
           INITIALIZE WS-4835-LOCAL
           INITIALIZE WS-4835-OUTPUT

      *****************************************************
      *            SET UP DISPLAY FIELDS                  *
      *****************************************************
           MOVE WS-4835-LOSS-GUARANTEE
             TO WS-4835-LOSS-GUARANTEE-X
           MOVE WS-4835-PROD-TO-COUNT
             TO WS-4835-PROD-TO-COUNT-X
           MOVE WS-4835-INPUT-FARM-UNIT-DEF
             TO WS-4835-INPUT-FARM-UNIT-DEF-X
           MOVE WS-4835-INSURED-SHARE
             TO WS-4835-INSURED-SHARE-X
           MOVE WS-4835-PRICE-ELECTION
             TO WS-4835-PRICE-ELECTION-X

      $IF DEBUG-SW DEFINED
           DISPLAY 'LOSS GUARANTEE       = ',
           WS-4835-LOSS-GUARANTEE-X UPON CONSOLE
           DISPLAY 'PRODUCTION TO COUNT  = ',
           WS-4835-PROD-TO-COUNT-X UPON CONSOLE
           DISPLAY 'INPUT FARM UNIT DEF  = ',
           WS-4835-INPUT-FARM-UNIT-DEF-X UPON CONSOLE
           DISPLAY 'INSURED SHARE        = ',
           WS-4835-INSURED-SHARE-X UPON CONSOLE
           DISPLAY 'PRICE ELECTION       = ',
           WS-4835-PRICE-ELECTION-X UPON CONSOLE
      $END

      *****************************************************
      *    CHECK PRE-CONDITIONS                           *
      *****************************************************
      *    *** REPLANTING NOT AVAILABLE FOR THESE CROPS ***
           IF WS-4835-STAGE-CD = WS-LITERAL-REPLANTED
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 044 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-4835-CALC-ERROR
              MOVE 'WS-4835-STAGE-CD' TO WS-8000-FIELD-NAME1
              MOVE WS-4835-STAGE-CD TO WS-8000-BAD-DATA1
              MOVE 'NOT REPLANT' TO WS-8000-CORR-DATA1
              MOVE 4835 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-4835-CROP-UNIT-OF-MEASURE = ZEROS
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-4835-CALC-ERROR
              MOVE 'WS-4835-CROP-UM' TO WS-8000-FIELD-NAME1
              MOVE ZERO TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 4835 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-4835-LOSS-GUARANTEE = ZEROS
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-4835-CALC-ERROR
              MOVE 'WS-4835-LOSS-GUARANTEE'
                TO WS-8000-FIELD-NAME1
              MOVE ZERO TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 4835 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

      *    *** WS-4835-PROD-TO-COUNT CAN = ZERO ***

      *    *** WS-4835-INPUT-FARM-UNIT-DEF CAN BE +/- 0 ***

           IF WS-4835-INSURED-SHARE = ZEROS
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-4835-CALC-ERROR
              MOVE 'WS-4835-INSURED-SHARE'
                TO WS-8000-FIELD-NAME1
              MOVE ZERO TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 4835 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-4835-PRICE-ELECTION = ZEROS
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-4835-CALC-ERROR
              MOVE 'WS-4835-PRICE-ELECTION'
                TO WS-8000-FIELD-NAME1
              MOVE ZERO TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 4835 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-4835-CALC-ERROR = WS-LITERAL-YES
              GO TO 4835-CALC-GTOBACCO-INDEM-EXIT
           END-IF

      *****************************************************
      *    PERFORM CALCULATIONS                           *
      *****************************************************
           PERFORM 4835-CALC-INDEMNITY
              THRU 4835-CALC-INDEMNITY-EXIT.


       4835-CALC-GTOBACCO-INDEM-EXIT.
           EXIT.


      *==============================================================*
      *    NORMAL INDEMNITY CALCULATION                              *
      *==============================================================*

       4835-CALC-INDEMNITY.

      $IF DEBUG-SW DEFINED
           DISPLAY '4835-CALCULATING GUARANTEE TOBACCO INDEMNITY'
           UPON CONSOLE
      $END

      *****************************************************
      *    CALCULATE FARM UNIT DEFICIENCY                 *
      *****************************************************
           COMPUTE WS-4835-FARM-UNIT-DEF-LBS ROUNDED =
              WS-4835-LOSS-GUARANTEE - WS-4835-PROD-TO-COUNT
              ON SIZE ERROR
                 MOVE 4835 TO WS-8020-PARAGRAPH-NO
                 MOVE 90017 TO WS-8020-INT-ERROR-NO
                 MOVE 'FARM UNIT DEF' TO WS-8020-FIELD-NAME
                 MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                 PERFORM 8020-RECORD-INT-ERROR
                    THRU 8020-RECORD-INT-ERROR-EXIT
           END-COMPUTE
           MOVE WS-4835-FARM-UNIT-DEF-LBS
             TO WS-4835-FARM-UNIT-DEF

      *****************************************************
      *    DISPLAY FARM UNIT DEFICIENCY RESULTS           *
      *****************************************************
      $IF DEBUG-SW DEFINED
           MOVE WS-4835-FARM-UNIT-DEF
             TO WS-4835-FARM-UNIT-DEF-X
           DISPLAY 'CALC FARM UNIT DEF   = ',
           WS-4835-FARM-UNIT-DEF-X UPON CONSOLE
      $END

      *****************************************************
      *    CALCULATE INDEMNITY                            *
      *****************************************************
           COMPUTE WS-4835-INDEMNITY ROUNDED =
              WS-4835-INPUT-FARM-UNIT-DEF *
              WS-4835-PRICE-ELECTION *
              WS-4835-INSURED-SHARE
              ON SIZE ERROR
                 MOVE 4835 TO WS-8020-PARAGRAPH-NO
                 MOVE 90017 TO WS-8020-INT-ERROR-NO
                 MOVE 'INDEMNITY' TO WS-8020-FIELD-NAME
                 MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                 PERFORM 8020-RECORD-INT-ERROR
                    THRU 8020-RECORD-INT-ERROR-EXIT
           END-COMPUTE.

      *****************************************************
      *    DISPLAY INDEMNITY RESULTS                      *
      *****************************************************
      $IF DEBUG-SW DEFINED
           MOVE WS-4835-INDEMNITY
             TO WS-4835-INDEMNITY-X
           DISPLAY 'INDEMNITY            = ',
           WS-4835-INDEMNITY-X UPON CONSOLE.
      $END

       4835-CALC-INDEMNITY-EXIT.
           EXIT.

