      ***************************************************************
      * File:      IF4860.CBL
      * Author:    Mike Ray
      * Date:      05/23/97
      * Purpose:   Calculates Farm Unit Deficiency and Indemnity
      *            for both Normal Indemnity and Replant Payments
      *            for income Protection Crops.
      ***************************************************************

       4860-CALC-IP-INDEM.

      $IF DEBUG-SW DEFINED
           DISPLAY '4860-CALCULATING INCOME PROTECTION INDEMNITY'
           UPON CONSOLE
      $END

      *****************************************************
      *    INITIALIZE LOCAL AND OUTPUT VARIABLES          *
      *****************************************************
           INITIALIZE WS-4860-LOCAL
           INITIALIZE WS-4860-OUTPUT

      *****************************************************
      *            SET UP DISPLAY FIELDS                  *
      *****************************************************
           MOVE WS-4860-LOSS-GUARANTEE
             TO WS-4860-LOSS-GUARANTEE-X
           MOVE WS-4860-PROD-TO-COUNT
             TO WS-4860-PROD-TO-COUNT-X
           MOVE WS-4860-INPUT-FARM-UNIT-DEF
             TO WS-4860-INPUT-FARM-UNIT-DEF-X
           MOVE WS-4860-INSURED-SHARE
             TO WS-4860-INSURED-SHARE-X

      $IF DEBUG-SW DEFINED
           DISPLAY 'LOSS GUARANTEE       = ',
           WS-4860-LOSS-GUARANTEE-X UPON CONSOLE
           DISPLAY 'PRODUCTION TO COUNT  = ',
           WS-4860-PROD-TO-COUNT-X UPON CONSOLE
           DISPLAY 'INPUT FARM UNIT DEF  = ',
           WS-4860-INPUT-FARM-UNIT-DEF-X UPON CONSOLE
           DISPLAY 'INSURED SHARE        = ',
           WS-4860-INSURED-SHARE-X UPON CONSOLE
      $END

      *****************************************************
      *    CHECK PRE-CONDITIONS                           *
      *****************************************************
           IF WS-4860-STAGE-CD = SPACES
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-4860-CALC-ERROR
              MOVE 'WS-4860-STAGE-CD' TO WS-8000-FIELD-NAME1
              MOVE SPACES TO WS-8000-BAD-DATA1
              MOVE 'NOT BLANK' TO WS-8000-CORR-DATA1
              MOVE 4860 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-4860-CROP-UNIT-OF-MEASURE = ZEROS
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-4860-CALC-ERROR
              MOVE 'WS-4860-CROP-UM' TO WS-8000-FIELD-NAME1
              MOVE ZERO TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 4860 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-4860-LOSS-GUARANTEE = ZEROS
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-4860-CALC-ERROR
              MOVE 'WS-4860-LOSS-GUARANTEE'
                TO WS-8000-FIELD-NAME1
              MOVE ZERO TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 4860 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

      *    *** WS-4860-PROD-TO-COUNT CAN = ZERO ***

      *    *** WS-4860-INPUT-FARM-UNIT-DEF CAN BE +/- 0 ***

           IF WS-4860-INSURED-SHARE = ZEROS
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-4860-CALC-ERROR
              MOVE 'WS-4860-INSURED-SHARE'
                TO WS-8000-FIELD-NAME1
              MOVE ZERO TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 4860 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF


           IF WS-4860-CALC-ERROR = WS-LITERAL-YES
              GO TO 4860-CALC-IP-INDEM-EXIT
           END-IF

      *****************************************************
      *    PERFORM CALCULATIONS                           *
      *****************************************************
           IF WS-4860-STAGE-CD = WS-LITERAL-REPLANTED
              PERFORM 4860-CALC-REPLANT-PAYMENT
                 THRU 4860-CALC-REPLANT-PAYMENT-EXIT
           ELSE
              PERFORM 4860-CALC-INDEMNITY
                 THRU 4860-CALC-INDEMNITY-EXIT
           END-IF.


       4860-CALC-IP-INDEM-EXIT.
           EXIT.


      *==============================================================*
      *    NORMAL INDEMNITY CALCULATION                              *
      *==============================================================*

       4860-CALC-INDEMNITY.

      $IF DEBUG-SW DEFINED
           DISPLAY '4860-CALCULATING INCOME PROTECTION INDEMNITY'
           UPON CONSOLE
      $END

      *****************************************************
      *    CALCULATE FARM UNIT DEFICIENCY                 *
      *****************************************************
           COMPUTE WS-4860-FARM-UNIT-DEF-LBS ROUNDED =
              WS-4860-LOSS-GUARANTEE - WS-4860-PROD-TO-COUNT
              ON SIZE ERROR
                 MOVE 4860 TO WS-8020-PARAGRAPH-NO
                 MOVE 90017 TO WS-8020-INT-ERROR-NO
                 MOVE 'FARM UNIT DEF' TO WS-8020-FIELD-NAME
                 MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                 PERFORM 8020-RECORD-INT-ERROR
                    THRU 8020-RECORD-INT-ERROR-EXIT
           END-COMPUTE
           MOVE WS-4860-FARM-UNIT-DEF-LBS
             TO WS-4860-FARM-UNIT-DEF

      *****************************************************
      *    DISPLAY FARM UNIT DEFICIENCY RESULTS           *
      *****************************************************
      $IF DEBUG-SW DEFINED
           MOVE WS-4860-FARM-UNIT-DEF
             TO WS-4860-FARM-UNIT-DEF-X
           DISPLAY 'CALC FARM UNIT DEF   = ',
           WS-4860-FARM-UNIT-DEF-X UPON CONSOLE
      $END

      *****************************************************
      *    CALCULATE INDEMNITY                            *
      *****************************************************
           MOVE WS-4860-INPUT-FARM-UNIT-DEF
             TO WS-4860-INDEMNITY.

      *****************************************************
      *    DISPLAY INDEMNITY RESULTS                      *
      *****************************************************
      $IF DEBUG-SW DEFINED
           MOVE WS-4860-INDEMNITY
             TO WS-4860-INDEMNITY-X
           DISPLAY 'INDEMNITY            = ',
           WS-4860-INDEMNITY-X UPON CONSOLE.
      $END

       4860-CALC-INDEMNITY-EXIT.
           EXIT.



      *==============================================================*
      *    REPLANT PAYMENT CALCULATION                               *
      *==============================================================*

       4860-CALC-REPLANT-PAYMENT.

      $IF DEBUG-SW DEFINED
           DISPLAY '4860-CALCULATING IP REPLANT PAYMENT'
           UPON CONSOLE
      $END

      *****************************************************
      *    CALCULATE FARM UNIT DEFICIENCY                 *
      *****************************************************
           MOVE WS-4860-LOSS-GUARANTEE
             TO WS-4860-FARM-UNIT-DEF

      *****************************************************
      *    DISPLAY FARM UNIT DEFICIENCY RESULTS           *
      *****************************************************
      $IF DEBUG-SW DEFINED
           MOVE WS-4860-FARM-UNIT-DEF
             TO WS-4860-FARM-UNIT-DEF-X
           DISPLAY 'CALC FARM UNIT DEF   = ',
           WS-4860-FARM-UNIT-DEF-X UPON CONSOLE
      $END

      *****************************************************
      *    CALCULATE REPLANT PAYMENT                      *
      *****************************************************
           COMPUTE WS-4860-INDEMNITY ROUNDED =
              WS-4860-INPUT-FARM-UNIT-DEF *
              WS-4860-INSURED-SHARE

      *******************************************************
              * WS-2630-PRICE-ELECTION

      *******************************************************

              ON SIZE ERROR
                 MOVE 4860 TO WS-8020-PARAGRAPH-NO
                 MOVE 90017 TO WS-8020-INT-ERROR-NO
                 MOVE 'REPLANT PAYMENT' TO WS-8020-FIELD-NAME
                 MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                 PERFORM 8020-RECORD-INT-ERROR
                    THRU 8020-RECORD-INT-ERROR-EXIT
           END-COMPUTE.

      *****************************************************
      *    DISPLAY REPLANT PAYMENT RESULTS                *
      *****************************************************
      $IF DEBUG-SW DEFINED
           MOVE WS-4860-INDEMNITY
             TO WS-4860-INDEMNITY-X
           DISPLAY 'REPLANT PAYMENT      = ',
           WS-4860-INDEMNITY-X UPON CONSOLE.
      $END


       4860-CALC-REPLANT-PAYMENT-EXIT.
           EXIT.


