      *************************************************************
      * File:      M0987.CBL
      * Author:    Mike Ray
      * Date:      04/02/97
      * Purpose:   Searches the policy statistics file for an
      *            existing record and then updates it.  If no
      *            record is found, a new one is created.
      *************************************************************

       0987-WRITE-POL-STATS-REC.

      $IF DEBUG-SW DEFINED
           DISPLAY '0987-WRITING POLICY STATS RECORD'
           UPON CONSOLE
      $END

      ************************************************
      *     INITIALIZE LOCAL WORKING STORAGE         *
      ************************************************
           INITIALIZE WS-0987-WORK

      ************************************************
      *             CHECK INPUT FIELDS               *
      ************************************************
      $IF DEBUG-SW DEFINED
           DISPLAY 'INPUT POLICY NUMBER = ',
           WS-0987-INPUT-POLICY-NO
           UPON CONSOLE
      $END

           IF WS-0987-INPUT-POLICY-NO = SPACES
              MOVE 0987 TO WS-8020-PARAGRAPH-NO
              MOVE 90003 TO WS-8020-INT-ERROR-NO
              MOVE 'POLICY NO' TO WS-8020-FIELD-NAME
              MOVE SPACES TO WS-8020-BAD-DATA
              MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
              PERFORM 8020-RECORD-INT-ERROR
                 THRU 8020-RECORD-INT-ERROR-EXIT
           END-IF

           IF WS-0987-INPUT-BATCH-NO IS NOT NUMERIC
              MOVE 0987 TO WS-8020-PARAGRAPH-NO
              MOVE 90001 TO WS-8020-INT-ERROR-NO
              MOVE 'WS-0987-BATCH-NO' TO WS-8020-FIELD-NAME
              MOVE WS-0987-INPUT-BATCH-NO TO WS-8020-BAD-DATA
              MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
              PERFORM 8020-RECORD-INT-ERROR
                 THRU 8020-RECORD-INT-ERROR-EXIT
           END-IF

           IF WS-0987-INPUT-BATCH-NO = ZEROS
              MOVE 0987 TO WS-8020-PARAGRAPH-NO
              MOVE 90003 TO WS-8020-INT-ERROR-NO
              MOVE 'WS-0987-BATCH-NO' TO WS-8020-FIELD-NAME
              MOVE WS-0987-INPUT-BATCH-NO TO WS-8020-BAD-DATA
              MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
              PERFORM 8020-RECORD-INT-ERROR
                 THRU 8020-RECORD-INT-ERROR-EXIT
           END-IF

           IF WS-0987-INPUT-FCIC-DATE IS NOT NUMERIC
              MOVE 0987 TO WS-8020-PARAGRAPH-NO
              MOVE 90001 TO WS-8020-INT-ERROR-NO
              MOVE 'WS-0987-FCIC-CONTROL-DATE' TO WS-8020-FIELD-NAME
              MOVE WS-0987-INPUT-FCIC-DATE TO WS-8020-BAD-DATA
              MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
              PERFORM 8020-RECORD-INT-ERROR
                 THRU 8020-RECORD-INT-ERROR-EXIT
           END-IF

           IF WS-0987-INPUT-FCIC-DATE = ZEROS
              MOVE 0987 TO WS-8020-PARAGRAPH-NO
              MOVE 90003 TO WS-8020-INT-ERROR-NO
              MOVE 'WS-0987-FCIC-CONTROL-DATE' TO WS-8020-FIELD-NAME
              MOVE WS-0987-INPUT-FCIC-DATE TO WS-8020-BAD-DATA
              MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
              PERFORM 8020-RECORD-INT-ERROR
                 THRU 8020-RECORD-INT-ERROR-EXIT
           END-IF

      ************************************************
      *         SEARCH FOR POLICY STATS RECORD       *
      ************************************************
           MOVE WS-LITERAL-NO TO WS-0987-MATCH-FOUND

           IF PSTATS-FILE-OPEN
              MOVE WS-0987-INPUT-POLICY-NO TO PSTATS-KEY
              READ POLICY-STATS-FILE
                 INVALID KEY
                    MOVE WS-LITERAL-NO TO WS-0987-MATCH-FOUND
                 NOT INVALID KEY
                    MOVE POLICY-STATS-RECORD TO WS-0987-ISAM-PSTATS
                    MOVE WS-LITERAL-YES TO WS-0987-MATCH-FOUND
              END-READ
           ELSE
              MOVE 0987 TO WS-8020-PARAGRAPH-NO
              MOVE 90013 TO WS-8020-INT-ERROR-NO
              MOVE 'POLICY STATS FILE' TO WS-8020-FIELD-NAME
              MOVE SPACES TO WS-8020-BAD-DATA
              MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
              PERFORM 8020-RECORD-INT-ERROR
                 THRU 8020-RECORD-INT-ERROR-EXIT
           END-IF

      ************************************************
      *    SET UP POLICY STATISTICS RECORD           *
      ************************************************
           MOVE WS-0987-INPUT-POLICY-NO
             TO WS-0987-ISAM-POLICY-NO
           MOVE WS-0987-INPUT-STATS
             TO WS-0987-ISAM-LATEST-STATS
           MOVE WS-LITERAL-NO
             TO WS-0987-ISAM-DELETE-FLAG
           MOVE WS-0987-INPUT-BATCH-NO
             TO WS-0987-ISAM-LATEST-SUB-BATCH
           MOVE WS-0987-INPUT-FCIC-DATE
             TO WS-0987-ISAM-LATEST-SUB-DATE

      ************************************************
      *    WRITE POLICY STATISTICS RECORD            *
      ************************************************

           IF WS-0987-MATCH-FOUND = WS-LITERAL-YES
              REWRITE POLICY-STATS-RECORD FROM WS-0987-ISAM-PSTATS
                 INVALID KEY
                    DISPLAY 'INVALID KEY ERROR - WRITE SKIPPED'
                    UPON CONSOLE
                    DISPLAY 'POLICY STATS KEY: ',
                    WS-0987-INPUT-POLICY-NO UPON CONSOLE
                    MOVE 0987 TO WS-8020-PARAGRAPH-NO
                    MOVE 90030 TO WS-8020-INT-ERROR-NO
                    MOVE 'POLICY STATS KEY' TO WS-8020-FIELD-NAME
                    MOVE WS-0987-INPUT-POLICY-NO TO WS-8020-BAD-DATA
                    MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                    PERFORM 8020-RECORD-INT-ERROR
                       THRU 8020-RECORD-INT-ERROR-EXIT
      $IF DEBUG-SW DEFINED
                 NOT INVALID KEY
                    DISPLAY 'UPDATED POLICY # ', WS-0987-INPUT-POLICY-NO
                    UPON CONSOLE
      $END
              END-REWRITE
           ELSE
      *       *** SET UP FIRST SUBMISSION FIELDS ***
              MOVE WS-0987-INPUT-BATCH-NO
                TO WS-0987-ISAM-FIRST-SUB-BATCH
              MOVE WS-0987-INPUT-FCIC-DATE
                TO WS-0987-ISAM-FIRST-SUB-DATE
              WRITE POLICY-STATS-RECORD FROM WS-0987-ISAM-PSTATS
                 INVALID KEY
                    DISPLAY 'INVALID KEY ERROR - WRITE SKIPPED'
                    UPON CONSOLE
                    DISPLAY 'POLICY STATS KEY: ',
                    WS-0987-INPUT-POLICY-NO UPON CONSOLE
                    MOVE 0987 TO WS-8020-PARAGRAPH-NO
                    MOVE 90029 TO WS-8020-INT-ERROR-NO
                    MOVE 'POLICY STATS KEY' TO WS-8020-FIELD-NAME
                    MOVE WS-0987-INPUT-POLICY-NO TO WS-8020-BAD-DATA
                    MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                    PERFORM 8020-RECORD-INT-ERROR
                       THRU 8020-RECORD-INT-ERROR-EXIT
      $IF DEBUG-SW DEFINED
                 NOT INVALID KEY
                    DISPLAY 'ADDED POLICY # ', WS-0987-INPUT-POLICY-NO
                    UPON CONSOLE
      $END
              END-WRITE
           END-IF

      ************************************************
      *          INITIALIZE INPUT FIELDS             *
      ************************************************
           INITIALIZE WS-0987-INPUT.


       0987-WRITE-POL-STATS-REC-EXIT.
           EXIT.


