      *************************************************************
      * File:      M0988.CBL
      * Author:    Mike Ray
      * Date:      04/03/97
      * Purpose:   Searches the policy statistics file for an
      *            existing record and then sets the delete flag
      *            and updates the batch number and date. If not
      *            found returns a flag.
      *************************************************************

       0988-DELETE-POL-STATS-REC.

      $IF DEBUG-SW DEFINED
           DISPLAY '0988-WRITING POLICY STATS RECORD'
           UPON CONSOLE
      $END

      ************************************************
      *  INITIALIZE LOCAL & OUTPUT WORKING STORAGE   *
      ************************************************
           INITIALIZE WS-0988-WORK
           INITIALIZE WS-0988-OUTPUT

      ************************************************
      *             CHECK INPUT FIELDS               *
      ************************************************
      $IF DEBUG-SW DEFINED
           DISPLAY 'INPUT POLICY NUMBER = ',
           WS-0988-INPUT-POLICY-NO
           UPON CONSOLE
      $END

           IF WS-0988-INPUT-POLICY-NO = SPACES
              MOVE 0988 TO WS-8020-PARAGRAPH-NO
              MOVE 90003 TO WS-8020-INT-ERROR-NO
              MOVE 'POLICY NO' TO WS-8020-FIELD-NAME
              MOVE SPACES TO WS-8020-BAD-DATA
              MOVE WS-LITERAL-NO TO WS-8020-ABORT-PROGRAM
              PERFORM 8020-RECORD-INT-ERROR
                 THRU 8020-RECORD-INT-ERROR-EXIT
              GO TO 0988-DELETE-POL-STATS-REC-EXIT
           END-IF

           IF WS-0988-INPUT-BATCH-NO IS NOT NUMERIC
              MOVE 0988 TO WS-8020-PARAGRAPH-NO
              MOVE 90001 TO WS-8020-INT-ERROR-NO
              MOVE 'WS-0988-BATCH-NO' TO WS-8020-FIELD-NAME
              MOVE WS-0988-INPUT-BATCH-NO TO WS-8020-BAD-DATA
              MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
              PERFORM 8020-RECORD-INT-ERROR
                 THRU 8020-RECORD-INT-ERROR-EXIT
           END-IF

           IF WS-0988-INPUT-BATCH-NO = ZEROS
              MOVE 0988 TO WS-8020-PARAGRAPH-NO
              MOVE 90003 TO WS-8020-INT-ERROR-NO
              MOVE 'WS-0988-BATCH-NO' TO WS-8020-FIELD-NAME
              MOVE WS-0988-INPUT-BATCH-NO TO WS-8020-BAD-DATA
              MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
              PERFORM 8020-RECORD-INT-ERROR
                 THRU 8020-RECORD-INT-ERROR-EXIT
           END-IF

           IF WS-0988-INPUT-FCIC-DATE IS NOT NUMERIC
              MOVE 0988 TO WS-8020-PARAGRAPH-NO
              MOVE 90001 TO WS-8020-INT-ERROR-NO
              MOVE 'WS-0988-FCIC-CONTROL-DATE' TO WS-8020-FIELD-NAME
              MOVE WS-0988-INPUT-FCIC-DATE TO WS-8020-BAD-DATA
              MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
              PERFORM 8020-RECORD-INT-ERROR
                 THRU 8020-RECORD-INT-ERROR-EXIT
           END-IF

           IF WS-0988-INPUT-FCIC-DATE = ZEROS
              MOVE 0988 TO WS-8020-PARAGRAPH-NO
              MOVE 90003 TO WS-8020-INT-ERROR-NO
              MOVE 'WS-0988-FCIC-CONTROL-DATE' TO WS-8020-FIELD-NAME
              MOVE WS-0988-INPUT-FCIC-DATE TO WS-8020-BAD-DATA
              MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
              PERFORM 8020-RECORD-INT-ERROR
                 THRU 8020-RECORD-INT-ERROR-EXIT
           END-IF

      ************************************************
      *         SEARCH FOR POLICY STATS RECORD       *
      ************************************************
           MOVE WS-LITERAL-NO TO WS-0988-MATCH-FOUND

           IF PSTATS-FILE-OPEN
              MOVE WS-0988-INPUT-POLICY-NO TO PSTATS-KEY
              READ POLICY-STATS-FILE
                 INVALID KEY
                    MOVE WS-LITERAL-NO TO WS-0988-MATCH-FOUND
                    GO TO 0988-DELETE-POL-STATS-REC-EXIT
                 NOT INVALID KEY
                    MOVE POLICY-STATS-RECORD TO WS-0988-ISAM-PSTATS
                    MOVE WS-LITERAL-YES TO WS-0988-MATCH-FOUND
              END-READ
           ELSE
              MOVE 0988 TO WS-8020-PARAGRAPH-NO
              MOVE 90013 TO WS-8020-INT-ERROR-NO
              MOVE 'POLICY STATS FILE' TO WS-8020-FIELD-NAME
              MOVE SPACES TO WS-8020-BAD-DATA
              MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
              PERFORM 8020-RECORD-INT-ERROR
                 THRU 8020-RECORD-INT-ERROR-EXIT
           END-IF

      ************************************************
      *    UPDATE RECORD TO SHOW DELETE              *
      ************************************************
           MOVE WS-LITERAL-YES
             TO WS-0988-ISAM-DELETE-FLAG
           MOVE WS-0988-INPUT-BATCH-NO
             TO WS-0988-ISAM-LATEST-SUB-BATCH
           MOVE WS-0988-INPUT-FCIC-DATE
             TO WS-0988-ISAM-LATEST-SUB-DATE

      $IF DEBUG-SW DEFINED
           PERFORM 0988-DISPLAY-RECORD
              THRU 0988-DISPLAY-RECORD-EXIT
      $END

      ************************************************
      *    UPDATE POLICY STATISTICS RECORD           *
      ************************************************

           REWRITE POLICY-STATS-RECORD FROM WS-0988-ISAM-PSTATS
              INVALID KEY
                 DISPLAY 'INVALID KEY ERROR - WRITE SKIPPED'
                 UPON CONSOLE
                 DISPLAY 'POLICY STATS KEY: ',
                 WS-0988-INPUT-POLICY-NO UPON CONSOLE
                 MOVE 0988 TO WS-8020-PARAGRAPH-NO
                 MOVE 90030 TO WS-8020-INT-ERROR-NO
                 MOVE 'POLICY STATS KEY' TO WS-8020-FIELD-NAME
                 MOVE WS-0988-INPUT-POLICY-NO TO WS-8020-BAD-DATA
                 MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                 PERFORM 8020-RECORD-INT-ERROR
                    THRU 8020-RECORD-INT-ERROR-EXIT
      $IF DEBUG-SW DEFINED
              NOT INVALID KEY
                 DISPLAY 'UPDATED POLICY # ', WS-0988-INPUT-POLICY-NO
                 UPON CONSOLE
      $END
           END-REWRITE

      ************************************************
      *          INITIALIZE INPUT FIELDS             *
      ************************************************
           INITIALIZE WS-0988-INPUT.


       0988-DELETE-POL-STATS-REC-EXIT.
           EXIT.


      $IF DEBUG-SW DEFINED

       0988-DISPLAY-RECORD.

           DISPLAY 'POLICY NUMBER : ', WS-0988-ISAM-POLICY-NO
           UPON CONSOLE
           DISPLAY '-----------------------------------------'
           UPON CONSOLE
           DISPLAY 'DELETE FLAG   : ', WS-0988-ISAM-DELETE-FLAG
           UPON CONSOLE
           DISPLAY 'LATEST SUBMISSION BATCH NO : ',
           WS-0988-ISAM-LATEST-SUB-BATCH UPON CONSOLE
           DISPLAY 'LATEST SUBMISSION DATE     : ',
           WS-0988-ISAM-LATEST-SUB-DATE UPON CONSOLE
           DISPLAY 'FIRST SUBMISSION BATCH NO  : ',
           WS-0988-ISAM-FIRST-SUB-BATCH UPON CONSOLE
           DISPLAY 'FIRST SUBMISSION DATE      : ',
           WS-0988-ISAM-FIRST-SUB-DATE UPON CONSOLE
           DISPLAY '-----------------------------------------'
           UPON CONSOLE
           DISPLAY 'ACCEPTED ACRES         : ',
           WS-0988-ISAM-ACP-ACRES UPON CONSOLE
           DISPLAY 'ACCEPTED LIABILITY     : ',
           WS-0988-ISAM-ACP-LIABILITY UPON CONSOLE
           DISPLAY 'ACCEPTED PREMIUM       : ',
           WS-0988-ISAM-ACP-PREMIUM UPON CONSOLE
           DISPLAY 'ACCEPTED PROD PREMIUM  : ',
           WS-0988-ISAM-ACP-PROD-PREMIUM UPON CONSOLE
           DISPLAY 'ACCEPTED LOSSES        : ',
           WS-0988-ISAM-ACP-LOSSES UPON CONSOLE.

       0988-DISPLAY-RECORD-EXIT.
           EXIT.

      $END
