      ****************************************************************
      * FILE:      FV1540.CBL                                        *
      * AUTHOR:    CHERYL D. WOOD                                    *
      * DATE:      1/11/96                                           *
      * PURPOSE:   VALIDATION FOR PAID DATE  IF THE FIELD IS         *
      *            IF THE FIELD IS POPULATED, THE VALUE MUST BE      *
      *            NUMERIC.  PAID DATE MUST BE A VALID DATE WHICH IS *
      *            < OR = TO THE CURRENT SYSTEM DATE.  THIS LOGIC    *
      *            ASSUMES THAT PAID DATE IS IN FORMAT MMDDYY.       *
      ****************************************************************

       1540-VAL-PAID-DT.

      $IF DEBUG-SW DEFINED
           DISPLAY '1540-VALIDATING PAID DATE'
           UPON CONSOLE
      $END

      **********************************************************
      *    INITIALIZE WORK FIELDS                              *
      **********************************************************
           INITIALIZE WS-1540-WORK
           MOVE WS-0004-SYS-DATE TO WS-1540-SYSTEM-DT

      **********************************************************
      *    CHECK PRE-CONDITIONS                                *
      **********************************************************

           IF WS-1540-SYSTEM-DT IS NOT NUMERIC
              MOVE 1540 TO WS-8020-PARAGRAPH-NO
              MOVE 90001 TO WS-8020-INT-ERROR-NO
              MOVE 'WS-1540-SYSTEM-DT' TO WS-8020-FIELD-NAME
              MOVE WS-1540-SYSTEM-DT TO WS-8020-BAD-DATA
              MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
              PERFORM 8020-RECORD-INT-ERROR
                 THRU 8020-RECORD-INT-ERROR-EXIT
           END-IF

           IF WS-1540-SYSTEM-DT IS EQUAL ZEROS
              MOVE 1540 TO WS-8020-PARAGRAPH-NO
              MOVE 90003 TO WS-8020-INT-ERROR-NO
              MOVE 'WS-1540-SYSTEM-DT' TO WS-8020-FIELD-NAME
              MOVE WS-1540-SYSTEM-DT TO WS-8020-BAD-DATA
              MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
              PERFORM 8020-RECORD-INT-ERROR
                 THRU 8020-RECORD-INT-ERROR-EXIT
           END-IF

           IF WS-1540-PAID-DT NOT NUMERIC
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 002 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-YES TO ERROR-PAID-DT
              MOVE WS-LITERAL-FV TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-PAID-DT TO WS-8000-FIELD-NAME1
              MOVE WS-1540-PAID-DT TO WS-8000-BAD-DATA1
              MOVE 1540 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
              GO TO 1540-VAL-PAID-DT-EXIT
           END-IF


           IF WS-1540-PAID-DT IS EQUAL TO ZEROS
              GO TO 1540-VAL-PAID-DT-EXIT
           END-IF

      **********************************************************
      *    DETERMINE WHETHER PAID DATE IS A VALID DATE IN      *
      *    FORMAT MMDDYY.                                      *
      **********************************************************

           MOVE WS-1540-PAID-DT TO WS-0555-INPUT-DATE
           PERFORM 0555-VAL-MMDDYY-DATE
              THRU 0555-VAL-MMDDYY-DATE-EXIT

           IF BAD-MONTH-0555
              MOVE WS-LITERAL-FV TO WS-8000-ERROR-TYPE
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 010 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-YES TO ERROR-PAID-DT
              MOVE WS-LITERAL-PAID-DT TO WS-8000-FIELD-NAME1
              MOVE WS-1540-PAID-DT TO WS-8000-BAD-DATA1
              MOVE '1 THRU 12' TO WS-8000-CORR-DATA1
              MOVE 1540 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
              GO TO 1540-VAL-PAID-DT-EXIT
           ELSE
              IF BAD-DAY-0555
                 MOVE WS-LITERAL-FV TO WS-8000-ERROR-TYPE
                 MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
                 MOVE 011 TO WS-8000-SHORT-ERROR
                 MOVE WS-LITERAL-YES TO ERROR-PAID-DT
                 MOVE WS-LITERAL-PAID-DT TO WS-8000-FIELD-NAME1
                 MOVE WS-1540-PAID-DT TO WS-8000-BAD-DATA1
                 MOVE SPACES TO WS-8000-CORR-DATA1
                 MOVE 1540 TO WS-8000-PARAGRAPH-NO
                 PERFORM 8000-RECORD-TRAN-ERROR
                    THRU 8000-RECORD-TRAN-ERROR-EXIT
                 GO TO 1540-VAL-PAID-DT-EXIT
              ELSE
                 IF REVERSED-DATE-0555
                    MOVE WS-LITERAL-FV TO WS-8000-ERROR-TYPE
                    MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
                    MOVE 013 TO WS-8000-SHORT-ERROR
                    MOVE WS-LITERAL-YES TO ERROR-PAID-DT
                    MOVE WS-LITERAL-PAID-DT TO WS-8000-FIELD-NAME1
                    MOVE WS-1540-PAID-DT TO WS-8000-BAD-DATA1
                    MOVE SPACES TO WS-8000-CORR-DATA1
                    MOVE 1540 TO WS-8000-PARAGRAPH-NO
                    PERFORM 8000-RECORD-TRAN-ERROR
                       THRU 8000-RECORD-TRAN-ERROR-EXIT
                    GO TO 1540-VAL-PAID-DT-EXIT
                 END-IF
              END-IF
           END-IF.


      **********************************************************
      *   PAID DATE CANNOT BE GREATER THAN THE CURRENT DATE    *
      **********************************************************

           IF WS-1540-PAID-DT = WS-1540-SYSTEM-DT
               GO TO 1540-VAL-PAID-DT-EXIT
           END-IF


           IF WS-1540-PAID-DT-YEAR > WS-1540-SYSTEM-DT-YEAR
              MOVE WS-LITERAL-FV TO WS-8000-ERROR-TYPE
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 011 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-YES TO ERROR-PAID-DT
              MOVE WS-LITERAL-PAID-DT TO WS-8000-FIELD-NAME1
              MOVE WS-1540-PAID-DT TO WS-8000-BAD-DATA1
              MOVE WS-1540-SYSTEM-DT TO WS-8000-CORR-DATA1
              MOVE 1540 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           ELSE
              IF WS-1540-PAID-DT-YEAR = WS-1540-SYSTEM-DT-YEAR
                 IF WS-1540-PAID-DT-MONTH
                    > WS-1540-SYSTEM-DT-MONTH
                    MOVE WS-LITERAL-FV TO WS-8000-ERROR-TYPE
                    MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
                    MOVE 011 TO WS-8000-SHORT-ERROR
                    MOVE WS-LITERAL-YES TO ERROR-PAID-DT
                    MOVE WS-LITERAL-PAID-DT TO WS-8000-FIELD-NAME1
                    MOVE WS-1540-PAID-DT TO WS-8000-BAD-DATA1
                    MOVE WS-1540-SYSTEM-DT TO WS-8000-CORR-DATA1
                    MOVE 1540 TO WS-8000-PARAGRAPH-NO
                    PERFORM 8000-RECORD-TRAN-ERROR
                       THRU 8000-RECORD-TRAN-ERROR-EXIT
                 ELSE
                    IF WS-1540-PAID-DT-MONTH
                       = WS-1540-SYSTEM-DT-MONTH
                       IF WS-1540-PAID-DT-DAY
                          > WS-1540-SYSTEM-DT-DAY
                          MOVE WS-LITERAL-FV TO WS-8000-ERROR-TYPE
                          MOVE WS-TRAN-TYPE
                            TO WS-8000-ERROR-TRAN-TYPE
                          MOVE 011 TO WS-8000-SHORT-ERROR
                          MOVE WS-LITERAL-YES TO ERROR-PAID-DT
                          MOVE WS-LITERAL-PAID-DT
                            TO WS-8000-FIELD-NAME1
                          MOVE WS-1540-PAID-DT TO WS-8000-BAD-DATA1
                          MOVE WS-1540-SYSTEM-DT TO WS-8000-CORR-DATA1
                          MOVE 1540 TO WS-8000-PARAGRAPH-NO
                          PERFORM 8000-RECORD-TRAN-ERROR
                             THRU 8000-RECORD-TRAN-ERROR-EXIT
                       END-IF
                    END-IF
                 END-IF
              END-IF
           END-IF.


       1540-VAL-PAID-DT-EXIT.
           EXIT.
