      ****************************************************************
      * FILE:      FV1605.CBL                                        *
      * AUTHOR:    CHERYL D. WOOD                                    *
      * DATE:      9/22/95                                           *
      * PURPOSE:   VALIDATION FOR DATE DRAFT ISSUED                  *
      *            VALUE MUST BE NUMERIC AND A VALID DATE            *
      *            MUST BE IN MMDDYY FORMAT.  DRAFT ISSUE DATE MUST  *
      *            BE LESS THAN OR EQUAL TO THE CURRENT SYSTEM DATE. *
      ****************************************************************

       1605-VAL-DT-DRAFT-ISSUE.

      $IF DEBUG-SW DEFINED
           DISPLAY '1605-VALIDATING DATE DRAFT ISSUED'
           UPON CONSOLE
      $END

      **********************************************************
      *    INITIALIZE WORK FIELDS                              *
      **********************************************************
           INITIALIZE WS-1605-WORK
           MOVE WS-0004-SYS-DATE TO WS-1605-SYSTEM-DT

      **********************************************************
      *    CHECK PRE-CONDITIONS                                *
      **********************************************************

           IF WS-1605-SYSTEM-DT IS NOT NUMERIC
              MOVE 1605 TO WS-8020-PARAGRAPH-NO
              MOVE 90001 TO WS-8020-INT-ERROR-NO
              MOVE 'WS-1605-SYSTEM-DT' TO WS-8020-FIELD-NAME
              MOVE WS-1605-SYSTEM-DT TO WS-8020-BAD-DATA
              MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
              PERFORM 8020-RECORD-INT-ERROR
                 THRU 8020-RECORD-INT-ERROR-EXIT
           END-IF

           IF WS-1605-SYSTEM-DT IS EQUAL ZEROS
              MOVE 1605 TO WS-8020-PARAGRAPH-NO
              MOVE 90003 TO WS-8020-INT-ERROR-NO
              MOVE 'WS-1605-SYSTEM-DT' TO WS-8020-FIELD-NAME
              MOVE WS-1605-SYSTEM-DT TO WS-8020-BAD-DATA
              MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
              PERFORM 8020-RECORD-INT-ERROR
                 THRU 8020-RECORD-INT-ERROR-EXIT
           END-IF


           IF WS-1605-DRAFT-ISSUE-DT NOT NUMERIC
              MOVE 20002 TO WS-8000-ERROR-CODE
              MOVE WS-LITERAL-YES TO ERROR-DT-DRAFT-ISSUED
              MOVE WS-LITERAL-FV TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-DT-DRAFT-ISSUE TO WS-8000-FIELD-NAME1
              MOVE WS-1605-DRAFT-ISSUE-DT TO WS-8000-BAD-DATA1
              MOVE SPACES TO WS-8000-CORR-DATA1
              MOVE 1605 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
              GO TO 1605-VAL-DT-DRAFT-ISSUE-EXIT
           END-IF

           IF WS-1605-DRAFT-ISSUE-DT EQUAL ZEROS
      *       MOVE 20004 TO WS-8000-ERROR-CODE
      *       MOVE WS-LITERAL-YES TO ERROR-DT-DRAFT-ISSUED
      *       MOVE WS-LITERAL-FV TO WS-8000-ERROR-TYPE
      *       MOVE WS-LITERAL-DT-DRAFT-ISSUE TO WS-8000-FIELD-NAME1
      *       MOVE WS-1605-DRAFT-ISSUE-DT TO WS-8000-BAD-DATA1
      *       MOVE SPACES TO WS-8000-CORR-DATA1
      *       MOVE 1605 TO WS-8000-PARAGRAPH-NO
      *       PERFORM 8000-RECORD-TRAN-ERROR
      *          THRU 8000-RECORD-TRAN-ERROR-EXIT
              GO TO 1605-VAL-DT-DRAFT-ISSUE-EXIT
           END-IF

      **********************************************************
      *    DETERMINE WHETHER DRAFT ISSUE DATE IS A VALID DATE  *
      *    IN FORMAT MMDDYY.                                   *
      **********************************************************

           MOVE WS-1605-DRAFT-ISSUE-DT TO WS-0555-INPUT-DATE
           PERFORM 0555-VAL-MMDDYY-DATE
              THRU 0555-VAL-MMDDYY-DATE-EXIT

           IF BAD-MONTH-0555
              MOVE WS-LITERAL-FV TO WS-8000-ERROR-TYPE
              MOVE 20010 TO WS-8000-ERROR-CODE
              MOVE WS-LITERAL-YES TO ERROR-DT-DRAFT-ISSUED
              MOVE WS-LITERAL-DT-DRAFT-ISSUE TO WS-8000-FIELD-NAME1
              MOVE WS-1605-DRAFT-ISSUE-DT TO WS-8000-BAD-DATA1
              MOVE '1 THRU 12' TO WS-8000-CORR-DATA1
              MOVE 1605 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
              GO TO 1605-VAL-DT-DRAFT-ISSUE-EXIT
           ELSE
              IF BAD-DAY-0555
                 MOVE WS-LITERAL-FV TO WS-8000-ERROR-TYPE
                 MOVE 20011 TO WS-8000-ERROR-CODE
                 MOVE WS-LITERAL-YES TO ERROR-DT-DRAFT-ISSUED
                 MOVE WS-LITERAL-DT-DRAFT-ISSUE TO WS-8000-FIELD-NAME1
                 MOVE WS-1605-DRAFT-ISSUE-DT TO WS-8000-BAD-DATA1
                 MOVE SPACES TO WS-8000-CORR-DATA1
                 MOVE 1605 TO WS-8000-PARAGRAPH-NO
                 PERFORM 8000-RECORD-TRAN-ERROR
                    THRU 8000-RECORD-TRAN-ERROR-EXIT
                 GO TO 1605-VAL-DT-DRAFT-ISSUE-EXIT
              ELSE
                 IF REVERSED-DATE-0555
                    MOVE WS-LITERAL-FV TO WS-8000-ERROR-TYPE
                    MOVE 20013 TO WS-8000-ERROR-CODE
                    MOVE WS-LITERAL-YES TO ERROR-DT-DRAFT-ISSUED
                    MOVE WS-LITERAL-DT-DRAFT-ISSUE
                      TO WS-8000-FIELD-NAME1
                    MOVE WS-1605-DRAFT-ISSUE-DT TO WS-8000-BAD-DATA1
                    MOVE SPACES TO WS-8000-CORR-DATA1
                    MOVE 1605 TO WS-8000-PARAGRAPH-NO
                    PERFORM 8000-RECORD-TRAN-ERROR
                       THRU 8000-RECORD-TRAN-ERROR-EXIT
                    GO TO 1605-VAL-DT-DRAFT-ISSUE-EXIT
                 END-IF
              END-IF
           END-IF


      **********************************************************
      *   DRAFT ISSUE DATE CANNOT BE GREATER THAN THE CURRENT  *
      *   DATE                                                 *
      **********************************************************

           IF WS-1605-DRAFT-ISSUE-DT = WS-1605-SYSTEM-DT
              GO TO 1605-VAL-DT-DRAFT-ISSUE-EXIT
           END-IF


           IF WS-1605-DRAFT-ISSUE-DT-YEAR
              > WS-1605-SYSTEM-DT-YEAR
              MOVE WS-LITERAL-FV TO WS-8000-ERROR-TYPE
              MOVE 20012 TO WS-8000-ERROR-CODE
              MOVE WS-LITERAL-YES TO ERROR-DT-DRAFT-ISSUED
              MOVE WS-LITERAL-DT-DRAFT-ISSUE
                TO WS-8000-FIELD-NAME1
              MOVE WS-1605-DRAFT-ISSUE-DT TO WS-8000-BAD-DATA1
              MOVE WS-1605-SYSTEM-DT TO WS-8000-CORR-DATA1
              MOVE 1605 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           ELSE
              IF WS-1605-DRAFT-ISSUE-DT-YEAR
                 = WS-1605-SYSTEM-DT-YEAR

                 IF WS-1605-DRAFT-ISSUE-DT-MONTH >
                    WS-1605-SYSTEM-DT-MONTH
                    MOVE WS-LITERAL-FV TO WS-8000-ERROR-TYPE
                    MOVE 20012 TO WS-8000-ERROR-CODE
                    MOVE WS-LITERAL-YES TO ERROR-DT-DRAFT-ISSUED
                    MOVE WS-LITERAL-DT-DRAFT-ISSUE
                      TO WS-8000-FIELD-NAME1
                    MOVE WS-1605-DRAFT-ISSUE-DT TO WS-8000-BAD-DATA1
                    MOVE WS-1605-SYSTEM-DT TO WS-8000-CORR-DATA1
                    MOVE 1605 TO WS-8000-PARAGRAPH-NO
                    PERFORM 8000-RECORD-TRAN-ERROR
                       THRU 8000-RECORD-TRAN-ERROR-EXIT
                 ELSE
                    IF WS-1605-DRAFT-ISSUE-DT-MONTH =
                       WS-1605-SYSTEM-DT-MONTH
                       IF WS-1605-DRAFT-ISSUE-DT-DAY >
                          WS-1605-SYSTEM-DT-DAY
                          MOVE WS-LITERAL-FV TO WS-8000-ERROR-TYPE
                          MOVE 20012 TO WS-8000-ERROR-CODE
                          MOVE WS-LITERAL-YES TO ERROR-DT-DRAFT-ISSUED
                          MOVE WS-LITERAL-DT-DRAFT-ISSUE
                            TO WS-8000-FIELD-NAME1
                          MOVE WS-1605-DRAFT-ISSUE-DT
                            TO WS-8000-BAD-DATA1
                          MOVE WS-1605-SYSTEM-DT TO WS-8000-CORR-DATA1
                          MOVE 1605 TO WS-8000-PARAGRAPH-NO
                          PERFORM 8000-RECORD-TRAN-ERROR
                             THRU 8000-RECORD-TRAN-ERROR-EXIT
                       END-IF
                    END-IF
                 END-IF
              END-IF
           END-IF.


       1605-VAL-DT-DRAFT-ISSUE-EXIT.
           EXIT.

