      ****************************************************************
      * FILE:      FV1815.CBL                                        *
      * AUTHOR:    CHERYL D. WOOD                                    *
      * DATE:      9/22/95                                           *
      * PURPOSE:   VALIDATION FOR INSURED SIGNATURE DATE             *
      *            VALUE MUST BE NUMERIC AND A VALID DATE            *
      *            MUST BE IN MMDDYY FORMAT.  DRAFT ISSUE DATE MUST  *
      *            BE LESS THAN OR EQUAL TO THE CURRENT SYSTEM DATE. *
      ****************************************************************

       1815-VAL-INSURED-SIG-DT.

      $IF DEBUG-SW DEFINED
           DISPLAY '1815-VALIDATING INSURED SIGNATURE DATE'
           UPON CONSOLE
      $END


      **********************************************************
      *    INITIALIZE WORK FIELDS                              *
      **********************************************************
           INITIALIZE WS-1815-WORK
           MOVE WS-0004-SYS-DATE TO WS-1815-SYSTEM-DT

      **********************************************************
      *    CHECK PRE-CONDITIONS                                *
      **********************************************************

           IF WS-1815-SYSTEM-DT IS NOT NUMERIC
              MOVE 1815 TO WS-8020-PARAGRAPH-NO
              MOVE 90001 TO WS-8020-INT-ERROR-NO
              MOVE 'WS-1815-SYSTEM-DT' TO WS-8020-FIELD-NAME
              MOVE WS-1815-SYSTEM-DT TO WS-8020-BAD-DATA
              MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
              PERFORM 8020-RECORD-INT-ERROR
                 THRU 8020-RECORD-INT-ERROR-EXIT
           END-IF

           IF WS-1815-SYSTEM-DT IS EQUAL ZEROS
              MOVE 1815 TO WS-8020-PARAGRAPH-NO
              MOVE 90003 TO WS-8020-INT-ERROR-NO
              MOVE 'WS-1815-SYSTEM-DT' TO WS-8020-FIELD-NAME
              MOVE WS-1815-SYSTEM-DT TO WS-8020-BAD-DATA
              MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
              PERFORM 8020-RECORD-INT-ERROR
                 THRU 8020-RECORD-INT-ERROR-EXIT
           END-IF


           IF WS-1815-INSURED-SIG-DT = SPACES
              GO TO 1815-VAL-INSURED-SIG-DT-EXIT
           END-IF

           IF WS-1815-INSURED-SIG-DT NOT NUMERIC
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 002 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-YES TO ERROR-INSURED-SIG-DT
              MOVE WS-LITERAL-FV TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-INSURE-SIG-DT
                TO WS-8000-FIELD-NAME1
              MOVE WS-1815-INSURED-SIG-DT TO WS-8000-BAD-DATA1
              MOVE SPACES TO WS-8000-CORR-DATA1
              MOVE 1815 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
              GO TO 1815-VAL-INSURED-SIG-DT-EXIT
           END-IF

           IF WS-1815-INSURED-SIG-DT EQUAL ZEROS
              GO TO 1815-VAL-INSURED-SIG-DT-EXIT
           END-IF

      **********************************************************
      *    DETERMINE WHETHER ADJUSTER SIGNATURE DATE IS A      *
      *    VALID DATE IN FORMAT MMDDYY.                        *
      **********************************************************

           MOVE WS-1815-INSURED-SIG-DT TO WS-0555-INPUT-DATE
           PERFORM 0555-VAL-MMDDYY-DATE
              THRU 0555-VAL-MMDDYY-DATE-EXIT

           IF BAD-MONTH-0555
              MOVE WS-LITERAL-FV TO WS-8000-ERROR-TYPE
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 010 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-YES TO ERROR-INSURED-SIG-DT
              MOVE WS-LITERAL-INSURE-SIG-DT
                TO WS-8000-FIELD-NAME1
              MOVE WS-1815-INSURED-SIG-DT TO WS-8000-BAD-DATA1
              MOVE '1 THRU 12' TO WS-8000-CORR-DATA1
              MOVE 1815 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
              GO TO 1815-VAL-INSURED-SIG-DT-EXIT
           ELSE
              IF BAD-DAY-0555
                 MOVE WS-LITERAL-FV TO WS-8000-ERROR-TYPE
                 MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
                 MOVE 011 TO WS-8000-SHORT-ERROR
                 MOVE WS-LITERAL-YES TO ERROR-INSURED-SIG-DT
                 MOVE WS-LITERAL-INSURE-SIG-DT
                   TO WS-8000-FIELD-NAME1
                 MOVE WS-1815-INSURED-SIG-DT TO WS-8000-BAD-DATA1
                 MOVE SPACES TO WS-8000-CORR-DATA1
                 MOVE 1815 TO WS-8000-PARAGRAPH-NO
                 PERFORM 8000-RECORD-TRAN-ERROR
                    THRU 8000-RECORD-TRAN-ERROR-EXIT
                 GO TO 1815-VAL-INSURED-SIG-DT-EXIT
              ELSE
                 IF REVERSED-DATE-0555
                    MOVE WS-LITERAL-FV TO WS-8000-ERROR-TYPE
                    MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
                    MOVE 013 TO WS-8000-SHORT-ERROR
                    MOVE WS-LITERAL-YES TO ERROR-INSURED-SIG-DT
                    MOVE WS-LITERAL-INSURE-SIG-DT
                      TO WS-8000-FIELD-NAME1
                    MOVE WS-1815-INSURED-SIG-DT TO WS-8000-BAD-DATA1
                    MOVE SPACES TO WS-8000-CORR-DATA1
                    MOVE 1815 TO WS-8000-PARAGRAPH-NO
                    PERFORM 8000-RECORD-TRAN-ERROR
                       THRU 8000-RECORD-TRAN-ERROR-EXIT
                    GO TO 1815-VAL-INSURED-SIG-DT-EXIT
                 END-IF
              END-IF
           END-IF


      **********************************************************
      *   ADJUSTER SIGNATURE DATE CANNOT BE GREATER THAN THE   *
      *   CURRENT DATE                                         *
      **********************************************************

           IF WS-1815-INSURED-SIG-DT = WS-1815-SYSTEM-DT
              GO TO 1815-VAL-INSURED-SIG-DT-EXIT
           END-IF


           IF WS-1815-INSURED-SIG-DT-YEAR > WS-1815-SYSTEM-DT-YEAR
              MOVE WS-LITERAL-FV TO WS-8000-ERROR-TYPE
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 012 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-YES TO ERROR-INSURED-SIG-DT
              MOVE WS-LITERAL-INSURE-SIG-DT
                TO WS-8000-FIELD-NAME1
              MOVE WS-1815-INSURED-SIG-DT TO WS-8000-BAD-DATA1
              MOVE WS-1815-SYSTEM-DT TO WS-8000-CORR-DATA1
              MOVE 1815 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           ELSE
              IF WS-1815-INSURED-SIG-DT-YEAR
                 = WS-1815-SYSTEM-DT-YEAR

                 IF WS-1815-INSURED-SIG-DT-MONTH >
                    WS-1815-SYSTEM-DT-MONTH
                    MOVE WS-LITERAL-FV TO WS-8000-ERROR-TYPE
                    MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
                    MOVE 012 TO WS-8000-SHORT-ERROR
                    MOVE WS-LITERAL-YES TO ERROR-INSURED-SIG-DT
                    MOVE WS-LITERAL-INSURE-SIG-DT
                      TO WS-8000-FIELD-NAME1
                    MOVE WS-1815-INSURED-SIG-DT TO WS-8000-BAD-DATA1
                    MOVE WS-1815-SYSTEM-DT TO WS-8000-CORR-DATA1
                    MOVE 1815 TO WS-8000-PARAGRAPH-NO
                    PERFORM 8000-RECORD-TRAN-ERROR
                       THRU 8000-RECORD-TRAN-ERROR-EXIT
                 ELSE
                    IF WS-1815-INSURED-SIG-DT-MONTH =
                       WS-1815-SYSTEM-DT-MONTH

                       IF WS-1815-INSURED-SIG-DT-DAY >
                          WS-1815-SYSTEM-DT-DAY

                          MOVE WS-LITERAL-FV TO WS-8000-ERROR-TYPE
                          MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
                          MOVE 012 TO WS-8000-SHORT-ERROR
                          MOVE WS-LITERAL-YES TO ERROR-INSURED-SIG-DT
                          MOVE WS-LITERAL-INSURE-SIG-DT
                            TO WS-8000-FIELD-NAME1
                          MOVE WS-1815-INSURED-SIG-DT
                            TO WS-8000-BAD-DATA1
                          MOVE WS-1815-SYSTEM-DT TO WS-8000-CORR-DATA1
                          MOVE 1815 TO WS-8000-PARAGRAPH-NO
                          PERFORM 8000-RECORD-TRAN-ERROR
                             THRU 8000-RECORD-TRAN-ERROR-EXIT
                       END-IF
                    END-IF
                 END-IF
              END-IF
           END-IF.


       1815-VAL-INSURED-SIG-DT-EXIT.
           EXIT.

