      ***************************************************************
      * FILE:      IF2015.CBL
      * AUTHOR:    MIKE RAY
      * DATE:      02/07/96
      * PURPOSE:
      *    THIS COPY FILE CONTAINS THE SEQUENCING LOGIC FOR THE TYPE
      *    15 RECORD.
      * MODIFICATIONS:
      * 12/03/96  PUT YIELD LIMIT FLAG CHECK BACK INTO PROGRAM
      *           PER M13 (REVISION 03).  JLH.
      ***************************************************************

       2015-VALIDATE-T15.


      $IF DEBUG-SW DEFINED
           DISPLAY '2015-INTER-FIELD VALIDATING T15'
      $END

      *****************************************************
      *    SET UP 88-LEVELS USED FOR INTER-FIELD VALS     *
      *****************************************************


           IF ERROR-CROP-YR IS NOT EQUAL TO WS-LITERAL-YES
              MOVE WS-T15-CROP-YEAR
                TO WS-0009-CROP-YEAR
           END-IF

           IF ERROR-CVG-FL IS NOT EQUAL TO WS-LITERAL-YES
              MOVE WS-T15-COVERAGE-FLG
                TO WS-0009-COVERAGE-FLG
           END-IF

           IF ERROR-CROP-CD NOT = WS-LITERAL-YES
              MOVE WS-T15-CROP-CD TO WS-0009-CROP-CATEGORIES
           END-IF


      *****************************************************
      *    INITIALIZE LOCAL VARIABLES.                    *
      *****************************************************
           INITIALIZE WS-2015-LOCAL

      **************************************************************
      *  WE ARE BORROWING ID TYPE AND ID NUMBER FROM               *
      *  WS-0005-CURRENT-POLICY AND PLACING IT IN WS-2015 LOCAL    *
      *  VARIABLES.  ANY LOOKUP OF ADM NCS DATA REQUIRES USING     *
      *  THE ID TYPE AND ID NUMBER.  THIS DATA SHOULD RESIDE ON    *
      *  THE TYPE 15 RECORD.  THE NEXT REVISION OF TRANSACTION     *
      *  TYPES SHOULD INCLUDE ADDING THESE FIELDS TO THE TYPE 15.  *
      **************************************************************
           MOVE WS-0005-ID-TYPE TO WS-2015-ID-TYPE
           MOVE WS-0005-ID-NUM TO WS-2015-ID-NUMBER


      *****************************************************
      *  THE FOLLOWING TWO BLOCKS VALIDATE THE REPORTING  *
      *  ORGANIZATION, LOCATION STATE, AND COMPANY/COUNTY *
      *  FOR CFSA AND REINSURED COMPANIES RESPECTIVELY    *
      *****************************************************

      *****************************************************
      *    VALIDATE REINSURED INFO                        *
      *****************************************************

           IF REINSURED
              INITIALIZE WS-2205-INPUT
              MOVE WS-T15-REPORTING-ORG TO WS-2205-INSURANCE-PROVIDER
              MOVE WS-T15-COMPANY-COUNTY TO WS-2205-COMPANY
              MOVE WS-0004-REINS-YR TO WS-2205-REINSURANCE-YEAR
              PERFORM 2205-VAL-REINSURED-INFO
                 THRU 2205-VAL-REINSURED-INFO-EXIT
           END-IF

      *****************************************************
      *    VALIDATE CROP YEAR                             *
      *****************************************************
           INITIALIZE WS-2475-INPUT
           MOVE WS-T15-CROP-CD TO WS-2475-CROP-CD
           MOVE WS-T15-CROP-YEAR TO WS-2475-CROP-YEAR
           MOVE WS-T15-RATE-STATE TO WS-2475-STATE-CD
           MOVE WS-0004-REINS-YR TO WS-2475-REINS-YEAR
           PERFORM 2475-VAL-CROP-YR
              THRU 2475-VAL-CROP-YR-EXIT


      *****************************************************
      *   VALIDATE RATE STATE AND COUNTY                  *
      *****************************************************
           INITIALIZE WS-2235-INPUT
           MOVE WS-T15-CROP-CD TO WS-2235-CROP-CD
           MOVE WS-T15-RATE-STATE TO WS-2235-RATE-STATE
           MOVE WS-T15-RATE-COUNTY TO WS-2235-RATE-COUNTY
           MOVE WS-T15-LOC-STATE TO WS-2235-LOCATION-STATE
           MOVE WS-T15-LOCATION-COUNTY TO WS-2235-LOCATION-COUNTY
           PERFORM 2235-VAL-NON-CAT-RATE
              THRU 2235-VAL-NON-CAT-RATE-EXIT

      *****************************************************
      *    VALIDATE CROP CODE                             *
      *****************************************************
           INITIALIZE WS-2237-INPUT
           MOVE WS-T15-CROP-CD TO WS-2237-CROP-CD
           MOVE WS-T15-CROP-YEAR TO WS-2237-CROP-YR
           PERFORM 2237-VAL-CROP-CODE
              THRU 2237-VAL-CROP-CODE-EXIT

      *****************************************************
      *    LOOKUP UNIT OF MEASURE FOR T15 CROP            *
      *****************************************************
           IF ERROR-CROP-CD <> WS-LITERAL-YES AND
              ERROR-RATE-STATE <> WS-LITERAL-YES
              INITIALIZE WS-7290-INPUT
              MOVE WS-T15-CROP-CD TO WS-7290-CROP-CD
              MOVE WS-T15-RATE-STATE TO WS-7290-STATE-CD
              MOVE WS-T15-TYPE-CD TO WS-7290-TYPE-CD
              MOVE WS-T15-INS-PLAN-CD TO WS-7290-INS-PLAN-CD
              PERFORM 7290-LOOKUP-UM
                 THRU 7290-LOOKUP-UM-EXIT
      $IF DEBUG-SW DEFINED
              DISPLAY 'UNIT OF MEASURE = ', WS-7290-UNIT-OF-MEASURE
      $END
              IF MATCH-FOUND-7290
                 MOVE WS-7290-UNIT-OF-MEASURE
                   TO WS-2015-CROP-UNIT-OF-MEASURE
              ELSE
                 MOVE WS-LITERAL-YES TO ERROR-UNIT-OF-MEASURE
                 MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
                 MOVE 044 TO WS-8000-SHORT-ERROR
                 MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
                 MOVE 'CROP' TO WS-8000-FIELD-NAME1
                 MOVE WS-T15-CROP-CD TO WS-8000-BAD-DATA1
                 MOVE 'NEEDS TO BE ADDED TO UNIT OF MEASURE TABLE'
                   TO WS-8000-CORR-DATA1
                 MOVE 2015 TO WS-8000-PARAGRAPH-NO
                 PERFORM 8000-RECORD-TRAN-ERROR
                    THRU 8000-RECORD-TRAN-ERROR-EXIT
              END-IF
           ELSE
              MOVE WS-LITERAL-YES TO ERROR-UNIT-OF-MEASURE
           END-IF


      *****************************************************
      *    VALIDATE LOCATION COUNTY                       *
      *****************************************************
           INITIALIZE WS-2250-INPUT
           MOVE WS-T15-LOC-STATE TO WS-2250-LOCATION-STATE
           MOVE WS-T15-LOCATION-COUNTY TO WS-2250-LOCATION-COUNTY
           PERFORM 2250-VAL-LOC-CNTY-INFO
              THRU 2250-VAL-LOC-CNTY-INFO-EXIT


      *****************************************************
      *    VALIDATE CROP TYPE                             *
      *****************************************************

           INITIALIZE WS-2240-INPUT
           MOVE WS-T15-CROP-CD TO WS-2240-CROP-CODE
           MOVE WS-T15-TYPE-CD TO WS-2240-CROP-TYPE
           PERFORM 2240-VAL-CROP-TYPE
              THRU 2240-VAL-CROP-TYPE-EXIT

      *****************************************************
      *    VALIDATE INSURABLE CROP/INSURANCE PLAN CODE    *
      *    MAKE SURE THAT THE CROP IS INSURABLE.          *
      *****************************************************
           INITIALIZE WS-2307-INPUT
           MOVE WS-T15-CROP-CD TO WS-2307-CROP-CD
           MOVE WS-T15-CROP-YEAR TO WS-2307-CROP-YEAR
           MOVE WS-T15-RATE-STATE TO WS-2307-RATE-STATE
           MOVE WS-T15-RATE-COUNTY TO WS-2307-RATE-COUNTY
           MOVE WS-T15-INS-PLAN-CD
                TO WS-2307-INSURANCE-PLAN-ID
           MOVE WS-T15-PRACTICE-CD TO WS-2307-PRACTICE-CD
           MOVE WS-T15-TYPE-CD TO WS-2307-TYPE-CD

           PERFORM 2307-VAL-REINS-INS-CROP
              THRU 2307-VAL-REINS-INS-CROP-EXIT

      *****************************************************
      *    VALIDATE PRACTICE CODE                         *
      *****************************************************
           INITIALIZE WS-2265-INPUT
           MOVE WS-T15-CROP-YEAR TO WS-2265-CROP-YEAR
           MOVE WS-T15-RATE-STATE TO WS-2265-STATE
           MOVE WS-T15-RATE-COUNTY TO WS-2265-COUNTY
           MOVE WS-T15-CROP-CD TO WS-2265-CROP-CD
           MOVE WS-T15-INS-PLAN-CD TO WS-2265-INSURANCE-PLAN-ID
           MOVE WS-T15-TYPE-CD TO WS-2265-TYPE
           MOVE WS-T15-PRACTICE-CD TO WS-2265-PRACTICE-CD
           PERFORM 2265-VAL-PRACTICE-CD
              THRU 2265-VAL-PRACTICE-CD-EXIT

      *****************************************************
      *  VALIDATE NCS YIELD FACTOR/YIELD LIMITATION FLAG  *
      *****************************************************
           INITIALIZE WS-2560-INPUT
           MOVE WS-T15-CROP-YEAR TO WS-2560-CROP-YEAR
           MOVE WS-T15-RATE-STATE TO WS-2560-RATE-STATE
           MOVE WS-T15-RATE-COUNTY TO WS-2560-RATE-COUNTY
           MOVE WS-T15-CROP-CD TO WS-2560-CROP-CD
           MOVE WS-T15-INS-PLAN-CD TO WS-2560-INS-PLAN-CD
           MOVE WS-T15-TYPE-CD TO WS-2560-TYPE-CD
           MOVE WS-T15-PRACTICE-CD TO WS-2560-PRACTICE-CD
           MOVE WS-T15-NCS-YIELD-FACTOR TO WS-2560-NCS-YIELD-FACTOR
           MOVE WS-2015-ID-TYPE TO WS-2560-ID-TYPE
           MOVE WS-2015-ID-NUMBER TO WS-2560-ID-NUM
           PERFORM 2560-VAL-NCS-YLD-FACTOR
              THRU 2560-VAL-NCS-YLD-FACTOR-EXIT

           MOVE WS-2560-NCS-PRODUCER
             TO WS-2015-NCS-PRODUCER

      *****************************************************
      *  VALIDATE YIELD LIMITATION FLAG                   *
      *****************************************************
           INITIALIZE WS-2505-INPUT
           MOVE WS-T15-COVERAGE-FLG TO WS-2505-COVERAGE-FLG
           MOVE WS-T15-YIELD-LIMIT-FLG TO WS-2505-YIELD-LIMIT-FLG
           MOVE WS-2015-NCS-PRODUCER
             TO WS-2505-NCS-PRODUCER
           PERFORM 2505-VAL-YLD-LIMIT-FLAG
              THRU 2505-VAL-YLD-LIMIT-FLAG-EXIT

      *****************************************************
      *       NO INTER-FIELD EDIT FOR REVIEW FLAG         *
      *****************************************************


      *****************************************************
      *            VALIDATE T15 MAP AREA                  *
      *****************************************************
           INITIALIZE WS-2570-INPUT
           MOVE WS-T15-MAP-AREA TO WS-2570-MAP-AREA
           MOVE WS-T15-TRANSITIONAL-YIELD
             TO WS-2570-TRANSITIONAL-YLD
           PERFORM 2570-VAL-T15-MAP-AREA
              THRU 2570-VAL-T15-MAP-AREA-EXIT

      *****************************************************
      *     NO INTER-FIELD EDIT FOR FCIC CONTROL DATE     *
      *****************************************************


      *****************************************************
      *            VALIDATE YIELD TYPES                   *
      *****************************************************
           INITIALIZE WS-2510-INPUT
           MOVE WS-T15-YIELD-TYPE-YEAR1 TO WS-2510-YIELD-TYPE1
           MOVE WS-T15-YIELD-TYPE-YEAR2 TO WS-2510-YIELD-TYPE2
           MOVE WS-T15-YIELD-TYPE-YEAR3 TO WS-2510-YIELD-TYPE3
           MOVE WS-T15-YIELD-TYPE-YEAR4 TO WS-2510-YIELD-TYPE4
           MOVE WS-T15-YIELD-TYPE-YEAR5 TO WS-2510-YIELD-TYPE5
           MOVE WS-T15-YIELD-TYPE-YEAR6 TO WS-2510-YIELD-TYPE6
           MOVE WS-T15-YIELD-TYPE-YEAR7 TO WS-2510-YIELD-TYPE7
           MOVE WS-T15-YIELD-TYPE-YEAR8 TO WS-2510-YIELD-TYPE8
           MOVE WS-T15-YIELD-TYPE-YEAR9 TO WS-2510-YIELD-TYPE9
           MOVE WS-T15-YIELD-TYPE-YEAR10 TO WS-2510-YIELD-TYPE10
           PERFORM 2510-VAL-YIELD-TYPES
              THRU 2510-VAL-YIELD-TYPES-EXIT

      *****************************************************
      *            VALIDATE YIELD SEQUENCE                *
      *****************************************************
           INITIALIZE WS-2515-INPUT
           MOVE WS-2015-NCS-PRODUCER TO WS-2515-NCS-FLAG
           MOVE WS-T15-YIELD-INDICATOR TO WS-2515-YIELD-INDICATOR
           MOVE WS-T15-YIELD-TYPE-YEAR1 TO WS-2515-YIELD-TYPE1
           MOVE WS-T15-YIELD-TYPE-YEAR2 TO WS-2515-YIELD-TYPE2
           MOVE WS-T15-YIELD-TYPE-YEAR3 TO WS-2515-YIELD-TYPE3
           MOVE WS-T15-YIELD-TYPE-YEAR4 TO WS-2515-YIELD-TYPE4
           MOVE WS-T15-YIELD-TYPE-YEAR5 TO WS-2515-YIELD-TYPE5
           MOVE WS-T15-YIELD-TYPE-YEAR6 TO WS-2515-YIELD-TYPE6
           MOVE WS-T15-YIELD-TYPE-YEAR7 TO WS-2515-YIELD-TYPE7
           MOVE WS-T15-YIELD-TYPE-YEAR8 TO WS-2515-YIELD-TYPE8
           MOVE WS-T15-YIELD-TYPE-YEAR9 TO WS-2515-YIELD-TYPE9
           MOVE WS-T15-YIELD-TYPE-YEAR10 TO WS-2515-YIELD-TYPE10
           PERFORM 2515-VAL-YIELD-TY-SEQ
              THRU 2515-VAL-YIELD-TY-SEQ-EXIT
           MOVE WS-2515-REFERENCE-UNIT-REQ
             TO WS-2015-REFERENCE-UNIT-REQ

      *****************************************************
      *           VALIDATE YIELD INDICATOR                *
      *****************************************************
           INITIALIZE WS-2555-INPUT
           MOVE WS-T15-YIELD-INDICATOR
             TO WS-2555-YIELD-INDICATOR
           MOVE WS-T15-CROP-CD TO WS-2555-CROP-CD
           PERFORM 2555-VAL-YIELD-INDICATOR
              THRU 2555-VAL-YIELD-INDICATOR-EXIT
           MOVE WS-2555-APPROVED-YIELD-REQ
             TO WS-2015-APPROVED-YIELD-REQ

      *****************************************************
      *         VALIDATE TRANSITIONAL T YIELD             *
      *****************************************************
           INITIALIZE WS-2530-INPUT
           MOVE WS-2015-CROP-UNIT-OF-MEASURE
             TO WS-2530-CROP-UNIT-OF-MEASURE
           MOVE WS-T15-CROP-YEAR TO WS-2530-CROP-YEAR
           MOVE WS-T15-RATE-STATE TO WS-2530-STATE
           MOVE WS-T15-RATE-COUNTY TO WS-2530-COUNTY
           MOVE WS-T15-CROP-CD TO WS-2530-CROP-CD
           MOVE WS-T15-INS-PLAN-CD TO WS-2530-INSURANCE-PLAN-ID
           MOVE WS-T15-PRACTICE-CD TO WS-2530-PRACTICE-CD
           MOVE WS-T15-TYPE-CD TO WS-2530-TYPE
           MOVE WS-T15-MAP-AREA TO WS-2530-MAP-AREA
           MOVE WS-T15-TRANSITIONAL-YIELD TO WS-2530-TRANS-YIELD
           MOVE WS-T15-CFSA-YIELD TO WS-2530-CFSA-YIELD
           MOVE WS-T15-YIELD-LIMIT-FLG TO WS-2530-YLD-LMT-FLG
           MOVE WS-T15-YIELD-TYPE-YEAR1 TO WS-2530-YIELD-TYPE1
           MOVE WS-T15-YIELD-TYPE-YEAR2 TO WS-2530-YIELD-TYPE2
           MOVE WS-T15-YIELD-TYPE-YEAR3 TO WS-2530-YIELD-TYPE3
           MOVE WS-T15-YIELD-TYPE-YEAR4 TO WS-2530-YIELD-TYPE4
           MOVE WS-T15-YIELD-TYPE-YEAR5 TO WS-2530-YIELD-TYPE5
           MOVE WS-T15-YIELD-TYPE-YEAR6 TO WS-2530-YIELD-TYPE6
           MOVE WS-T15-YIELD-TYPE-YEAR7 TO WS-2530-YIELD-TYPE7
           MOVE WS-T15-YIELD-TYPE-YEAR8 TO WS-2530-YIELD-TYPE8
           MOVE WS-T15-YIELD-TYPE-YEAR9 TO WS-2530-YIELD-TYPE9
           MOVE WS-T15-YIELD-TYPE-YEAR10 TO WS-2530-YIELD-TYPE10
           PERFORM 2530-VAL-TRANSITIONAL-YLD
              THRU 2530-VAL-TRANSITIONAL-YLD-EXIT
           MOVE WS-2530-CFSA-YIELD-REQ TO WS-2015-CFSA-YLD-REQ

      ************************************************************
      *   VALIDATE APPROVED & ANNUAL YIELDS AGAINST DISTRICT AVG *
      ************************************************************

      *    INITIALIZE WS-2532-INPUT
      *    MOVE WS-2015-CROP-UNIT-OF-MEASURE
      *      TO WS-2532-CROP-UNIT-OF-MEASURE
      *    MOVE WS-T15-CROP-YEAR TO WS-2532-CROP-YEAR
      *    MOVE WS-T15-RATE-STATE TO WS-2532-STATE
      *    MOVE WS-T15-RATE-COUNTY TO WS-2532-COUNTY
      *    MOVE WS-T15-CROP-CD TO WS-2532-CROP-CD
      *    move ws-t15-ins-plan-cd to ws-2532-insurance-plan-id
      *    MOVE WS-T15-PRACTICE-CD TO WS-2532-PRACTICE-CD
      *    MOVE WS-T15-TYPE-CD TO WS-2532-TYPE
      *    MOVE WS-T15-MAP-AREA TO WS-2532-MAP-AREA
      *    MOVE WS-T15-ANNUAL-YIELD1 TO WS-2532-ANNUAL-YLD-1
      *    MOVE WS-T15-ANNUAL-YIELD2 TO WS-2532-ANNUAL-YLD-2
      *    MOVE WS-T15-ANNUAL-YIELD3 TO WS-2532-ANNUAL-YLD-3
      *    MOVE WS-T15-ANNUAL-YIELD4 TO WS-2532-ANNUAL-YLD-4
      *    MOVE WS-T15-ANNUAL-YIELD5 TO WS-2532-ANNUAL-YLD-5
      *    MOVE WS-T15-ANNUAL-YIELD6 TO WS-2532-ANNUAL-YLD-6
      *    MOVE WS-T15-ANNUAL-YIELD7 TO WS-2532-ANNUAL-YLD-7
      *    MOVE WS-T15-ANNUAL-YIELD8 TO WS-2532-ANNUAL-YLD-8
      *    MOVE WS-T15-ANNUAL-YIELD9 TO WS-2532-ANNUAL-YLD-9
      *    MOVE WS-T15-ANNUAL-YIELD10 TO WS-2532-ANNUAL-YLD-10
      *    MOVE WS-T15-YLD-CHK-BYPASS-FLAG TO WS-2532-BYPASS-FLAG
      *    PERFORM 2532-VAL-YLD-WITH-DIST-AVG
      *       THRU 2532-VAL-YLD-DIST-AVG-EXIT

      *****************************************************
      *             VALIDATE CFSA YIELD                   *
      *****************************************************
      *****************************************************
      *   VALIDATE COUNTY AVG PER ACRE REVENUE WHICH IS   *
      *   IN FSA YIELD FIELD, IF THE INSURANCE PLAN CODE  *
      *   IS AVOCADO REVENUE COVERAGE                     *
      *****************************************************
           IF WS-T15-INS-PLAN-CD = WS-LITERAL-ARC
              INITIALIZE WS-2537-INPUT
              MOVE WS-T15-CROP-CD TO WS-2537-CROP-CD
              MOVE WS-T15-CROP-YEAR TO WS-2537-CROP-YR
              MOVE WS-T15-RATE-STATE TO WS-2537-STATE-CD
              MOVE WS-T15-RATE-COUNTY TO WS-2537-COUNTY-CD
              MOVE WS-T15-INS-PLAN-CD TO WS-2537-INSURANCE-PLAN-ID
              MOVE WS-T15-PRACTICE-CD TO WS-2537-PRACTICE-CD
              MOVE WS-T15-TYPE-CD TO WS-2537-TYPE-CD
              MOVE WS-T15-YIELD-YEAR1 TO WS-2537-YLD-YR1
              MOVE WS-T15-YIELD-YEAR2 TO WS-2537-YLD-YR2
              MOVE WS-T15-YIELD-YEAR3 TO WS-2537-YLD-YR3
              MOVE WS-T15-YIELD-YEAR4 TO WS-2537-YLD-YR4
              MOVE WS-T15-YIELD-YEAR5 TO WS-2537-YLD-YR5
              MOVE WS-T15-YIELD-YEAR6 TO WS-2537-YLD-YR6
              MOVE WS-T15-YIELD-YEAR7 TO WS-2537-YLD-YR7
              MOVE WS-T15-YIELD-YEAR8 TO WS-2537-YLD-YR8
              MOVE WS-T15-YIELD-YEAR9 TO WS-2537-YLD-YR9
              MOVE WS-T15-YIELD-YEAR10 TO WS-2537-YLD-YR10
              MOVE WS-T15-ANNUAL-YIELD1 TO WS-2537-ANNUAL-YLD-1
              MOVE WS-T15-ANNUAL-YIELD2 TO WS-2537-ANNUAL-YLD-2
              MOVE WS-T15-ANNUAL-YIELD3 TO WS-2537-ANNUAL-YLD-3
              MOVE WS-T15-ANNUAL-YIELD4 TO WS-2537-ANNUAL-YLD-4
              MOVE WS-T15-ANNUAL-YIELD5 TO WS-2537-ANNUAL-YLD-5
              MOVE WS-T15-ANNUAL-YIELD6 TO WS-2537-ANNUAL-YLD-6
              MOVE WS-T15-ANNUAL-YIELD7 TO WS-2537-ANNUAL-YLD-7
              MOVE WS-T15-ANNUAL-YIELD8 TO WS-2537-ANNUAL-YLD-8
              MOVE WS-T15-ANNUAL-YIELD9 TO WS-2537-ANNUAL-YLD-9
              MOVE WS-T15-ANNUAL-YIELD10 TO WS-2537-ANNUAL-YLD-10

              PERFORM 2537-GET-AVG-REVENUES
                 THRU 2537-GET-AVG-REVENUES-EXIT
           END-IF

      *****************************************************
      *         VALIDATE PREVIOUSLY APPROVED YIELD        *
      *****************************************************
           INITIALIZE WS-2545-INPUT
           MOVE WS-T15-CROP-CD TO WS-2545-CROP-CD
           MOVE WS-T15-PREV-APPROV-YIELD
             TO WS-2545-PREV-APPROVED-YLD
           MOVE WS-T15-YIELD-LIMIT-FLG TO WS-2545-YLD-LMT-FLG
           MOVE WS-T15-YIELD-TYPE-YEAR1 TO WS-2545-YIELD-TYPE1
           MOVE WS-T15-YIELD-TYPE-YEAR2 TO WS-2545-YIELD-TYPE2
           MOVE WS-T15-YIELD-TYPE-YEAR3 TO WS-2545-YIELD-TYPE3
           MOVE WS-T15-YIELD-TYPE-YEAR4 TO WS-2545-YIELD-TYPE4
           MOVE WS-T15-YIELD-TYPE-YEAR5 TO WS-2545-YIELD-TYPE5
           MOVE WS-T15-YIELD-TYPE-YEAR6 TO WS-2545-YIELD-TYPE6
           MOVE WS-T15-YIELD-TYPE-YEAR7 TO WS-2545-YIELD-TYPE7
           MOVE WS-T15-YIELD-TYPE-YEAR8 TO WS-2545-YIELD-TYPE8
           MOVE WS-T15-YIELD-TYPE-YEAR9 TO WS-2545-YIELD-TYPE9
           MOVE WS-T15-YIELD-TYPE-YEAR10 TO WS-2545-YIELD-TYPE10
           PERFORM 2545-VAL-PR-APPROVED-YLD
              THRU 2545-VAL-PR-APPROVED-YLD-EXIT


      *****************************************************
      *          VALIDATE YIELDS/TYPES/ACREAGES           *
      *****************************************************
           INITIALIZE WS-2525-INPUT
           MOVE WS-2015-CROP-UNIT-OF-MEASURE
             TO WS-2525-CROP-UNIT-OF-MEASURE
           MOVE WS-T15-PREV-APPROV-YIELD
             TO WS-2525-PREV-APPROVED-YLD
           MOVE WS-T15-TRANSITIONAL-YIELD
             TO WS-2525-TRANSITIONAL-YLD
           MOVE WS-T15-CROP-CD TO WS-2525-CROP-CD
           MOVE WS-T15-NCS-YIELD-FACTOR
             TO WS-2525-NCS-YIELD-FACTOR
           MOVE WS-T15-YIELD-TYPE-YEAR1 TO WS-2525-YIELD-TYPE1
           MOVE WS-T15-YIELD-TYPE-YEAR2 TO WS-2525-YIELD-TYPE2
           MOVE WS-T15-YIELD-TYPE-YEAR3 TO WS-2525-YIELD-TYPE3
           MOVE WS-T15-YIELD-TYPE-YEAR4 TO WS-2525-YIELD-TYPE4
           MOVE WS-T15-YIELD-TYPE-YEAR5 TO WS-2525-YIELD-TYPE5
           MOVE WS-T15-YIELD-TYPE-YEAR6 TO WS-2525-YIELD-TYPE6
           MOVE WS-T15-YIELD-TYPE-YEAR7 TO WS-2525-YIELD-TYPE7
           MOVE WS-T15-YIELD-TYPE-YEAR8 TO WS-2525-YIELD-TYPE8
           MOVE WS-T15-YIELD-TYPE-YEAR9 TO WS-2525-YIELD-TYPE9
           MOVE WS-T15-YIELD-TYPE-YEAR10 TO WS-2525-YIELD-TYPE10
           MOVE WS-T15-ANNUAL-YIELD1 TO WS-2525-ANNUAL-YLD-1
           MOVE WS-T15-ANNUAL-YIELD2 TO WS-2525-ANNUAL-YLD-2
           MOVE WS-T15-ANNUAL-YIELD3 TO WS-2525-ANNUAL-YLD-3
           MOVE WS-T15-ANNUAL-YIELD4 TO WS-2525-ANNUAL-YLD-4
           MOVE WS-T15-ANNUAL-YIELD5 TO WS-2525-ANNUAL-YLD-5
           MOVE WS-T15-ANNUAL-YIELD6 TO WS-2525-ANNUAL-YLD-6
           MOVE WS-T15-ANNUAL-YIELD7 TO WS-2525-ANNUAL-YLD-7
           MOVE WS-T15-ANNUAL-YIELD8 TO WS-2525-ANNUAL-YLD-8
           MOVE WS-T15-ANNUAL-YIELD9 TO WS-2525-ANNUAL-YLD-9
           MOVE WS-T15-ANNUAL-YIELD10 TO WS-2525-ANNUAL-YLD-10
           MOVE WS-T15-YIELD-ACRE1 TO WS-2525-YIELD-ACRES1
           MOVE WS-T15-YIELD-ACRE2 TO WS-2525-YIELD-ACRES2
           MOVE WS-T15-YIELD-ACRE3 TO WS-2525-YIELD-ACRES3
           MOVE WS-T15-YIELD-ACRE4 TO WS-2525-YIELD-ACRES4
           MOVE WS-T15-YIELD-ACRE5 TO WS-2525-YIELD-ACRES5
           MOVE WS-T15-YIELD-ACRE6 TO WS-2525-YIELD-ACRES6
           MOVE WS-T15-YIELD-ACRE7 TO WS-2525-YIELD-ACRES7
           MOVE WS-T15-YIELD-ACRE8 TO WS-2525-YIELD-ACRES8
           MOVE WS-T15-YIELD-ACRE9 TO WS-2525-YIELD-ACRES9
           MOVE WS-T15-YIELD-ACRE10 TO WS-2525-YIELD-ACRES10
           PERFORM 2525-VAL-YIELD-COMBOS
              THRU 2525-VAL-YIELD-COMBOS-EXIT
           MOVE WS-2525-AVERAGE-YIELD TO WS-2015-AVERAGE-YIELD
           MOVE WS-2525-ACTUAL-YEARS TO WS-2015-ACTUAL-YEARS
           MOVE WS-2525-TOTAL-YEARS TO WS-2015-TOTAL-YEARS

      *****************************************************
      *             VALIDATE YIELD YEARS                  *
      *****************************************************
           INITIALIZE WS-2540-INPUT
           MOVE WS-T15-CROP-YEAR TO WS-2540-CROP-YEAR
           MOVE WS-T15-CROP-CD TO WS-2540-CROP-CD
           MOVE WS-T15-YIELD-YEAR1 TO WS-2540-YIELD-YEAR1
           MOVE WS-T15-YIELD-YEAR2 TO WS-2540-YIELD-YEAR2
           MOVE WS-T15-YIELD-YEAR3 TO WS-2540-YIELD-YEAR3
           MOVE WS-T15-YIELD-YEAR4 TO WS-2540-YIELD-YEAR4
           MOVE WS-T15-YIELD-YEAR5 TO WS-2540-YIELD-YEAR5
           MOVE WS-T15-YIELD-YEAR6 TO WS-2540-YIELD-YEAR6
           MOVE WS-T15-YIELD-YEAR7 TO WS-2540-YIELD-YEAR7
           MOVE WS-T15-YIELD-YEAR8 TO WS-2540-YIELD-YEAR8
           MOVE WS-T15-YIELD-YEAR9 TO WS-2540-YIELD-YEAR9
           MOVE WS-T15-YIELD-YEAR10 TO WS-2540-YIELD-YEAR10
           PERFORM 2540-VAL-YIELD-YEARS
              THRU 2540-VAL-YIELD-YEARS-EXIT


      *****************************************************
      *           VALIDATE APPROVED YIELD                 *
      *****************************************************
           IF WS-2015-APPROVED-YIELD-REQ = WS-LITERAL-YES
              INITIALIZE WS-2550-INPUT
              MOVE WS-T15-CROP-CD TO WS-2550-CROP-CD
              MOVE WS-2015-CROP-UNIT-OF-MEASURE
                TO WS-2550-CROP-UNIT-OF-MEASURE
              MOVE WS-T15-APPROVED-YIELD
                TO WS-2550-APPROVED-YIELD
              MOVE WS-T15-YIELD-LIMIT-FLG
                TO WS-2550-YIELD-LIMITATION-FLG
              MOVE WS-T15-NCS-EXCEPTION-FLAG
                TO WS-2550-NCS-EXCEPTION-FLAG
              MOVE WS-T15-YIELD-INDICATOR
                TO WS-2550-YIELD-INDICATOR
              MOVE WS-2015-ACTUAL-YEARS
                TO WS-2550-ACTUAL-YEARS
              MOVE WS-T15-PREV-APPROV-YIELD
                TO WS-2550-PREV-APPROVED-YIELD
              MOVE WS-T15-TRANSITIONAL-YIELD
                TO WS-2550-TRANSITIONAL-YIELD
              MOVE WS-2015-AVERAGE-YIELD
                TO WS-2550-AVERAGE-YIELD
              MOVE WS-2015-CROP-UNIT-OF-MEASURE
                TO WS-2550-UNIT-OF-MEASURE
              MOVE WS-T15-INS-PLAN-CD
                TO WS-2550-INS-PLAN-CD
              MOVE WS-2015-REFERENCE-UNIT-REQ
                TO WS-2550-IN-REFERENCE-UNIT-REQ
              PERFORM 2550-VAL-APPROVED-YIELD
                 THRU 2550-VAL-APPROVED-YIELD-EXIT
              MOVE WS-2550-REFERENCE-UNIT-REQ
                TO WS-2015-REFERENCE-UNIT-REQ
              MOVE WS-2550-REFERENCE-YEARS-REQ
                TO WS-2015-REFERENCE-YEARS-REQ
           END-IF


      *****************************************************
      *    VALIDATE NON CAT FARM SERIAL NO                *
      *    FARM SERIAL NUMBERS ARE ONLY REQUIRED FOR      *
      *    BUY-UP POLICIES FOR PEANUTS AND QUOTA TOBACCO. *
      *****************************************************
           IF NOT CAT-COVERAGE
              INITIALIZE WS-2285-INPUT
              MOVE WS-T15-CROP-CD TO WS-2285-CROP-CD
              MOVE WS-T15-FARM-SERIAL-NUM TO WS-2285-FARM-SERIAL-NUMBER
              MOVE WS-T15-INS-PLAN-CD TO WS-2285-INS-PLAN-CD
              MOVE WS-T15-RATE-STATE TO WS-2285-RATE-STATE
              MOVE WS-T15-RATE-COUNTY TO WS-2285-RATE-COUNTY
              PERFORM 2285-VAL-FARM-SERIAL-NO
                 THRU 2285-VAL-FARM-SERIAL-NO-EXIT
           END-IF.

       2015-VALIDATE-T15-EXIT.
           EXIT.
