      ***************************************************************
      * FILE:      IF2021.CBL
      * AUTHOR:    LINDA FUNN
      * DATE:      11/30/95
      * PURPOSE:
      *    THIS COPY FILE CONTAINS THE SEQUENCING LOGIC FOR THE TYPE
      *    21A RECORD.
      *
      * CONTAINS:
      *
      ***************************************************************

       2021-VALIDATE-T21.

      $IF DEBUG-SW DEFINED
           DISPLAY '2021-INTER-FIELD VALIDATING T21'
           UPON CONSOLE
      $END

      *****************************************************
      *    SET UP 88-LEVELS USED FOR INTER-FIELD VALS     *
      *****************************************************

           IF ERROR-CROP-YR NOT = WS-LITERAL-YES
              MOVE WS-T21-CROP-YEAR TO WS-0009-CROP-YEAR
           END-IF

           IF ERROR-CVG-FL NOT = WS-LITERAL-YES
              MOVE WS-T21-COVERAGE-FLG TO WS-0009-COVERAGE-FLG
           END-IF


           IF ERROR-CROP-CD NOT = WS-LITERAL-YES
              MOVE WS-T21-CROP-CD TO WS-0009-CROP-CATEGORIES
           END-IF

      * REPORTING ORGANIZATION HAS BEEN FULLY VALIDATED BY FV

      * LOCATION STATE IS FULLY VALIDATED BY FV

      * COMPANY IS VALIDATED BY THE FOLLOWING EDIT


      *****************************************************
      *    VALIDATE REINSURED INFO                        *
      *****************************************************

           IF REINSURED
              INITIALIZE WS-2205-INPUT
              MOVE WS-T21-REPORTING-ORG TO WS-2205-INSURANCE-PROVIDER
              MOVE WS-T21-COMPANY-COUNTY TO WS-2205-COMPANY
              MOVE WS-0004-REINS-YR TO WS-2205-REINSURANCE-YEAR
              PERFORM 2205-VAL-REINSURED-INFO
                 THRU 2205-VAL-REINSURED-INFO-EXIT
           END-IF

      * POLICY NUMBER IS FULLY VALIDATED BY FV

      * CROP YEAR IS VALIDATED IN IR3425-VAL-RELATED-TYPE-11

      * RECORD TYPE IS FULLY VALIDATED BY FV

      * CLAIM NUMBER IS FULLY VALIDATED BY FV AND IR

      * BRANCH OFFICE/STATE CODE IS VALIDATED
      * BY 2200-VAL-CFSA-INFO & 2205-VAL-REINSURED-INFO

      * RECORD NUMBER IS FULLY VALIDATED BY FV

      * ADJUSTER ID CODE IS FULLY VALIDATED BY FV

      * ADJUSTER SIGNATURE DATE IS EDITED BELOW IN 2435-VAL-REINS-LOSS-INFO

      * CROP CODE IS VALIDATED BELOW

      *****************************************************
      *    VALIDATE CROP CODE                             *
      *****************************************************
           INITIALIZE WS-2237-INPUT
           MOVE WS-T21-CROP-CD TO WS-2237-CROP-CD
           MOVE WS-T21-CROP-YEAR TO WS-2237-CROP-YR
           PERFORM 2237-VAL-CROP-CODE
              THRU 2237-VAL-CROP-CODE-EXIT


      * PRACTICE CODE IS VALIDATED IN IR3425-VAL-RELATED-TYPE-11

      * TYPE CODE IS VALIDATED BELOW

      ******************************************************
      *    VALIDATE CROP TYPE                              *
      ******************************************************
           INITIALIZE WS-2240-INPUT
           MOVE WS-T21-CROP-CD TO WS-2240-CROP-CODE
           MOVE WS-T21-TYPE-CD TO WS-2240-CROP-TYPE
           PERFORM 2240-VAL-CROP-TYPE
             THRU 2240-VAL-CROP-TYPE-EXIT


      *****************************************************
      *    LOOKUP UNIT OF MEASURE FOR T21 CROP            *
      *****************************************************
           IF ERROR-CROP-CD <> WS-LITERAL-YES AND
              ERROR-LOC-STATE <> WS-LITERAL-YES
              INITIALIZE WS-7290-INPUT
              MOVE WS-T21-CROP-CD TO WS-7290-CROP-CD
              MOVE WS-T21-LOC-STATE TO WS-7290-STATE-CD
              MOVE WS-T21-TYPE-CD TO WS-7290-TYPE-CD
              MOVE WS-T21-INS-PLAN-CD TO WS-7290-INS-PLAN-CD
              PERFORM 7290-LOOKUP-UM
                 THRU 7290-LOOKUP-UM-EXIT
              IF MATCH-FOUND-7290
      $IF DEBUG-SW DEFINED
              DISPLAY 'UNIT OF MEASURE = ', WS-7290-UNIT-OF-MEASURE
              UPON CONSOLE
      $END
                 MOVE WS-7290-UNIT-OF-MEASURE
                   TO WS-2021-CROP-UNIT-OF-MEASURE
              ELSE
                 MOVE WS-LITERAL-YES TO ERROR-UNIT-OF-MEASURE
                 MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
                 MOVE 044 TO WS-8000-SHORT-ERROR
                 MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
                 MOVE 'CROP' TO WS-8000-FIELD-NAME1
                 MOVE WS-T21-CROP-CD TO WS-8000-BAD-DATA1
                 MOVE 'NEEDS TO BE ADDED TO UNIT OF MEASURE TABLE'
                   TO WS-8000-CORR-DATA1
                 MOVE 2021 TO WS-8000-PARAGRAPH-NO
                 PERFORM 8000-RECORD-TRAN-ERROR
                    THRU 8000-RECORD-TRAN-ERROR-EXIT
              END-IF
           ELSE
              MOVE WS-LITERAL-YES TO ERROR-UNIT-OF-MEASURE
           END-IF


      **************************************************************
      *  WE ARE BORROWING SEVERAL FIELDS FROM THE CORRESPONDING
      *  TYPE 11 RECORD AND PLACING THEM IN WS2021 LOCAL VARIABLES.
      *
      *  THESE FIELDS SHOULD BE ADDED TO THE T21 TRANSACTION IN THE
      *  FUTURE:
      *  PERCENT ELECTION
      *  DOLLAR AMOUNT OF INSURANCE
      *  GUARANTEE REDUCTION PERCENT
      *  RATE STATE
      *  RATE COUNTY
      *  TYPE/PRACTICE OPTION CODE
      *  CRUSH DISTRICT
      ***************************************************************
           PERFORM 2021-GET-T11-FIELDS
              THRU 2021-GET-T11-FIELDS-EXIT


      * BASIC UNIT NUMBER IS FULLY VALIDATED BY FV

      * OPTIONAL UNIT IS VALIDATED AFTER INSURABLE CROP/INSURANCE PLAN CD

      * SECTION IS NOT REQUIRED

      * TOWNSHIP IS NOT REQUIRED

      * RANGE IS NOT REQUIRED

      * LOCATION COUNTY IS VALIDATED BELOW

      *****************************************************
      *    VALIDATE LOCATION COUNTY                       *
      *****************************************************


      *****************************************************
      *    VALIDATE INSURABLE CROP                        *
      *    Make sure that the crop is insurable.          *
      *    Lookup the Insurance Plan Code.                *
      *****************************************************

           INITIALIZE WS-2307-INPUT
           MOVE WS-T21-CROP-CD TO WS-2307-CROP-CD
           MOVE WS-T21-CROP-YEAR TO WS-2307-CROP-YEAR
           MOVE WS-T21-LOC-STATE TO WS-2307-RATE-STATE
           MOVE WS-T21-LOCATION-COUNTY TO WS-2307-RATE-COUNTY
           MOVE WS-T21-PRACTICE-CD TO WS-2307-PRACTICE-CD
           MOVE WS-T21-TYPE-CD TO WS-2307-TYPE-CD
           MOVE WS-T21-INS-PLAN-CD TO WS-2307-INSURANCE-PLAN-ID

           PERFORM 2307-VAL-REINS-INS-CROP
              THRU 2307-VAL-REINS-INS-CROP-EXIT


      * FARM SERIAL NUMBER IS VALIDATED IN IR3425-VAL-RELATED-TYPE-11

      * RATE CLASSIFICATION IS VALIDATED BELOW

      *****************************************************
      *    VALIDATE RATE CLASS FOR GROUP CROPS            *
      *****************************************************
           INITIALIZE WS-2370-INPUT

           MOVE WS-T21-INS-PLAN-CD TO WS-2370-INS-PLAN-CD
           MOVE WS-T21-RATE-CLASS TO WS-2370-RATE-CLASS

           PERFORM 2370-VAL-RATE-CLASS
              THRU 2370-VAL-RATE-CLASS-EXIT


      * COVERAGE LEVEL PERCENT FOR REINSURED COMPANIES
      * IS VALIDATED IN IR3425-VAL-RELATED-TYPE-11

      *****************************************************
      *    VALIDATE COVERAGE LEVEL PERCENT                *
      *****************************************************


      * WS-T21-PRICE-ELECTION IS VALIDATED BELOW
      *****************************************************
      *           VALIDATE PRICE ELECTION                 *
      *****************************************************
           INITIALIZE WS-2295-INPUT
           MOVE WS-T21-INS-PLAN-CD TO WS-2295-INS-PLAN-CD
           MOVE WS-T21-CROP-CD TO WS-2295-CROP-CD
           MOVE WS-2021-RATE-STATE TO WS-2295-RATE-STATE
           MOVE WS-2021-RATE-COUNTY TO WS-2295-RATE-COUNTY
           MOVE WS-T21-PRICE-ELECTION TO WS-2295-PRICE-ELECTION
           MOVE WS-T21-TYPE-CD TO WS-2295-TYPE-CD
           MOVE WS-T21-PRACTICE-CD TO WS-2295-PRACTICE-CD
           MOVE WS-T21-RATE-CLASS TO WS-2295-RATE-CLASS
           MOVE WS-T21-CROP-YEAR TO WS-2295-CROP-YR
           MOVE WS-2021-CRUSH-DISTRICT TO WS-2295-CRUSH-DISTRICT
           MOVE WS-2021-TYPE-PRACT-OPTION-CD
             TO WS-2295-TYPE-PRACTICE-OPTION
           PERFORM 2295-VAL-PRICE-ELECTION
              THRU 2295-VAL-PRICE-ELECTION-EXIT


      * DETERMINED ACRES IS FULLY VALIDATED BY FV

      * LIABILITY FACTOR IS FULLY VALIDATED BY FV

      * STAGE CODE IS VALIDATED BELOW

      ******************************************************
      *    VALIDATE STAGE CODE                             *
      ******************************************************
           INITIALIZE WS-2590-INPUT
           MOVE WS-T21-CROP-CD TO WS-2590-CROP-CD
           MOVE WS-T21-INS-PLAN-CD TO WS-2590-INS-PLAN-CD
           MOVE WS-T21-STAGE-CD TO WS-2590-STAGE-CD
           MOVE WS-T21-COVERAGE-FLG TO WS-2590-COVERAGE-FL
           MOVE WS-T21-LOC-STATE TO WS-2590-LOC-STATE
           MOVE WS-T21-RATE-CLASS TO WS-2590-RATE-CLASS
           MOVE WS-T21-LOCATION-COUNTY TO WS-2590-LOC-COUNTY
           MOVE WS-T21-CROP-YEAR TO WS-2590-CROP-YR
           PERFORM 2590-VAL-STAGE-CODE
              THRU 2590-VAL-STAGE-CODE-EXIT
           MOVE WS-2590-STAGE-PCT-FCTR
             TO WS-2021-STAGE-PCT-FCTR


      * LOSS GUARANTEE IS VALIDATED AFTER SIMPLIFIED CLAIM FLAG

      * INSURED SHARE IS VALIDATED BELOW

      *****************************************************
      *    VALIDATE INSURED SHARE                         *
      *****************************************************
           INITIALIZE WS-2575-INPUT
           MOVE WS-T21-CROP-CD TO WS-2575-CROP-CD
           MOVE WS-T21-INS-PLAN-CD TO WS-2575-INS-PLAN-CD
           MOVE WS-T21-INSURED-SHARE TO WS-2575-INSURED-SHARE
           PERFORM 2575-VAL-INSURED-SHARE
              THRU 2575-VAL-INSURED-SHARE-EXIT

      * PRODUCTION TO COUNT IS NOT VALIDATED

      * 100% REPLANT FLAG IS NOT VALIDATED

      * FARM UNIT DEFICIENCY IS VALIDATED AFTER LOSS GUARANTEE

      * YIELD IS VALIDATED BELOW

      ************************************************************
      *        VALIDATE YIELD                                    *
      ************************************************************
           INITIALIZE WS-2610-INPUT
           MOVE WS-T21-INS-PLAN-CD TO WS-2610-INS-PLAN
           MOVE WS-T21-CROP-CD TO WS-2610-CROP-CD
           MOVE WS-T21-YIELD TO WS-2610-YIELD-QUOTA
           PERFORM 2610-VAL-T21-YIELD-QUOTA
              THRU 2610-VAL-T21-YIELD-QUOTA-EXIT

      *****************************************************
      *        VALIDATE QUOTA                             *
      *****************************************************
           INITIALIZE WS-2315-INPUT
           MOVE WS-T21-INS-PLAN-CD TO WS-2315-INS-PLAN-CD
           MOVE WS-T21-CROP-CD TO WS-2315-CROP-CD
           MOVE WS-T21-QUOTA TO WS-2315-QUOTA
           PERFORM 2315-VAL-QUOTA
              THRU 2315-VAL-QUOTA-EXIT


      * AUDIT CORRECTION IS FULLY VALIDATED BY FV

      * GROUP PAYMENT FACTOR IS VALIDATED BELOW

      ************************************************************
      *    VALIDATE GROUP PAYMENT CALCULATION FACTOR             *
      *    & DETERMINE PRELIMINARY PAYMENT CALCULATION FACTOR    *
      ************************************************************
           INITIALIZE WS-2580-INPUT
           MOVE WS-2021-CROP-UNIT-OF-MEASURE
             TO WS-2580-CROP-UNIT-OF-MEASURE
           MOVE WS-T21-INS-PLAN-CD TO WS-2580-INS-PLAN-CD
           MOVE WS-T21-CROP-CD TO WS-2580-CROP-CD
           MOVE WS-T21-STAGE-CD TO WS-2580-STAGE-CD
           MOVE WS-T21-COVERAGE-LEVEL-PCT TO WS-2580-COVERAGE-LVL-PCT
           MOVE WS-T21-GRP-PMT-CALC-FCTR TO WS-2580-GROUP-PMT-CALC-FCTR
           MOVE WS-T21-CROP-YEAR TO WS-2580-CROP-YEAR
           MOVE WS-T21-LOC-STATE TO WS-2580-LOCATION-STATE
           MOVE WS-T21-LOCATION-COUNTY TO WS-2580-LOCATION-COUNTY
           MOVE WS-T21-TYPE-CD TO WS-2580-TYPE-CD
           MOVE WS-T21-PRACTICE-CD TO WS-2580-PRACTICE-CD
           MOVE WS-T21-COVERAGE-FLG TO WS-2580-COVERAGE-FL
           PERFORM 2580-VAL-GRP-PMT-CALC
              THRU 2580-VAL-GRP-PMT-CALC-EXIT

           IF UPDATE-MADE-2580
      *     **WS-2580-OUT-GRP-PMT-CALC-FCTR IS ONLY SET WHEN THE RECORD
      *     **IS UNDER CAT COVERAGE
              MOVE WS-2580-OUT-GRP-PMT-CALC-FCTR
                TO WS-T21-GRP-PMT-CALC-FCTR
           END-IF

           MOVE WS-2580-PRELIM-PMT-CALC-FACTOR
             TO WS-2021-PRELIM-PMT-CALC-FACTOR

      **** INDEMNITY IS EDITED BELOW AND AFTER LOSS GUARANTEE

      ************************************************************
      *    VALIDATE INDEMNITY WITH FARM UNIT DEFICIENCY          *
      ************************************************************
           INITIALIZE WS-2440-INPUT
           MOVE WS-T21-FARM-UNIT-DEFIC TO WS-2440-FARM-UNIT-DEF
           MOVE WS-T21-INDEMNITY TO WS-2440-INDEMNITY
           PERFORM 2440-VAL-INDEM-W-DEFICNY
              THRU 2440-VAL-INDEM-W-DEFICNY-EXIT


      * HARVESTED PRODUCTION IS VALIDATED BELOW

      ************************************************************
      *    VALIDATE HARVESTED PRODUCTION WITH PRODUCTION TO COUNT*
      ************************************************************
           INITIALIZE WS-2445-INPUT
           MOVE WS-T21-HARVEST-PROD TO WS-2445-HARVEST-PROD
           MOVE WS-T21-PROD-TO-CNT TO WS-2445-PROD-TO-COUNT
           PERFORM 2445-VAL-HARVESTED-PROD
              THRU 2445-VAL-HARVESTED-PROD-EXIT


      * PRIMARY MONTH IS VALIDATED BELOW

      ************************************************************
      *    VALIDATE PRIMARY MONTH                                *
      ************************************************************
           INITIALIZE WS-2450-INPUT
           MOVE WS-T21-PRIMARY-MONTH TO WS-2450-PRIMARY-MONTH
           MOVE WS-T21-INDEMNITY TO WS-2450-INDEMNITY
           PERFORM 2450-VAL-PRIMARY-MONTH
              THRU 2450-VAL-PRIMARY-MONTH-EXIT

      * SECONDARY MONTH IS VALIDATED AFTER PRIMARY PERCENT

      * PRIMARY CAUSE IS VALIDATED BELOW

      ************************************************************
      *    VALIDATE PRIMARY CAUSE                                *
      ************************************************************
           INITIALIZE WS-2595-INPUT
           MOVE WS-T21-INS-PLAN-CD TO WS-2595-INS-PLAN-CD
           MOVE WS-T21-CROP-CD TO WS-2595-CROP-CD
           MOVE WS-T21-LOC-STATE TO WS-2595-LOC-STATE
           MOVE 1 TO WS-2595-SOURCE-FIELD
           MOVE WS-T21-PRIMARY-CAUSE TO WS-2595-LOSS-CAUSE-CD

           PERFORM 2595-VAL-LOSS-CAUSE-CD
              THRU 2595-VAL-LOSS-CAUSE-CD-EXIT


      * PRIMARY PERCENT IS VALIDATED BELOW

      ************************************************************
      *    VALIDATE PRIMARY PERCENT                              *
      ************************************************************
           INITIALIZE WS-2455-INPUT
           MOVE WS-T21-PRIMARY-PCT TO WS-2455-PRIMARY-PCT
           MOVE WS-T21-PRIMARY-CAUSE TO WS-2455-PRIMARY-CAUSE
           PERFORM 2455-VAL-PRIMARY-PCT
              THRU 2455-VAL-PRIMARY-PCT-EXIT


      ************************************************************
      *    VALIDATE SECONDARY MONTH                              *
      ************************************************************
           INITIALIZE WS-2460-INPUT
           MOVE WS-T21-INS-PLAN-CD TO WS-2460-INS-PLAN-CD
           MOVE WS-T21-SECONDARY-MONTH TO WS-2460-SECONDARY-MONTH
           MOVE WS-T21-PRIMARY-PCT TO WS-2460-PRIMARY-PCT
           PERFORM 2460-VAL-SECONDARY-MONTH
              THRU 2460-VAL-SECONDARY-MONTH-EXIT


      * SECONDARY CAUSE IS VALIDATED BELOW

      ************************************************************
      *    VALIDATE SECONDARY CAUSE                              *
      ************************************************************
           INITIALIZE WS-2595-INPUT
           MOVE WS-T21-INS-PLAN-CD TO WS-2595-INS-PLAN-CD
           MOVE WS-T21-CROP-CD TO WS-2595-CROP-CD
           MOVE WS-T21-LOC-STATE TO WS-2595-LOC-STATE
           MOVE WS-T21-SECONDARY-CAUSE TO WS-2595-LOSS-CAUSE-CD
           MOVE 2 TO WS-2595-SOURCE-FIELD

           PERFORM 2595-VAL-LOSS-CAUSE-CD
              THRU 2595-VAL-LOSS-CAUSE-CD-EXIT


      * SUGAR FACTOR IS VALIDATED BELOW

      ************************************************************
      *    VALIDATE SUGAR FCTR                                   *
      ************************************************************
           INITIALIZE WS-2465-INPUT
           MOVE WS-T21-SUGAR-FCTR TO WS-2465-SUGAR-FACTOR
           MOVE WS-T21-CROP-CD TO WS-2465-CROP-CD
           MOVE WS-T21-HARVEST-PROD TO WS-2465-HARVEST-PROD
           PERFORM 2465-VAL-SUGAR-FACTOR
              THRU 2465-VAL-SUGAR-FACTOR-EXIT.

      * ACREAGE RECORD NUMBER IS NOT EDITED

      * INSURED SIGNATURE DATE IS EDITED ABOVE IN 2435-VAL-REINS-LOSS-INFO

      * RO CONTROL DATE IS NOT EDITED

      * FCIC CONTROL DATE IS NOT EDITED

      * SIMPLIFIED CLAIM FLAG IS VALIDATED BELOW

      ************************************************************
      *    VALIDATE SIMPLIFIED CLAIM FLAG                        *
      ************************************************************
           INITIALIZE WS-2600-INPUT
           MOVE WS-T21-CROP-CD TO WS-2600-CROP-CD
           MOVE WS-T21-SIMPLIFIED-CLM-FLG TO WS-2600-SIMPLE-CLAIM-FL
           MOVE WS-T21-COVERAGE-FLG TO WS-2600-COVERAGE-FL
           PERFORM 2600-VAL-SIMPLE-CLAIM-FL
              THRU 2600-VAL-SIMPLE-CLAIM-FL-EXIT


      *****************************************************
      *    VALIDATE STAGE GPA/LOSS GUARANTEE              *
      *****************************************************
           INITIALIZE WS-2615-INPUT
           MOVE WS-T21-STAGE-GUAR-PER-ACRE
             TO WS-2615-INPUT-STAGE-GPA
           MOVE WS-T21-LOSS-GUARANTEE
             TO WS-2615-INPUT-LOSS-GUARANTEE
           MOVE WS-T21-STAGE-CD TO WS-2615-STAGE-CD
           MOVE WS-T21-INS-PLAN-CD TO WS-2615-INS-PLAN-CD
           MOVE WS-T21-CROP-CD TO WS-2615-CROP-CD
           MOVE WS-T21-TYPE-CD TO WS-2615-TYPE-CD
           MOVE WS-2021-MULTIPLE-GUAR-RED-PCTS
             TO WS-2615-MULTIPLE-GUAR-RED-PCT
           MOVE WS-T21-YIELD TO WS-2615-YIELD
           MOVE WS-T21-QUOTA TO WS-2615-QUOTA
           MOVE WS-T21-COVERAGE-LEVEL-PCT
             TO WS-2615-COVERAGE-LEVEL-PCT
           MOVE WS-T21-GUARANTEE-RED-PCT
             TO WS-2615-GUAR-REDUCTION-FCTR
           MOVE WS-2021-STAGE-PCT-FCTR TO WS-2615-STAGE-PERCENT-FCTR
           MOVE WS-T21-PRICE-ELECTION TO WS-2615-PRICE-ELECTION
           MOVE WS-T21-REVENUE-CVG-LEVEL-PCT
             TO WS-2615-RA-COVERAGE-LEVEL
           MOVE WS-T21-DOLLAR-AMT-INSUR TO WS-2615-DOLLAR-AMT-INS
           MOVE WS-2021-CROP-UNIT-OF-MEASURE
             TO WS-2615-CROP-UNIT-OF-MEASURE
           MOVE WS-T21-INSURED-SHARE TO WS-2615-INSURED-SHARE
           MOVE WS-T21-DETERMINED-ACRES TO WS-2615-DETERMINED-ACRES
           MOVE WS-T21-LIABILITY-FACTOR
             TO WS-2615-LIABILITY-ADJ-FACTOR
           PERFORM 2615-VAL-LOSS-GUARANTEE
              THRU 2615-VAL-LOSS-GUARANTEE-EXIT

      *****************************************************
      *    VALIDATE INDEMNITY                             *
      *****************************************************
           INITIALIZE WS-2630-INPUT
           MOVE WS-T21-INDEMNITY TO WS-2630-INPUT-INDEMNITY
           MOVE WS-T21-FARM-UNIT-DEFIC TO WS-2630-INPUT-FARM-UNIT-DEF
           MOVE WS-T21-INS-PLAN-CD TO WS-2630-INS-PLAN-CD
           MOVE WS-T21-CROP-CD TO WS-2630-CROP-CD
           MOVE WS-T21-STAGE-CD TO WS-2630-STAGE-CD
           MOVE WS-2021-CROP-UNIT-OF-MEASURE
             TO WS-2630-CROP-UNIT-OF-MEASURE
           MOVE WS-T21-LOSS-GUARANTEE TO WS-2630-LOSS-GUARANTEE
           MOVE WS-T21-PROD-TO-CNT TO WS-2630-PROD-TO-COUNT
           MOVE WS-T21-INSURED-SHARE TO WS-2630-INSURED-SHARE
           MOVE WS-T21-PRICE-ELECTION TO WS-2630-PRICE-ELECTION
           MOVE WS-2021-PERCENT-ELECTION TO WS-2630-PERCENT-ELECTION
           MOVE WS-T21-GRP-PMT-CALC-FCTR TO WS-2630-GRP-PAYMENT-FACTOR
           PERFORM 2630-VAL-INDEMNITY
              THRU 2630-VAL-INDEMNITY-EXIT.


      * COMPUTE INTEREST CODE IS EDITED ABOVE IN 2435-VAL-REINS-LOSS-INFO

      * COVERAGE FLAG IS FULLY VALIDATED BY FV



       2021-VALIDATE-T21-EXIT.
           EXIT.


       2021-GET-T11-FIELDS.

      $IF DEBUG-SW DEFINED
           DISPLAY '2021-LOOKING UP FIELDS FROM THE TYPE 11'
           UPON CONSOLE
      $END

      *********************************************************
           MOVE WS-LITERAL-NO TO WS-2021-T11-MATCH-FOUND

      *********************************************************

           IF WS-0011-T11-REC-COUNT > ZERO
              PERFORM 2021-FIND-T11
                 THRU 2021-FIND-T11-EXIT
                 WITH TEST AFTER
              VARYING WS-0011-T11-INT-INDEX FROM 1 BY 1
                UNTIL WS-0011-T11-INT-INDEX = WS-0011-T11-REC-COUNT
                   OR WS-2021-T11-MATCH-FOUND = WS-LITERAL-YES
           else
              MOVE WS-LITERAL-YES TO ERROR-RATE-STATE
              MOVE 21056 TO WS-8000-ERROR-CODE
              MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
              MOVE 'T11 RECORD' TO WS-8000-FIELD-NAME1
              MOVE 'NOT FOUND' TO WS-8000-BAD-DATA1
              MOVE 'NEEDED FOR PRICE ELECTION EDIT'
                TO WS-8000-CORR-DATA1
              MOVE 2021 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
              go to 2021-GET-T11-FIELDS-EXIT
           END-IF

           IF WS-2021-PERCENT-ELECTION = ZERO
              MOVE WS-LITERAL-YES TO ERROR-YLD-CONVER-FCTR
           END-IF

      *    *** RA RECORDS MUST PROVIDE THE CORRECT GUARANTEE
      *    *** REDUCTION PERCENT.
           IF WS-T21-INS-PLAN-CD = WS-LITERAL-RA
              MOVE WS-LITERAL-NO TO WS-2021-MULTIPLE-GUAR-RED-PCTS
           END-IF

           IF WS-2021-RATE-STATE = ZERO
              MOVE WS-LITERAL-YES TO ERROR-RATE-STATE
              MOVE 21056 TO WS-8000-ERROR-CODE
              MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
              MOVE 'T11 RATE STATE' TO WS-8000-FIELD-NAME1
              MOVE 'NOT FOUND' TO WS-8000-BAD-DATA1
              MOVE 'NEEDED FOR PRICE ELECTION EDIT'
                TO WS-8000-CORR-DATA1
              MOVE 2021 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-2021-RATE-COUNTY = ZERO
              MOVE WS-LITERAL-YES TO ERROR-RATE-COUNTY
              MOVE 21056 TO WS-8000-ERROR-CODE
              MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
              MOVE 'T11 RATE STATE' TO WS-8000-FIELD-NAME1
              MOVE 'NOT FOUND' TO WS-8000-BAD-DATA1
              MOVE 'NEEDED FOR PRICE ELECTION EDIT'
                TO WS-8000-CORR-DATA1
              MOVE 2021 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-T21-GUARANTEE-RED-PCT = ZERO AND
              WS-T21-INS-PLAN-CD <> WS-LITERAL-RA
              IF WS-2021-GUAR-REDUCTION-FCTR > ZERO
                 MOVE WS-2021-GUAR-REDUCTION-FCTR
                   TO WS-T21-GUARANTEE-RED-PCT
              END-IF
      *       IF WS-2021-GUAR-REDUCTION-FCTR > 0.70
      *          MOVE WS-2021-GUAR-REDUCTION-FCTR
      *            TO WS-2021-GUAR-REDUCTION-FCTR-X
      *          MOVE WS-LITERAL-YES TO ERROR-GUAR-RED-PCT
      *          MOVE 21079 TO WS-8000-ERROR-CODE
      *          MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
      *          MOVE 'T11 GUAR RED%' TO WS-8000-FIELD-NAME1
      *          MOVE WS-2021-GUAR-REDUCTION-FCTR-X
      *            TO WS-8000-BAD-DATA1
      *          MOVE '<= 0.700'
      *            TO WS-8000-CORR-DATA1
      *          MOVE 2021 TO WS-8000-PARAGRAPH-NO
      *          PERFORM 8000-RECORD-TRAN-ERROR
      *             THRU 8000-RECORD-TRAN-ERROR-EXIT
      *          MOVE ZERO TO WS-2021-GUAR-REDUCTION-FCTR
      *       END-IF
      *    END-IF


      ********************************************************

           IF WS-T21-CROP-CD <> WS-LITERAL-NURSERY
      ********************************************************

           IF WS-T21-DOLLAR-AMT-INSUR = ZERO
              IF WS-2021-DOLLAR-AMT-INS = ZERO
                 MOVE WS-LITERAL-YES TO ERROR-DOLLAR-AMT-INSUR
                 IF WS-T21-INS-PLAN-CD = WS-LITERAL-DOLLAR-AMT OR
                    WS-T21-INS-PLAN-CD = WS-LITERAL-GRP
                    MOVE 21056 TO WS-8000-ERROR-CODE
                    MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                    MOVE 'T11 DOLLAR AMT' TO WS-8000-FIELD-NAME1
                    MOVE 'NOT FOUND' TO WS-8000-BAD-DATA1
                    MOVE 'NEEDED FOR GUARANTEE CALC'
                      TO WS-8000-CORR-DATA1
                    MOVE 2021 TO WS-8000-PARAGRAPH-NO
                    PERFORM 8000-RECORD-TRAN-ERROR
                       THRU 8000-RECORD-TRAN-ERROR-EXIT
                 END-IF
              ELSE
                 MOVE WS-2021-DOLLAR-AMT-INS
                   TO WS-T21-DOLLAR-AMT-INSUR
              END-IF
              END-IF
           END-IF.


       2021-GET-T11-FIELDS-EXIT.
           EXIT.


       2021-FIND-T11.

           SET WS-0011-T11-INDEX TO WS-0011-T11-INT-INDEX

      $IF DEBUG-SW DEFINED
           DISPLAY 'T11 SEQ # = ',
           WS-0011-TBL-TRAN-SEQ-NO(WS-0011-T11-INDEX)
           UPON CONSOLE
           DISPLAY 'T11 REC # = ',
           WS-0011-TBL-RECORD-NUM(WS-0011-T11-INDEX),
           ' PCT ELECT ',
           WS-0011-TBL-YLD-CONVR-PCT-FCTR(WS-0011-T11-INDEX),
           ' $AMT INS ',
           WS-0011-TBL-DOLLAR-AMT-INSUR(WS-0011-T11-INDEX),
           ' GUAR RED % ',
           WS-0011-TBL-GUARANTEE-RED-PCT(WS-0011-T11-INDEX),
           ' RATE STATE ',
           WS-0011-TBL-RATE-STATE(WS-0011-T11-INDEX),
           ' RATE CNTY ',
           WS-0011-TBL-RATE-COUNTY(WS-0011-T11-INDEX)
           UPON CONSOLE
           DISPLAY 'TYPE/PRACTICE OPTION CD ',
           WS-0011-TBL-TYPE-PRAC-OPT-CD(WS-0011-T11-INDEX),
           ' CRUSH DISTRICT ',
           WS-0011-TBL-CRUSH-DISTRICT(WS-0011-T11-INDEX)
           UPON CONSOLE
      $END

      *    *** SEE IF THIS T11 MATCHES BASED UPON RECORD NUMBER
           IF WS-T21-ACREAGE-REC-NO <> ZERO
              IF WS-0011-TBL-RECORD-NUM(WS-0011-T11-INDEX) =
                 WS-T21-ACREAGE-REC-NO
                 MOVE WS-LITERAL-YES TO WS-2021-T11-MATCH-FOUND
                 MOVE WS-0011-TBL-YLD-CONVR-PCT-FCTR
                      (WS-0011-T11-INDEX)
                   TO WS-2021-PERCENT-ELECTION
                 MOVE WS-0011-TBL-DOLLAR-AMT-INSUR
                      (WS-0011-T11-INDEX)
                   TO WS-2021-DOLLAR-AMT-INS
                 MOVE WS-0011-TBL-GUARANTEE-RED-PCT
                      (WS-0011-T11-INDEX)
                   TO WS-2021-GUAR-REDUCTION-FCTR
                 MOVE WS-0011-TBL-RATE-STATE(WS-0011-T11-INDEX)
                   TO WS-2021-RATE-STATE
                 MOVE WS-0011-TBL-RATE-COUNTY(WS-0011-T11-INDEX)
                   TO WS-2021-RATE-COUNTY
                 MOVE WS-0011-TBL-TYPE-PRAC-OPT-CD(WS-0011-T11-INDEX)
                   TO WS-2021-TYPE-PRACT-OPTION-CD
                 MOVE WS-0011-TBL-CRUSH-DISTRICT(WS-0011-T11-INDEX)
                   TO WS-2021-CRUSH-DISTRICT
                 MOVE WS-LITERAL-NO
                   TO WS-2021-MULTIPLE-GUAR-RED-PCTS
                 GO TO 2021-FIND-T11-EXIT
              END-IF
           END-IF


      $IF DEBUG-SW DEFINED
           DISPLAY 'T11 CNTY ',
           WS-0011-TBL-LOCATION-COUNTY(WS-0011-T11-INDEX),
           ' TYPE ', WS-0011-TBL-TYPE-CD(WS-0011-T11-INDEX),
           ' UNIT ', WS-0011-TBL-UNIT-NUM(WS-0011-T11-INDEX),
           ' PCT ELECT ',
           WS-0011-TBL-YLD-CONVR-PCT-FCTR(WS-0011-T11-INDEX),
           ' $AMT INS ',
           WS-0011-TBL-DOLLAR-AMT-INSUR(WS-0011-T11-INDEX),
           ' GUAR RED % ',
           WS-0011-TBL-GUARANTEE-RED-PCT(WS-0011-T11-INDEX),
           ' RATE STATE ',
           WS-0011-TBL-RATE-STATE(WS-0011-T11-INDEX),
           ' RATE CNTY ',
           WS-0011-TBL-RATE-COUNTY(WS-0011-T11-INDEX)
           UPON CONSOLE
           DISPLAY 'TYPE/PRACTICE OPTION CD ',
           WS-0011-TBL-TYPE-PRAC-OPT-CD(WS-0011-T11-INDEX),
           ' CRUSH DISTRICT ',
           WS-0011-TBL-CRUSH-DISTRICT(WS-0011-T11-INDEX)
           UPON CONSOLE
      $END

           IF WS-T21-LOCATION-COUNTY =
              WS-0011-TBL-LOCATION-COUNTY(WS-0011-T11-INDEX) AND
              WS-T21-TYPE-CD =
              WS-0011-TBL-TYPE-CD(WS-0011-T11-INDEX) AND
              WS-T21-UNIT-NUM =
              WS-0011-TBL-UNIT-NUM(WS-0011-T11-INDEX)
              IF WS-0011-TBL-YLD-CONVR-PCT-FCTR(WS-0011-T11-INDEX) >
                 WS-2021-PERCENT-ELECTION
                 MOVE WS-0011-TBL-YLD-CONVR-PCT-FCTR
                      (WS-0011-T11-INDEX)
                   TO WS-2021-PERCENT-ELECTION
              END-IF
              IF WS-0011-TBL-DOLLAR-AMT-INSUR(WS-0011-T11-INDEX) >
                 WS-2021-DOLLAR-AMT-INS
                 MOVE WS-0011-TBL-DOLLAR-AMT-INSUR
                      (WS-0011-T11-INDEX)
                   TO WS-2021-DOLLAR-AMT-INS
              END-IF
              IF WS-2021-GUAR-REDUCTION-FCTR <> ZERO
                 MOVE WS-LITERAL-YES
                   TO WS-2021-MULTIPLE-GUAR-RED-PCTS
              END-IF
      *       *** KEEP THE SMALLEST GUARANTEE REDUCTION %
              IF WS-0011-TBL-GUARANTEE-RED-PCT(WS-0011-T11-INDEX) <
                 WS-2021-GUAR-REDUCTION-FCTR
                 MOVE WS-0011-TBL-GUARANTEE-RED-PCT
                      (WS-0011-T11-INDEX)
                   TO WS-2021-GUAR-REDUCTION-FCTR
              END-IF
              MOVE WS-0011-TBL-RATE-STATE(WS-0011-T11-INDEX)
                TO WS-2021-RATE-STATE
              MOVE WS-0011-TBL-RATE-COUNTY(WS-0011-T11-INDEX)
                TO WS-2021-RATE-COUNTY
              MOVE WS-0011-TBL-TYPE-PRAC-OPT-CD(WS-0011-T11-INDEX)
                TO WS-2021-TYPE-PRACT-OPTION-CD
              MOVE WS-0011-TBL-CRUSH-DISTRICT(WS-0011-T11-INDEX)
                TO WS-2021-CRUSH-DISTRICT
           END-IF.


       2021-FIND-T11-EXIT.
           EXIT.



