      ******************************************************************
      *  File:     IF2215.CBL
      *  Author:   Laura Dittamo
      *  Date:     7/31/95
      *  Purpose:  Validate the id type for a given entity type.
      *            Record Number 001 may not have entity type = "O".
      *
      *  Entity Type                            Id Type
      *  I-Individual                           1-SSN
      *  J-Joint Operators                      2-EIN
      *  T-Irrevocable Trust                    4-EIN Applied For
      *  M-Tobacco Producer
      *  U-Individual with Undivided Interest
      *  R-Revocable Trust
      *
      *  C-Corporation                          2-EIN
      *  N-Enterprise                           4-EIN Applied For
      *  P-Partnership
      *  E-Tax Exempt
      *  G-Government
      *
      *  O-Other                                2-EIN
      *                                         3-Other
      *                                         4-EIN Applied For
      *
      *  B-Bureau of Indian Affairs             5-BIA NUMber
      *
      ******************************************************************

       2215-VAL-ENTITY-ID-INFO.

      $IF DEBUG-SW DEFINED
           DISPLAY '2215-VALIDATING ENTITY/ID INFO'
           UPON CONSOLE
      $END

      ************************************************
      *            CHECK PRE-CONDITIONS              *
      ************************************************

           IF ERROR-ENTITY-TYPE = WS-LITERAL-YES
              GO TO 2215-VAL-ENTITY-ID-INFO-EXIT
           END-IF

           IF ERROR-REC-NO NOT = WS-LITERAL-YES
      **************************************************
      *  RECORD NUMBER 001 MAY NOT HAVE ENTITY TYPE    *
      *  'O' (OTHER).                                  *
      **************************************************
              IF WS-2215-ENTITY-TYPE = WS-LITERAL-OTHER-ENTITY
                 AND WS-2215-RECORD-NUMBER = 001
                 MOVE 10055 TO WS-8000-ERROR-CODE
                 MOVE WS-LITERAL-YES TO ERROR-REC-NO
                 MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                 MOVE WS-LITERAL-REC-NO TO WS-8000-FIELD-NAME1
                 MOVE WS-2215-RECORD-NUMBER TO WS-8000-BAD-DATA1
                 MOVE SPACES TO WS-8000-CORR-DATA1
                 MOVE WS-LITERAL-ENTITY-TYPE TO WS-8000-FIELD-NAME2
                 MOVE WS-2215-ENTITY-TYPE TO WS-8000-CORR-DATA2
                 MOVE 2215 TO WS-8000-PARAGRAPH-NO
                 PERFORM 8000-RECORD-TRAN-ERROR
                    THRU 8000-RECORD-TRAN-ERROR-EXIT
                 GO TO 2215-VAL-ENTITY-ID-INFO-EXIT
              END-IF
           END-IF

           IF ERROR-ID-TYPE = WS-LITERAL-YES
              GO TO 2215-VAL-ENTITY-ID-INFO-EXIT
           END-IF


      ************************************************
      *              NORMAL PROCESSING               *
      ************************************************

           EVALUATE WS-2215-ENTITY-TYPE

              WHEN WS-LITERAL-INDIVIDUAL
                 IF (WS-2215-ID-TYPE NOT = WS-LITERAL-SSN
                    AND WS-2215-ID-TYPE NOT = WS-LITERAL-EIN
                    AND WS-2215-ID-TYPE NOT
                        = WS-LITERAL-EIN-APPLIED-FOR)
                    MOVE 10056 TO WS-8000-ERROR-CODE
                    MOVE WS-LITERAL-YES TO ERROR-ID-TYPE
                    MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                    MOVE WS-LITERAL-ID-TYPE TO WS-8000-FIELD-NAME1
                    MOVE WS-2215-ID-TYPE TO WS-8000-BAD-DATA1
                    MOVE '1, 2, 4' TO WS-8000-CORR-DATA1
                    MOVE WS-LITERAL-ENTITY-TYPE TO WS-8000-FIELD-NAME2
                    MOVE WS-2215-ENTITY-TYPE TO WS-8000-CORR-DATA2
                    MOVE 2215 TO WS-8000-PARAGRAPH-NO
                    PERFORM 8000-RECORD-TRAN-ERROR
                       THRU 8000-RECORD-TRAN-ERROR-EXIT
                 END-IF

              WHEN WS-LITERAL-IRREVOCABLE-TRUST
                 IF (WS-2215-ID-TYPE NOT = WS-LITERAL-SSN
                    AND WS-2215-ID-TYPE NOT = WS-LITERAL-EIN
                    AND WS-2215-ID-TYPE NOT
                        = WS-LITERAL-EIN-APPLIED-FOR)
                    MOVE 10056 TO WS-8000-ERROR-CODE
                    MOVE WS-LITERAL-YES TO ERROR-ID-TYPE
                    MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                    MOVE WS-LITERAL-ID-TYPE TO WS-8000-FIELD-NAME1
                    MOVE WS-2215-ID-TYPE TO WS-8000-BAD-DATA1
                    MOVE '1, 2, 4' TO WS-8000-CORR-DATA1
                    MOVE WS-LITERAL-ENTITY-TYPE TO WS-8000-FIELD-NAME2
                    MOVE WS-2215-ENTITY-TYPE TO WS-8000-CORR-DATA2
                    MOVE 2215 TO WS-8000-PARAGRAPH-NO
                    PERFORM 8000-RECORD-TRAN-ERROR
                       THRU 8000-RECORD-TRAN-ERROR-EXIT
                 END-IF

              WHEN WS-LITERAL-REVOCABLE-TRUST
                 IF (WS-2215-ID-TYPE NOT = WS-LITERAL-SSN AND
                    WS-2215-ID-TYPE NOT = WS-LITERAL-EIN AND
                    WS-2215-ID-TYPE NOT = WS-LITERAL-EIN-APPLIED-FOR)
                    MOVE 10056 TO WS-8000-ERROR-CODE
                    MOVE WS-LITERAL-YES TO ERROR-ID-TYPE
                    MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                    MOVE WS-LITERAL-ID-TYPE TO WS-8000-FIELD-NAME1
                    MOVE WS-2215-ID-TYPE TO WS-8000-BAD-DATA1
                    MOVE '1, 2, 4' TO WS-8000-CORR-DATA1
                    MOVE WS-LITERAL-ENTITY-TYPE TO WS-8000-FIELD-NAME2
                    MOVE WS-2215-ENTITY-TYPE TO WS-8000-CORR-DATA2
                    MOVE 2215 TO WS-8000-PARAGRAPH-NO
                    PERFORM 8000-RECORD-TRAN-ERROR
                       THRU 8000-RECORD-TRAN-ERROR-EXIT
                 END-IF

              WHEN WS-LITERAL-TOBACCO-MKTG-CARD
                 IF (WS-2215-ID-TYPE NOT = WS-LITERAL-SSN
                    AND WS-2215-ID-TYPE NOT = WS-LITERAL-EIN
                    AND WS-2215-ID-TYPE NOT
                        = WS-LITERAL-EIN-APPLIED-FOR)
                    MOVE 10056 TO WS-8000-ERROR-CODE
                    MOVE WS-LITERAL-YES TO ERROR-ID-TYPE
                    MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                    MOVE WS-LITERAL-ID-TYPE TO WS-8000-FIELD-NAME1
                    MOVE WS-2215-ID-TYPE TO WS-8000-BAD-DATA1
                    MOVE '1, 2, 4' TO WS-8000-CORR-DATA1
                    MOVE WS-LITERAL-ENTITY-TYPE TO WS-8000-FIELD-NAME2
                    MOVE WS-2215-ENTITY-TYPE TO WS-8000-CORR-DATA2
                    MOVE 2215 TO WS-8000-PARAGRAPH-NO
                    PERFORM 8000-RECORD-TRAN-ERROR
                       THRU 8000-RECORD-TRAN-ERROR-EXIT
                 END-IF

              WHEN WS-LITERAL-UNDIVIDED-INTEREST
                 IF (WS-2215-ID-TYPE NOT = WS-LITERAL-SSN
                    AND WS-2215-ID-TYPE NOT = WS-LITERAL-EIN
                    AND WS-2215-ID-TYPE NOT
                        = WS-LITERAL-EIN-APPLIED-FOR)
                    MOVE 10056 TO WS-8000-ERROR-CODE
                    MOVE WS-LITERAL-YES TO ERROR-ID-TYPE
                    MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                    MOVE WS-LITERAL-ID-TYPE TO WS-8000-FIELD-NAME1
                    MOVE WS-2215-ID-TYPE TO WS-8000-BAD-DATA1
                    MOVE '1, 2, 4' TO WS-8000-CORR-DATA1
                    MOVE WS-LITERAL-ENTITY-TYPE TO WS-8000-FIELD-NAME2
                    MOVE WS-2215-ENTITY-TYPE TO WS-8000-CORR-DATA2
                    MOVE 2215 TO WS-8000-PARAGRAPH-NO
                    PERFORM 8000-RECORD-TRAN-ERROR
                       THRU 8000-RECORD-TRAN-ERROR-EXIT
                 END-IF

              WHEN WS-LITERAL-CORPORATION
                 IF (WS-2215-ID-TYPE NOT = WS-LITERAL-EIN AND
                    WS-2215-ID-TYPE NOT = WS-LITERAL-EIN-APPLIED-FOR)
                    MOVE 10056 TO WS-8000-ERROR-CODE
                    MOVE WS-LITERAL-YES TO ERROR-ID-TYPE
                    MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                    MOVE WS-LITERAL-ID-TYPE TO WS-8000-FIELD-NAME1
                    MOVE WS-2215-ID-TYPE TO WS-8000-BAD-DATA1
                    MOVE '2 OR 4' TO WS-8000-CORR-DATA1
                    MOVE WS-LITERAL-ENTITY-TYPE TO WS-8000-FIELD-NAME2
                    MOVE WS-2215-ENTITY-TYPE TO WS-8000-CORR-DATA2
                    MOVE 2215 TO WS-8000-PARAGRAPH-NO
                    PERFORM 8000-RECORD-TRAN-ERROR
                       THRU 8000-RECORD-TRAN-ERROR-EXIT
                 END-IF

              WHEN WS-LITERAL-PARTNERSHIP
                 IF (WS-2215-ID-TYPE NOT = WS-LITERAL-EIN AND
                    WS-2215-ID-TYPE NOT = WS-LITERAL-EIN-APPLIED-FOR)
                    MOVE 10056 TO WS-8000-ERROR-CODE
                    MOVE WS-LITERAL-YES TO ERROR-ID-TYPE
                    MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                    MOVE WS-LITERAL-ID-TYPE TO WS-8000-FIELD-NAME1
                    MOVE WS-2215-ID-TYPE TO WS-8000-BAD-DATA1
                    MOVE '2 OR 4' TO WS-8000-CORR-DATA1
                    MOVE WS-LITERAL-ENTITY-TYPE TO WS-8000-FIELD-NAME2
                    MOVE WS-2215-ENTITY-TYPE TO WS-8000-CORR-DATA2
                    MOVE 2215 TO WS-8000-PARAGRAPH-NO
                    PERFORM 8000-RECORD-TRAN-ERROR
                       THRU 8000-RECORD-TRAN-ERROR-EXIT
                 END-IF

              WHEN WS-LITERAL-TAX-EXEMPT
                 IF (WS-2215-ID-TYPE NOT = WS-LITERAL-EIN AND
                    WS-2215-ID-TYPE NOT = WS-LITERAL-EIN-APPLIED-FOR)
                    MOVE 10056 TO WS-8000-ERROR-CODE
                    MOVE WS-LITERAL-YES TO ERROR-ID-TYPE
                    MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                    MOVE WS-LITERAL-ID-TYPE TO WS-8000-FIELD-NAME1
                    MOVE WS-2215-ID-TYPE TO WS-8000-BAD-DATA1
                    MOVE '2 OR 4' TO WS-8000-CORR-DATA1
                    MOVE WS-LITERAL-ENTITY-TYPE TO WS-8000-FIELD-NAME2
                    MOVE WS-2215-ENTITY-TYPE TO WS-8000-CORR-DATA2
                    MOVE 2215 TO WS-8000-PARAGRAPH-NO
                    PERFORM 8000-RECORD-TRAN-ERROR
                       THRU 8000-RECORD-TRAN-ERROR-EXIT
                 END-IF

              WHEN WS-LITERAL-GOVERNMENT
                 IF (WS-2215-ID-TYPE NOT = WS-LITERAL-EIN AND
                    WS-2215-ID-TYPE NOT = WS-LITERAL-EIN-APPLIED-FOR)
                    MOVE 10056 TO WS-8000-ERROR-CODE
                    MOVE WS-LITERAL-YES TO ERROR-ID-TYPE
                    MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                    MOVE WS-LITERAL-ID-TYPE TO WS-8000-FIELD-NAME1
                    MOVE WS-2215-ID-TYPE TO WS-8000-BAD-DATA1
                    MOVE '2 OR 4' TO WS-8000-CORR-DATA1
                    MOVE WS-LITERAL-ENTITY-TYPE TO WS-8000-FIELD-NAME2
                    MOVE WS-2215-ENTITY-TYPE TO WS-8000-CORR-DATA2
                    MOVE 2215 TO WS-8000-PARAGRAPH-NO
                    PERFORM 8000-RECORD-TRAN-ERROR
                       THRU 8000-RECORD-TRAN-ERROR-EXIT
                 END-IF

              WHEN WS-LITERAL-JOINT-OPERATORS
                 IF (WS-2215-ID-TYPE NOT = WS-LITERAL-SSN AND
                    WS-2215-ID-TYPE NOT = WS-LITERAL-EIN AND
                    WS-2215-ID-TYPE NOT = WS-LITERAL-EIN-APPLIED-FOR)
                    MOVE 10056 TO WS-8000-ERROR-CODE
                    MOVE WS-LITERAL-YES TO ERROR-ID-TYPE
                    MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                    MOVE WS-LITERAL-ID-TYPE TO WS-8000-FIELD-NAME1
                    MOVE WS-2215-ID-TYPE TO WS-8000-BAD-DATA1
                    MOVE '1, 2, 4' TO WS-8000-CORR-DATA1
                    MOVE WS-LITERAL-ENTITY-TYPE TO WS-8000-FIELD-NAME2
                    MOVE WS-2215-ENTITY-TYPE TO WS-8000-CORR-DATA2
                    MOVE 2215 TO WS-8000-PARAGRAPH-NO
                    PERFORM 8000-RECORD-TRAN-ERROR
                       THRU 8000-RECORD-TRAN-ERROR-EXIT
                 END-IF

              WHEN WS-LITERAL-ENTERPRISE
                 IF (WS-2215-ID-TYPE NOT = WS-LITERAL-EIN AND
                    WS-2215-ID-TYPE NOT = WS-LITERAL-EIN-APPLIED-FOR)
                    MOVE 10056 TO WS-8000-ERROR-CODE
                    MOVE WS-LITERAL-YES TO ERROR-ID-TYPE
                    MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                    MOVE WS-LITERAL-ID-TYPE TO WS-8000-FIELD-NAME1
                    MOVE WS-2215-ID-TYPE TO WS-8000-BAD-DATA1
                    MOVE '2 OR 4' TO WS-8000-CORR-DATA1
                    MOVE WS-LITERAL-ENTITY-TYPE TO WS-8000-FIELD-NAME2
                    MOVE WS-2215-ENTITY-TYPE TO WS-8000-CORR-DATA2
                    MOVE 2215 TO WS-8000-PARAGRAPH-NO
                    PERFORM 8000-RECORD-TRAN-ERROR
                       THRU 8000-RECORD-TRAN-ERROR-EXIT
                 END-IF

              WHEN WS-LITERAL-OTHER-ENTITY
                 IF (WS-2215-ID-TYPE NOT = WS-LITERAL-EIN AND
                    WS-2215-ID-TYPE NOT = WS-LITERAL-OTHER-ID AND
                    WS-2215-ID-TYPE NOT = WS-LITERAL-EIN-APPLIED-FOR)
                    MOVE 10056 TO WS-8000-ERROR-CODE
                    MOVE WS-LITERAL-YES TO ERROR-ID-TYPE
                    MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                    MOVE WS-LITERAL-ID-TYPE TO WS-8000-FIELD-NAME1
                    MOVE WS-2215-ID-TYPE TO WS-8000-BAD-DATA1
                    MOVE '2, 3, 4' TO WS-8000-CORR-DATA1
                    MOVE WS-LITERAL-ENTITY-TYPE TO WS-8000-FIELD-NAME2
                    MOVE WS-2215-ENTITY-TYPE TO WS-8000-CORR-DATA2
                    MOVE 2215 TO WS-8000-PARAGRAPH-NO
                    PERFORM 8000-RECORD-TRAN-ERROR
                       THRU 8000-RECORD-TRAN-ERROR-EXIT
                 END-IF

              WHEN WS-LITERAL-BIA
                 IF WS-2215-ID-TYPE NOT = WS-LITERAL-BIA-NUM
                    MOVE 10056 TO WS-8000-ERROR-CODE
                    MOVE WS-LITERAL-YES TO ERROR-ID-TYPE
                    MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                    MOVE WS-LITERAL-ID-TYPE TO WS-8000-FIELD-NAME1
                    MOVE WS-2215-ID-TYPE TO WS-8000-BAD-DATA1
                    MOVE '5' TO WS-8000-CORR-DATA1
                    MOVE WS-LITERAL-ENTITY-TYPE TO WS-8000-FIELD-NAME2
                    MOVE WS-2215-ENTITY-TYPE TO WS-8000-CORR-DATA2
                    MOVE 2215 TO WS-8000-PARAGRAPH-NO
                    PERFORM 8000-RECORD-TRAN-ERROR
                       THRU 8000-RECORD-TRAN-ERROR-EXIT
                 END-IF

              WHEN OTHER
                 MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
                 MOVE 044 TO WS-8000-SHORT-ERROR
                 MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
                 MOVE 'WS-2215-ENTITY-TYPE' TO WS-8000-FIELD-NAME1
                 MOVE WS-2215-ENTITY-TYPE TO WS-8000-BAD-DATA1
                 MOVE 'SEE M-13' TO WS-8000-CORR-DATA1
                 MOVE 2215 TO WS-8000-PARAGRAPH-NO
                 MOVE WS-LITERAL-YES TO ERROR-ENTITY-TYPE
                 MOVE WS-LITERAL-YES TO ERROR-ID-TYPE
                 PERFORM 8000-RECORD-TRAN-ERROR
                    THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-EVALUATE.


       2215-VAL-ENTITY-ID-INFO-EXIT.
           EXIT.





