      ******************************************************************
      *  File:     IF2235.CBL
      *  Author:   Laura Dittamo
      *  Date:     8/10/95
      *  Purpose:  Perform interfield edits for rate state and rate
      *            county.  When the policy is not CFSA under CAT
      *            coverage Rate State and Rate County must contain
      *            valid values.  By field, valid values are:
      * - Rate State {value > 0 - db check done in field validation};*
      * - Rate County {county codes in database}; **
      *  *   If the crop code=56 (Nursery), the Rate State must equal
      *      the Location State.
      *  **  If the crop code=56 (Nursery), the Rate County must equal
      *      the Location County.
      ******************************************************************

       2235-VAL-NON-CAT-RATE.

      $IF DEBUG-SW DEFINED
           DISPLAY '2235-VALIDATING NON-CAT RATE STATE AND COUNTY'
           UPON CONSOLE
      $END

      ************************************************
      *              CHECK PRE-CONDITIONS            *
      ************************************************

           IF ERROR-RO = WS-LITERAL-YES OR
              ERROR-CVG-FL = WS-LITERAL-YES OR
              ERROR-RATE-STATE = WS-LITERAL-YES OR
              ERROR-CROP-CD = WS-LITERAL-YES OR
              ERROR-LOC-STATE = WS-LITERAL-YES OR
              ERROR-RATE-COUNTY = WS-LITERAL-YES

              MOVE WS-LITERAL-YES TO ERROR-RATE-COUNTY
              MOVE WS-LITERAL-YES TO ERROR-RATE-STATE
              GO TO 2235-VAL-NON-CAT-RATE-EXIT
           END-IF

      ************************************************
      *              NORMAL PROCESSING               *
      ************************************************

      **************************
      * RATE STATE VALIDATION  *
      **************************

           IF WS-2235-RATE-STATE > ZERO
      *****************************************
      * IF THE CROP IS NURSERY THE RATE STATE *
      * MUST EQUAL THE LOCATION STATE         *
      *****************************************

              IF WS-2235-CROP-CD = WS-LITERAL-NURSERY
                 IF WS-2235-RATE-STATE NOT = WS-2235-LOCATION-STATE
                    MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                    MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
                    MOVE 023 TO WS-8000-SHORT-ERROR
                    MOVE WS-LITERAL-YES TO ERROR-RATE-STATE
                    MOVE WS-LITERAL-RT-STATE TO WS-8000-FIELD-NAME1
                    MOVE WS-2235-RATE-STATE TO WS-8000-BAD-DATA1
                    MOVE WS-2235-LOCATION-STATE TO WS-8000-CORR-DATA1
                    MOVE WS-LITERAL-CROP-CD TO WS-8000-FIELD-NAME2
                    MOVE SPACES TO WS-8000-BAD-DATA2
                    MOVE WS-2235-CROP-CD TO WS-8000-CORR-DATA2
                    MOVE 2235 TO WS-8000-PARAGRAPH-NO
                    PERFORM 8000-RECORD-TRAN-ERROR
                       THRU 8000-RECORD-TRAN-ERROR-EXIT
                 END-IF
              END-IF
           ELSE
              MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 004 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-YES TO ERROR-RATE-STATE
              MOVE WS-LITERAL-RT-STATE TO WS-8000-FIELD-NAME1
              MOVE WS-2235-RATE-STATE TO WS-8000-BAD-DATA1
              MOVE SPACES TO WS-8000-CORR-DATA1
              MOVE 2235 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

      ************************************************
      *    CHECK PRE-CONDITIONS FOR RATE COUNTY      *
      ************************************************

           IF ERROR-RATE-STATE = WS-LITERAL-YES OR
              ERROR-RATE-COUNTY = WS-LITERAL-YES OR
              ERROR-LOC-CNTY = WS-LITERAL-YES

              MOVE WS-LITERAL-YES TO ERROR-RATE-COUNTY
              GO TO 2235-VAL-NON-CAT-RATE-EXIT
           END-IF

      **************************
      * RATE COUNTY VALIDATION *
      **************************

           IF WS-2235-RATE-COUNTY = ZEROS
              MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 004 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-YES TO ERROR-RATE-COUNTY
              MOVE WS-LITERAL-RT-CNTY TO WS-8000-FIELD-NAME1
              MOVE WS-2235-RATE-COUNTY TO WS-8000-BAD-DATA1
              MOVE SPACES TO WS-8000-CORR-DATA1
              MOVE 2235 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
              GO TO 2235-VAL-NON-CAT-RATE-EXIT
           END-IF


      $IF DATABASE-SW DEFINED
           PERFORM 2235-LOOKUP-COUNTY-DB
              THRU 2235-LOOKUP-COUNTY-DB-EXIT.
      $END


      $IF ISAM-SW DEFINED
           PERFORM 2235-LOOKUP-COUNTY-TBL
              THRU 2235-LOOKUP-COUNTY-TBL-EXIT.
      $END



       2235-VAL-NON-CAT-RATE-EXIT.
           EXIT.



      $IF DATABASE-SW DEFINED

       2235-LOOKUP-COUNTY-DB.

           INITIALIZE WS-6265-INPUT

           MOVE WS-2235-RATE-STATE TO WS-6265-FIPS-STATE-CD
           MOVE WS-2235-RATE-COUNTY TO WS-6265-COUNTY

           PERFORM 6265-LOOKUP-COUNTY
              THRU 6265-LOOKUP-COUNTY-EXIT

           IF MATCH-FOUND-6265
      ******************************************
      * IF THE CROP IS NURSERY THE RATE COUNTY *
      * MUST EQUAL THE LOCATION COUNTY         *
      ******************************************

              IF WS-2235-CROP-CD = WS-LITERAL-NURSERY
                 IF WS-2235-RATE-COUNTY NOT = WS-2235-LOCATION-COUNTY
                    MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                    MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
                    MOVE 024 TO WS-8000-SHORT-ERROR
                    MOVE WS-LITERAL-YES TO ERROR-RATE-COUNTY
                    MOVE WS-LITERAL-RT-CNTY TO WS-8000-FIELD-NAME1
                    MOVE WS-2235-RATE-COUNTY TO WS-8000-BAD-DATA1
                    MOVE WS-2235-LOCATION-COUNTY
                      TO WS-8000-CORR-DATA1
                    MOVE 2235 TO WS-8000-PARAGRAPH-NO
                    PERFORM 8000-RECORD-TRAN-ERROR
                       THRU 8000-RECORD-TRAN-ERROR-EXIT
                 END-IF
              END-IF
           ELSE
      * COUNTY NOT FOUND
              MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 009 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-YES TO ERROR-RATE-COUNTY
              MOVE WS-LITERAL-RT-CNTY TO WS-8000-FIELD-NAME1
              MOVE WS-2235-RATE-COUNTY TO WS-8000-BAD-DATA1
              MOVE SPACES TO WS-8000-CORR-DATA1
              MOVE 'COUNTY' TO WS-8000-TABLE-NAME
              MOVE 2235 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF.


       2235-LOOKUP-COUNTY-DB-EXIT.
           EXIT.

      $END

      $IF ISAM-SW DEFINED

       2235-LOOKUP-COUNTY-TBL.

           INITIALIZE WS-7265-I-FIPS-STATE
           INITIALIZE WS-7265-I-COUNTY

           MOVE WS-2235-RATE-STATE TO WS-7265-I-FIPS-STATE
           MOVE WS-2235-RATE-COUNTY TO WS-7265-I-COUNTY

           PERFORM 7265-LOOKUP-COUNTY-TBL
              THRU 7265-LOOKUP-COUNTY-TBL-EXIT

           IF MATCH-FOUND-7265
      ******************************************
      * IF THE CROP IS NURSERY THE RATE COUNTY *
      * MUST EQUAL THE LOCATION COUNTY         *
      ******************************************

              IF WS-2235-CROP-CD = WS-LITERAL-NURSERY
                 IF WS-2235-RATE-COUNTY NOT = WS-2235-LOCATION-COUNTY
                    MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                    MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
                    MOVE 024 TO WS-8000-SHORT-ERROR
                    MOVE WS-LITERAL-YES TO ERROR-RATE-COUNTY
                    MOVE WS-LITERAL-RT-CNTY TO WS-8000-FIELD-NAME1
                    MOVE WS-2235-RATE-COUNTY TO WS-8000-BAD-DATA1
                    MOVE WS-2235-LOCATION-COUNTY
                      TO WS-8000-CORR-DATA1
                    MOVE 2235 TO WS-8000-PARAGRAPH-NO
                    PERFORM 8000-RECORD-TRAN-ERROR
                       THRU 8000-RECORD-TRAN-ERROR-EXIT
                 END-IF
              END-IF
           ELSE
      * COUNTY NOT FOUND
              MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 009 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-YES TO ERROR-RATE-COUNTY
              MOVE WS-LITERAL-RT-CNTY TO WS-8000-FIELD-NAME1
              MOVE WS-2235-RATE-COUNTY TO WS-8000-BAD-DATA1
              MOVE SPACES TO WS-8000-CORR-DATA1
              MOVE 'COUNTY' TO WS-8000-TABLE-NAME
              MOVE 2235 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF.

       2235-LOOKUP-COUNTY-TBL-EXIT.
           EXIT.

      $END
