      ******************************************************************
      *    File:     IF2240.CBL                                        *
      *    Author:   C. B. O'Neill                                     *
      *    Date:     8/30/95                                           *
      *    Purpose:  2240-val-crop-type                                *
      *                                                                *
      *              Type 11, 15:                                      *
      *              Ensure crop type is valid.  Ensure that certain   *
      *              combinations of crop and crop type are not        *
      *              permitted if coverage is catastrophic.            *
      *                                                                *
      *              Type 14:                                          *
      *              Crop Type must be spaces unless the crop is one   *
      *              of the following:                                 *
      *                                                                *
      *                                                                *
      *                       TEXAS CITRUS TREES (0025) - NOT for 97   *
      *                       FLORIDA CITRUS (0026) - for 97, NOT 98   *
      *                       CALIFORNIA GRAPES (0053)  - for 97 & 98  *
      *                                                                *
      *    Note:     Crop type can be spaces.  If so, the logic to     *
      *              look up the crop type against either the database *
      *              or working storage table is bypassed.  However,   *
      *              the logic to evaluate the crop type with crop code*
      *              will be performed.                                *
      ******************************************************************

       2240-VAL-CROP-TYPE.

      $IF DEBUG-SW DEFINED
           DISPLAY '2240-VALIDATING CROP TYPE = ' WS-2240-CROP-TYPE
           UPON CONSOLE
      $END

      ************************************************
      *    CHECK PRECONDITIONS                       *
      ************************************************
           IF ERROR-CROP-CD = WS-LITERAL-YES OR
              ERROR-CROP-TYPE = WS-LITERAL-YES OR
              ERROR-CVG-FL = WS-LITERAL-YES OR
              ERROR-RATE-STATE = WS-LITERAL-YES
              MOVE WS-LITERAL-YES TO ERROR-CROP-TYPE
              GO TO 2240-VAL-CROP-TYPE-EXIT
           END-IF

      ************************************************
      *    CHECK TO SEE IF TYPE IS REQUIRED          *
      ************************************************

           IF TYPE14
              EVALUATE WS-2240-CROP-CODE
               WHEN WS-LITERAL-CITRUS
                  IF WS-2240-RATE-STATE = WS-LITERAL-FLORIDA
                     CONTINUE
                  ELSE
                     IF WS-2240-CROP-TYPE <> ZEROS
                        MOVE WS-LITERAL-YES TO ERROR-CROP-TYPE
                        MOVE WS-LITERAL-IF  TO WS-8000-ERROR-TYPE
                        MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
                        MOVE 007 TO WS-8000-SHORT-ERROR
                        MOVE WS-LITERAL-CROP-TYPE
                          TO WS-8000-FIELD-NAME1
                        MOVE WS-2240-CROP-TYPE TO WS-8000-BAD-DATA1
                        MOVE ZEROS TO WS-8000-CORR-DATA1
                        MOVE 'CROP TYPE' TO WS-8000-TABLE-NAME
                        MOVE 2240 TO WS-8000-PARAGRAPH-NO
                        PERFORM 8000-RECORD-TRAN-ERROR
                           THRU 8000-RECORD-TRAN-ERROR-EXIT
                     END-IF
                     GO TO 2240-VAL-CROP-TYPE-EXIT
                  END-IF

               WHEN WS-LITERAL-CITRUS-TREES
                  IF WS-2240-RATE-STATE = WS-LITERAL-TEXAS
                     CONTINUE
                  ELSE
                     IF WS-2240-CROP-TYPE <> ZEROS
                        MOVE WS-LITERAL-YES TO ERROR-CROP-TYPE
                        MOVE WS-LITERAL-IF  TO WS-8000-ERROR-TYPE
                        MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
                        MOVE 007 TO WS-8000-SHORT-ERROR
                        MOVE WS-LITERAL-CROP-TYPE
                          TO WS-8000-FIELD-NAME1
                        MOVE WS-2240-CROP-TYPE TO WS-8000-BAD-DATA1
                        MOVE ZEROS TO WS-8000-CORR-DATA1
                        MOVE 'CROP TYPE' TO WS-8000-TABLE-NAME
                        MOVE 2240 TO WS-8000-PARAGRAPH-NO
                        PERFORM 8000-RECORD-TRAN-ERROR
                           THRU 8000-RECORD-TRAN-ERROR-EXIT
                     END-IF
                     GO TO 2240-VAL-CROP-TYPE-EXIT
                  END-IF

               WHEN WS-LITERAL-GRAPES
                  IF WS-2240-RATE-STATE = WS-LITERAL-CALIFORNIA
                     CONTINUE
                  ELSE
                     IF WS-2240-CROP-TYPE <> ZEROS
                        MOVE WS-LITERAL-YES TO ERROR-CROP-TYPE
                        MOVE WS-LITERAL-IF  TO WS-8000-ERROR-TYPE
                        MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
                        MOVE 007 TO WS-8000-SHORT-ERROR
                        MOVE WS-LITERAL-CROP-TYPE
                          TO WS-8000-FIELD-NAME1
                        MOVE WS-2240-CROP-TYPE TO WS-8000-BAD-DATA1
                        MOVE SPACES TO WS-8000-CORR-DATA1
                        MOVE 'CROP TYPE' TO WS-8000-TABLE-NAME
                        MOVE 2240 TO WS-8000-PARAGRAPH-NO
                        PERFORM 8000-RECORD-TRAN-ERROR
                           THRU 8000-RECORD-TRAN-ERROR-EXIT
                     END-IF
                     GO TO 2240-VAL-CROP-TYPE-EXIT
                  END-IF
               WHEN WS-LITERAL-GRAPEFRUIT
               WHEN WS-LITERAL-ALL-OTH-GRAPEFRUIT
               WHEN WS-LITERAL-RUBY-RED-GRAPEFRUIT
               WHEN WS-LITERAL-RIO-RED-STAR-RUBY
               WHEN WS-LITERAL-LEMONS
               WHEN WS-LITERAL-TANGELOS
               WHEN WS-LITERAL-MANDARINS
               WHEN WS-LITERAL-ORANGES
               WHEN WS-LITERAL-MINEOLA-TANGELOS
               WHEN WS-LITERAL-NAVEL-ORANGES
               WHEN WS-LITERAL-SWEET-ORANGES
               WHEN WS-LITERAL-VALENCIA-ORANGES
               WHEN WS-LITERAL-ORLANDO-TANGELOS
               WHEN WS-LITERAL-KINNOW-MANDARINS
               WHEN WS-LITERAL-EARLY-MID-ORANGES
               WHEN WS-LITERAL-LATE-ORANGES
                    GO TO 2240-VAL-CROP-TYPE-EXIT

               WHEN WS-LITERAL-FLUE-CURED-TOBACCO
               WHEN WS-LITERAL-FIRE-CURED-TOBACCO
               WHEN WS-LITERAL-BURLEY-TOBACCO
               WHEN WS-LITERAL-MARYLAND-TOBACCO
               WHEN WS-LITERAL-DARK-AIR-TOBACCO
               WHEN WS-LITERAL-CIGAR-FILL-TOBACCO
               WHEN WS-LITERAL-CIGAR-BINDR-TOBACCO
               WHEN WS-LITERAL-CIGAR-WRAPR-TOBACCO
                   MOVE ZEROS TO WS-2240-CROP-TYPE
                   MOVE ZEROS TO WS-T14-TYPE-CD
                           GO TO 2240-VAL-CROP-TYPE-EXIT
               WHEN OTHER
                  IF WS-2240-CROP-TYPE <> ZEROS
                     MOVE WS-LITERAL-YES TO ERROR-CROP-TYPE
                     MOVE WS-LITERAL-IF  TO WS-8000-ERROR-TYPE
                     MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
                     MOVE 007 TO WS-8000-SHORT-ERROR
                     MOVE WS-LITERAL-CROP-TYPE TO WS-8000-FIELD-NAME1
                     MOVE WS-2240-CROP-TYPE TO WS-8000-BAD-DATA1
                     MOVE '000' TO WS-8000-CORR-DATA1
                     MOVE 'CROP TYPE' TO WS-8000-TABLE-NAME
                     MOVE 2240 TO WS-8000-PARAGRAPH-NO
                     PERFORM 8000-RECORD-TRAN-ERROR
                        THRU 8000-RECORD-TRAN-ERROR-EXIT
                  END-IF
      *           *** FOR THESE CROPS NO TYPE IS REQUIRED
      *           *** AND NO FURTHER EDITS ARE NECESSARY.
                  GO TO 2240-VAL-CROP-TYPE-EXIT
              END-EVALUATE

              IF WS-2240-CROP-TYPE = ZEROS OR
                 WS-2240-CROP-TYPE = '997'
                 MOVE WS-LITERAL-YES TO ERROR-CROP-TYPE
                 MOVE WS-LITERAL-IF  TO WS-8000-ERROR-TYPE
                 MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
                 MOVE 032 TO WS-8000-SHORT-ERROR
                 MOVE WS-LITERAL-CROP-TYPE TO WS-8000-FIELD-NAME1
                 MOVE SPACES TO WS-8000-BAD-DATA1
                 MOVE 'NOT  ZEROS OR 997' TO WS-8000-CORR-DATA1
                 MOVE 'CROP TYPE' TO WS-8000-TABLE-NAME
                 MOVE 2240 TO WS-8000-PARAGRAPH-NO
                 PERFORM 8000-RECORD-TRAN-ERROR
                    THRU 8000-RECORD-TRAN-ERROR-EXIT
                 GO TO 2240-VAL-CROP-TYPE-EXIT
              END-IF
           END-IF

      ************************************************
      *    LOOK UP CROP TYPE IN CROP TYPE TABLE      *
      ************************************************
           PERFORM 2240-LOOKUP-CROP-TYPE
              THRU 2240-LOOKUP-CROP-TYPE-EXIT.


       2240-VAL-CROP-TYPE-EXIT.
           EXIT.




       2240-LOOKUP-CROP-TYPE.

      **********************************************************
      * 997 IS IN THE ADM FOR ALL CROPS WHICH DO NOT REQUIRE A *
      * CROP TYPE.                                             *
      **********************************************************
           IF WS-2240-CROP-TYPE = ZEROS
              MOVE '997' TO WS-2240-CROP-TYPE
           END-IF

      $IF ISAM-SW DEFINED
           MOVE WS-2240-CROP-CODE TO WS-7275-I-CROP
           MOVE WS-2240-CROP-TYPE TO WS-7275-I-CROP-TYPE
           PERFORM 7275-LOOKUP-CROP-TYPE-TBL
              THRU 7275-LOOKUP-CROP-TYPE-TBL-EXIT

           IF NOT MATCH-FOUND-7275
              IF WS-2240-CROP-TYPE = '997'
                 MOVE WS-LITERAL-YES TO ERROR-CROP-TYPE
                 MOVE WS-LITERAL-IF  TO WS-8000-ERROR-TYPE
                 MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
                 MOVE 032 TO WS-8000-SHORT-ERROR
                 MOVE WS-LITERAL-CROP-TYPE TO WS-8000-FIELD-NAME1
                 MOVE WS-2240-CROP-TYPE TO WS-8000-BAD-DATA1
                 MOVE '997 IS NOT VALID FOR THIS CROP'
                   TO WS-8000-CORR-DATA1
                 MOVE 'CROP TYPE' TO WS-8000-TABLE-NAME
                 MOVE 2240 TO WS-8000-PARAGRAPH-NO
                 PERFORM 8000-RECORD-TRAN-ERROR
                    THRU 8000-RECORD-TRAN-ERROR-EXIT
              ELSE
                 MOVE WS-LITERAL-YES TO ERROR-CROP-TYPE
                 MOVE WS-LITERAL-IF  TO WS-8000-ERROR-TYPE
                 MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
                 MOVE 009 TO WS-8000-SHORT-ERROR
                 MOVE WS-LITERAL-CROP-TYPE TO WS-8000-FIELD-NAME1
                 MOVE WS-2240-CROP-TYPE TO WS-8000-BAD-DATA1
                 MOVE SPACES TO WS-8000-CORR-DATA1
                 MOVE 'CROP TYPE' TO WS-8000-TABLE-NAME
                 MOVE 2240 TO WS-8000-PARAGRAPH-NO
                 PERFORM 8000-RECORD-TRAN-ERROR
                    THRU 8000-RECORD-TRAN-ERROR-EXIT
              END-IF
              GO TO 2240-LOOKUP-CROP-TYPE-EXIT
           END-IF.
      $ELSE
           CONTINUE.
      $END

       2240-LOOKUP-CROP-TYPE-EXIT.
           EXIT.

