
      ***************************************************************
      * File:      IF2255.CBL
      * Author:    Laura Dittamo/Mike Ray
      * Date:      01/04/96
      * Purpose:
      *    This routine determines whether each newly submitted type
      *    14 transaction is on time or late.
      *
      *    Assigned Risk = 0   FCIC Control Date cannot be greater
      *                        than the earliest sales closing date
      *                        for the crop in the county plus 45
      *                        days
      *    Assigned Risk = 1   FCIC Control Date cannot be greater
      *                        than the earliest sales closing date
      *                        for the crop in the county plus 30
      *                        days
      *    Assigned Risk = 2   FCIC Control Date cannot  be greater
      *                        than the earliest acreage reporting
      *                        date for the crop in the county plus
      *                        30 days and the record must be CAT
      *                        coverage.
      *    Assigned Risk = 3   FCIC Control Date cannot be greater
      *                        than June 1, 1996.
      *
      *    This routine creates an assigned risk record in the
      *    assigned risk table. If the transaction is submitted before
      *    the assigned risk cutoff date then the transaction may change
      *    an existing assigned risk record.
      *
      *    If the current crop is different from the held crop, the
      *    Assigned risk inter-record edits are performed and the table
      *    is initialized before the new record is added.
      *
      *  Modifications
      *
      *  11/05/97  Use RATE state & county instead of LOCATION for
      *            ADM3 lookup.  jlh.
      ***************************************************************

       2255-DETERMINE-TRANS-LATE.

      $IF DEBUG-SW DEFINED
           DISPLAY '2255-DETERMINING IF TRANSACTION IS LATE'
           UPON CONSOLE
      $END

      **********************************************
      *       INITIALIZE LOCAL VARIABLES           *
      **********************************************
           INITIALIZE WS-2255-WORK

      **********************************************
      *            CHECK PRE-CONDITIONS            *
      **********************************************
           IF ERROR-FCIC-CTRL-DT = WS-LITERAL-YES
              MOVE WS-0004-FCIC-PROC-DATE TO WS-2255-FCIC-CTRL-DT
              MOVE WS-0004-FCIC-PROC-TIME TO WS-2255-FCIC-PROC-TIME
      $IF DEBUG-SW DEFINED
           DISPLAY 'FCIC CTRL DT BAD; RESET TO WS-0004-FCIC-CTRL-DT'
           UPON CONSOLE
      $END
           END-IF

           IF ERROR-LOC-STATE = WS-LITERAL-YES
              OR ERROR-LOC-CNTY = WS-LITERAL-YES
              OR ERROR-CROP-CD = WS-LITERAL-YES
              OR ERROR-INSUR-PLAN-CD = WS-LITERAL-YES
              OR ERROR-CROP-TYPE = WS-LITERAL-YES
              OR ERROR-ASSIGNED-RISK = WS-LITERAL-YES
              OR ERROR-FCIC-CTRL-DT = WS-LITERAL-YES
              OR ERROR-LATE-PROCESS-FL = WS-LITERAL-YES
              OR ERROR-RO = WS-LITERAL-YES
              OR ERROR-CPNY-CNTY = WS-LITERAL-YES
              OR ERROR-POLICY-NO = WS-LITERAL-YES
              OR ERROR-CROP-YR = WS-LITERAL-YES
              OR ERROR-DUAL-CVG-FL = WS-LITERAL-YES
              OR ERROR-REINSURE-YR = WS-LITERAL-YES
              OR ERROR-CVG-FL = WS-LITERAL-YES

              GO TO 2255-DETERMINE-TRANS-LATE-EXIT
           END-IF

           IF WS-0004-BATCH-NO IS NOT NUMERIC
              MOVE 2255 TO WS-8020-PARAGRAPH-NO
              MOVE 90001 TO WS-8020-INT-ERROR-NO
              MOVE 'WS-0004-BATCH-NO' TO WS-8020-FIELD-NAME
              MOVE WS-0004-BATCH-NO TO WS-8020-BAD-DATA
              MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
              PERFORM 8020-RECORD-INT-ERROR
                 THRU 8020-RECORD-INT-ERROR-EXIT
           END-IF

           IF WS-0004-BATCH-NO IS EQUAL ZEROS
              MOVE 2255 TO WS-8020-PARAGRAPH-NO
              MOVE 90003 TO WS-8020-INT-ERROR-NO
              MOVE 'WS-0004-BATCH-NO' TO WS-8020-FIELD-NAME
              MOVE WS-0004-BATCH-NO TO WS-8020-BAD-DATA
              MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
              PERFORM 8020-RECORD-INT-ERROR
                 THRU 8020-RECORD-INT-ERROR-EXIT
           END-IF

           IF WS-0004-TRAN-SEQ-NO IS NOT NUMERIC
              MOVE 2255 TO WS-8020-PARAGRAPH-NO
              MOVE 90001 TO WS-8020-INT-ERROR-NO
              MOVE 'WS-0004-TRAN-SEQ-NO' TO WS-8020-FIELD-NAME
              MOVE WS-0004-TRAN-SEQ-NO TO WS-8020-BAD-DATA
              MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
              PERFORM 8020-RECORD-INT-ERROR
                 THRU 8020-RECORD-INT-ERROR-EXIT
           END-IF

           IF WS-0004-TRAN-SEQ-NO IS EQUAL ZEROS
              MOVE 2255 TO WS-8020-PARAGRAPH-NO
              MOVE 90003 TO WS-8020-INT-ERROR-NO
              MOVE 'WS-0004-TRAN-SEQ-NO' TO WS-8020-FIELD-NAME
              MOVE WS-0004-TRAN-SEQ-NO TO WS-8020-BAD-DATA
              MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
              PERFORM 8020-RECORD-INT-ERROR
                 THRU 8020-RECORD-INT-ERROR-EXIT
           END-IF

           IF WS-0004-REINS-YR IS NOT NUMERIC
              MOVE 2255 TO WS-8020-PARAGRAPH-NO
              MOVE 90001 TO WS-8020-INT-ERROR-NO
              MOVE 'WS-0004-REINS-YR' TO WS-8020-FIELD-NAME
              MOVE WS-0004-REINS-YR TO WS-8020-BAD-DATA
              MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
              PERFORM 8020-RECORD-INT-ERROR
                 THRU 8020-RECORD-INT-ERROR-EXIT
           END-IF

           IF WS-0004-REINS-YR IS EQUAL ZEROS
              MOVE 2255 TO WS-8020-PARAGRAPH-NO
              MOVE 90003 TO WS-8020-INT-ERROR-NO
              MOVE 'WS-0004-REINS-YR' TO WS-8020-FIELD-NAME
              MOVE WS-0004-REINS-YR TO WS-8020-BAD-DATA
              MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
              PERFORM 8020-RECORD-INT-ERROR
                 THRU 8020-RECORD-INT-ERROR-EXIT
           END-IF

           IF WS-0009-LATE-PROCESS-FLG IS NOT NUMERIC
              MOVE WS-LITERAL-YES TO ERROR-LATE-PROCESS-FL
              MOVE 2255 TO WS-8020-PARAGRAPH-NO
              MOVE 90001 TO WS-8020-INT-ERROR-NO
              MOVE WS-LITERAL-LATE-PROC-FL TO WS-8020-FIELD-NAME
              MOVE WS-0009-LATE-PROCESS-FLG TO WS-8020-BAD-DATA
              MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
              PERFORM 8020-RECORD-INT-ERROR
                 THRU 8020-RECORD-INT-ERROR-EXIT
           END-IF

      **********************************************
      *        DETERMINE WHETHER OR NOT A CROP     *
      *        CHANGE HAS OCCURED.                 *
      **********************************************

           IF (WS-2255-CROP-CD <> WS-0006-CROP-CODE) AND
              (WS-7014-ASGD-RISK-REC-COUNT > ZERO)
              PERFORM 3345-SAME-ASGD-RISK
                 THRU 3345-SAME-ASGD-RISK-EXIT

      *       ************************************************
      *       *   WRITE OUT ASSIGNED RISK RECORDS            *
      *       ************************************************
              PERFORM 0990-RECORD-ASSIGNED-RISK
                 THRU 0990-RECORD-ASSIGNED-RISK-EXIT
      **      INITIALIZE THE ASSIGNED RISK TABLE
              INITIALIZE WS-7014-ASGD-RISK-STATUS
              INITIALIZE WS-7014-ASGD-RISK-TBL
           END-IF

      **********************************************
      *        DETERMINE WHETHER THIS TYPE 14      *
      *        HAS BEEN SUBMITTED PREVIOUSLY       *
      **********************************************

           PERFORM 2255-LOOKUP-14-RECORD
              THRU 2255-LOOKUP-14-RECORD-EXIT

           IF WS-2255-EXISTING-14-REC-FOUND = WS-LITERAL-YES
      *       ** RESET THE VALUE OF LOC COUNTY WITH THE INPUT 14'S
      *       ** VALUE IF THE RECORD FOUND HAS RATE COUNTY = 999.
      *       ** THIS LOGIC CAN BE REMOVED WHEN ALL OF THE DATA MIGRATED
      *       ** FROM THE IBM IS NO LONGER NECESSARY
              IF WS-2255-WORK-LOC-COUNTY = 999
                 MOVE WS-2255-LOC-COUNTY
                   TO WS-2255-WORK-LOC-COUNTY
              END-IF

      *       ** RECALCULATE CUTOFF DATE AS IT MAY HAVE CHANGED SINCE
      *       ** THE RECORD WAS CREATED.
              INITIALIZE WS-4200-INPUT
              MOVE WS-2255-WORK-CROP-YEAR TO WS-4200-CROP-YEAR
              MOVE WS-2255-RATE-STATE TO WS-4200-RATE-STATE
              MOVE WS-2255-RATE-COUNTY TO WS-4200-RATE-COUNTY
              MOVE WS-2255-WORK-CROP-CD TO WS-4200-CROP-CD
              MOVE WS-2255-WORK-INSURANCE-PLAN
                   TO WS-4200-INSURANCE-PLAN-ID
              MOVE WS-2255-TYPE-CD TO WS-4200-TYPE-CD
              MOVE WS-2255-WORK-ASSIGNED-RISK TO WS-4200-ASSIGNED-RISK
              PERFORM 4200-CALC-AR-CUTOFF-DT
                 THRU 4200-CALC-AR-CUTOFF-DT-EXIT

              IF CALC-ERROR-4200
                 MOVE WS-LITERAL-YES TO ERROR-ASSIGNED-RISK
                 GO TO 2255-DETERMINE-TRANS-LATE-EXIT
              END-IF

              IF WS-4200-LATE-DATE = ZEROS
      *          *** LATE DATE COULD NOT BE DETERMINED
                 MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                 MOVE 14065 TO WS-8000-ERROR-CODE
                 MOVE WS-LITERAL-YES TO ERROR-ASSIGNED-RISK
                 MOVE 2255 TO WS-8000-PARAGRAPH-NO
                 PERFORM 8000-RECORD-TRAN-ERROR
                    THRU 8000-RECORD-TRAN-ERROR-EXIT
                 GO TO 2255-DETERMINE-TRANS-LATE-EXIT
              ELSE
                 IF WS-4200-LATE-DATE <> WS-2255-WORK-CUTOFF-DATE
                    MOVE WS-4200-LATE-DATE
                      TO WS-2255-WORK-CUTOFF-DATE
                    PERFORM 2255-UPDATE-T14
                       THRU 2255-UPDATE-T14-EXIT
                 END-IF
              END-IF
           END-IF

      *    *** DETERMINE NEW ASSIGNED RISK CUTOFF DATE
      *    *** BASED ON NEW ASSIGNED RISK SETTING
           INITIALIZE WS-4200-INPUT
           MOVE WS-2255-CROP-YEAR TO WS-4200-CROP-YEAR
           MOVE WS-2255-RATE-STATE TO WS-4200-RATE-STATE                ]97C-JLH
           MOVE WS-2255-RATE-COUNTY TO WS-4200-RATE-COUNTY
           MOVE WS-2255-CROP-CD TO WS-4200-CROP-CD
           MOVE WS-2255-INSURANCE-PLAN-ID
             TO WS-4200-INSURANCE-PLAN-ID
           MOVE WS-2255-TYPE-CD TO WS-4200-TYPE-CD
           MOVE WS-2255-ASSIGNED-RISK TO WS-4200-ASSIGNED-RISK
           PERFORM 4200-CALC-AR-CUTOFF-DT
              THRU 4200-CALC-AR-CUTOFF-DT-EXIT
           IF CALC-ERROR-4200
              MOVE WS-LITERAL-YES TO ERROR-ASSIGNED-RISK
              GO TO 2255-DETERMINE-TRANS-LATE-EXIT
           END-IF

           IF WS-4200-LATE-DATE = ZEROS
      *       *** LATE DATE COULD NOT BE DETERMINED
              MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
              MOVE 14065 TO WS-8000-ERROR-CODE
              MOVE WS-LITERAL-YES TO ERROR-ASSIGNED-RISK
              MOVE 2255 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
                GO TO 2255-DETERMINE-TRANS-LATE-EXIT
           ELSE
              MOVE WS-4200-LATE-DATE TO WS-2255-NEW-LATE-DATE
           END-IF

      *************************************************
      *  PROCESS THE NEW ASSIGNED RISK SETTING IF     *
      *  THIS IS THE FIRST TIME THE 14 IS SUBMITTED   *
      *************************************************

           IF WS-2255-EXISTING-14-REC-FOUND = WS-LITERAL-NO
              IF WS-2255-ASSIGNED-RISK = WS-LITERAL-ALT-CROP-EXT AND
                 WS-2255-COVERAGE-FLAG <> WS-LITERAL-CAT
                 MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                 MOVE 14050 TO WS-8000-ERROR-CODE
                 MOVE WS-LITERAL-YES TO ERROR-ASSIGNED-RISK
                 MOVE WS-LITERAL-ASSIGNED-RISK
                   TO WS-8000-FIELD-NAME1
                 MOVE 2255 TO WS-8000-PARAGRAPH-NO
                 PERFORM 8000-RECORD-TRAN-ERROR
                    THRU 8000-RECORD-TRAN-ERROR-EXIT
                 GO TO 2255-DETERMINE-TRANS-LATE-EXIT
              END-IF

      *       *** SEE IF THIS CHANGE IS BEFORE THE CUTOFF DATE FOR
      *       *** THE NEW ASSIGNED RISK SETTING
              INITIALIZE WS-0560-INPUT
              MOVE WS-2255-FCIC-CTRL-DT TO WS-0560-INPUT-DATE1
              MOVE WS-2255-NEW-LATE-DATE TO WS-0560-INPUT-DATE2
              PERFORM 0560-COMPARE-DATES-6
                 THRU 0560-COMPARE-DATES-6-EXIT
      *       *** DATE COMPARE FAILED
              IF NOT VALID-RESULT-FLAG-0560
                 MOVE 2255 TO WS-8020-PARAGRAPH-NO
                 MOVE 90004 TO WS-8020-INT-ERROR-NO
                 MOVE 'WS-0560-RESULT-FLAG' TO WS-8020-FIELD-NAME
                 MOVE WS-0560-RESULT-FLAG TO WS-8020-BAD-DATA
                 MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                 PERFORM 8020-RECORD-INT-ERROR
                    THRU 8020-RECORD-INT-ERROR-EXIT
              END-IF
      *       *** TRANSACTION IS TOO LATE FOR THE CUTOFF DATE FOR
      *       *** THE NEW ASSIGNED RISK SETTING
              IF DATE1-GREATER-THAN-DATE2-0560
                 IF WS-2255-ASSIGNED-RISK = WS-LITERAL-NOT-ASSIGNED
                    IF WS-2255-LATE-PROCESS-FLG > ZERO
      *                *** THE CHANGE IS VALID; ADD IT TO THE TABLE
      *                *** FOR INTER-RECORD VALIDATION
                       PERFORM 2255-ADD-INPUT-RECORD
                          THRU 2255-ADD-INPUT-RECORD-EXIT
                    ELSE
                       MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                       MOVE 14054 TO WS-8000-ERROR-CODE
                       MOVE WS-LITERAL-YES TO ERROR-ASSIGNED-RISK
                       MOVE WS-LITERAL-FCIC-CTRL-DT
                         TO WS-8000-FIELD-NAME1
                       MOVE WS-2255-FCIC-CTRL-DT TO WS-8000-BAD-DATA1
                       STRING '<= '
                          DELIMITED BY SIZE
                          WS-2255-NEW-LATE-DATE
                          DELIMITED BY SIZE
                          INTO WS-8000-CORR-DATA1
                       END-STRING
                       MOVE 2255 TO WS-8000-PARAGRAPH-NO
                       PERFORM 8000-RECORD-TRAN-ERROR
                          THRU 8000-RECORD-TRAN-ERROR-EXIT
                    END-IF
                 ELSE
                    MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                    MOVE 14055 TO WS-8000-ERROR-CODE
                    MOVE WS-LITERAL-YES TO ERROR-ASSIGNED-RISK
                    MOVE WS-LITERAL-FCIC-CTRL-DT
                      TO WS-8000-FIELD-NAME1
                    MOVE WS-2255-FCIC-CTRL-DT TO WS-8000-BAD-DATA1
                    STRING '<= '
                       DELIMITED BY SIZE
                       WS-2255-NEW-LATE-DATE
                       DELIMITED BY SIZE
                       INTO WS-8000-CORR-DATA1
                    END-STRING
                    MOVE 2255 TO WS-8000-PARAGRAPH-NO
                    PERFORM 8000-RECORD-TRAN-ERROR
                       THRU 8000-RECORD-TRAN-ERROR-EXIT
                 END-IF
              ELSE
      *          *** THE CHANGE IS VALID; ADD IT TO THE TABLE
      *          *** FOR INTER-RECORD VALIDATION
                 PERFORM 2255-ADD-INPUT-RECORD
                    THRU 2255-ADD-INPUT-RECORD-EXIT
              END-IF
              GO TO 2255-DETERMINE-TRANS-LATE-EXIT
           END-IF

      ***************************************************
      *  COMPARE THE NEW AND OLD ASSIGNED RISK SETTINGS *
      ***************************************************

      *    *** ASSIGNED RISK DID NOT CHANGE ***
           IF WS-2255-ASSIGNED-RISK = WS-2255-WORK-ASSIGNED-RISK
              GO TO 2255-DETERMINE-TRANS-LATE-EXIT
           END-IF

      *    *** CHECK INPUT ASSIGNED RISK SETTING
           EVALUATE WS-2255-ASSIGNED-RISK
             WHEN WS-LITERAL-NOT-ASSIGNED
                IF WS-2255-WORK-ASSIGNED-RISK
                   = WS-LITERAL-ASSIGNED
      *            *** SEE IF THIS CHANGE IS BEFORE THE CURRENT CUTOFF DATE
                   INITIALIZE WS-0560-INPUT
                   MOVE WS-2255-FCIC-CTRL-DT
                     TO WS-0560-INPUT-DATE1
                   MOVE WS-2255-WORK-CUTOFF-DATE
                     TO WS-0560-INPUT-DATE2
                   PERFORM 0560-COMPARE-DATES-6
                      THRU 0560-COMPARE-DATES-6-EXIT
      *            *** DATE COMPARE FAILED
                   IF NOT VALID-RESULT-FLAG-0560
                      MOVE 2255 TO WS-8020-PARAGRAPH-NO
                      MOVE 90004 TO WS-8020-INT-ERROR-NO
                      MOVE 'WS-0560-RESULT-FLAG' TO WS-8020-FIELD-NAME
                      MOVE WS-0560-RESULT-FLAG TO WS-8020-BAD-DATA
                      MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                      PERFORM 8020-RECORD-INT-ERROR
                         THRU 8020-RECORD-INT-ERROR-EXIT
                   END-IF
      *            *** TRANSACTION IS TOO LATE FOR THE CURRENT CUTOFF DATE
                   IF DATE1-GREATER-THAN-DATE2-0560
                      MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                      MOVE 14056 TO WS-8000-ERROR-CODE
                      MOVE WS-LITERAL-YES TO ERROR-ASSIGNED-RISK
                      MOVE WS-LITERAL-ASSIGNED-RISK
                        TO WS-8000-FIELD-NAME1
                      MOVE 'CUTOFF DATE' TO WS-8000-BAD-DATA1
                      STRING '<= '
                         DELIMITED BY SIZE
                         WS-2255-WORK-CUTOFF-DATE
                         DELIMITED BY SIZE
                         INTO WS-8000-CORR-DATA1
                      END-STRING
                      MOVE 2255 TO WS-8000-PARAGRAPH-NO
                      PERFORM 8000-RECORD-TRAN-ERROR
                         THRU 8000-RECORD-TRAN-ERROR-EXIT
                      GO TO 2255-DETERMINE-TRANS-LATE-EXIT
                   END-IF
                ELSE
      *            *** DROP THROUGH & CHECK NEW CUTOFF
                   CONTINUE
                END-IF

             WHEN WS-LITERAL-ASSIGNED
      *         *** DROP THROUGH & CHECK NEW CUTOFF
                CONTINUE
             WHEN WS-LITERAL-ALT-CROP-EXT
                IF WS-2255-COVERAGE-FLAG <> WS-LITERAL-CAT
                   MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                   MOVE 14050 TO WS-8000-ERROR-CODE
                   MOVE WS-LITERAL-YES TO ERROR-ASSIGNED-RISK
                   MOVE WS-LITERAL-ASSIGNED-RISK
                     TO WS-8000-FIELD-NAME1
                   MOVE 2255 TO WS-8000-PARAGRAPH-NO
                   PERFORM 8000-RECORD-TRAN-ERROR
                      THRU 8000-RECORD-TRAN-ERROR-EXIT
                   GO TO 2255-DETERMINE-TRANS-LATE-EXIT
                ELSE
      *            *** DROP THROUGH & CHECK NEW CUTOFF
                   CONTINUE
                END-IF
             WHEN WS-LITERAL-MGR96014
             when ws-literal-mgr97023
             when ws-literal-mgr97024
      *         *** DROP THROUGH & CHECK NEW CUTOFF
                CONTINUE
             WHEN OTHER
                MOVE WS-LITERAL-YES TO ERROR-ASSIGNED-RISK
                MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
                MOVE 044 TO WS-8000-SHORT-ERROR
                MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
                MOVE WS-LITERAL-ASSIGNED-RISK TO WS-8000-FIELD-NAME1
                MOVE WS-2255-ASSIGNED-RISK TO WS-8000-BAD-DATA1
                MOVE 'NO LOGIC FOR THIS VALUE' TO WS-8000-CORR-DATA1
                MOVE 2255 TO WS-8000-PARAGRAPH-NO
                PERFORM 8000-RECORD-TRAN-ERROR
                   THRU 8000-RECORD-TRAN-ERROR-EXIT
                GO TO 2255-DETERMINE-TRANS-LATE-EXIT
           END-EVALUATE

      *    *** SEE IF THIS CHANGE IS BEFORE THE CUTOFF DATE FOR
      *    *** THE NEW ASSIGNED RISK SETTING
           INITIALIZE WS-0560-INPUT
           MOVE WS-2255-FCIC-CTRL-DT TO WS-0560-INPUT-DATE1
           MOVE WS-2255-NEW-LATE-DATE TO WS-0560-INPUT-DATE2
           PERFORM 0560-COMPARE-DATES-6
              THRU 0560-COMPARE-DATES-6-EXIT
      *    *** DATE COMPARE FAILED
           IF NOT VALID-RESULT-FLAG-0560
              MOVE 2255 TO WS-8020-PARAGRAPH-NO
              MOVE 90004 TO WS-8020-INT-ERROR-NO
              MOVE 'WS-0560-RESULT-FLAG' TO WS-8020-FIELD-NAME
              MOVE WS-0560-RESULT-FLAG TO WS-8020-BAD-DATA
              MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
              PERFORM 8020-RECORD-INT-ERROR
                 THRU 8020-RECORD-INT-ERROR-EXIT
           END-IF
      *    *** TRANSACTION IS TOO LATE FOR THE CUTOFF DATE FOR
      *    *** THE NEW ASSIGNED RISK SETTING
           IF DATE1-GREATER-THAN-DATE2-0560
              IF WS-2255-ASSIGNED-RISK = WS-LITERAL-NOT-ASSIGNED
                 IF WS-2255-LATE-PROCESS-FLG > ZERO
      *             *** THE CHANGE IS VALID; ADD IT TO THE TABLE
      *             *** FOR INTER-RECORD VALIDATION
                    PERFORM 2255-ADD-INPUT-RECORD
                       THRU 2255-ADD-INPUT-RECORD-EXIT
                 ELSE
                    MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                    MOVE 14054 TO WS-8000-ERROR-CODE
                    MOVE WS-LITERAL-YES TO ERROR-ASSIGNED-RISK
                    MOVE WS-LITERAL-FCIC-CTRL-DT
                      TO WS-8000-FIELD-NAME1
                    MOVE WS-2255-FCIC-CTRL-DT TO WS-8000-BAD-DATA1
                    STRING '<= '
                       DELIMITED BY SIZE
                       WS-2255-NEW-LATE-DATE
                       DELIMITED BY SIZE
                       INTO WS-8000-CORR-DATA1
                    END-STRING
                    MOVE 2255 TO WS-8000-PARAGRAPH-NO
                    PERFORM 8000-RECORD-TRAN-ERROR
                       THRU 8000-RECORD-TRAN-ERROR-EXIT
                 END-IF
                 GO TO 2255-DETERMINE-TRANS-LATE-EXIT
              END-IF
              MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
              MOVE 14066 TO WS-8000-ERROR-CODE
              MOVE WS-LITERAL-YES TO ERROR-ASSIGNED-RISK
              MOVE WS-LITERAL-FCIC-CTRL-DT
                TO WS-8000-FIELD-NAME1
              MOVE WS-2255-FCIC-CTRL-DT TO WS-8000-BAD-DATA1
              STRING '<= '
                 DELIMITED BY SIZE
                 WS-2255-NEW-LATE-DATE
                 DELIMITED BY SIZE
                 INTO WS-8000-CORR-DATA1
              END-STRING
              MOVE 2255 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           ELSE
      *       *** THE CHANGE IS VALID; ADD IT TO THE TABLE
      *       *** FOR INTER-RECORD VALIDATION
              PERFORM 2255-ADD-INPUT-RECORD
                 THRU 2255-ADD-INPUT-RECORD-EXIT
           END-IF

      *****************************************************
      *         INITIALIZE INPUT FIELDS                   *
      *****************************************************
           INITIALIZE WS-2255-INPUT-FIELDS.


       2255-DETERMINE-TRANS-LATE-EXIT.
           EXIT.



      $IF ISAM-SW DEFINED

       2255-LOOKUP-14-RECORD.

      $IF DEBUG-SW DEFINED
           DISPLAY '2255-LOCATING PREVIOUSLY SUBMITTED 14'
           UPON CONSOLE
      $END

           IF WS-2255-TYPE-CD = SPACES
              OR WS-2255-TYPE-CD = ZEROS
              MOVE '9997' TO WS-2255-CROP-POLICY-TYPE
           ELSE
      **      LOOKUP THE ASSOCIATED CROP POLICY TYPE
              INITIALIZE WS-7280-I-CROP-POL-TYPE-AREA
              MOVE WS-2255-LOC-STATE TO WS-7280-I-FIPS-STATE
              MOVE WS-2255-CROP-CD TO WS-7280-I-CROP
              MOVE WS-2255-TYPE-CD TO WS-7280-I-CROP-TYPE
              PERFORM 7280-LOOKUP-CPT-TBL
                 THRU 7280-LOOKUP-CPT-TBL-EXIT

              IF MATCH-FOUND-7280
                 MOVE WS-7280-O-CROP-POL-TYPE
                   TO WS-2255-CROP-POLICY-TYPE
              ELSE
                 MOVE '9997' TO WS-2255-CROP-POLICY-TYPE
              END-IF
           END-IF

           INITIALIZE WS-2255-TYPE-14-DATES-WORK
           INITIALIZE WS-7560-INPUT-KEY
           INITIALIZE WS-7560-INPUT-DUAL-CVG-FLG-CHG

           MOVE WS-2255-REPORTING-ORG TO WS-7560-INPUT-REPORTING-ORG
           MOVE WS-2255-LOC-STATE TO WS-7560-INPUT-LOC-STATE
           MOVE WS-2255-COMPANY-COUNTY TO WS-7560-INPUT-COMPANY-COUNTY
           MOVE WS-2255-POLICY-NUM TO WS-7560-INPUT-POLICY-NUM
           MOVE WS-2255-CROP-YEAR TO WS-7560-INPUT-CROP-YEAR
           MOVE WS-2255-CROP-CD TO WS-7560-INPUT-CROP-CD
           MOVE WS-2255-INSURANCE-PLAN-ID
             TO WS-7560-INPUT-INSURANCE-PLAN
           MOVE WS-2255-DUAL-CVG-FLG TO WS-7560-INPUT-DUAL-CVG-FLG
           MOVE WS-2255-LOC-COUNTY TO WS-7560-INPUT-LOC-COUNTY
           MOVE WS-2255-CROP-POLICY-TYPE
             TO WS-7560-INPUT-CROP-POLICY-TYPE

           MOVE WS-2255-FCIC-CTRL-DT TO WS-7560-DUAL-LAST-DATE-CHANGE
           MOVE WS-0004-BATCH-NO     TO WS-7560-DUAL-BATCH-NUM-CHANGE
           MOVE WS-0004-TRAN-SEQ-NO  TO WS-7560-DUAL-TRANS-SEQ-CHANGE

           MOVE WS-LITERAL-NO TO WS-2255-EXISTING-14-REC-FOUND

           PERFORM 7560-LOOKUP-TYPE-14-DATES
              THRU 7560-LOOKUP-TYPE-14-DATES-EXIT

           IF MATCH-FOUND-7560
              MOVE WS-7560-TYPE-14-DATES-REC
                TO WS-2255-TYPE-14-DATES-WORK
              MOVE WS-LITERAL-YES TO WS-2255-EXISTING-14-REC-FOUND
           END-IF.

       2255-LOOKUP-14-RECORD-EXIT.
           EXIT.


       2255-ADD-INPUT-RECORD.

      $IF DEBUG-SW DEFINED
           DISPLAY '2255-PUTTING INPUT AR SETTING IN TABLE'
           UPON CONSOLE
      $END

           IF WS-2255-TYPE-CD = SPACES
              OR WS-2255-TYPE-CD = ZEROS
              MOVE '9997' TO WS-2255-CROP-POLICY-TYPE
           ELSE
      **   LOOKUP THE ASSOCIATED CROP POLICY TYPE
              INITIALIZE WS-7280-I-CROP-POL-TYPE-AREA
              MOVE WS-2255-LOC-STATE TO WS-7280-I-FIPS-STATE
              MOVE WS-2255-CROP-CD TO WS-7280-I-CROP
              MOVE WS-2255-TYPE-CD TO WS-7280-I-CROP-TYPE
              PERFORM 7280-LOOKUP-CPT-TBL
                 THRU 7280-LOOKUP-CPT-TBL-EXIT

              IF MATCH-FOUND-7280
                 MOVE WS-7280-O-CROP-POL-TYPE
                   TO WS-2255-CROP-POLICY-TYPE
              ELSE
                 MOVE '9997' TO WS-2255-CROP-POLICY-TYPE
              END-IF
           END-IF

      *    *** THE INPUT TRANSACTION GOES IN THE TABLE FOR IR EDITS
           MOVE WS-LITERAL-NO TO WS-7045-TRAN-REJECTED-FLAG
           MOVE WS-2255-REPORTING-ORG TO WS-7045-REPORTING-ORG
           MOVE WS-2255-LOC-STATE TO WS-7045-LOC-STATE
           MOVE WS-2255-COMPANY-COUNTY
             TO WS-7045-COMPANY-COUNTY
           MOVE WS-2255-POLICY-NUM TO WS-7045-POLICY-NUM
           MOVE WS-2255-CROP-YEAR TO WS-7045-CROP-YEAR
           MOVE WS-2255-LOC-COUNTY TO WS-7045-LOC-COUNTY
           MOVE WS-2255-CROP-CD TO WS-7045-CROP-CD
           MOVE WS-2255-INSURANCE-PLAN-ID TO WS-7045-INSURANCE-PLAN-ID
           MOVE WS-2255-CROP-POLICY-TYPE
             TO WS-7045-CROP-POLICY-TYPE
           MOVE WS-2255-DUAL-CVG-FLG
             TO WS-7045-DUAL-COVERAGE-FLAG
           MOVE WS-2255-NEW-LATE-DATE TO WS-7045-CUTOFF-DATE
           MOVE WS-0009-ASSIGNED-RISK TO WS-7045-ASSIGNED-RISK
           MOVE WS-2255-COVERAGE-FLAG TO WS-7045-COVERAGE-FLAG
           MOVE WS-2255-FCIC-CTRL-DT
             TO WS-7045-FCIC-CONTROL-DATE
           MOVE WS-2255-FCIC-PROC-TIME TO WS-7045-FCIC-PROC-TIME
           MOVE WS-0004-BATCH-NO TO WS-7045-BATCH-ID-NUM
           MOVE WS-0004-TRAN-SEQ-NO TO WS-7045-TRAN-SEQ-NUM
           PERFORM 7045-ADD-ASGD-RISK-RECORD
              THRU 7045-ADD-ASGD-RISK-RECORD-EXIT.

       2255-ADD-INPUT-RECORD-EXIT.
           EXIT.


       2255-UPDATE-T14.

      $IF DEBUG-SW DEFINED
           DISPLAY '2255-PUTTING EXISTING AR SETTING IN TABLE'
           UPON CONSOLE
      $END

      *    *** UPDATE EXISTING AR RECORD WITH NEW CUTOFF DT.
           INITIALIZE WS-0975-INPUT-REC
           MOVE WS-2255-TYPE-14-DATES-WORK TO WS-0975-INPUT-REC
           PERFORM 0975-WRITE-TYPE-14-DT-REC
              THRU 0975-WRITE-TYPE-14-DT-REC-EXIT.

       2255-UPDATE-T14-EXIT.
           EXIT.
