      *****************************************************************
      * FILE:      IF2260.CBL                                         *
      * AUTHOR:    CHERYL D. WOOD                                     *
      * DATE:      10/12/95                                           *
      * PURPOSE:   VALIDATION FOR MAP AREA.  IF THE MAP AREA IS       *
      *            POPULATED (GREATER THAN SPACES), VALIDATE INPUT    *
      *            WITH VALID MAP AREA IDS. IF THE INS PLAN IS APH    *
      *            OF ANY TYPE THEN LOOK IN THE HIGH RISK MAP AREA    *
      *            FILE (ADMH); OTHERWISE LOOK IN THE REGULAR MAP     *
      *            AREA TABLE (ADMM).                                 *
      *****************************************************************

       2260-VAL-MAP-AREA.

      $IF DEBUG-SW DEFINED
           DISPLAY '2260-VALIDATING MAP AREA'
           UPON CONSOLE
      $END

      ****************************************************************
      *                   INITIALIZE OUTPUT FIELDS                   *
      ****************************************************************
           INITIALIZE WS-2260-OUTPUT

      ****************************************************************
      *            CHECK THE PRE-CONDITIONS BEFORE THE EDIT          *
      ****************************************************************

           IF ERROR-MAP-AREA = WS-LITERAL-YES
              OR ERROR-RATE-COUNTY = WS-LITERAL-YES
              OR ERROR-RATE-STATE = WS-LITERAL-YES
              OR ERROR-CROP-CD = WS-LITERAL-YES
              OR ERROR-PRACTICE-CD = WS-LITERAL-YES
              OR ERROR-CROP-YR = WS-LITERAL-YES
              OR ERROR-RATE-CLASS = WS-LITERAL-YES
              OR ERROR-INSUR-PLAN-CD = WS-LITERAL-YES
              MOVE WS-LITERAL-YES TO ERROR-MAP-AREA
              GO TO 2260-VAL-MAP-AREA-EXIT
           END-IF

      ****************************************************************
      *                MAIN VALIDATION LOGIC                         *
      ****************************************************************

           IF WS-2260-MAP-AREA = ZEROS
              OR WS-2260-MAP-AREA = SPACES
              MOVE 1.000 TO WS-2260-MAP-FACTOR
              GO TO 2260-VAL-MAP-AREA-EXIT
           END-IF

      $IF DEBUG-SW DEFINED
           DISPLAY 'MAP AREA = ', WS-2260-MAP-AREA
           UPON CONSOLE
      $END

           IF WS-2260-CROP-CD NOT = WS-LITERAL-GRAPES
              IF (WS-2260-MAP-AREA NOT = SPACES) AND
                 (WS-2260-MAP-AREA NOT = ZEROS)
                 IF (WS-2260-MAP-POS1 = SPACES) OR
                    (WS-2260-MAP-POS2 = SPACES) OR
                    (WS-2260-MAP-POS3 = SPACES)
                    MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                    MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
                    MOVE 008 TO WS-8000-SHORT-ERROR
                    MOVE WS-LITERAL-YES TO ERROR-MAP-AREA
                    MOVE WS-LITERAL-MAP-AREA TO WS-8000-FIELD-NAME1
                    MOVE WS-2260-MAP-AREA TO WS-8000-BAD-DATA1
                    MOVE '001, 002, ETC. OR BLANK' TO WS-8000-CORR-DATA1
                    MOVE 2260 TO WS-8000-PARAGRAPH-NO
                    PERFORM 8000-RECORD-TRAN-ERROR
                       THRU 8000-RECORD-TRAN-ERROR-EXIT
                    GO TO 2260-VAL-MAP-AREA-EXIT
                 END-IF
              END-IF
           END-IF

           IF WS-2260-INS-PLAN-CD = WS-LITERAL-APH OR
              WS-2260-INS-PLAN-CD = WS-LITERAL-APH-AREA-SPAN OR
              WS-2260-INS-PLAN-CD = WS-LITERAL-CRC OR
              WS-2260-INS-PLAN-CD = WS-LITERAL-RA
              PERFORM 2260-LOOKUP-HIGH-RISK-MAP
                 THRU 2260-LOOKUP-HIGH-RISK-MAP-EXIT
           ELSE
              PERFORM 2260-LOOKUP-MAP-AREA
                 THRU 2260-LOOKUP-MAP-AREA-EXIT
           END-IF.

       2260-VAL-MAP-AREA-EXIT.
           EXIT.



      $IF ISAM-SW DEFINED

       2260-LOOKUP-MAP-AREA.

           INITIALIZE WS-7530-INPUT-KEY
      *    ******* SUFFIX SET BY LOOKUP *********
           MOVE WS-2260-PRACTICE-CD TO WS-7530-INPUT-PRACTICE-CD
           MOVE WS-2260-CROP-YR TO WS-7530-INPUT-CROP-YR
           MOVE WS-2260-RATE-STATE TO WS-7530-INPUT-STATE-CD
           MOVE WS-2260-RATE-COUNTY TO WS-7530-INPUT-COUNTY-CD
           MOVE WS-2260-CROP-CD TO WS-7530-INPUT-CROP-CD
           MOVE WS-2260-INS-PLAN-CD TO WS-7530-INPUT-INSURANCE-PLAN
           MOVE WS-2260-MAP-AREA TO WS-7530-INPUT-MAP-AREA
      *    *** SET UP ERROR IN CASE RECORD IS NOT FOUND ***
           STRING 'KEY = '
              DELIMITED BY SIZE
              WS-7530-INPUT-KEY
              DELIMITED BY SIZE
              INTO WS-8000-CORR-DATA1
           END-STRING
           PERFORM 7530-LOOKUP-ADMM
              THRU 7530-LOOKUP-ADMM-EXIT
           IF MATCH-FOUND-7530
      *       ** CLEAR OUT CORR DATA1
              MOVE SPACES TO WS-8000-CORR-DATA1
              MOVE WS-7530-MAP-FACTOR TO WS-2260-MAP-FACTOR
           ELSE
              MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 009 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-YES TO ERROR-MAP-AREA
              MOVE 'ADMM REC' TO WS-8000-FIELD-NAME1
              MOVE 'NOT FOUND' TO WS-8000-BAD-DATA1
      *       *** CORR DATA 1 IS SET ABOVE ***
              MOVE 'MAP_AREA' TO WS-8000-TABLE-NAME
              MOVE 2260 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF.


       2260-LOOKUP-MAP-AREA-EXIT.
           EXIT.



       2260-LOOKUP-HIGH-RISK-MAP.

           INITIALIZE WS-7525-INPUT-KEY
           MOVE WS-2260-PRACTICE-CD TO WS-7525-INPUT-PRACTICE-CD
           MOVE WS-2260-CROP-YR TO WS-7525-INPUT-CROP-YR
           MOVE WS-2260-RATE-STATE TO WS-7525-INPUT-STATE-CD
           MOVE WS-2260-RATE-COUNTY
             TO WS-7525-INPUT-COUNTY-CD
           MOVE WS-2260-CROP-CD TO WS-7525-INPUT-CROP-CD
           MOVE WS-2260-INS-PLAN-CD TO WS-7525-INPUT-INSURANCE-PLAN
           MOVE WS-2260-MAP-AREA TO WS-7525-INPUT-MAP-AREA
           MOVE WS-2260-RATE-CLASS TO WS-7525-INPUT-RATE-CLASS
      *    *** SET UP ERROR IN CASE RECORD IS NOT FOUND ***
           STRING 'KEY = '
              DELIMITED BY SIZE
              WS-7525-INPUT-KEY
              DELIMITED BY SIZE
              INTO WS-8000-CORR-DATA1
           END-STRING
           PERFORM 7525-LOOKUP-ADMH
              THRU 7525-LOOKUP-ADMH-EXIT

           IF MATCH-FOUND-7525
      *       ** CLEAR OUT CORR DATA1
              MOVE SPACES TO WS-8000-CORR-DATA1
              MOVE WS-7525-MAP-FACTOR TO WS-2260-MAP-FACTOR
           ELSE
              MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 009 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-YES TO ERROR-MAP-AREA
              MOVE 'ADMH REC' TO WS-8000-FIELD-NAME1
              MOVE 'NOT FOUND' TO WS-8000-BAD-DATA1
      *       *** CORR DATA 1 IS SET ABOVE ***
              MOVE 'MAP_AREA' TO WS-8000-TABLE-NAME
              MOVE 2260 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF.


       2260-LOOKUP-HIGH-RISK-MAP-EXIT.
           EXIT.

      $END


