      *****************************************************************
      * File:      IF2270.CBL
      * Author:    Laura Dittamo
      * Date:      10/05/95
      * Purpose:
      *    This routine validates the Unit Option Code and Option
      *    Code.  When Unit Option Code contains a 'BU', the database
      *    is searched with the concatenation of the two codes (Unit
      *    Option Code used in the first two positions).  If the Unit
      *    Option Code is blank, the database is searched using only
      *    the Option Code.
      *****************************************************************

       2270-VAL-OPTION-CDS.

      $IF DEBUG-SW DEFINED
           DISPLAY '2270-VALIDATING OPTION CODES'
           UPON CONSOLE
      $END

      **********************************************************
      *   INITIALIZE OUTPUT FIELDS                             *
      **********************************************************
           INITIALIZE WS-2270-WORK
           INITIALIZE WS-2270-OUTPUT

      **********************************************************
      *      CHECK PRE-CONDITIONS                              *
      **********************************************************

           IF ERROR-UNIT-OPT-CD = WS-LITERAL-YES OR
              ERROR-OPT-CD = WS-LITERAL-YES OR
              ERROR-CROP-CD = WS-LITERAL-YES OR
              ERROR-CROP-YR = WS-LITERAL-YES OR
              ERROR-RATE-COUNTY = WS-LITERAL-YES OR
              ERROR-RATE-STATE = WS-LITERAL-YES OR
              ERROR-INSUR-PLAN-CD = WS-LITERAL-YES
              MOVE WS-LITERAL-YES TO ERROR-OPT-CD
              MOVE WS-LITERAL-YES TO ERROR-UNIT-OPT-CD
              GO TO 2270-VAL-OPTION-CDS-EXIT
           END-IF

      $IF DEBUG-SW DEFINED
           DISPLAY 'INPUT OPTION CD = ', WS-2270-OPTION-CD
           UPON CONSOLE
           DISPLAY 'INPUT UNIT OPT  = ', WS-2270-UNIT-OPTION-CD
           UPON CONSOLE
      $END

      **********************************************************
      *      REVENUE ASSURANCE EDITS                           *
      **********************************************************
           IF WS-2270-UNIT-OPTION-CD = WS-LITERAL-ENTERPRISE-UNIT OR
              WS-2270-UNIT-OPTION-CD = WS-LITERAL-WHOLE-FARM-UNIT
              IF WS-2270-INSURANCE-PLAN-ID <> WS-LITERAL-RA
                 MOVE WS-LITERAL-IF  TO WS-8000-ERROR-TYPE
                 MOVE 11009 TO WS-8000-ERROR-CODE
                 MOVE WS-LITERAL-YES TO ERROR-OPT-CD
                 MOVE WS-LITERAL-YES TO ERROR-UNIT-OPT-CD
                 MOVE WS-LITERAL-UNIT-OPT-CD
                   TO WS-8000-FIELD-NAME1
                 MOVE WS-2270-UNIT-OPTION-CD TO WS-8000-BAD-DATA1
                 MOVE 'BU OR SPACES' TO WS-8000-CORR-DATA1
                 MOVE 'OPTION DATA' TO WS-8000-TABLE-NAME
                 MOVE 2270 TO WS-8000-PARAGRAPH-NO
                 PERFORM 8000-RECORD-TRAN-ERROR
                    THRU 8000-RECORD-TRAN-ERROR-EXIT
              ELSE
                 MOVE 1.000 TO WS-2270-OPTION-FACTOR
              END-IF
              GO TO 2270-VAL-OPTION-CDS-EXIT
           END-IF

      **********************************************************
      *      LOOKUP OPTIONS                                    *
      **********************************************************

           PERFORM 2270-LOOKUP-OPTIONS
              THRU 2270-LOOKUP-OPTIONS-EXIT

      ************************************************
      *    SEE IF CAT COVERAGE IS ALLOWED.           *
      ************************************************
           IF ERROR-CVG-FL = WS-LITERAL-YES
              GO TO 2270-VAL-OPTION-CDS-EXIT
           END-IF

           IF NOT CAT-COVERAGE
              GO TO 2270-VAL-OPTION-CDS-EXIT
           END-IF

      ******************************************************************
      *    CHECK FOR GRP, GRP CROPS CANNOT BE CAT COVERED EXCEPT       *
      *    FOR FORAGE PRODUCTION                                       *
      ******************************************************************
           IF WS-2270-INSURANCE-PLAN-ID = WS-LITERAL-GRP
              IF WS-2270-CROP-CD = WS-LITERAL-FORAGE-PROD
                 GO TO 2270-VAL-OPTION-CDS-EXIT
              END-IF
              MOVE WS-LITERAL-YES TO ERROR-CVG-FL
              MOVE WS-LITERAL-IF  TO WS-8000-ERROR-TYPE
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 020 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-CVG-FL TO WS-8000-FIELD-NAME1
              MOVE WS-0009-COVERAGE-FLG TO WS-8000-BAD-DATA1
              MOVE 'NOT C' TO WS-8000-CORR-DATA1
              MOVE SPACES TO WS-8000-TABLE-NAME
              MOVE 2270 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
              GO TO 2270-VAL-OPTION-CDS-EXIT
           END-IF

      ******************************************************************
      *    BELOW:  CHECK OPTION CODES, SOME CROPS AND OPTIONS ARE NOT  *
      *            ELIGIBLE FOR CAT COVERAGE.                          *
      ******************************************************************

           EVALUATE WS-2270-CROP-CD
               WHEN WS-LITERAL-WHEAT
                  IF WS-2270-OPTION-CD-P1-2 = 'WA' OR 'WB'
                     MOVE WS-LITERAL-NO
                       TO WS-2270-VALID-FOR-CAT-FLAG
                  ELSE
                     MOVE WS-LITERAL-YES
                       TO WS-2270-VALID-FOR-CAT-FLAG
                  END-IF
               WHEN WS-LITERAL-COTTON
                  IF WS-2270-OPTION-CD-P1-2 = 'IN'
                     MOVE WS-LITERAL-NO
                       TO WS-2270-VALID-FOR-CAT-FLAG
                  ELSE
                     MOVE WS-LITERAL-YES
                       TO WS-2270-VALID-FOR-CAT-FLAG
                  END-IF
               WHEN WS-LITERAL-APPLES
                  IF WS-2270-OPTION-CD-P1-2 = 'FA' OR
                     (WS-2270-OPTION-CD-P1-2 = 'FB' AND
                      WS-2270-OPTION-CD-P3-4 = 'SU')
                     MOVE WS-LITERAL-NO
                       TO WS-2270-VALID-FOR-CAT-FLAG
                  ELSE
                     MOVE WS-LITERAL-YES
                       TO WS-2270-VALID-FOR-CAT-FLAG
                  END-IF
               WHEN WS-LITERAL-POTATOES
                  IF WS-2270-OPTION-CD-P1-2 = 'CS' OR 'FF' OR
                     'PA' OR 'PB' OR 'QA' OR 'QB'
                     MOVE WS-LITERAL-NO
                       TO WS-2270-VALID-FOR-CAT-FLAG
                  ELSE
                     MOVE WS-LITERAL-YES
                       TO WS-2270-VALID-FOR-CAT-FLAG
                  END-IF
               WHEN WS-LITERAL-BARLEY
                  IF WS-2270-OPTION-CD-P1-2 = 'MA' OR 'MB'
                     MOVE WS-LITERAL-NO
                       TO WS-2270-VALID-FOR-CAT-FLAG
                  ELSE
                     MOVE WS-LITERAL-YES
                       TO WS-2270-VALID-FOR-CAT-FLAG
                  END-IF
               WHEN OTHER
                  MOVE WS-LITERAL-YES
                    TO WS-2270-VALID-FOR-CAT-FLAG
           END-EVALUATE

           evaluate WS-T11-INSUR-PLAN-CD
               when WS-LITERAL-CRC
               when WS-LITERAL-IP
                  MOVE WS-LITERAL-NO
                    TO WS-2270-VALID-FOR-CAT-FLAG
           end-evaluate

      **********************************************************
      *              RECORD ERROR                              *
      **********************************************************
           IF WS-2270-VALID-FOR-CAT-FLAG = WS-LITERAL-NO
              MOVE WS-LITERAL-YES TO ERROR-CVG-FL
              MOVE WS-LITERAL-IF  TO WS-8000-ERROR-TYPE
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 020 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-CVG-FL TO WS-8000-FIELD-NAME1
              MOVE WS-0009-COVERAGE-FLG TO WS-8000-BAD-DATA1
              MOVE 'NOT C' TO WS-8000-CORR-DATA1
              MOVE SPACES TO WS-8000-TABLE-NAME
              MOVE 2270 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF.


       2270-VAL-OPTION-CDS-EXIT.
           EXIT.



       2270-LOOKUP-OPTIONS.

           IF WS-2270-UNIT-OPTION-CD = SPACES
              IF WS-2270-OPTION-CD = SPACES
                 MOVE 1.000 TO WS-2270-OPTION-FACTOR
                 GO TO 2270-LOOKUP-OPTIONS-EXIT
              ELSE
                 MOVE WS-2270-OPTION-CD TO WS-2270-ADM-OPTION-CD
              END-IF
           ELSE
              MOVE WS-2270-UNIT-OPTION-CD TO WS-2270-ADM-OPT-CD-POS1-2
              MOVE WS-2270-OPTION-CD TO WS-2270-ADM-OPT-CD-POS3-8
           END-IF


           INITIALIZE WS-7535-INPUT-KEY
      $IF DEBUG-SW DEFINED
           DISPLAY 'ADM OPT CD 1 = ', WS-2270-ADM-OPT-CD-POS1-2
           UPON CONSOLE
           DISPLAY 'ADM OPT CD 2 = ', WS-2270-ADM-OPT-CD-POS3-8
           UPON CONSOLE
      $END

           MOVE WS-2270-CROP-YEAR TO WS-7535-INPUT-CROP-YR
           MOVE WS-2270-RATE-STATE TO WS-7535-INPUT-STATE-CD
           MOVE WS-2270-RATE-COUNTY TO WS-7535-INPUT-COUNTY-CD
           MOVE WS-2270-CROP-CD TO WS-7535-INPUT-CROP-CD
           MOVE WS-2270-INSURANCE-PLAN-ID
             TO WS-7535-INPUT-INSURANCE-PLAN
           MOVE WS-2270-ADM-OPTION-CD TO WS-7535-INPUT-OPTION-CD

      *    *** SET UP ERROR STRING IN CASE ADMO NOT FOUND
           STRING 'ADMO KEY = '
               DELIMITED BY SIZE
               WS-7535-INPUT-KEY
               DELIMITED BY SIZE
               INTO WS-8000-CORR-DATA1
           END-STRING

           PERFORM 7535-LOOKUP-ADMO
              THRU 7535-LOOKUP-ADMO-EXIT

           IF NOT MATCH-FOUND-7535
              MOVE WS-LITERAL-IF  TO WS-8000-ERROR-TYPE
              MOVE 11009 TO WS-8000-ERROR-CODE
              MOVE WS-LITERAL-YES TO ERROR-OPT-CD
              MOVE WS-LITERAL-OPTION-CD TO WS-8000-FIELD-NAME1
              MOVE 'NOT FOUND' TO WS-8000-BAD-DATA1
      *       *** SEARCH KEY USED IS IN CORR-DATA1
              MOVE WS-LITERAL-YES TO ERROR-UNIT-OPT-CD
              MOVE 'OPTION DATA' TO WS-8000-TABLE-NAME
              MOVE 2270 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           ELSE
              MOVE WS-7535-OPTION-FACTOR TO WS-2270-OPTION-FACTOR
              MOVE SPACES TO WS-8000-CORR-DATA1
           END-IF.

       2270-LOOKUP-OPTIONS-EXIT.
           EXIT.
