      *****************************************************************
      *  File:  IF2287.CBL
      *  Author: C. S. Davis/Laura Dittamo
      *  Date:   09/13/95
      *  Purpose:
      *   Perform interfield edits for coverage level percent. When the
      *   policy is not under CAT coverage, coverage level percent must
      *   contain valid values.
      *
      * - Coverage Level Percent
      *          - Texas Citrus Trees (Crop Cd 25, Rate State 48)
      *                FOR '97 - Crop Cd 0240, 0241, 0242, 0243, 0244)
      *            valid percentages {.50, .55, .60, .65, .70, .75}
      *          - Group Crops (Ins Plan 12) valid percentages
      *            {.70, .75, .80, .85, .90}
      *            GRP Forage Production {.65}
      *          - All other crops - valid percentages
      *            {.50, .55, .60, .65, .70, .75};
      *          - IP Crops
      *            {.00}
      *          - Avocados (Ins Plan 46, Crop Cd 0019)
      *            (.30, .50, .65, .75)
      *          - Florida Citrus for '98 crop year (0245 thru 0251)
      *            valid percentages (.50,.55,.60,.65,.70,.75,.80,.85)
      *****************************************************************

       2287-VAL-NON-CAT-CVG-PCT.

      $IF DEBUG-SW DEFINED
           DISPLAY '2287-VALIDATE NON CAT COVERAGE COVERAGE LEVEL PCT'
           UPON CONSOLE
      $END

           IF ERROR-RO = WS-LITERAL-YES OR
              ERROR-CVG-FL = WS-LITERAL-YES OR
              ERROR-CROP-CD = WS-LITERAL-YES OR
              ERROR-INSUR-PLAN-CD = WS-LITERAL-YES OR
              ERROR-RATE-STATE = WS-LITERAL-YES OR
              ERROR-CVG-LVL-PCT = WS-LITERAL-YES
              MOVE WS-LITERAL-YES TO ERROR-CVG-LVL-PCT
              GO TO 2287-VAL-NON-CAT-CVG-PCT-EXIT
           END-IF

      *************************************
      * COVERAGE LEVEL PERCENT VALIDATION *
      *************************************

           IF (WS-2287-CROP-CD = WS-LITERAL-CITRUS-TREES-I OR
               WS-2287-CROP-CD = WS-LITERAL-CITRUS-TREES-II OR
               WS-2287-CROP-CD = WS-LITERAL-CITRUS-TREES-III OR
               WS-2287-CROP-CD = WS-LITERAL-CITRUS-TREES-IV OR
               WS-2287-CROP-CD = WS-LITERAL-CITRUS-TREES-V)
               AND WS-2287-RATE-STATE = WS-LITERAL-TEXAS
              IF NOT VALID-TEXAS-CITRUS-PCT-2287
                 MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                 MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
                 MOVE 026 TO WS-8000-SHORT-ERROR
                 MOVE WS-LITERAL-YES TO ERROR-CVG-LVL-PCT
                 MOVE WS-LITERAL-CVG-LVL-PCT TO WS-8000-FIELD-NAME1
                 MOVE WS-2287-CVG-LVL-PCT TO WS-8000-BAD-DATA1
                 MOVE '{50,55,60,65,70,75}' TO WS-8000-CORR-DATA1
                 MOVE WS-LITERAL-CROP-CD TO WS-8000-FIELD-NAME2
                 MOVE SPACES TO WS-8000-BAD-DATA2
                 MOVE WS-2287-CROP-CD TO WS-8000-CORR-DATA2
                 MOVE WS-LITERAL-INSURE-PLAN-CD TO WS-8000-FIELD-NAME3
                 MOVE SPACES TO WS-8000-BAD-DATA3
                 MOVE WS-2287-INS-PLAN-CD TO WS-8000-CORR-DATA3
                 MOVE 2287 TO WS-8000-PARAGRAPH-NO
                 PERFORM 8000-RECORD-TRAN-ERROR
                    THRU 8000-RECORD-TRAN-ERROR-EXIT
              END-IF
           ELSE
           IF (WS-2287-CROP-CD = WS-LITERAL-CITRUS-I OR
               WS-2287-CROP-CD = WS-LITERAL-CITRUS-II OR
               WS-2287-CROP-CD = WS-LITERAL-CITRUS-III OR
               WS-2287-CROP-CD = WS-LITERAL-CITRUS-IV OR
               WS-2287-CROP-CD = WS-LITERAL-CITRUS-V OR
               WS-2287-CROP-CD = WS-LITERAL-CITRUS-VI OR
               WS-2287-CROP-CD = WS-LITERAL-CITRUS-VII)
               AND WS-2287-RATE-STATE = WS-LITERAL-FLORIDA
              IF NOT VALID-FLORIDA-CITRUS-PCT-2287
                 MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                 MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
                 MOVE 028 TO WS-8000-SHORT-ERROR
                 MOVE WS-LITERAL-YES TO ERROR-CVG-LVL-PCT
                 MOVE WS-LITERAL-CVG-LVL-PCT TO WS-8000-FIELD-NAME1
                 MOVE WS-2287-CVG-LVL-PCT TO WS-8000-BAD-DATA1
                 MOVE '50,55,60,65,70,75,80,85' TO WS-8000-CORR-DATA1
                 MOVE WS-LITERAL-CROP-CD TO WS-8000-FIELD-NAME2
                 MOVE SPACES TO WS-8000-BAD-DATA2
                 MOVE WS-2287-CROP-CD TO WS-8000-CORR-DATA2
                 MOVE WS-LITERAL-INSURE-PLAN-CD
                   TO WS-8000-FIELD-NAME3
                 MOVE SPACES TO WS-8000-BAD-DATA3
                 MOVE WS-2287-INS-PLAN-CD TO WS-8000-CORR-DATA3
                 MOVE 2287 TO WS-8000-PARAGRAPH-NO
                 PERFORM 8000-RECORD-TRAN-ERROR
                    THRU 8000-RECORD-TRAN-ERROR-EXIT
              END-IF
              ELSE
              IF WS-2287-INS-PLAN-CD = WS-LITERAL-GRP
                 IF WS-2287-CROP-CD = WS-LITERAL-FORAGE-PROD
                    AND CAT-COVERAGE
                    IF WS-2287-CVG-LVL-PCT <> 65
                    MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                    MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
                    MOVE 027 TO WS-8000-SHORT-ERROR
                    MOVE WS-LITERAL-YES TO ERROR-CVG-LVL-PCT
                    MOVE WS-LITERAL-CVG-LVL-PCT TO WS-8000-FIELD-NAME1
                    MOVE WS-2287-CVG-LVL-PCT TO WS-8000-BAD-DATA1
                    MOVE 65 TO WS-8000-CORR-DATA1
                    MOVE 2287 TO WS-8000-PARAGRAPH-NO
                    PERFORM 8000-RECORD-TRAN-ERROR
                       THRU 8000-RECORD-TRAN-ERROR-EXIT
                    END-IF
                 ELSE
                    IF NOT VALID-GROUP-CROP-PCT-2287
                       MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                       MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
                       MOVE 027 TO WS-8000-SHORT-ERROR
                       MOVE WS-LITERAL-YES TO ERROR-CVG-LVL-PCT
                       MOVE WS-LITERAL-CVG-LVL-PCT
                         TO WS-8000-FIELD-NAME1
                       MOVE WS-2287-CVG-LVL-PCT TO WS-8000-BAD-DATA1
                       MOVE '{70,75,80,85,90}' TO WS-8000-CORR-DATA1
                       MOVE WS-LITERAL-CROP-CD TO WS-8000-FIELD-NAME2
                       MOVE SPACES TO WS-8000-BAD-DATA2
                       MOVE WS-2287-CROP-CD TO WS-8000-CORR-DATA2
                       MOVE WS-LITERAL-CVG-FL
                         TO WS-8000-FIELD-NAME3
                       MOVE SPACES TO WS-8000-BAD-DATA3
                       MOVE WS-T11-COVERAGE-FLG TO WS-8000-CORR-DATA3
                       MOVE 2287 TO WS-8000-PARAGRAPH-NO
                       PERFORM 8000-RECORD-TRAN-ERROR
                          THRU 8000-RECORD-TRAN-ERROR-EXIT
                    END-IF
                 END-IF
              ELSE
                 IF WS-2287-INS-PLAN-CD = WS-LITERAL-ARC
                    IF NOT VALID-AVOCADO-PCT-2287
                       MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                       MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
                       MOVE 028 TO WS-8000-SHORT-ERROR
                       MOVE WS-LITERAL-YES TO ERROR-CVG-LVL-PCT
                       MOVE WS-LITERAL-CVG-LVL-PCT
                         TO WS-8000-FIELD-NAME1
                       MOVE WS-2287-CVG-LVL-PCT TO WS-8000-BAD-DATA1
                       MOVE '{30,50,65,75}' TO WS-8000-CORR-DATA1
                       MOVE WS-LITERAL-CROP-CD TO WS-8000-FIELD-NAME2
                       MOVE SPACES TO WS-8000-BAD-DATA2
                       MOVE WS-2287-CROP-CD TO WS-8000-CORR-DATA2
                       MOVE WS-LITERAL-INSURE-PLAN-CD
                         TO WS-8000-FIELD-NAME3
                       MOVE SPACES TO WS-8000-BAD-DATA3
                       MOVE WS-2287-INS-PLAN-CD TO WS-8000-CORR-DATA3
                       MOVE 2287 TO WS-8000-PARAGRAPH-NO
                       PERFORM 8000-RECORD-TRAN-ERROR
                          THRU 8000-RECORD-TRAN-ERROR-EXIT
                    END-IF
              ELSE
                 IF WS-2287-INS-PLAN-CD = WS-LITERAL-IP OR
                    WS-2287-INS-PLAN-CD = WS-LITERAL-RA
                    IF WS-2287-CVG-LVL-PCT <> ZEROS
                    MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                    MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
                    MOVE 007 TO WS-8000-SHORT-ERROR
                    MOVE WS-LITERAL-YES TO ERROR-CVG-LVL-PCT
                    MOVE WS-LITERAL-CVG-LVL-PCT TO WS-8000-FIELD-NAME1
                    MOVE WS-2287-CVG-LVL-PCT TO WS-8000-BAD-DATA1
                    MOVE '00' TO WS-8000-CORR-DATA1
                    MOVE 2287 TO WS-8000-PARAGRAPH-NO
                    PERFORM 8000-RECORD-TRAN-ERROR
                       THRU 8000-RECORD-TRAN-ERROR-EXIT
                    END-IF
                 ELSE
                    IF NOT VALID-GENERAL-CROP-PCT-2287
                       MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                       MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
                       MOVE 028 TO WS-8000-SHORT-ERROR
                       MOVE WS-LITERAL-YES TO ERROR-CVG-LVL-PCT
                       MOVE WS-LITERAL-CVG-LVL-PCT
                         TO WS-8000-FIELD-NAME1
                       MOVE WS-2287-CVG-LVL-PCT TO WS-8000-BAD-DATA1
                       MOVE '{50,55,60,65,70,75}' TO WS-8000-CORR-DATA1
                       MOVE WS-LITERAL-CROP-CD TO WS-8000-FIELD-NAME2
                       MOVE SPACES TO WS-8000-BAD-DATA2
                       MOVE WS-2287-CROP-CD TO WS-8000-CORR-DATA2
                       MOVE WS-LITERAL-INSURE-PLAN-CD
                         TO WS-8000-FIELD-NAME3
                       MOVE SPACES TO WS-8000-BAD-DATA3
                       MOVE WS-2287-INS-PLAN-CD TO WS-8000-CORR-DATA3
                       MOVE 2287 TO WS-8000-PARAGRAPH-NO
                       PERFORM 8000-RECORD-TRAN-ERROR
                          THRU 8000-RECORD-TRAN-ERROR-EXIT
                    END-IF
                 END-IF
              END-IF
           END-IF.

      $IF DEBUG-SW DEFINED
           DISPLAY 'COVERAGE LEVEL % = ', WS-2287-CVG-LVL-PCT
           UPON CONSOLE.
      $END

       2287-VAL-NON-CAT-CVG-PCT-EXIT.
           EXIT.


