      *****************************************************************
      *  File:  IF2289.CBL
      *  Author: C. S. Davis/Laura Dittamo
      *  Date:   09/13/95
      *  Purpose:
      *   Perform interfield edits for experience factor.
      *
      * - Experience Factor
      *          - Forage Seeding (Crop Cd 0032) must be > = .50 and
      *            < = 3.50
      *          - Avocados (Ins Plan 46) must = 1.00
      *          - Group Crops (Ins Plan 12), Florida Fruit Tree Crops
      *            (Ins Plan 40), Income Protection Crops (42),
      *            CRC Crops (Ins Plan 44), Texas Citrus (Crop Cd 0224,
      *            0225,0226,0228,0238, Rate State 48)
      *            Specified crops {0012, 0013, 0015, 0019, 0022, 0023,
      *            0024, 0029, 0036, 0043, 0044, 0046, 0049, 0050, 0052,
      *            0056, 0058, 0060, 0062, 0077, 0083, 0086, 0089, 0090,
      *            0095, 0240, 0241, 0242, 0243, 0244}
      *            must = 1.00
      *          - All other crops must be > = .50 and < = 1.00
      *
      *****************************************************************

       2289-VAL-EXPERIENCE-FCTR.

      $IF DEBUG-SW DEFINED
           DISPLAY '2289-VALIDATING EXPERIENCE FACTOR'
           UPON CONSOLE
      $END

      ****************************************************************
      *              INITIALIZE OUTPUTS & LOCAL WS                   *
      ****************************************************************


      ****************************************************************
      *              CHECK PRE-CONDITIONS                            *
      ****************************************************************

           IF ERROR-RO = WS-LITERAL-YES OR
              ERROR-CVG-FL = WS-LITERAL-YES OR
              ERROR-EXPER-FCTR = WS-LITERAL-YES OR
              ERROR-CROP-CD = WS-LITERAL-YES OR
              ERROR-INSUR-PLAN-CD = WS-LITERAL-YES OR
              ERROR-RATE-STATE = WS-LITERAL-YES
              MOVE WS-LITERAL-YES TO ERROR-EXPER-FCTR
              GO TO 2289-VAL-EXPERIENCE-FCTR-EXIT
           END-IF

      ********************************
      * EXPERIENCE FACTOR VALIDATION *
      ********************************

      *    *** SET UP ERROR DISPLAY FIELD
           MOVE WS-2289-EXPERIENCE-FACTOR
             TO WS-2289-EXPERIENCE-FACTOR-X

           EVALUATE WS-2289-EXPERIENCE-FACTOR
               WHEN < 0.50
      *           ***** ALWAYS WRONG *****
                  MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                  MOVE 11016 TO WS-8000-ERROR-CODE
                  MOVE WS-LITERAL-YES TO ERROR-EXPER-FCTR
                  MOVE WS-LITERAL-EXPER-FCTR TO WS-8000-FIELD-NAME1
                  MOVE WS-2289-EXPERIENCE-FACTOR-X
                    TO WS-8000-BAD-DATA1
                  MOVE '>= .50' TO WS-8000-CORR-DATA1
                  MOVE WS-LITERAL-CROP-CD TO WS-8000-FIELD-NAME2
                  MOVE SPACES TO WS-8000-BAD-DATA2
                  MOVE WS-2289-CROP-CD TO WS-8000-CORR-DATA2
                  MOVE WS-LITERAL-INSURE-PLAN-CD
                    TO WS-8000-FIELD-NAME3
                  MOVE SPACES TO WS-8000-BAD-DATA3
                  MOVE WS-2289-INS-PLAN-CD TO WS-8000-CORR-DATA3
                  MOVE 2289 TO WS-8000-PARAGRAPH-NO
                  PERFORM 8000-RECORD-TRAN-ERROR
                     THRU 8000-RECORD-TRAN-ERROR-EXIT
                  GO TO 2289-VAL-EXPERIENCE-FCTR-EXIT

               WHEN 0.50 THRU 0.99
                  IF WS-2289-INS-PLAN-CD = WS-LITERAL-GRP
                     OR WS-2289-INS-PLAN-CD = WS-LITERAL-FLORIDA-FRUIT
                     OR WS-2289-INS-PLAN-CD = WS-LITERAL-IP
                     OR WS-2289-INS-PLAN-CD = WS-LITERAL-CRC
                     OR WS-2289-INS-PLAN-CD = WS-LITERAL-ARC
                     MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                     MOVE 11008 TO WS-8000-ERROR-CODE
                     MOVE WS-LITERAL-YES TO ERROR-EXPER-FCTR
                     MOVE WS-LITERAL-EXPER-FCTR TO WS-8000-FIELD-NAME1
                     MOVE WS-2289-EXPERIENCE-FACTOR-X
                       TO WS-8000-BAD-DATA1
                     MOVE '1.00' TO WS-8000-CORR-DATA1
                     MOVE WS-LITERAL-CROP-CD TO WS-8000-FIELD-NAME2
                     MOVE SPACES TO WS-8000-BAD-DATA2
                     MOVE WS-2289-CROP-CD TO WS-8000-CORR-DATA2
                     MOVE WS-LITERAL-INSURE-PLAN-CD
                       TO WS-8000-FIELD-NAME3
                     MOVE SPACES TO WS-8000-BAD-DATA3
                     MOVE WS-2289-INS-PLAN-CD TO WS-8000-CORR-DATA3
                     MOVE 2289 TO WS-8000-PARAGRAPH-NO
                     PERFORM 8000-RECORD-TRAN-ERROR
                        THRU 8000-RECORD-TRAN-ERROR-EXIT
                     GO TO 2289-VAL-EXPERIENCE-FCTR-EXIT
                  END-IF

                  IF (WS-2289-CROP-CD = WS-LITERAL-EARLY-MID-ORANGES OR
                     WS-2289-CROP-CD = WS-LITERAL-EARLY-MID-ORANGES OR
                     WS-2289-CROP-CD = WS-LITERAL-LATE-ORANGES OR
                     WS-2289-CROP-CD = WS-LITERAL-ALL-OTH-GRAPEFRUIT OR
                     WS-2289-CROP-CD = WS-LITERAL-RUBY-RED-GRAPEFRUIT OR
                     WS-2289-CROP-CD = WS-LITERAL-RIO-RED-STAR-RUBY) AND
                     (WS-2289-RATE-STATE = WS-LITERAL-TEXAS)
                     MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                     MOVE 11008 TO WS-8000-ERROR-CODE
                     MOVE WS-LITERAL-YES TO ERROR-EXPER-FCTR
                     MOVE WS-LITERAL-EXPER-FCTR TO WS-8000-FIELD-NAME1
                     MOVE WS-2289-EXPERIENCE-FACTOR-X
                       TO WS-8000-BAD-DATA1
                     MOVE '1.00' TO WS-8000-CORR-DATA1
                     MOVE WS-LITERAL-CROP-CD TO WS-8000-FIELD-NAME2
                     MOVE SPACES TO WS-8000-BAD-DATA2
                     MOVE WS-2289-CROP-CD TO WS-8000-CORR-DATA2
                     MOVE WS-LITERAL-INSURE-PLAN-CD
                       TO WS-8000-FIELD-NAME3
                     MOVE SPACES TO WS-8000-BAD-DATA3
                     MOVE WS-2289-INS-PLAN-CD TO WS-8000-CORR-DATA3
                     MOVE 2289 TO WS-8000-PARAGRAPH-NO
                     PERFORM 8000-RECORD-TRAN-ERROR
                        THRU 8000-RECORD-TRAN-ERROR-EXIT
                     GO TO 2289-VAL-EXPERIENCE-FCTR-EXIT
                  END-IF

                  IF WS-2289-CROP-CD = WS-LITERAL-BLUEBERRIES OR
                     WS-2289-CROP-CD = WS-LITERAL-ONIONS OR
                     WS-2289-CROP-CD = WS-LITERAL-CANOLA OR
                     WS-2289-CROP-CD = WS-LITERAL-COTTON-XTRA-LONG OR
                     WS-2289-CROP-CD = WS-LITERAL-MAC-NUTS OR
                     WS-2289-CROP-CD = WS-LITERAL-MAC-TREES OR
      *              WS-2289-CROP-CD = WS-LITERAL-CITRUS-TREES OR
                     WS-2289-CROP-CD = WS-LITERAL-CITRUS-TREES-I OR
                     WS-2289-CROP-CD = WS-LITERAL-CITRUS-TREES-II OR
                     WS-2289-CROP-CD = WS-LITERAL-CITRUS-TREES-III OR
                     WS-2289-CROP-CD = WS-LITERAL-CITRUS-TREES-IV OR
                     WS-2289-CROP-CD = WS-LITERAL-CITRUS-TREES-V OR
                     WS-2289-CROP-CD = WS-LITERAL-WALNUTS OR
                     WS-2289-CROP-CD = WS-LITERAL-PRUNES OR
                     WS-2289-CROP-CD = WS-LITERAL-POPCORN OR
                     WS-2289-CROP-CD = WS-LITERAL-FRESH-SWEET-CORN OR
                     WS-2289-CROP-CD = WS-LITERAL-CANNING-BEANS OR
                     WS-2289-CROP-CD = WS-LITERAL-SAFFLOWER OR
                     WS-2289-CROP-CD = WS-LITERAL-HYBRID-SORGHUM-SEED OR
                     WS-2289-CROP-CD = WS-LITERAL-TABLE-GRAPES OR
                     WS-2289-CROP-CD = WS-LITERAL-NURSERY OR
                     WS-2289-CROP-CD = WS-LITERAL-CRANBERRIES OR
                     WS-2289-CROP-CD = WS-LITERAL-FIGS OR
                     WS-2289-CROP-CD = WS-LITERAL-HYBRID-CORN-SEED OR
                     WS-2289-CROP-CD = WS-LITERAL-FRESH-APRICOTS OR
                     WS-2289-CROP-CD = WS-LITERAL-PROCESSING-APRICOTS OR
                     WS-2289-CROP-CD = WS-LITERAL-FRESH-NECTARINES OR
                     WS-2289-CROP-CD = WS-LITERAL-PROC-CLING-PEACHES OR
                     WS-2289-CROP-CD = WS-LITERAL-PROCESS-FREESTONE OR
                     WS-2289-CROP-CD = WS-LITERAL-FRESH-FREESTONE OR
                     WS-2289-CROP-CD = WS-LITERAL-PEPPERS OR
                     WS-2289-CROP-CD = WS-LITERAL-FRESH-TOMATOES OR
                     WS-2289-CROP-CD = WS-LITERAL-PEARS OR
                     WS-2289-CROP-CD = WS-LITERAL-FRESH-PLUMS OR
                     WS-2289-CROP-CD = WS-LITERAL-AVOCADOS
                     MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                     MOVE 11008 TO WS-8000-ERROR-CODE
                     MOVE WS-LITERAL-YES TO ERROR-EXPER-FCTR
                     MOVE WS-LITERAL-EXPER-FCTR TO WS-8000-FIELD-NAME1
                     MOVE WS-2289-EXPERIENCE-FACTOR-X
                       TO WS-8000-BAD-DATA1
                     MOVE '1.00' TO WS-8000-CORR-DATA1
                     MOVE WS-LITERAL-CROP-CD TO WS-8000-FIELD-NAME2
                     MOVE SPACES TO WS-8000-BAD-DATA2
                     MOVE WS-2289-CROP-CD TO WS-8000-CORR-DATA2
                     MOVE WS-LITERAL-INSURE-PLAN-CD
                       TO WS-8000-FIELD-NAME3
                     MOVE SPACES TO WS-8000-BAD-DATA3
                     MOVE WS-2289-INS-PLAN-CD TO WS-8000-CORR-DATA3
                     MOVE 2289 TO WS-8000-PARAGRAPH-NO
                     PERFORM 8000-RECORD-TRAN-ERROR
                        THRU 8000-RECORD-TRAN-ERROR-EXIT
                     GO TO 2289-VAL-EXPERIENCE-FCTR-EXIT
                  END-IF

               WHEN 1.00
      *           ***** ALWAYS VALID *****
                  CONTINUE
               WHEN 1.01 THRU 3.50
      *           ***** OK FOR FORAGE SEEDING *****
                  IF WS-2289-CROP-CD = WS-LITERAL-FORAGE-SEED
                     CONTINUE
                  ELSE
                     MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                     MOVE 11016 TO WS-8000-ERROR-CODE
                     MOVE WS-LITERAL-YES TO ERROR-EXPER-FCTR
                     MOVE WS-LITERAL-EXPER-FCTR TO WS-8000-FIELD-NAME1
                     MOVE WS-2289-EXPERIENCE-FACTOR-X
                       TO WS-8000-BAD-DATA1
                     MOVE '<= 1.00' TO WS-8000-CORR-DATA1
                     MOVE WS-LITERAL-CROP-CD TO WS-8000-FIELD-NAME2
                     MOVE SPACES TO WS-8000-BAD-DATA2
                     MOVE WS-2289-CROP-CD TO WS-8000-CORR-DATA2
                     MOVE WS-LITERAL-INSURE-PLAN-CD
                       TO WS-8000-FIELD-NAME3
                     MOVE SPACES TO WS-8000-BAD-DATA3
                     MOVE WS-2289-INS-PLAN-CD TO WS-8000-CORR-DATA3
                     MOVE 2289 TO WS-8000-PARAGRAPH-NO
                     PERFORM 8000-RECORD-TRAN-ERROR
                        THRU 8000-RECORD-TRAN-ERROR-EXIT
                     GO TO 2289-VAL-EXPERIENCE-FCTR-EXIT
                  END-IF

               WHEN > 3.5
      *           ***** ALWAYS WRONG *****
                  MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                  MOVE 11016 TO WS-8000-ERROR-CODE
                  MOVE WS-LITERAL-YES TO ERROR-EXPER-FCTR
                  MOVE WS-LITERAL-EXPER-FCTR TO WS-8000-FIELD-NAME1
                  MOVE WS-2289-EXPERIENCE-FACTOR-X
                    TO WS-8000-BAD-DATA1
                  MOVE '<= 1.00; <= 3.50 FOR FORAGE SEEDING'
                    TO WS-8000-CORR-DATA1
                  MOVE WS-LITERAL-CROP-CD TO WS-8000-FIELD-NAME2
                  MOVE SPACES TO WS-8000-BAD-DATA2
                  MOVE WS-2289-CROP-CD TO WS-8000-CORR-DATA2
                  MOVE WS-LITERAL-INSURE-PLAN-CD
                    TO WS-8000-FIELD-NAME3
                  MOVE SPACES TO WS-8000-BAD-DATA3
                  MOVE WS-2289-INS-PLAN-CD TO WS-8000-CORR-DATA3
                  MOVE 2289 TO WS-8000-PARAGRAPH-NO
                  PERFORM 8000-RECORD-TRAN-ERROR
                     THRU 8000-RECORD-TRAN-ERROR-EXIT
                  GO TO 2289-VAL-EXPERIENCE-FCTR-EXIT

               WHEN OTHER
      *           ***** ALWAYS WRONG *****
                  MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                  MOVE 11016 TO WS-8000-ERROR-CODE
                  MOVE WS-LITERAL-YES TO ERROR-EXPER-FCTR
                  MOVE WS-LITERAL-EXPER-FCTR TO WS-8000-FIELD-NAME1
                  MOVE WS-2289-EXPERIENCE-FACTOR-X
                    TO WS-8000-BAD-DATA1
                  MOVE '0.50-1.00' TO WS-8000-CORR-DATA1
                  MOVE WS-LITERAL-CROP-CD TO WS-8000-FIELD-NAME2
                  MOVE SPACES TO WS-8000-BAD-DATA2
                  MOVE WS-2289-CROP-CD TO WS-8000-CORR-DATA2
                  MOVE WS-LITERAL-INSURE-PLAN-CD
                    TO WS-8000-FIELD-NAME3
                  MOVE SPACES TO WS-8000-BAD-DATA3
                  MOVE WS-2289-INS-PLAN-CD TO WS-8000-CORR-DATA3
                  MOVE 2289 TO WS-8000-PARAGRAPH-NO
                  PERFORM 8000-RECORD-TRAN-ERROR
                     THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-EVALUATE.





       2289-VAL-EXPERIENCE-FCTR-EXIT.
            EXIT.



