      *****************************************************************
      * File:      IF2292.CBL
      * Author:    Laura Dittamo
      * Date:      10/19/95
      * Purpose:   This routine validates the Dollar Amount of
      *            Insurance field.
      *
      *    - CAT, Minimum and Maximum Dollar Amounts are retrieved from
      *      ADM1 (and from County Dollar Insurance in the database).
      *      For Group Crops (Ins Plan 12) and Dollar Crops (Ins Plan 50)
      *      the input Dollar Amount Insurance must fall within this
      *      min and max.
      *       EXCEPTIONS:
      *         1.  If the Dollar Crop is Nursery, no Dollar Amount
      *             of Insurance is applicable
      *             same for florida-fruit gh 12/96
      *         2.  If the Dollar Crop is Raisins (Crop 37), the max amount
      *             retrieved must be multiplied by the Coverage
      *             Level Percent.  Dollar Amount Insurance for
      *             Raisins must fall within the min (from the database)
      *             and the adjusted max.
      *         3.  If the crop is insured under the Income Protection
      *             plan (Plan 42) then the Dollar Amount of insurance
      *             field will contain the Dollar Amount of Protection
      *             per Acre.
      *         4.  If the crop is insured under the Revenue Assurance
      *             plan (Plan 25) the Dollar Amount of Insurance Field
      *             will contain the dollar amount of protection per acre.
      *         5.  If the crop is insured under the Avocado Dollar Amount
      *             of insurance plan, the dollar amount of insurance field
      *             will contain the farmer's approved average revenue in
      *             whole dollars.  This needs to be validated at the IR
      *             level because it requires data from the type 15 record.
      *
      *****************************************************************

       2292-VAL-DOLLAR-AMT-INS.

      $IF DEBUG-SW DEFINED
           DISPLAY '2292-VALIDATING DOLLAR AMOUNT OF INSURANCE'
           UPON CONSOLE
      $END

      ****************************************************************
      *      INITIALIZE LOCAL AND OUTPUT WORKING STORAGE             *
      ****************************************************************
           INITIALIZE WS-2292-WORK
           INITIALIZE WS-2292-OUTPUT
           MOVE WS-LITERAL-NO TO WS-2292-UPDATE-DOLLAR-AMT-INS

      ****************************************************************
      *      SET UP DISPLAY FIELDS                                   *
      ****************************************************************
           MOVE WS-2292-DOLLAR-AMT-INS TO WS-2292-DOLLAR-AMT-INS-X

      ****************************************************************
      *            CHECK THE PRE-CONDITIONS BEFORE THE EDIT          *
      ****************************************************************
           IF ERROR-RO = WS-LITERAL-YES OR
              ERROR-CVG-FL = WS-LITERAL-YES OR
              ERROR-CROP-CD = WS-LITERAL-YES OR
              ERROR-INSUR-PLAN-CD = WS-LITERAL-YES OR
              ERROR-CVG-LVL-PCT = WS-LITERAL-YES OR
              ERROR-DOLLAR-AMT-INSUR = WS-LITERAL-YES
              MOVE WS-LITERAL-YES TO ERROR-DOLLAR-AMT-INSUR
              GO TO 2292-VAL-DOLLAR-AMT-INS-EXIT
           END-IF

      $IF DEBUG-SW DEFINED
           DISPLAY '$ AMT OF INSURANCE = ', WS-2292-DOLLAR-AMT-INS-X
            UPON CONSOLE
      $END

      ****************************************************************
      *            DETERMINE WHAT EDIT APPLIES                       *
      ****************************************************************


           EVALUATE WS-2292-INS-PLAN-CD
               WHEN WS-LITERAL-GRP
                  IF WS-2292-DOLLAR-AMT-INS = ZEROS
                     MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                     MOVE 11005 TO WS-8000-ERROR-CODE
                     MOVE WS-LITERAL-YES TO ERROR-DOLLAR-AMT-INSUR
                     MOVE WS-LITERAL-DOLLAR-AMT-INSUR
                       TO WS-8000-FIELD-NAME1
                     MOVE WS-2292-DOLLAR-AMT-INS-X
                       TO WS-8000-BAD-DATA1
                     MOVE 2292 TO WS-8000-PARAGRAPH-NO
                     PERFORM 8000-RECORD-TRAN-ERROR
                        THRU 8000-RECORD-TRAN-ERROR-EXIT
                  ELSE
                     PERFORM 2292-CHECK-GRP-DOL-AMT
                        THRU 2292-CHECK-GRP-DOL-AMT-EXIT
                  END-IF

               WHEN WS-LITERAL-DOLLAR-AMT
      *           ** $AMT OF INSURANCE IS NOT APPLICABLE FOR NURSERY
                  IF WS-2292-CROP-CD = WS-LITERAL-NURSERY
                    or ws-2292-ins-plan-cd = ws-literal-florida-fruit
                     GO TO 2292-VAL-DOLLAR-AMT-INS-EXIT
                  ELSE
                     IF WS-2292-DOLLAR-AMT-INS = ZEROS
                        MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                        MOVE 11005 TO WS-8000-ERROR-CODE
                        MOVE WS-LITERAL-YES TO ERROR-DOLLAR-AMT-INSUR
                        MOVE WS-LITERAL-DOLLAR-AMT-INSUR
                          TO WS-8000-FIELD-NAME1
                        MOVE WS-2292-DOLLAR-AMT-INS-X
                          TO WS-8000-BAD-DATA1
                        MOVE 2292 TO WS-8000-PARAGRAPH-NO
                        PERFORM 8000-RECORD-TRAN-ERROR
                           THRU 8000-RECORD-TRAN-ERROR-EXIT
                     ELSE
                        PERFORM 2292-CHECK-DOLLAR-AMT-INS
                           THRU 2292-CHECK-DOLLAR-AMT-INS-EXIT
                     END-IF
                  END-IF

               WHEN WS-LITERAL-IP
                  IF ERROR-YLD-QUOTA = WS-LITERAL-YES OR
                     ERROR-PRICE-ELECTION = WS-LITERAL-YES OR
                     ERROR-UNIT-OF-MEASURE = WS-LITERAL-YES OR
                     ERROR-GUAR-RED-FLG = WS-LITERAL-YES OR
                     ERROR-GUAR-RED-PCT = WS-LITERAL-YES
                     MOVE WS-LITERAL-YES TO ERROR-DOLLAR-AMT-INSUR
                     GO TO 2292-VAL-DOLLAR-AMT-INS-EXIT
                  END-IF

                  IF WS-2292-DOLLAR-AMT-INS = ZEROS
                     MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                     MOVE 11005 TO WS-8000-ERROR-CODE
                     MOVE WS-LITERAL-YES TO ERROR-DOLLAR-AMT-INSUR
                     MOVE WS-LITERAL-DOLLAR-AMT-INSUR
                       TO WS-8000-FIELD-NAME1
                     MOVE WS-2292-DOLLAR-AMT-INS-X
                       TO WS-8000-BAD-DATA1
                     MOVE 2292 TO WS-8000-PARAGRAPH-NO
                     PERFORM 8000-RECORD-TRAN-ERROR
                        THRU 8000-RECORD-TRAN-ERROR-EXIT
                  ELSE
                     PERFORM 2292-CHECK-IP-DOLLAR-AMT
                        THRU 2292-CHECK-IP-DOLLAR-AMT-EXIT
                  END-IF

               WHEN WS-LITERAL-RA
                  IF ERROR-YLD-QUOTA = WS-LITERAL-YES OR
                     ERROR-PRICE-ELECTION = WS-LITERAL-YES OR
                     ERROR-REVENUE-CVG-LVL = WS-LITERAL-YES OR
                     ERROR-UNIT-OPT-CD = WS-LITERAL-YES
                     MOVE WS-LITERAL-YES TO ERROR-DOLLAR-AMT-INSUR
                     GO TO 2292-VAL-DOLLAR-AMT-INS-EXIT
                  END-IF

                  IF WS-2292-DOLLAR-AMT-INS = ZEROS
                     MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                     MOVE 11005 TO WS-8000-ERROR-CODE
                     MOVE WS-LITERAL-YES TO ERROR-DOLLAR-AMT-INSUR
                     MOVE WS-LITERAL-DOLLAR-AMT-INSUR
                       TO WS-8000-FIELD-NAME1
                     MOVE WS-2292-DOLLAR-AMT-INS-X
                       TO WS-8000-BAD-DATA1
                     MOVE 2292 TO WS-8000-PARAGRAPH-NO
                     PERFORM 8000-RECORD-TRAN-ERROR
                        THRU 8000-RECORD-TRAN-ERROR-EXIT
                  END-IF
      *           *** IF BASIC OR OPTIONAL UNIT ORGANIZATION THEN
      *           *** VALIDATE $AMT INSURANCE NOW, OTHERWISE WAIT
      *           *** UNTIL INTER-RECORD EDITS.
                  IF WS-2292-UNIT-OPT-CD = WS-LITERAL-BASIC-UNIT OR
                     WS-2292-UNIT-OPT-CD = WS-LITERAL-OPT-UNIT
                     PERFORM 2292-CHECK-RA-DOLLAR-AMT
                        THRU 2292-CHECK-RA-DOLLAR-AMT-EXIT
                  END-IF

               WHEN WS-LITERAL-ARC
                  IF WS-2292-DOLLAR-AMT-INS = ZEROS
                     MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                     MOVE 11005 TO WS-8000-ERROR-CODE
                     MOVE WS-LITERAL-YES TO ERROR-DOLLAR-AMT-INSUR
                     MOVE WS-LITERAL-DOLLAR-AMT-INSUR
                       TO WS-8000-FIELD-NAME1
                     MOVE WS-2292-DOLLAR-AMT-INS
                       TO WS-2292-DOLLAR-AMT-INS-X
                     MOVE WS-2292-DOLLAR-AMT-INS-X
                       TO WS-8000-BAD-DATA1
                     MOVE 'AVOCADO APPROVED AVG REV > ZERO'
                       TO WS-8000-CORR-DATA1
                     MOVE 2292 TO WS-8000-PARAGRAPH-NO
                     PERFORM 8000-RECORD-TRAN-ERROR
                        THRU 8000-RECORD-TRAN-ERROR-EXIT
                  END-IF

               WHEN OTHER
                  IF WS-2292-DOLLAR-AMT-INS > ZEROS
      *              *** ZERO OUT UNNECESSARY DOLLAR AMT INS ***
                     MOVE WS-LITERAL-YES
                       TO WS-2292-UPDATE-DOLLAR-AMT-INS
                     MOVE ZEROS TO WS-2292-NEW-DOLLAR-AMT-INS
      *              MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
      *              MOVE 11007 TO WS-8000-ERROR-CODE
      *              MOVE WS-LITERAL-YES TO ERROR-DOLLAR-AMT-INSUR
      *              MOVE WS-LITERAL-DOLLAR-AMT-INSUR
      *                TO WS-8000-FIELD-NAME1
      *              MOVE WS-2292-DOLLAR-AMT-INS
      *                TO WS-2292-DOLLAR-AMT-INS-X
      *              MOVE WS-2292-DOLLAR-AMT-INS-X
      *                TO WS-8000-BAD-DATA1
      *              STRING 'INS PLAN CD = '
      *                DELIMITED BY SIZE
      *                WS-2292-INS-PLAN-CD
      *                DELIMITED BY SIZE
      *                INTO WS-8000-CORR-DATA1
      *              END-STRING
      *              MOVE 2292 TO WS-8000-PARAGRAPH-NO
      *              PERFORM 8000-RECORD-TRAN-ERROR
      *                 THRU 8000-RECORD-TRAN-ERROR-EXIT
                  END-IF
           END-EVALUATE.


       2292-VAL-DOLLAR-AMT-INS-EXIT.
           EXIT.


      *==============================================================*
      *    REVENUE ASSURANCE DOLLAR AMT EDITS                        *
      *==============================================================*
       2292-CHECK-RA-DOLLAR-AMT.

      *    *** VALIDATES THE DOLLAR AMOUNT OF INSURANCE FOR
      *    *** BASIC AND OPTIONAL UNITS UNDER REVENUE ASSURANCE.

      *    *******************************************
      *    *   SET UP DISPLAY FIELDS                 *
      *    *******************************************
           MOVE WS-2292-REVENUE-CVG-LVL-PCT
             TO WS-2292-REVENUE-CVG-LVL-PCT-X
           MOVE WS-2292-YIELD TO WS-2292-YIELD-X
           MOVE WS-2292-PRICE-ELECTION TO WS-2292-PRICE-ELECTION-X

      $IF DEBUG-SW DEFINED
           DISPLAY 'REVENUE CVG LEVEL % = ',
           WS-2292-REVENUE-CVG-LVL-PCT-X UPON CONSOLE
           DISPLAY 'YIELD               = ',
           WS-2292-YIELD-X UPON CONSOLE
           DISPLAY 'PRICE ELECTION      = ',
           WS-2292-PRICE-ELECTION-X UPON CONSOLE
      $END

      *    *******************************************
      *    *   CHECK REVENUE COVERAGE LEVEL %        *
      *    *******************************************
           IF WS-2292-REVENUE-CVG-LVL-PCT = ZERO
              MOVE 11005 TO WS-8000-ERROR-CODE
              MOVE WS-LITERAL-YES TO ERROR-REVENUE-CVG-LVL
              MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-REVENUE-CVG-LVL
                TO WS-8000-FIELD-NAME1
              MOVE WS-2292-REVENUE-CVG-LVL-PCT-X
                TO WS-8000-BAD-DATA1
              MOVE 2292 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
              GO TO 2292-CHECK-RA-DOLLAR-AMT-EXIT
           END-IF

      *    *******************************************
      *    *   CALCULATE DOLLAR AMOUNT OF INS        *
      *    *******************************************
           COMPUTE WS-2292-RA-DOLLAR-AMT ROUNDED =
              WS-2292-REVENUE-CVG-LVL-PCT *
              (WS-2292-YIELD * WS-2292-PRICE-ELECTION)
           ON SIZE ERROR
              MOVE 2292 TO WS-8020-PARAGRAPH-NO
              MOVE 90017 TO WS-8020-INT-ERROR-NO
              MOVE 'RA $AMT INSURANCE'
                TO WS-8020-FIELD-NAME
              MOVE WS-2292-RA-DOLLAR-AMT-X
                TO WS-8020-BAD-DATA
              MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
              PERFORM 8020-RECORD-INT-ERROR
                 THRU 8020-RECORD-INT-ERROR-EXIT
           END-COMPUTE

           MOVE WS-2292-RA-DOLLAR-AMT
             TO WS-2292-RA-DOLLAR-AMT-X

      $IF DEBUG-SW DEFINED
           DISPLAY 'INPUT $AMT INSURANCE = $',
           WS-2292-DOLLAR-AMT-INS-X
           UPON CONSOLE
           DISPLAY 'RA $AMT INSURANCE    = $',
           WS-2292-RA-DOLLAR-AMT-X
           UPON CONSOLE
      $END


      *    *******************************************
      *    *   VALIDATE INPUT AGAINST CALCULATION    *
      *    *******************************************
           IF WS-2292-DOLLAR-AMT-INS <
              (WS-2292-RA-DOLLAR-AMT - 1) OR
              WS-2292-DOLLAR-AMT-INS >
              (WS-2292-RA-DOLLAR-AMT + 1)
              MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
              MOVE 11079 TO WS-8000-ERROR-CODE
              MOVE WS-LITERAL-YES TO ERROR-DOLLAR-AMT-INSUR
              MOVE 'RA $AMT INS'
                TO WS-8000-FIELD-NAME1
              MOVE WS-2292-DOLLAR-AMT-INS-X
                TO WS-8000-BAD-DATA1
              STRING '= $'
                DELIMITED BY SIZE
                WS-2292-RA-DOLLAR-AMT-X
                DELIMITED BY SIZE
                ' +/- $1.00'
                DELIMITED BY SIZE
                INTO WS-8000-CORR-DATA1
              END-STRING
              MOVE 2292 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF.


       2292-CHECK-RA-DOLLAR-AMT-EXIT.
           EXIT.


      *==============================================================*
      *    INCOME PROTECTION DOLLAR AMT EDITS                        *
      *==============================================================*
       2292-CHECK-IP-DOLLAR-AMT.

           INITIALIZE WS-4105-INPUT
           MOVE WS-2292-YIELD TO WS-4105-YIELD
           MOVE WS-2292-PRICE-ELECTION
             TO WS-4105-PRICE-ELECTION
           MOVE WS-2292-CVG-LVL-PERCENT
             TO WS-4105-CVG-LVL-PERCENT
           MOVE WS-2292-CROP-UNIT-OF-MEASURE
             TO WS-4105-CROP-UNIT-OF-MEASURE
           MOVE WS-2292-GUAR-REDUCTION-FCTR
             TO WS-4105-GUAR-REDUCTION-FCTR
           PERFORM 4105-CALC-IP-DOLLAR-AMT
              THRU 4105-CALC-IP-DOLLAR-AMT-EXIT
           IF CALC-ERROR-4105
              MOVE WS-LITERAL-YES TO ERROR-DOLLAR-AMT-INSUR
              GO TO 2292-CHECK-IP-DOLLAR-AMT-EXIT
           END-IF

           IF WS-2292-DOLLAR-AMT-INS >= (WS-4105-MIN-PROT-ACRE - 3) and
              WS-2292-DOLLAR-AMT-INS <= (WS-4105-MAX-PROT-ACRE + 3)
              continue
           else
              MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
              MOVE 11079 TO WS-8000-ERROR-CODE
              MOVE WS-LITERAL-YES TO ERROR-DOLLAR-AMT-INSUR
              MOVE 'IP PROT/ACRE'
                TO WS-8000-FIELD-NAME1
              MOVE WS-2292-DOLLAR-AMT-INS-X
                TO WS-8000-BAD-DATA1
              STRING '>= '
                DELIMITED BY SIZE
                WS-4105-MIN-PROT-ACRE-X
                DELIMITED BY SIZE
                ' <= '
                DELIMITED BY SIZE
                WS-4105-MAX-PROT-ACRE-X
                DELIMITED BY SIZE
                INTO WS-8000-CORR-DATA1
              END-STRING
              MOVE 2292 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF.


       2292-CHECK-IP-DOLLAR-AMT-EXIT.
           EXIT.


      *==============================================================*
      *    GRP DOLLAR AMT EDITS                                      *
      *==============================================================*
       2292-CHECK-GRP-DOL-AMT.

      ****************************************************************
      *      LOOKUP & VALIDATE DOLLAR AMT OF INSURANCE               *
      ****************************************************************
           IF ERROR-RATE-COUNTY = WS-LITERAL-YES OR
              ERROR-RATE-STATE = WS-LITERAL-YES OR
              ERROR-CROP-YR = WS-LITERAL-YES OR
              ERROR-CROP-TYPE = WS-LITERAL-YES OR
              ERROR-PRACTICE-CD = WS-LITERAL-YES OR
              ERROR-RATE-CLASS = WS-LITERAL-YES
              MOVE WS-LITERAL-YES TO ERROR-DOLLAR-AMT-INSUR
              GO TO 2292-CHECK-GRP-DOL-AMT-EXIT
           END-IF

           PERFORM 2292-LOOKUP-DOLLAR-AMT
              THRU 2292-LOOKUP-DOLLAR-AMT-EXIT

           IF ERROR-DOLLAR-AMT-INSUR = WS-LITERAL-YES
              GO TO 2292-CHECK-GRP-DOL-AMT-EXIT
           END-IF

      ****************************************************************
      *               CAT COVERAGE RULES                             *
      ****************************************************************

           IF CAT-COVERAGE
      *       *** COMPUTE 65% DOLLAR AMT INS TO FEED CAT 65/100
      *       *** PREMIUM CALCULATION
              COMPUTE WS-2292-CAT-65-PCT-DOLLAR-AMT ROUNDED =
              WS-2292-100-PCT-MAX-DOLLAR-AMT * 0.65
              ON SIZE ERROR
                 MOVE 2292 TO WS-8020-PARAGRAPH-NO
                 MOVE 90017 TO WS-8020-INT-ERROR-NO
                 MOVE 'WS-2292-CAT-65-PCT-DOLLAR-AMT'
                   TO WS-8020-FIELD-NAME
                 MOVE WS-2292-CAT-65-PCT-DOLLAR-AMT
                   TO WS-2292-DOLLAR-AMT-INS-X
                 MOVE WS-2292-DOLLAR-AMT-INS-X
                   TO WS-8020-BAD-DATA
                 MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                 PERFORM 8020-RECORD-INT-ERROR
                    THRU 8020-RECORD-INT-ERROR-EXIT
              END-COMPUTE

      $IF DEBUG-SW DEFINED
           DISPLAY 'CAT 65% MAX $AMT = ',
           WS-2292-CAT-65-PCT-DOLLAR-AMT
           UPON CONSOLE
      $END

            IF WS-2292-INS-PLAN-CD <> WS-LITERAL-ARC
               IF WS-2292-DOLLAR-AMT-INS < WS-2292-CAT-DOLLAR-AMT    OR
                  WS-2292-DOLLAR-AMT-INS > (WS-2292-CAT-DOLLAR-AMT + 1)
                  MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                  MOVE 11062 TO WS-8000-ERROR-CODE
                  MOVE WS-LITERAL-YES TO ERROR-DOLLAR-AMT-INSUR
                  MOVE WS-LITERAL-DOLLAR-AMT-INSUR
                    TO WS-8000-FIELD-NAME1
                  MOVE WS-2292-DOLLAR-AMT-INS
                    TO WS-2292-DOLLAR-AMT-INS-X
                  MOVE WS-2292-DOLLAR-AMT-INS-X
                    TO WS-8000-BAD-DATA1
                  MOVE WS-2292-CAT-DOLLAR-AMT
                    TO WS-2292-DOLLAR-AMT-INS-X
                  MOVE WS-2292-DOLLAR-AMT-INS-X
                    TO WS-8000-CORR-DATA1
                  MOVE 2292 TO WS-8000-PARAGRAPH-NO
                  PERFORM 8000-RECORD-TRAN-ERROR
                     THRU 8000-RECORD-TRAN-ERROR-EXIT
               END-IF
               GO TO 2292-CHECK-GRP-DOL-AMT-EXIT
              END-IF
           END-IF

      ****************************************************************
      *      NOT-CAT GRP CROPS                                       *
      ****************************************************************

      *    FOR GROUP CROPS (INS PLAN 12) AND DOLLAR CROPS
      *    (INS PLAN 50), THE INPUT DOLLAR AMOUNT INSURANCE MUST FALL
      *    WITHIN THE MIN AND MAX VALUES FROM THE DATABASE.

           IF WS-2292-DOLLAR-AMT-INS < WS-2292-GRP-MIN-DOLLAR-AMT  OR
              WS-2292-DOLLAR-AMT-INS > WS-2292-100-PCT-MAX-DOLLAR-AMT
              MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
              MOVE 11016 TO WS-8000-ERROR-CODE
              MOVE WS-LITERAL-YES TO ERROR-DOLLAR-AMT-INSUR
              MOVE WS-LITERAL-DOLLAR-AMT-INSUR
                TO WS-8000-FIELD-NAME1
              MOVE WS-2292-DOLLAR-AMT-INS
                TO WS-2292-DOLLAR-AMT-INS-X
              MOVE WS-2292-DOLLAR-AMT-INS-X
                TO WS-8000-BAD-DATA1
              MOVE WS-2292-GRP-MIN-DOLLAR-AMT
                TO WS-2292-DOLLAR-AMT-INS-X
              STRING '= '
                DELIMITED BY SIZE
                WS-2292-DOLLAR-AMT-INS-X
                DELIMITED BY SIZE
                INTO WS-8000-CORR-DATA1
              END-STRING
              MOVE 2292 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF.

       2292-CHECK-GRP-DOL-AMT-EXIT.
           EXIT.


      *==============================================================*
      *    DOLLAR AMOUNT OF INS CROPS DOLLAR AMT INS EDITS           *
      *==============================================================*
       2292-CHECK-DOLLAR-AMT-INS.


      ****************************************************************
      *      LOOKUP & VALIDATE DOLLAR AMT OF INSURANCE               *
      ****************************************************************
           IF ERROR-RATE-COUNTY = WS-LITERAL-YES OR
              ERROR-RATE-STATE = WS-LITERAL-YES OR
              ERROR-CROP-YR = WS-LITERAL-YES OR
              ERROR-CROP-TYPE = WS-LITERAL-YES OR
              ERROR-PRACTICE-CD = WS-LITERAL-YES OR
              ERROR-RATE-CLASS = WS-LITERAL-YES
              MOVE WS-LITERAL-YES TO ERROR-DOLLAR-AMT-INSUR
              GO TO 2292-CHECK-DOLLAR-AMT-INS-EXIT
           END-IF

           PERFORM 2292-LOOKUP-DOLLAR-AMT
              THRU 2292-LOOKUP-DOLLAR-AMT-EXIT

           IF ERROR-DOLLAR-AMT-INSUR = WS-LITERAL-YES
              GO TO 2292-CHECK-DOLLAR-AMT-INS-EXIT
           END-IF


      ****************************************************************
      *               CAT COVERAGE RULES                             *
      ****************************************************************

           IF CAT-COVERAGE

      *       *** COMPUTE 65% DOLLAR AMT INS TO FEED CAT 65/100
      *       *** PREMIUM CALCULATION
              COMPUTE WS-2292-CAT-65-PCT-DOLLAR-AMT ROUNDED =
              WS-2292-100-PCT-MAX-DOLLAR-AMT * 0.65
              ON SIZE ERROR
                 MOVE 2292 TO WS-8020-PARAGRAPH-NO
                 MOVE 90017 TO WS-8020-INT-ERROR-NO
                 MOVE 'WS-2292-CAT-65-PCT-DOLLAR-AMT'
                   TO WS-8020-FIELD-NAME
                 MOVE WS-2292-CAT-65-PCT-DOLLAR-AMT
                   TO WS-2292-DOLLAR-AMT-INS-X
                 MOVE WS-2292-DOLLAR-AMT-INS-X
                   TO WS-8020-BAD-DATA
                 MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                 PERFORM 8020-RECORD-INT-ERROR
                    THRU 8020-RECORD-INT-ERROR-EXIT
              END-COMPUTE

      $IF DEBUG-SW DEFINED
           DISPLAY 'CAT 65% MAX $AMT = ',
           WS-2292-CAT-65-PCT-DOLLAR-AMT
           UPON CONSOLE
      $END
              IF ws-2292-crop-cd = ws-literal-citrus-trees-i   or
                 ws-2292-crop-cd = ws-literal-citrus-trees-iI  or
                 ws-2292-crop-cd = ws-literal-citrus-trees-iii or
                 ws-2292-crop-cd = ws-literal-citrus-trees-iv  or
                 ws-2292-crop-cd = ws-literal-citrus-trees-v
                 MULTIPLY .33 BY WS-2292-CAT-DOLLAR-AMT
                          GIVING WS-2292-MIN-DOLLAR-AMT ROUNDED
                 IF WS-2292-DOLLAR-AMT-INS < WS-2292-MIN-DOLLAR-AMT OR
                    WS-2292-DOLLAR-AMT-INS > WS-2292-CAT-DOLLAR-AMT
                    MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                    MOVE 11062 TO WS-8000-ERROR-CODE
                    MOVE WS-LITERAL-YES TO ERROR-DOLLAR-AMT-INSUR
                    MOVE WS-LITERAL-DOLLAR-AMT-INSUR
                      TO WS-8000-FIELD-NAME1
                    MOVE WS-2292-DOLLAR-AMT-INS-X
                      TO WS-8000-BAD-DATA1
                    MOVE WS-2292-CAT-DOLLAR-AMT
                      TO WS-2292-DOLLAR-AMT-INS-X
                    MOVE WS-2292-DOLLAR-AMT-INS-X
                      TO WS-8000-CORR-DATA1
                    MOVE 2292 TO WS-8000-PARAGRAPH-NO
                    PERFORM 8000-RECORD-TRAN-ERROR
                       THRU 8000-RECORD-TRAN-ERROR-EXIT
                 END-IF
              ELSE
                 IF WS-2292-DOLLAR-AMT-INS <> WS-2292-CAT-DOLLAR-AMT
                    MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                    MOVE 11062 TO WS-8000-ERROR-CODE
                    MOVE WS-LITERAL-YES TO ERROR-DOLLAR-AMT-INSUR
                    MOVE WS-LITERAL-DOLLAR-AMT-INSUR
                      TO WS-8000-FIELD-NAME1
                    MOVE WS-2292-DOLLAR-AMT-INS-X
                      TO WS-8000-BAD-DATA1
                    MOVE WS-2292-CAT-DOLLAR-AMT
                      TO WS-2292-DOLLAR-AMT-INS-X
                    MOVE WS-2292-DOLLAR-AMT-INS-X
                      TO WS-8000-CORR-DATA1
                    MOVE 2292 TO WS-8000-PARAGRAPH-NO
                    PERFORM 8000-RECORD-TRAN-ERROR
                       THRU 8000-RECORD-TRAN-ERROR-EXIT
                 END-IF
              END-IF
              GO TO 2292-CHECK-DOLLAR-AMT-INS-EXIT
           END-IF

      ****************************************************************
      *                   RAISIN RULES                               *
      ****************************************************************

      *      IF THE DOLLAR CROP IS RAISINS
      *      (CROP 37), THE MAX AMOUNT RETRIEVED FROM THE DATABASE MUST
      *      BE MULTIPLIED BY THE COVERAGE LEVEL PERCENT.  DOLLAR
      *      AMOUNT INSURANCE FOR RAISINS MUST FALL WITHIN THE MIN
      *      (FROM THE DATABASE) AND THE ADJUSTED MAX.

           IF WS-2292-CROP-CD = WS-LITERAL-RAISINS
              COMPUTE WS-2292-ADJUSTED-MAX-DOL-AMT ROUNDED =
              WS-2292-100-PCT-MAX-DOLLAR-AMT
              * (WS-2292-CVG-LVL-PCT / 100)
              ON SIZE ERROR
                 MOVE 2292 TO WS-8020-PARAGRAPH-NO
                 MOVE 90017 TO WS-8020-INT-ERROR-NO
                 MOVE 'WS-2292-ADJUSTED-MAX-DOL-AMT'
                   TO WS-8020-FIELD-NAME
                 MOVE WS-2292-ADJUSTED-MAX-DOL-AMT
                   TO WS-2292-DOLLAR-AMT-INS-X
                 MOVE WS-2292-DOLLAR-AMT-INS-X
                   TO WS-8020-BAD-DATA
                 MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                 PERFORM 8020-RECORD-INT-ERROR
                    THRU 8020-RECORD-INT-ERROR-EXIT
              END-COMPUTE

      $IF DEBUG-SW DEFINED
           DISPLAY 'RAISIN MAX $ AMT = ', WS-2292-ADJUSTED-MAX-DOL-AMT
           UPON CONSOLE
      $END
              IF (WS-2292-DOLLAR-AMT-INS <=
                 WS-2292-ADJUSTED-MAX-DOL-AMT) AND
                 (WS-2292-DOLLAR-AMT-INS >=
                 WS-2292-MIN-DOLLAR-AMT)
                 CONTINUE
              ELSE
                 MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                 MOVE 11059 TO WS-8000-ERROR-CODE
                 MOVE WS-LITERAL-YES TO ERROR-DOLLAR-AMT-INSUR
                 MOVE WS-LITERAL-DOLLAR-AMT-INSUR
                   TO WS-8000-FIELD-NAME1
                 MOVE WS-2292-DOLLAR-AMT-INS
                   TO WS-2292-DOLLAR-AMT-INS-X
                 MOVE WS-2292-DOLLAR-AMT-INS-X
                   TO WS-8000-BAD-DATA1
                 MOVE SPACES TO WS-8000-BAD-DATA3
                 MOVE WS-2292-ADJUSTED-MAX-DOL-AMT
                   TO WS-2292-DOLLAR-AMT-INS-2-X
                 MOVE WS-2292-DOLLAR-AMT-INS-2-X
                   TO WS-8000-CORR-DATA3
                 MOVE WS-2292-MIN-DOLLAR-AMT
                   TO WS-2292-DOLLAR-AMT-INS-X
                 STRING WS-2292-DOLLAR-AMT-INS-X
                        DELIMITED BY SIZE
                        ' - '
                        DELIMITED BY SIZE
                        WS-2292-DOLLAR-AMT-INS-2-X
                        DELIMITED BY SIZE
                   INTO WS-8000-CORR-DATA1
                 END-STRING
                 MOVE 2292 TO WS-8000-PARAGRAPH-NO
                 PERFORM 8000-RECORD-TRAN-ERROR
                    THRU 8000-RECORD-TRAN-ERROR-EXIT
              END-IF
           END-IF

      ****************************************************************
      *      NOT-CAT DOLLAR AMT INS PLAN CROPS                       *
      ****************************************************************

      *    FOR GROUP CROPS (INS PLAN 12) AND DOLLAR CROPS
      *    (INS PLAN 50), THE INPUT DOLLAR AMOUNT INSURANCE MUST FALL
      *    WITHIN THE MIN AND MAX VALUES FROM THE DATABASE. FOR TEXAS
      *    CITRUS TREES, THERE MAY BE A 33% DEHORNING FACTOR.

           IF ws-2292-crop-cd = ws-literal-citrus-trees-i   or
              ws-2292-crop-cd = ws-literal-citrus-trees-ii  or
              ws-2292-crop-cd = ws-literal-citrus-trees-iii or
              ws-2292-crop-cd = ws-literal-citrus-trees-iv  or
              ws-2292-crop-cd = ws-literal-citrus-trees-v
              MULTIPLY .33 BY WS-2292-MIN-DOLLAR-AMT ROUNDED
           END-IF

           IF (WS-2292-DOLLAR-AMT-INS <
              (WS-2292-MIN-DOLLAR-AMT - 3)) OR
              (WS-2292-DOLLAR-AMT-INS >
              (WS-2292-MAX-DOLLAR-AMT + 3))
              MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
              MOVE 11016 TO WS-8000-ERROR-CODE
              MOVE WS-LITERAL-YES TO ERROR-DOLLAR-AMT-INSUR
              MOVE WS-LITERAL-DOLLAR-AMT-INSUR
                TO WS-8000-FIELD-NAME1
              MOVE WS-2292-DOLLAR-AMT-INS
                TO WS-2292-DOLLAR-AMT-INS-X
              MOVE WS-2292-DOLLAR-AMT-INS-X
                TO WS-8000-BAD-DATA1
              MOVE WS-2292-MIN-DOLLAR-AMT
                TO WS-2292-DOLLAR-AMT-INS-X
              MOVE WS-2292-MAX-DOLLAR-AMT
                TO WS-2292-DOLLAR-AMT-INS-2-X
              STRING '>= '
                DELIMITED BY SIZE
                WS-2292-DOLLAR-AMT-INS-X
                DELIMITED BY SIZE
                ' AND <= '
                DELIMITED BY SIZE
                WS-2292-DOLLAR-AMT-INS-2-X
                DELIMITED BY SIZE
                INTO WS-8000-CORR-DATA1
              END-STRING
              MOVE 2292 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF.

       2292-CHECK-DOLLAR-AMT-INS-EXIT.
           EXIT.


      *==============================================================*
      *    ADM DOLLAR AMOUNT OF INSURANCE LOOKUP.                    *
      *==============================================================*

      $IF ISAM-SW DEFINED

       2292-LOOKUP-DOLLAR-AMT.

           IF WS-2292-TYPE-CD IS EQUAL SPACES
              MOVE '997' TO WS-2292-TYPE-CD
           END-IF

           IF WS-2292-INS-PLAN-CD = WS-LITERAL-DOLLAR-AMT
              INITIALIZE WS-7505-INPUT-KEY
              MOVE WS-2292-INS-PLAN-CD TO WS-7505-INPUT-INSURANCE-PLAN
              MOVE WS-2292-CROP-YEAR TO WS-7505-INPUT-CROP-YR
              MOVE WS-2292-RATE-STATE TO WS-7505-INPUT-STATE-CD
              MOVE WS-2292-RATE-COUNTY TO WS-7505-INPUT-COUNTY-CD
              MOVE WS-2292-CROP-CD TO WS-7505-INPUT-CROP-CD
              MOVE WS-2292-PRACTICE-CD TO WS-7505-INPUT-PRACTICE-CD
              MOVE WS-2292-TYPE-CD TO WS-7505-INPUT-TYPE-CD
              MOVE WS-2292-RATE-CLASS TO WS-7505-INPUT-RATE-CLASS
              PERFORM 7505-LOOKUP-ADM1
                 THRU 7505-LOOKUP-ADM1-EXIT

              IF MATCH-FOUND-7505
                 MOVE WS-7505-CAT-DOLLAR-AMT-INS
                   TO WS-2292-CAT-DOLLAR-AMT
                 MOVE WS-7505-MIN-DOLLAR-AMT-INS
                   TO WS-2292-MIN-DOLLAR-AMT
                 MOVE WS-7505-MAX-DOLLAR-AMT-INS
                   TO WS-2292-MAX-DOLLAR-AMT
                 MOVE WS-7505-REF-MAX-DOLLAR-AMT-INS
                   TO WS-2292-100-PCT-MAX-DOLLAR-AMT
              ELSE
      **           NO CAT, MIN, MAX DOLLAR INS AMOUNTS FOUND
                 MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                 MOVE WS-LITERAL-YES TO ERROR-DOLLAR-AMT-INSUR
                 MOVE 11058 TO WS-8000-ERROR-CODE
                 MOVE 'ADM1 KEY =' TO WS-8000-FIELD-NAME1
                 MOVE WS-7505-INPUT-KEY TO WS-8000-BAD-DATA1
                 MOVE 'ADM1' TO WS-8000-TABLE-NAME
                 MOVE 2292 TO WS-8000-PARAGRAPH-NO
                 PERFORM 8000-RECORD-TRAN-ERROR
                    THRU 8000-RECORD-TRAN-ERROR-EXIT
                 GO TO 2292-LOOKUP-DOLLAR-AMT-EXIT
              END-IF
           ELSE
              IF WS-2292-INS-PLAN-CD = WS-LITERAL-GRP
                 INITIALIZE WS-7507-INPUT-KEY
                 MOVE WS-2292-CROP-YEAR TO WS-7507-INPUT-CROP-YR
                 MOVE WS-2292-RATE-STATE TO WS-7507-INPUT-STATE-CD
                 MOVE WS-2292-RATE-COUNTY TO WS-7507-INPUT-COUNTY-CD
                 MOVE WS-2292-CROP-CD TO WS-7507-INPUT-CROP-CD
                 MOVE WS-2292-INS-PLAN-CD
                   TO WS-7507-INPUT-INSURANCE-PLAN
                 MOVE WS-2292-PRACTICE-CD TO WS-7507-INPUT-PRACTICE-CD
                 MOVE WS-2292-TYPE-CD TO WS-7507-INPUT-TYPE-CD
                 PERFORM 7507-LOOKUP-ADM1G
                    THRU 7507-LOOKUP-ADM1G-EXIT

                 IF MATCH-FOUND-7507
                    MOVE WS-7507-MAXIMUM-LIABILITY
                      TO WS-2292-100-PCT-MAX-DOLLAR-AMT
                    COMPUTE WS-2292-GRP-MIN-DOLLAR-AMT ROUNDED =
                       WS-7507-MAXIMUM-LIABILITY
                       * .60
                       ON SIZE ERROR
                          MOVE 2292 TO WS-8020-PARAGRAPH-NO
                          MOVE 90017 TO WS-8020-INT-ERROR-NO
                          MOVE 'WS-2292-GRP-MIN-DOLLAR-AMT-INS'
                            TO WS-8020-FIELD-NAME
                          MOVE WS-2292-INTEGER-ERROR
                            TO WS-8020-BAD-DATA
                          MOVE WS-LITERAL-YES
                            TO WS-8020-ABORT-PROGRAM
                          PERFORM 8020-RECORD-INT-ERROR
                             THRU 8020-RECORD-INT-ERROR-EXIT
                    END-COMPUTE
                    MOVE WS-2292-GRP-MIN-DOLLAR-AMT
                      TO WS-2292-CAT-DOLLAR-AMT
                 ELSE
      **            NO GROUP CAT, MIN, MAX DOLLAR INS AMOUNTS FOUND
                    MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                    MOVE WS-LITERAL-YES TO ERROR-DOLLAR-AMT-INSUR
                    MOVE 11058 TO WS-8000-ERROR-CODE
                    MOVE WS-LITERAL-CROP-YR TO WS-8000-FIELD-NAME1
                    MOVE SPACES TO WS-8000-BAD-DATA1
                    MOVE WS-LITERAL-INSURE-PLAN-CD
                      TO WS-8000-FIELD-NAME2
                    MOVE SPACES TO WS-8000-BAD-DATA2
                    MOVE WS-LITERAL-CROP-CD TO WS-8000-FIELD-NAME3
                    MOVE SPACES TO WS-8000-BAD-DATA3
                    MOVE WS-2292-CROP-YEAR TO WS-8000-CORR-DATA1
                    MOVE WS-2292-INS-PLAN-CD TO WS-8000-CORR-DATA2
                    MOVE WS-2292-CROP-CD TO WS-8000-CORR-DATA3
                    MOVE 'ADM1G' TO WS-8000-TABLE-NAME
                    MOVE 2292 TO WS-8000-PARAGRAPH-NO
                    PERFORM 8000-RECORD-TRAN-ERROR
                       THRU 8000-RECORD-TRAN-ERROR-EXIT
                    GO TO 2292-LOOKUP-DOLLAR-AMT-EXIT
                 END-IF
              END-IF
           END-IF.

       2292-LOOKUP-DOLLAR-AMT-EXIT.
           EXIT.
      $END
