      *****************************************************************
      * FILE:      IF2307.CBL
      * AUTHOR:    CHERYL D. WOOD
      * DATE:      10/12/95
      * PURPOSE:   VALIDATION FOR INSURABLE CROP/INSURANCE PLAN CODE.
      *
      *          LOOKUP THE POLICY IN ADM2 - RATE FACTORS
      *****************************************************************

       2307-VAL-REINS-INS-CROP.

      $IF DEBUG-SW DEFINED
           DISPLAY '2307-VALIDATING INSURABLE CROP & INS PLAN CD'
           UPON CONSOLE
      $END

      ****************************************************************
      *      INITIALIZE OUTPUT WORKING STORAGE                       *
      ****************************************************************

      ****************************************************************
      *            CHECK THE PRE-CONDITIONS BEFORE THE EDIT          *
      ****************************************************************
           IF ERROR-CROP-CD = WS-LITERAL-YES OR
              ERROR-CROP-YR = WS-LITERAL-YES OR
              ERROR-INSUR-PLAN-CD = WS-LITERAL-YES OR
              ERROR-RATE-STATE = WS-LITERAL-YES OR
              ERROR-RATE-COUNTY = WS-LITERAL-YES OR
              ERROR-PRACTICE-CD = WS-LITERAL-YES OR
              ERROR-CROP-TYPE = WS-LITERAL-YES
              MOVE WS-LITERAL-YES TO ERROR-CROP-CD
              MOVE WS-LITERAL-YES TO ERROR-INSUR-PLAN-CD
              GO TO 2307-VAL-REINS-INS-CROP-EXIT
           END-IF

      ****************************************************
      *          CORRECT BLANK TYPE CODES                *
      ****************************************************
           IF WS-2307-TYPE-CD = ZEROS
      *       *** FOR TYPE 14 RECORDS WE WANT TO READ WITH A PARTIAL KEY
      *       *** INSTEAD OF LOOKING FOR A RECORD WITH '997' AS A VALID
      *       *** TYPE
              IF TYPE14 OR
                 (WS-2307-RATE-STATE = WS-LITERAL-COLORADO AND
                 WS-2307-CROP-CD = WS-LITERAL-POTATOES)
                 CONTINUE
              ELSE
                 MOVE 997 TO WS-2307-TYPE-CD
              END-IF
           END-IF

      ****************************************************
      *   SKIP EDIT FOR T21 RECORDS BECAUSE THEY MAY NOT *
      *   BE EDITABLE BECAUSE THEY LACK RATE STATE/CNTY  *
      ****************************************************
           IF TYPE21
              IF WS-0011-T11-REC-COUNT > 0
                 IF WS-0011-TBL-INSURANCE-PLAN-CD (1) <>
                    WS-2307-INSURANCE-PLAN-ID
              MOVE WS-LITERAL-IF  TO WS-8000-ERROR-TYPE
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE WS-LITERAL-YES TO ERROR-INSUR-PLAN-CD
              MOVE 21056 TO WS-8000-ERROR-CODE
              MOVE 'T21 REC ' TO WS-8000-FIELD-NAME1
              MOVE 'NO MATCH 11 ' TO WS-8000-BAD-DATA1
              MOVE 2307 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT

              GO TO 2307-VAL-REINS-INS-CROP-EXIT
           END-IF
              GO TO 2307-VAL-REINS-INS-CROP-EXIT
           END-IF
              GO TO 2307-VAL-REINS-INS-CROP-EXIT
           END-IF

      *****************************************************************
      *   DETERMINE WHETHER THIS TRANSACTION IS AN INSURABLE CROP
      *****************************************************************
           PERFORM 2307-LOOKUP-INS-CROP
              THRU 2307-LOOKUP-INS-CROP-EXIT.


       2307-VAL-REINS-INS-CROP-EXIT.
           EXIT.


       2307-LOOKUP-INS-CROP.

      *****************************************************************
      *       LOOKUP INSURABLE CROPS IN ADM2                          *
      *****************************************************************
           INITIALIZE WS-7510-INPUT-KEY
           MOVE WS-2307-CROP-YEAR TO WS-7510-INPUT-CROP-YR

           MOVE WS-2307-RATE-STATE TO WS-7510-INPUT-STATE-CD
           MOVE WS-2307-CROP-CD TO WS-7510-INPUT-CROP-CD
           MOVE WS-2307-RATE-COUNTY TO WS-7510-INPUT-COUNTY-CD
           MOVE WS-2307-INSURANCE-PLAN-ID
             TO WS-7510-INPUT-INSURANCE-PLAN
           MOVE WS-2307-TYPE-CD TO WS-7510-INPUT-TYPE-CD
           MOVE WS-2307-PRACTICE-CD TO WS-7510-INPUT-PRACTICE-CD
      *    *** SET UP ERROR STRING IN CASE ADM2 NOT FOUND
           STRING 'ADM2 KEY = '
               DELIMITED BY SIZE
               WS-7510-INPUT-KEY
               DELIMITED BY SIZE
               INTO WS-8000-CORR-DATA1
           END-STRING
           PERFORM 7510-LOOKUP-ADM2
              THRU 7510-LOOKUP-ADM2-EXIT

           IF MATCH-FOUND-7510
      *       *** ANY MATCH IS GOOD ENOUGH FOR A TYPE 14 RECORD
              IF TYPE14
                 MOVE SPACES TO WS-8000-CORR-DATA1
                 GO TO 2307-LOOKUP-INS-CROP-EXIT
              END-IF
      *       *** THE CRC APH FLAG INDICATES AN APH RECORD
      *       *** WHICH IS NOT A VALID INSURABLE CROP.
      *       *** THESE RECORDS HAVE BEEN ADDED TO ENABLE
      *       *** INSURABLE CRC TYPES AND PRACTICES TO USE
      *       *** CORRESPONDING APH RECORDS AS A BASIS FOR
      *       *** SUBSIDY CALCULATIONS.
      *       *** CRC TYPES AND PRACTICES ARE IN ADM2 UNDER
      *       *** THE CRC INSURANCE PLAN AND SHOULD NOT BE
      *       *** LOOKED UP USING THE APH PLAN CODE.
              IF WS-7510-CRC-APH-FLAG = 'C' AND
                 FULL-KEY-7510
                 MOVE WS-LITERAL-IF  TO WS-8000-ERROR-TYPE
                 MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
                 MOVE WS-LITERAL-YES TO ERROR-INSUR-PLAN-CD
                 MOVE 038 TO WS-8000-SHORT-ERROR
                 MOVE WS-LITERAL-YES TO ERROR-CROP-CD
                 MOVE 'ADM2 REC' TO WS-8000-FIELD-NAME1
                 MOVE 'CRC APH REC' TO WS-8000-BAD-DATA1
      *          *** SEARCH KEY USED IS IN CORR-DATA1
                 MOVE 2307 TO WS-8000-PARAGRAPH-NO
                 PERFORM 8000-RECORD-TRAN-ERROR
                    THRU 8000-RECORD-TRAN-ERROR-EXIT
                 GO TO 2307-LOOKUP-INS-CROP-EXIT
              END-IF

      *       *** CLEAR THE ERROR SET ABOVE
              MOVE SPACES TO WS-8000-CORR-DATA1

           ELSE
              MOVE WS-LITERAL-IF  TO WS-8000-ERROR-TYPE
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE WS-LITERAL-YES TO ERROR-INSUR-PLAN-CD
              MOVE 038 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-YES TO ERROR-CROP-CD
              MOVE 'ADM2 REC' TO WS-8000-FIELD-NAME1
              MOVE 'NOT FOUND' TO WS-8000-BAD-DATA1
      *       *** SEARCH KEY USED IS IN CORR-DATA1
              MOVE 2307 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF.


       2307-LOOKUP-INS-CROP-EXIT.
           EXIT.
