      *****************************************************************
      * FILE:      IF2330.CBL                                         *
      * AUTHOR:    CHERYL D. WOOD                                     *
      * DATE:      10/12/95                                           *
      * PURPOSE:   VALIDATION FOR YIELD CONVERSION FACTOR             *
      *            OR PERCENT ELECTION.  IF THE INPUT TRANSACTION     *
      *            MATCHES ONE OF THE TABLE ENTRIES BELOW,            *
      *            THE PERCENT ELECTION MUST BE GREATER THAN OR EQUAL *
      *            TO .60 AND LESS THAN OR EQUAL TO 1.00.             *
      *                                                               *
      *      CROP            RATE        RATE      TYPE               *
      *                      STATE       COUNTY    CODE               *
      *                                                               *
      * MACADAMIA TREES (24) ALL          ALL      ALL                *
      * CITRUS TREES (25)    TEXAS        ALL      ALL                *
      * CANNING BEANS (46)   IDAHO (16)   ALL      301, 302           *
      * CANNING BEANS (46)   UTAH (49)    ALL      301                *
      * CANNING BEANS (46)   OREGON (41)  45       302                *
      * DRY BEANS (47)       ALL          ALL      62                 *
      * GREEN PEAS (64)      ALL          ALL      ALL                *
      * DRY PEAS (67)        ALL          ALL      98                 *
      * MALT BARLEY OPT. B   ALL          ALL      ALL                *
      *****************************************************************

       2330-VAL-PERCENT-ELECTION.

      ****************************************************************
      *                   INITIALIZE OUTPUT FIELDS                   *
      ****************************************************************
           INITIALIZE WS-2330-WORK
           INITIALIZE WS-2330-OUTPUT
           MOVE 1.00 TO WS-2330-OUTPUT-PERCENT-ELECT

      *    *** SET UP DISPLAY FIELDS FOR ERRORS
           MOVE WS-2330-PERCENT-ELECTION TO WS-2330-PERCENT-ELECTION-X

      $IF DEBUG-SW DEFINED
           DISPLAY '2330-VALIDATING PERCENT ELECTION = '
           WS-2330-PERCENT-ELECTION-X
           UPON CONSOLE
      $END

      ****************************************************************
      *            CHECK THE PRE-CONDITIONS BEFORE THE EDIT          *
      ****************************************************************

           IF ERROR-YLD-CONVER-FCTR = WS-LITERAL-YES OR
              ERROR-CROP-CD = WS-LITERAL-YES OR
              ERROR-RATE-COUNTY = WS-LITERAL-YES OR
              ERROR-RATE-STATE = WS-LITERAL-YES OR
              ERROR-CROP-TYPE = WS-LITERAL-YES OR
              ERROR-CVG-FL = WS-LITERAL-YES

              MOVE WS-LITERAL-YES TO ERROR-YLD-CONVER-FCTR
              GO TO 2330-VAL-PERCENT-ELECTION-EXIT
           END-IF

      ****************************************************************
      *                   PERFORM VALIDATION                         *
      ****************************************************************

           EVALUATE WS-2330-CROP-CD
               WHEN WS-LITERAL-MAC-TREES
                  PERFORM 2330-TEST-VALID-PERCENT
                     THRU 2330-TEST-VALID-PERCENT-EXIT

               WHEN WS-LITERAL-CITRUS-TREES
               WHEN WS-LITERAL-CITRUS-TREES-I
               WHEN WS-LITERAL-CITRUS-TREES-II
               WHEN WS-LITERAL-CITRUS-TREES-III
               WHEN WS-LITERAL-CITRUS-TREES-IV
               WHEN WS-LITERAL-CITRUS-TREES-V
                  PERFORM 2330-TEST-VALID-PERCENT
                     THRU 2330-TEST-VALID-PERCENT-EXIT

               WHEN WS-LITERAL-GREEN-PEAS
                  PERFORM 2330-TEST-VALID-PERCENT
                     THRU 2330-TEST-VALID-PERCENT-EXIT

               WHEN WS-LITERAL-DRY-PEAS
                  IF (WS-2330-TYPE-CD = '098')
                     PERFORM 2330-TEST-VALID-PERCENT
                        THRU 2330-TEST-VALID-PERCENT-EXIT
                  ELSE
                     MOVE 1.00 TO WS-2330-OUTPUT-PERCENT-ELECT
                  END-IF

               WHEN WS-LITERAL-DRY-BEANS
                  IF (WS-2330-TYPE-CD = '062')
                     PERFORM 2330-TEST-VALID-PERCENT
                        THRU 2330-TEST-VALID-PERCENT-EXIT
                  ELSE
                     MOVE 1.00 TO WS-2330-OUTPUT-PERCENT-ELECT
                  END-IF

               WHEN WS-LITERAL-CANNING-BEANS
                  IF ((WS-2330-TYPE-CD = '302') AND
                     (WS-2330-RATE-STATE = WS-LITERAL-OREGON) AND
                     (WS-2330-RATE-COUNTY = 045))
                     OR
                     ((WS-2330-TYPE-CD = '301') AND
                     (WS-2330-RATE-STATE = WS-LITERAL-UTAH))
                     OR
                     ((WS-2330-TYPE-CD = '302' OR
                     WS-2330-TYPE-CD = '301') AND
                     (WS-2330-RATE-STATE = WS-LITERAL-IDAHO))
                     PERFORM 2330-TEST-VALID-PERCENT
                        THRU 2330-TEST-VALID-PERCENT-EXIT
                  ELSE
                     MOVE 1.00 TO WS-2330-OUTPUT-PERCENT-ELECT
                  END-IF

               WHEN WS-LITERAL-BARLEY
                  EVALUATE WS-T11-TYPE-PRAC-OPT-CD
                     WHEN WS-LITERAL-MALT-BARLEY-OPT-B
                        PERFORM 2330-TEST-VALID-PERCENT
                           THRU 2330-TEST-VALID-PERCENT-EXIT
                  END-EVALUATE

               WHEN OTHER
                  MOVE 1.00 TO WS-2330-OUTPUT-PERCENT-ELECT
           END-EVALUATE.

       2330-VAL-PERCENT-ELECTION-EXIT.
      $IF DEBUG-SW DEFINED
           move WS-2330-OUTPUT-PERCENT-ELECT to 
           WS-2330-OUT-PERCENT-ELEC-X
           DISPLAY '2330-OUTPUT PERCENT ELECTION = '
           WS-2330-OUT-PERCENT-ELEC-X
           UPON CONSOLE.
      $END
       2330-get-out.
           EXIT.


       2330-TEST-VALID-PERCENT.

           MOVE 1.00 TO WS-2330-OUTPUT-PERCENT-ELECT

           IF CAT-COVERAGE
              IF WS-2330-PERCENT-ELECTION = 0.60
                 MOVE WS-2330-PERCENT-ELECTION
                   TO WS-2330-OUTPUT-PERCENT-ELECT
                 GO TO 2330-TEST-VALID-PERCENT-EXIT
              ELSE
                 MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                 MOVE 11016 TO WS-8000-ERROR-CODE
                 MOVE WS-LITERAL-YES TO ERROR-YLD-CONVER-FCTR
                 MOVE WS-LITERAL-YLD-CONVER-FCTR TO WS-8000-FIELD-NAME1
                 MOVE WS-2330-PERCENT-ELECTION-X
                   TO WS-8000-BAD-DATA1
                 MOVE WS-LITERAL-CROP-CD TO WS-8000-FIELD-NAME2
                 MOVE SPACES TO WS-8000-BAD-DATA2
                 MOVE WS-LITERAL-TYPE-CODE TO WS-8000-FIELD-NAME3
                 MOVE SPACES TO WS-8000-BAD-DATA3
                 MOVE '.60' TO WS-8000-CORR-DATA1
                 MOVE WS-2330-CROP-CD TO WS-8000-CORR-DATA2
                 MOVE WS-2330-TYPE-CD TO WS-8000-CORR-DATA3
                 MOVE 2330 TO WS-8000-PARAGRAPH-NO
                 PERFORM 8000-RECORD-TRAN-ERROR
                    THRU 8000-RECORD-TRAN-ERROR-EXIT
              END-IF
           ELSE
              IF VALID-PCT-2330
                 MOVE WS-2330-PERCENT-ELECTION
                   TO WS-2330-OUTPUT-PERCENT-ELECT
                 GO TO 2330-TEST-VALID-PERCENT-EXIT
              ELSE
                 MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                 MOVE 11016 TO WS-8000-ERROR-CODE
                 MOVE WS-LITERAL-YES TO ERROR-YLD-CONVER-FCTR
                 MOVE WS-LITERAL-YLD-CONVER-FCTR TO WS-8000-FIELD-NAME1
                 MOVE WS-2330-PERCENT-ELECTION-X
                   TO WS-8000-BAD-DATA1
                 MOVE WS-LITERAL-CROP-CD TO WS-8000-FIELD-NAME2
                 MOVE SPACES TO WS-8000-BAD-DATA2
                 MOVE WS-LITERAL-TYPE-CODE TO WS-8000-FIELD-NAME3
                 MOVE SPACES TO WS-8000-BAD-DATA3
                 MOVE '.60 THRU 1.00' TO WS-8000-CORR-DATA1
                 MOVE WS-2330-CROP-CD TO WS-8000-CORR-DATA2
                 MOVE WS-2330-TYPE-CD TO WS-8000-CORR-DATA3
                 MOVE 2330 TO WS-8000-PARAGRAPH-NO
                 PERFORM 8000-RECORD-TRAN-ERROR
                    THRU 8000-RECORD-TRAN-ERROR-EXIT
              END-IF
           END-IF.

       2330-TEST-VALID-PERCENT-EXIT.
           EXIT.
