      *****************************************************************
      * File:      IF2335.CBL
      * Author:    Laura Dittamo
      * Date:      10/19/95
      * Purpose:   This routine validates the Base Premium Rate.
      *            The Base Premium Rate is a percentage of the
      *            liability.
      *
      *            IP Crops must have Base Premium Rate = ADMIR
      *
      *            For all other crops/plans:
      *            The Base premium rate is validated against
      *            the ADM1, ADM1G, ADMAR, NCS, and FCIC-2 agreement
      *            rates depending upon the values in the NCS/FCIC-2
      *            flag and the Insurance plan code.
      *
      *            RA Crops must have a base premium rate equal to
      *            the calculated value.
      *
      *     Modifications:
      *
      *     12/96  Convert NCS/FCIC2 flags to a one byte field rep.
      *            Add new flags W, S, & A.  jlh.
      *****************************************************************

       2335-VAL-BASE-PREM-RT.

      $IF DEBUG-SW DEFINED
           DISPLAY '2335-VALIDATING BASE PREMIUM RATE - NCS FLG = '
               WS-0009-NCS-FCIC-2-FLG
           UPON CONSOLE
      $END

      ***************************************************************
      *         INITIALIZE OUTPUT & LOCAL WORKING STORAGE           *
      ***************************************************************
           INITIALIZE WS-2335-WORK
           INITIALIZE WS-2335-OUTPUT

      ***************************************************************
      *         CHECK PRE-CONDITIONS                                *
      ***************************************************************

           IF ERROR-CROP-CD = WS-LITERAL-YES OR
              ERROR-INSUR-PLAN-CD = WS-LITERAL-YES OR
              ERROR-RATE-COUNTY = WS-LITERAL-YES OR
              ERROR-RATE-STATE = WS-LITERAL-YES OR
              ERROR-CROP-YR = WS-LITERAL-YES OR
              ERROR-CROP-TYPE = WS-LITERAL-YES OR
              ERROR-PRACTICE-CD = WS-LITERAL-YES OR
              ERROR-NCS-FCIC-2-FL = WS-LITERAL-YES OR
              ERROR-BASE-PREM-RT = WS-LITERAL-YES OR
              ERROR-CVG-LVL-PCT = WS-LITERAL-YES OR
              ERROR-RATE-CLASS = WS-LITERAL-YES OR
              ERROR-ID-NO = WS-LITERAL-YES OR
              ERROR-OPT-CD = WS-LITERAL-YES OR
              ERROR-PARTIAL-PP-FLAG = WS-LITERAL-YES OR
              ERROR-MAP-AREA = WS-LITERAL-YES OR

      * line below added because ERROR-ID-NO is initialized
      * for each new transaction - rgh
              WS-2335-ID-NUM not numeric

              MOVE WS-LITERAL-YES TO ERROR-BASE-PREM-RT
              GO TO 2335-VAL-BASE-PREM-RT-EXIT
           END-IF

      ***************************************************************
      *         SET UP DISPLAY FIELDS                               *
      ***************************************************************
           MOVE WS-2335-BASE-PREMIUM-RATE
             TO WS-2335-BASE-PREMIUM-RATE-X
           MOVE WS-2335-MAP-FACTOR
             TO WS-2335-MAP-FACTOR-X

      $IF DEBUG-SW DEFINED
           DISPLAY 'BASE PREMIUM RATE = $',
           WS-2335-BASE-PREMIUM-RATE-X
           UPON CONSOLE
           DISPLAY 'MAP FACTOR        = ',
           WS-2335-MAP-FACTOR-X
           UPON CONSOLE
      $END

      ***************************************************************
      *         IP VALIDATION                                       *
      ***************************************************************
           IF WS-2335-INS-PLAN-CD = WS-LITERAL-IP
              IF WS-2335-BASE-PREMIUM-RATE = ZERO
                 MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                 MOVE 11005 TO WS-8000-ERROR-CODE
                 MOVE WS-LITERAL-YES TO ERROR-BASE-PREM-RT
                 MOVE WS-LITERAL-BASE-PREM-RT
                   TO WS-8000-FIELD-NAME1
                 MOVE WS-2335-BASE-PREMIUM-RATE-X
                   TO WS-8000-BAD-DATA1
                 MOVE '> ZERO' TO WS-8000-CORR-DATA1
                 MOVE 2335 TO WS-8000-PARAGRAPH-NO
                 PERFORM 8000-RECORD-TRAN-ERROR
                    THRU 8000-RECORD-TRAN-ERROR-EXIT
              ELSE
                 PERFORM 2335-LOOKUP-ADMIR-RATE
                    THRU 2335-LOOKUP-ADMIR-RATE-EXIT
                 IF ERROR-BASE-PREM-RT = WS-LITERAL-YES
                    GO TO 2335-VAL-BASE-PREM-RT-EXIT
                 END-IF
                 IF WS-2335-BASE-PREMIUM-RATE <>
                    WS-2335-ADMIR-RATE
                    MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                    MOVE 11104 TO WS-8000-ERROR-CODE
                    MOVE WS-LITERAL-YES TO ERROR-BASE-PREM-RT
                    MOVE WS-LITERAL-BASE-PREM-RT
                      TO WS-8000-FIELD-NAME1
                    MOVE WS-2335-BASE-PREMIUM-RATE-X
                      TO WS-8000-BAD-DATA1
                    STRING 'MUST = $'
                      DELIMITED BY SIZE
                      WS-2335-ADMIR-RATE-X
                      DELIMITED BY SIZE
                      INTO WS-8000-CORR-DATA1
                    END-STRING
                    MOVE 2335 TO WS-8000-PARAGRAPH-NO
                    PERFORM 8000-RECORD-TRAN-ERROR
                       THRU 8000-RECORD-TRAN-ERROR-EXIT
                 END-IF
              END-IF
              GO TO 2335-VAL-BASE-PREM-RT-EXIT
           END-IF


      ***************************************************************
      *         AVOCADO VALIDATION                                  *
      ***************************************************************
           IF WS-2335-INS-PLAN-CD = WS-LITERAL-ARC
              IF WS-2335-BASE-PREMIUM-RATE = ZERO
                 MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                 MOVE 11005 TO WS-8000-ERROR-CODE
                 MOVE WS-LITERAL-YES TO ERROR-BASE-PREM-RT
                 MOVE WS-LITERAL-BASE-PREM-RT
                   TO WS-8000-FIELD-NAME1
                 MOVE WS-2335-BASE-PREMIUM-RATE-X
                   TO WS-8000-BAD-DATA1
                 MOVE '> ZERO' TO WS-8000-CORR-DATA1
                 MOVE 2335 TO WS-8000-PARAGRAPH-NO
                 PERFORM 8000-RECORD-TRAN-ERROR
                    THRU 8000-RECORD-TRAN-ERROR-EXIT
              ELSE
                 PERFORM 2335-FIND-AVOCADO-RATE
                    THRU 2335-FIND-AVOCADO-RATE-EXIT
                 IF ERROR-BASE-PREM-RT = WS-LITERAL-YES
                    GO TO 2335-VAL-BASE-PREM-RT-EXIT
                 END-IF
                 IF WS-2335-BASE-PREMIUM-RATE <>
                    WS-2335-ADMAR-RATE
                    MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                    MOVE 11104 TO WS-8000-ERROR-CODE
                    MOVE WS-LITERAL-YES TO ERROR-BASE-PREM-RT
                    MOVE WS-LITERAL-BASE-PREM-RT
                      TO WS-8000-FIELD-NAME1
                    MOVE WS-2335-BASE-PREMIUM-RATE-X
                      TO WS-8000-BAD-DATA1
                    STRING 'MUST = $'
                      DELIMITED BY SIZE
                      WS-2335-ADMAR-RATE-X
                      DELIMITED BY SIZE
                      INTO WS-8000-CORR-DATA1
                    END-STRING
                    MOVE 2335 TO WS-8000-PARAGRAPH-NO
                    PERFORM 8000-RECORD-TRAN-ERROR
                       THRU 8000-RECORD-TRAN-ERROR-EXIT
                 END-IF
              END-IF
              GO TO 2335-VAL-BASE-PREM-RT-EXIT
           END-IF

      ***************************************************************
      *         RA VALIDATION                                       *
      ***************************************************************
           IF WS-2335-INS-PLAN-CD = WS-LITERAL-RA
              IF ERROR-PRICE-ELECTION = WS-LITERAL-YES OR
                 ERROR-YLD-QUOTA = WS-LITERAL-YES OR
                 ERROR-REVENUE-CVG-LVL = WS-LITERAL-YES
                 MOVE WS-LITERAL-YES TO ERROR-BASE-PREM-RT
                 GO TO 2335-VAL-BASE-PREM-RT-EXIT
              END-IF

              INITIALIZE WS-4110-INPUT
              MOVE WS-2335-PRICE-ELECTION
                TO WS-4110-PRICE-ELECTION
              MOVE WS-2335-YIELD TO WS-4110-YIELD
              MOVE WS-2335-REVENUE-CVG-LVL-PCT
                TO WS-4110-REVENUE-CVG-LVL-PCT
              MOVE WS-2335-MAP-FACTOR
                TO WS-4110-MAP-FACTOR
              MOVE WS-2335-PARTIAL-PP-FLAG
                TO WS-4110-PARTIAL-PP-FLAG
              MOVE WS-2335-CROP-YEAR TO WS-4110-CROP-YEAR
              MOVE WS-2335-RATE-STATE TO WS-4110-STATE
              MOVE WS-2335-RATE-COUNTY TO WS-4110-COUNTY-CD
              MOVE WS-2335-CROP-CD TO WS-4110-CROP-CD
              MOVE WS-2335-INS-PLAN-CD TO WS-4110-INS-PLAN-CD
              PERFORM 4110-CALC-RA-BASE-PREMIUM
                 THRU 4110-CALC-RA-BASE-PREMIUM-EXIT
              IF CALC-ERROR-4110
                 MOVE WS-LITERAL-YES TO ERROR-BASE-PREM-RT
                 GO TO 2335-VAL-BASE-PREM-RT-EXIT
              END-IF
              MOVE WS-4110-BASE-PREMIUM-RATE
                TO WS-2335-RA-BASE-PREMIUM-RATE
              MOVE WS-2335-RA-BASE-PREMIUM-RATE
                TO WS-2335-RA-BASE-PREMIUM-RATE-X

              IF (WS-2335-BASE-PREMIUM-RATE <
                 (WS-2335-RA-BASE-PREMIUM-RATE - 0.02)) OR
                 (WS-2335-BASE-PREMIUM-RATE >
                 (WS-2335-RA-BASE-PREMIUM-RATE + 0.02))
                 MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                 MOVE 11099 TO WS-8000-ERROR-CODE
                 MOVE WS-LITERAL-YES TO ERROR-BASE-PREM-RT
                 MOVE WS-LITERAL-BASE-PREM-RT
                   TO WS-8000-FIELD-NAME1
                 MOVE WS-2335-BASE-PREMIUM-RATE-X
                   TO WS-8000-BAD-DATA1
                 STRING 'MUST = $'
                   DELIMITED BY SIZE
                   WS-2335-RA-BASE-PREMIUM-RATE-X
                   DELIMITED BY SIZE
                   ' +/- $0.02'
                   DELIMITED BY SIZE
                   INTO WS-8000-CORR-DATA1
                 END-STRING
                 MOVE 2335 TO WS-8000-PARAGRAPH-NO
                 PERFORM 8000-RECORD-TRAN-ERROR
                    THRU 8000-RECORD-TRAN-ERROR-EXIT
              END-IF
              GO TO 2335-VAL-BASE-PREM-RT-EXIT
           END-IF

      ***************************************************************
      *               LOOKUP BASE PREMIUM RATE                      *
      *               FOR ALL OTHER CROPS/PLANS                     *
      ***************************************************************

           IF WS-2335-TYPE-CD = SPACES
              OR WS-2335-TYPE-CD = ZEROS
              MOVE '997' TO WS-7555-INPUT-TYPE-CD
           END-IF

           IF WS-0009-NCS-FCIC-2-FLG = WS-LITERAL-NCS-BY-LEGAL
      *       *** INFLATE NCS RATE TO MAKE UP A 65% BASE PREMIUM NCS RATE FOR CAT
              COMPUTE WS-2335-CAT-65-PCT-PREM-RATE ROUNDED =
                  (((WS-2335-BASE-PREMIUM-RATE * 100) / 50) * 0.65)
                 ON SIZE ERROR
                    MOVE 2335 TO WS-8020-PARAGRAPH-NO
                    MOVE 90017 TO WS-8020-INT-ERROR-NO
                    MOVE 'NCS CAT 65% RATE'
                      TO WS-8020-FIELD-NAME
                    MOVE WS-2335-CAT-65-PCT-PREM-RATE
                      TO WS-2335-CAT-65-PCT-PREM-RATE-X
                    MOVE WS-2335-CAT-65-PCT-PREM-RATE-X
                      TO WS-8020-BAD-DATA
                    MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                    PERFORM 8020-RECORD-INT-ERROR
                       THRU 8020-RECORD-INT-ERROR-EXIT
              END-COMPUTE
           ELSE
               PERFORM 2335-LOOKUP-NCS-RATE
                  THRU 2335-LOOKUP-NCS-RATE-EXIT
               IF WS-2335-INS-PLAN-CD = WS-LITERAL-GRP
                  PERFORM 2335-LOOKUP-ADM1G-RATE
                     THRU 2335-LOOKUP-ADM1G-RATE-EXIT
               ELSE
                  PERFORM 2335-LOOKUP-ADM1-RATE
                     THRU 2335-LOOKUP-ADM1-RATE-EXIT
               END-IF

               IF ERROR-BASE-PREM-RT = WS-LITERAL-YES
                  GO TO 2335-VAL-BASE-PREM-RT-EXIT
               END-IF

               IF WS-2335-NCS-RATE-PCT > WS-2335-ADM1-RATE-PCT
                  MOVE WS-2335-NCS-RATE-PCT
                    TO WS-2335-HIGHEST-RATE-FOUND
                  MOVE WS-2335-NCS-RATE-PCT
                    TO WS-2335-HIGHEST-RATE-FOUND-X
               ELSE
                  MOVE WS-2335-ADM1-RATE-PCT
                    TO WS-2335-HIGHEST-RATE-FOUND
                  MOVE WS-2335-ADM1-RATE-PCT
                    TO WS-2335-HIGHEST-RATE-FOUND-X
               END-IF
           END-IF


      ***************************************************************
      *    CHECK INPUT RATE AGAINST ADM RATE OR ALLOW OVERRIDE      *
      *    DUE TO NCS/FCIC-2 FLAG SETTINGS                          *
      ***************************************************************
           EVALUATE WS-0009-NCS-FCIC-2-FLG
               WHEN WS-LITERAL-NCS-INSURED
                  IF WS-2335-NCS-RATE-PCT = ZEROS
                     MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                     MOVE 11009 TO WS-8000-ERROR-CODE
                     MOVE WS-LITERAL-YES TO ERROR-BASE-PREM-RT
                     MOVE WS-LITERAL-BASE-PREM-RT
                       TO WS-8000-FIELD-NAME1
                     MOVE WS-2335-BASE-PREMIUM-RATE-X
                       TO WS-8000-BAD-DATA1
                     STRING 'NO NCS RATE FOR NCS PROD, ADM RT = '
                       DELIMITED BY SIZE
                       WS-2335-HIGHEST-RATE-FOUND-X
                       DELIMITED BY SIZE
                       INTO WS-8000-CORR-DATA1
                     END-STRING
                     MOVE 2335 TO WS-8000-PARAGRAPH-NO
                     PERFORM 8000-RECORD-TRAN-ERROR
                        THRU 8000-RECORD-TRAN-ERROR-EXIT
                     GO TO 2335-VAL-BASE-PREM-RT-EXIT
                  END-IF
                  multiply ws-2335-base-premium-rate by 
                     ws-2335-map-factor giving
                        ws-2335-rate-times-factor rounded
                  move ws-2335-rate-times-factor
                     to ws-2335-rate-times-factor-x

      $IF DEBUG-SW DEFINED
              display 'MAP FACTOR = ' ws-2335-map-factor
              DISPLAY 'BASE PREMIUM RATE * MAP FACTOR = ', 
                 ws-2335-rate-times-factor-x
              UPON CONSOLE
      $END
                  IF ws-2335-rate-times-factor >=
                          WS-2335-HIGHEST-RATE-FOUND
      * do not use map-factor later in calculating total-premium
      * if the input base-prem-rate was = the ncs-rate on the ssn file
      * so move 1 to map-factor so it isn't applied to ncs rate in 
      * if2350/c4405 when calcing premium
                             if WS-2335-NCS-RATE-PCT =
                                WS-2335-HIGHEST-RATE-FOUND
                                and ws-2335-ncs-rate =
                                    WS-2335-HIGHEST-RATE-FOUND
                                       move 1 to ws-2335-map-factor
                             end-if
      *              CONTINUE
                     GO TO 2335-VAL-BASE-PREM-RT-EXIT
                  ELSE
                     MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                     MOVE 11104 TO WS-8000-ERROR-CODE

                     MOVE WS-LITERAL-YES TO ERROR-BASE-PREM-RT
                     MOVE WS-LITERAL-BASE-PREM-RT
                       TO WS-8000-FIELD-NAME1
                     MOVE WS-2335-BASE-PREMIUM-RATE-X
                       TO WS-8000-BAD-DATA1
                     move ws-2335-highest-rate-found-x
                       to ws-8000-corr-data1
                     MOVE 2335 TO WS-8000-PARAGRAPH-NO
                     PERFORM 8000-RECORD-TRAN-ERROR
                        THRU 8000-RECORD-TRAN-ERROR-EXIT
                     GO TO 2335-VAL-BASE-PREM-RT-EXIT
                  END-IF

      *           IF WS-2335-BASE-PREMIUM-RATE <
      *              WS-2335-HIGHEST-RATE-FOUND
      *              MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
      *              MOVE 11104 TO WS-8000-ERROR-CODE
      *              MOVE WS-LITERAL-YES TO ERROR-BASE-PREM-RT
      *              MOVE WS-LITERAL-BASE-PREM-RT
      *                TO WS-8000-FIELD-NAME1
      *              MOVE WS-2335-BASE-PREMIUM-RATE-X
      *                TO WS-8000-BAD-DATA1
      *              STRING 'HIGH NCS OR ADM RATE FOUND = '
      *                DELIMITED BY SIZE
      *                WS-2335-HIGHEST-RATE-FOUND-X
      *                DELIMITED BY SIZE
      *                INTO WS-8000-CORR-DATA1
      *              END-STRING
      *              MOVE 2335 TO WS-8000-PARAGRAPH-NO
      *              PERFORM 8000-RECORD-TRAN-ERROR
      *                 THRU 8000-RECORD-TRAN-ERROR-EXIT
      *           END-IF

               WHEN WS-LITERAL-NCS-BY-LEGAL
               WHEN WS-LITERAL-FCIC2-NO-REF-CNTY
               WHEN WS-LITERAL-FCIC2-NCS-PRODUCER
                  IF WS-2335-BASE-PREMIUM-RATE = ZERO
                     MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                     MOVE 11005 TO WS-8000-ERROR-CODE
                     MOVE WS-LITERAL-YES TO ERROR-BASE-PREM-RT
                     MOVE WS-LITERAL-BASE-PREM-RT
                       TO WS-8000-FIELD-NAME1
                     MOVE WS-2335-BASE-PREMIUM-RATE-X
                       TO WS-8000-BAD-DATA1
                     MOVE '> 0' TO WS-8000-CORR-DATA1
                     MOVE 2335 TO WS-8000-PARAGRAPH-NO
                     PERFORM 8000-RECORD-TRAN-ERROR
                        THRU 8000-RECORD-TRAN-ERROR-EXIT
                     GO TO 2335-VAL-BASE-PREM-RT-EXIT
                  END-IF

               WHEN WS-LITERAL-FCI-2-PRICE-EXCEPT
                  IF WS-2335-BASE-PREMIUM-RATE <
                     WS-2335-HIGHEST-RATE-FOUND
                     MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                     MOVE 11104 TO WS-8000-ERROR-CODE
                     MOVE WS-LITERAL-YES TO ERROR-BASE-PREM-RT
                     MOVE WS-LITERAL-BASE-PREM-RT
                       TO WS-8000-FIELD-NAME1
                     MOVE WS-2335-BASE-PREMIUM-RATE-X
                       TO WS-8000-BAD-DATA1
                     STRING 'MUST BE >= HIGHEST OF NCS OR ADM RATE '
                       DELIMITED BY SIZE
                       WS-2335-HIGHEST-RATE-FOUND-X
                       DELIMITED BY SIZE
                       INTO WS-8000-CORR-DATA1
                     END-STRING
                     MOVE 2335 TO WS-8000-PARAGRAPH-NO
                     PERFORM 8000-RECORD-TRAN-ERROR
                        THRU 8000-RECORD-TRAN-ERROR-EXIT
                  END-IF

               WHEN WS-LITERAL-FCIC2
                  IF WS-2335-BASE-PREMIUM-RATE <
                     WS-2335-HIGHEST-RATE-FOUND
                     MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                     MOVE 11104 TO WS-8000-ERROR-CODE
                     MOVE WS-LITERAL-YES TO ERROR-BASE-PREM-RT
                     MOVE WS-LITERAL-BASE-PREM-RT
                       TO WS-8000-FIELD-NAME1
                     MOVE WS-2335-BASE-PREMIUM-RATE-X
                       TO WS-8000-BAD-DATA1
                     STRING 'MUST BE >= HIGHEST OF NCS OR ADM RATE '
                       DELIMITED BY SIZE
                       WS-2335-HIGHEST-RATE-FOUND-X
                       DELIMITED BY SIZE
                       INTO WS-8000-CORR-DATA1
                     END-STRING
                     MOVE 2335 TO WS-8000-PARAGRAPH-NO
                     PERFORM 8000-RECORD-TRAN-ERROR
                        THRU 8000-RECORD-TRAN-ERROR-EXIT
                  END-IF

               WHEN WS-LITERAL-33-SUPP-RATE
                  IF WS-2335-BASE-PREMIUM-RATE = ZERO
                     MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                     MOVE 11005 TO WS-8000-ERROR-CODE
                     MOVE WS-LITERAL-YES TO ERROR-BASE-PREM-RT
                     MOVE WS-LITERAL-BASE-PREM-RT
                       TO WS-8000-FIELD-NAME1
                     MOVE WS-2335-BASE-PREMIUM-RATE-X
                       TO WS-8000-BAD-DATA1
                     MOVE "> 0"
                       TO WS-8000-CORR-DATA1
                     MOVE 2335 TO WS-8000-PARAGRAPH-NO
                     PERFORM 8000-RECORD-TRAN-ERROR
                        THRU 8000-RECORD-TRAN-ERROR-EXIT
                     GO TO 2335-VAL-BASE-PREM-RT-EXIT
                  else
                     GO TO 2335-VAL-BASE-PREM-RT-EXIT
                  END-IF
               WHEN WS-LITERAL-NO-NCS
                  IF WS-2335-BASE-PREMIUM-RATE = ZERO
                     MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                     MOVE 11005 TO WS-8000-ERROR-CODE
                     MOVE WS-LITERAL-YES TO ERROR-BASE-PREM-RT
                     MOVE WS-LITERAL-BASE-PREM-RT
                       TO WS-8000-FIELD-NAME1
                     MOVE WS-2335-BASE-PREMIUM-RATE-X
                       TO WS-8000-BAD-DATA1
                     STRING 'MUST BE = $'
                       DELIMITED BY SIZE
                       WS-2335-HIGHEST-RATE-FOUND-X
                       DELIMITED BY SIZE
                       INTO WS-8000-CORR-DATA1
                     END-STRING
                     MOVE 2335 TO WS-8000-PARAGRAPH-NO
                     PERFORM 8000-RECORD-TRAN-ERROR
                        THRU 8000-RECORD-TRAN-ERROR-EXIT
                     GO TO 2335-VAL-BASE-PREM-RT-EXIT
                  END-IF
                  IF WS-0009-NCS-FCIC-2-FLG = WS-LITERAL-NO-NCS AND
                     WS-2335-NCS-RATE-FOUND-FLAG = WS-LITERAL-YES
                     MOVE WS-LITERAL-if TO WS-8000-ERROR-TYPE
                     MOVE 11004 TO WS-8000-ERROR-CODE
                     MOVE WS-LITERAL-YES TO ERROR-NCS-FCIC-2-FL
                     MOVE WS-LITERAL-NCS-FCIC-2-FL
                       TO WS-8000-FIELD-NAME1
                     MOVE WS-0009-NCS-FCIC-2-FLG
                       TO WS-8000-BAD-DATA1
                     MOVE 'NOT BLANK: PRODUCER IS ON NCS FILE'
                       TO WS-8000-CORR-DATA1
                     MOVE 2335 TO WS-8000-PARAGRAPH-NO
                     PERFORM 8000-RECORD-TRAN-ERROR
                        THRU 8000-RECORD-TRAN-ERROR-EXIT
                  END-IF
                  IF WS-2335-BASE-PREMIUM-RATE <>
                     WS-2335-HIGHEST-RATE-FOUND
                     MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                     MOVE 11104 TO WS-8000-ERROR-CODE
                     MOVE WS-LITERAL-YES TO ERROR-BASE-PREM-RT
                     MOVE WS-LITERAL-BASE-PREM-RT
                       TO WS-8000-FIELD-NAME1
                     MOVE WS-2335-BASE-PREMIUM-RATE-X
                       TO WS-8000-BAD-DATA1
                     STRING 'MUST BE = $'
                       DELIMITED BY SIZE
                       WS-2335-HIGHEST-RATE-FOUND-X
                       DELIMITED BY SIZE
                       INTO WS-8000-CORR-DATA1
                     END-STRING
                     MOVE 2335 TO WS-8000-PARAGRAPH-NO
                     PERFORM 8000-RECORD-TRAN-ERROR
                        THRU 8000-RECORD-TRAN-ERROR-EXIT
                  END-IF

               WHEN OTHER
                  MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                  MOVE 11008 TO WS-8000-ERROR-CODE
                  MOVE WS-LITERAL-YES TO ERROR-NCS-FCIC-2-FL
                  MOVE WS-LITERAL-NCS-FCIC-2-FL TO WS-8000-FIELD-NAME1
                  MOVE WS-0009-NCS-FCIC-2-FLG TO WS-8000-BAD-DATA1
                  MOVE 'Y,N,R,P,W,F,3 OR BLANK' TO WS-8000-CORR-DATA1
                  MOVE 2335 TO WS-8000-PARAGRAPH-NO
                  PERFORM 8000-RECORD-TRAN-ERROR
                     THRU 8000-RECORD-TRAN-ERROR-EXIT
            END-EVALUATE.

       2335-VAL-BASE-PREM-RT-EXIT.
           EXIT.

       2335-LOOKUP-NCS-RATE.

      *    FIND THE HIGHEST NCS RATE FOR THIS CROP ON THE POLICY
      *     IF WS-2335-ID-TYPE <> WS-LITERAL-SSN
           IF WS-2335-ID-NUM = ZEROS
              MOVE 1 TO WS-2335-NCS-RATE-PCT
              GO TO 2335-LOOKUP-NCS-RATE-EXIT
           END-IF

      * routine added 7/2/97 to lookup sbi ssn's and use their
      * rates if higher than the policy record NCS looked up next.
      * If sbi rate > policy rec rate use it, otherwise use policy rate.

           IF WS-0010-SBI-REC-COUNT > 0
              PERFORM 2335-PROCESS-SBI-TBL
                 THRU 2335-PROCESS-SBI-TBL-EXIT
                 WITH TEST AFTER
              VARYING WS-0010-SBI-INT-INDEX FROM 1 BY 1
                 UNTIL WS-0010-SBI-INT-INDEX = WS-0010-SBI-REC-COUNT
           END-IF

           INITIALIZE WS-7555-INPUT-KEY
           MOVE WS-2335-ID-NUM TO WS-7555-INPUT-ID-NUM
           MOVE WS-2335-CROP-YEAR TO WS-7555-INPUT-CROP-YR
           MOVE WS-2335-RATE-STATE TO WS-7555-INPUT-STATE-CD
           MOVE WS-2335-RATE-COUNTY TO WS-7555-INPUT-COUNTY-CD
           MOVE WS-2335-CROP-CD TO WS-7555-INPUT-CROP-CD
           MOVE WS-2335-INS-PLAN-CD
             TO WS-7555-INPUT-INSURANCE-PLAN
           MOVE WS-2335-TYPE-CD TO WS-7555-INPUT-TYPE-CD
           MOVE WS-2335-PRACTICE-CD TO WS-7555-INPUT-PRACTICE-CD
           MOVE WS-2335-OPTION-CD TO WS-7555-INPUT-OPTION-CD
           PERFORM 7555-LOOKUP-ADMSSN
              THRU 7555-LOOKUP-ADMSSN-EXIT

           IF MATCH-FOUND-7555
      $IF DEBUG-SW DEFINED
              DISPLAY 'NCS RECORD FOUND, RAW RATE= ' ws-7555-rate
              UPON CONSOLE
      $END
              if ws-7555-rate > ws-2335-ncs-rate
                 move ws-7555-rate   to ws-2335-ncs-rate
                 MOVE WS-LITERAL-YES TO WS-2335-NCS-RATE-FOUND-FLAG
              end-if
           end-if
           IF ws-2335-ncs-rate > 0
      $IF DEBUG-SW DEFINED
              DISPLAY 'NCS RECORD FOUND, HIGHEST RAW RATE= '
                 ws-2335-ncs-rate
              UPON CONSOLE
      $END
              perform 2335-FIND-RATE-DIFF
                   thru 2335-FIND-RATE-DIFF-EXIT
              if match-found-7510
      *       MOVE WS-7555-RATE TO WS-2335-NCS-RATE

      *    WHEN AN NCS RATE IS FOUND, THIS RATE REPRESENTS 75% OF THE
      *    ACTUAL BASE PREMIUM RATE.  THE RATE MUST ALSO BE ADJUSTED
      *    BY THE COVERAGE LEVEL PERCENT.  MULTIPLY THE ADM NCS RATE
      *    BY COVERAGE LEVEL PERCENT/.75 TO DERIVE THE FULL BASE
      *    PREMIUM RATE.
              COMPUTE WS-2335-NCS-RATE-PCT ROUNDED =
                 WS-2335-NCS-RATE * ws-2335-elect-rate-diff
      *          * ((WS-2335-CVG-LVL-PCT / 100) / 0.75)
                 ON SIZE ERROR
                    MOVE 2335 TO WS-8020-PARAGRAPH-NO
                    MOVE 90017 TO WS-8020-INT-ERROR-NO
                    MOVE 'WS-2335-NCS-RATE-PCT'
                      TO WS-8020-FIELD-NAME
                    MOVE WS-2335-NCS-RATE-PCT
                      TO WS-2335-NCS-RATE-PCT-X
                    MOVE WS-2335-NCS-RATE-PCT-X
                      TO WS-8020-BAD-DATA
                    MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                    PERFORM 8020-RECORD-INT-ERROR
                       THRU 8020-RECORD-INT-ERROR-EXIT
              END-COMPUTE
              MOVE WS-2335-NCS-RATE-PCT TO WS-2335-NCS-RATE-PCT-X

              COMPUTE WS-2335-CAT-65-PCT-PREM-RATE ROUNDED =
                 WS-2335-NCS-RATE
                 * (0.65 / 0.75)
                 ON SIZE ERROR
                    MOVE 2335 TO WS-8020-PARAGRAPH-NO
                    MOVE 90017 TO WS-8020-INT-ERROR-NO
                    MOVE 'NCS CAT 65% RATE'
                      TO WS-8020-FIELD-NAME
                    MOVE WS-2335-CAT-65-PCT-PREM-RATE
                      TO WS-2335-CAT-65-PCT-PREM-RATE-X
                    MOVE WS-2335-CAT-65-PCT-PREM-RATE-X
                      TO WS-8020-BAD-DATA
                    MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                    PERFORM 8020-RECORD-INT-ERROR
                       THRU 8020-RECORD-INT-ERROR-EXIT
              END-COMPUTE
              MOVE WS-2335-CAT-65-PCT-PREM-RATE
                TO WS-2335-CAT-65-PCT-PREM-RATE-X

      $IF DEBUG-SW DEFINED
              DISPLAY 'NCS RATE     = ', WS-2335-NCS-RATE-PCT-X
              UPON CONSOLE
              DISPLAY 'NCS CAT RATE = ',
              WS-2335-CAT-65-PCT-PREM-RATE-X
              UPON CONSOLE
      $END

           ELSE
      *        THIS PRODUCER IS NOT LISTED UNDER NCS
               MOVE ZEROS TO WS-2335-NCS-RATE-PCT
      $IF DEBUG-SW DEFINED
              DISPLAY "NCS RECORD NOT FOUND ON NCS FILE"
              UPON CONSOLE
      $END

           END-IF.

       2335-LOOKUP-NCS-RATE-EXIT.
           EXIT.


       2335-LOOKUP-ADM1-RATE.

           INITIALIZE WS-7505-INPUT-KEY
           MOVE WS-2335-CROP-YEAR TO WS-7505-INPUT-CROP-YR
           MOVE WS-2335-RATE-STATE TO WS-7505-INPUT-STATE-CD
           MOVE WS-2335-RATE-COUNTY TO WS-7505-INPUT-COUNTY-CD
           MOVE WS-2335-CROP-CD TO WS-7505-INPUT-CROP-CD
           MOVE WS-2335-INS-PLAN-CD TO WS-7505-INPUT-INSURANCE-PLAN
           MOVE WS-2335-PRACTICE-CD TO WS-7505-INPUT-PRACTICE-CD
           MOVE WS-2335-TYPE-CD TO WS-7505-INPUT-TYPE-CD
           MOVE WS-2335-RATE-CLASS TO WS-7505-INPUT-RATE-CLASS
      *    *** SET UP ERROR STRING IN CASE ADM1 NOT FOUND
           STRING 'ADM1 KEY = '
               DELIMITED BY SIZE
               WS-7505-INPUT-KEY
               DELIMITED BY SIZE
               INTO WS-8000-CORR-DATA1
           END-STRING

           PERFORM 7505-LOOKUP-ADM1
              THRU 7505-LOOKUP-ADM1-EXIT

           IF MATCH-FOUND-7505
      *       *** CLEAR THE ERROR SET ABOVE
              MOVE SPACES TO WS-8000-CORR-DATA1

              EVALUATE WS-2335-CVG-LVL-PCT
                WHEN WS-7505-COVERAGE-LEVEL-01
                   MOVE WS-7505-BASE-PREMIUM-RATE-01
                     TO WS-2335-ADM1-RATE-PCT
                WHEN WS-7505-COVERAGE-LEVEL-02
                   MOVE WS-7505-BASE-PREMIUM-RATE-02
                     TO WS-2335-ADM1-RATE-PCT
                WHEN WS-7505-COVERAGE-LEVEL-03
                   MOVE WS-7505-BASE-PREMIUM-RATE-03
                     TO WS-2335-ADM1-RATE-PCT
                WHEN WS-7505-COVERAGE-LEVEL-04
                   MOVE WS-7505-BASE-PREMIUM-RATE-04
                     TO WS-2335-ADM1-RATE-PCT
                WHEN WS-7505-COVERAGE-LEVEL-05
                   MOVE WS-7505-BASE-PREMIUM-RATE-05
                     TO WS-2335-ADM1-RATE-PCT
                WHEN WS-7505-COVERAGE-LEVEL-06
                   MOVE WS-7505-BASE-PREMIUM-RATE-06
                     TO WS-2335-ADM1-RATE-PCT
                WHEN WS-7505-COVERAGE-LEVEL-07
                   MOVE WS-7505-BASE-PREMIUM-RATE-07
                     TO WS-2335-ADM1-RATE-PCT
                WHEN WS-7505-COVERAGE-LEVEL-08
                   MOVE WS-7505-BASE-PREMIUM-RATE-08
                     TO WS-2335-ADM1-RATE-PCT
                WHEN WS-7505-COVERAGE-LEVEL-09
                   MOVE WS-7505-BASE-PREMIUM-RATE-09
                     TO WS-2335-ADM1-RATE-PCT
                WHEN WS-7505-COVERAGE-LEVEL-10
                   MOVE WS-7505-BASE-PREMIUM-RATE-10
                     TO WS-2335-ADM1-RATE-PCT
                WHEN WS-7505-COVERAGE-LEVEL-11
                   MOVE WS-7505-BASE-PREMIUM-RATE-11
                     TO WS-2335-ADM1-RATE-PCT
                WHEN WS-7505-COVERAGE-LEVEL-12
                   MOVE WS-7505-BASE-PREMIUM-RATE-12
                     TO WS-2335-ADM1-RATE-PCT
                WHEN WS-7505-COVERAGE-LEVEL-13
                   MOVE WS-7505-BASE-PREMIUM-RATE-13
                     TO WS-2335-ADM1-RATE-PCT
                WHEN WS-7505-COVERAGE-LEVEL-14
                   MOVE WS-7505-BASE-PREMIUM-RATE-14
                     TO WS-2335-ADM1-RATE-PCT
                WHEN WS-7505-COVERAGE-LEVEL-15
                   MOVE WS-7505-BASE-PREMIUM-RATE-15
                     TO WS-2335-ADM1-RATE-PCT
                WHEN WS-7505-COVERAGE-LEVEL-16
                   MOVE WS-7505-BASE-PREMIUM-RATE-16
                     TO WS-2335-ADM1-RATE-PCT
                WHEN OTHER
                   MOVE WS-LITERAL-YES TO ERROR-BASE-PREM-RT
                   MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
                   MOVE 044 TO WS-8000-SHORT-ERROR
                   MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
                   MOVE WS-LITERAL-CVG-LVL-PCT TO WS-8000-FIELD-NAME1
                   MOVE WS-2335-CVG-LVL-PCT TO WS-8000-BAD-DATA1
                   MOVE 'NO BASE PREM RT FOUND FOR THIS ADM1 CVG%'
                     TO WS-8000-CORR-DATA1
                   MOVE 2335 TO WS-8000-PARAGRAPH-NO
                   PERFORM 8000-RECORD-TRAN-ERROR
                      THRU 8000-RECORD-TRAN-ERROR-EXIT
                   GO TO 2335-LOOKUP-ADM1-RATE-EXIT
              END-EVALUATE

              MOVE WS-2335-ADM1-RATE-PCT TO WS-2335-ADM1-RATE-PCT-X
      $IF DEBUG-SW DEFINED
              DISPLAY 'ADM1 RATE     = ', WS-2335-ADM1-RATE-PCT-X
              UPON CONSOLE
      $END
              IF NOT CAT-COVERAGE
                 GO TO 2335-LOOKUP-ADM1-RATE-EXIT
              END-IF

      *       *** FIND CAT 65% BASE PREMIUM RATE ***
              EVALUATE 65
                WHEN WS-7505-COVERAGE-LEVEL-01
                   MOVE WS-7505-BASE-PREMIUM-RATE-01
                     TO WS-2335-CAT-65-PCT-PREM-RATE
                WHEN WS-7505-COVERAGE-LEVEL-02
                   MOVE WS-7505-BASE-PREMIUM-RATE-02
                     TO WS-2335-CAT-65-PCT-PREM-RATE
                WHEN WS-7505-COVERAGE-LEVEL-03
                   MOVE WS-7505-BASE-PREMIUM-RATE-03
                     TO WS-2335-CAT-65-PCT-PREM-RATE
                WHEN WS-7505-COVERAGE-LEVEL-04
                   MOVE WS-7505-BASE-PREMIUM-RATE-04
                     TO WS-2335-CAT-65-PCT-PREM-RATE
                WHEN WS-7505-COVERAGE-LEVEL-05
                   MOVE WS-7505-BASE-PREMIUM-RATE-05
                     TO WS-2335-CAT-65-PCT-PREM-RATE
                WHEN WS-7505-COVERAGE-LEVEL-06
                   MOVE WS-7505-BASE-PREMIUM-RATE-06
                     TO WS-2335-CAT-65-PCT-PREM-RATE
                WHEN WS-7505-COVERAGE-LEVEL-07
                   MOVE WS-7505-BASE-PREMIUM-RATE-07
                     TO WS-2335-CAT-65-PCT-PREM-RATE
                WHEN WS-7505-COVERAGE-LEVEL-08
                   MOVE WS-7505-BASE-PREMIUM-RATE-08
                     TO WS-2335-CAT-65-PCT-PREM-RATE
                WHEN WS-7505-COVERAGE-LEVEL-09
                   MOVE WS-7505-BASE-PREMIUM-RATE-09
                     TO WS-2335-CAT-65-PCT-PREM-RATE
                WHEN WS-7505-COVERAGE-LEVEL-10
                   MOVE WS-7505-BASE-PREMIUM-RATE-10
                     TO WS-2335-CAT-65-PCT-PREM-RATE
                WHEN WS-7505-COVERAGE-LEVEL-11
                   MOVE WS-7505-BASE-PREMIUM-RATE-11
                     TO WS-2335-CAT-65-PCT-PREM-RATE
                WHEN WS-7505-COVERAGE-LEVEL-12
                   MOVE WS-7505-BASE-PREMIUM-RATE-12
                     TO WS-2335-CAT-65-PCT-PREM-RATE
                WHEN WS-7505-COVERAGE-LEVEL-13
                   MOVE WS-7505-BASE-PREMIUM-RATE-13
                     TO WS-2335-CAT-65-PCT-PREM-RATE
                WHEN WS-7505-COVERAGE-LEVEL-14
                   MOVE WS-7505-BASE-PREMIUM-RATE-14
                     TO WS-2335-CAT-65-PCT-PREM-RATE
                WHEN WS-7505-COVERAGE-LEVEL-15
                   MOVE WS-7505-BASE-PREMIUM-RATE-15
                     TO WS-2335-CAT-65-PCT-PREM-RATE
                WHEN WS-7505-COVERAGE-LEVEL-16
                   MOVE WS-7505-BASE-PREMIUM-RATE-16
                     TO WS-2335-CAT-65-PCT-PREM-RATE
                WHEN OTHER
                   MOVE WS-LITERAL-YES TO ERROR-BASE-PREM-RT
                   MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
                   MOVE 044 TO WS-8000-SHORT-ERROR
                   MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
                   MOVE WS-LITERAL-CVG-LVL-PCT TO WS-8000-FIELD-NAME1
                   MOVE 65 TO WS-8000-BAD-DATA1
                   MOVE 'NO BASE PREM RT FOUND FOR THIS ADM1 CVG%'
                     TO WS-8000-CORR-DATA1
                   MOVE 2335 TO WS-8000-PARAGRAPH-NO
                   PERFORM 8000-RECORD-TRAN-ERROR
                      THRU 8000-RECORD-TRAN-ERROR-EXIT
                   GO TO 2335-LOOKUP-ADM1-RATE-EXIT
              END-EVALUATE

              MOVE WS-2335-CAT-65-PCT-PREM-RATE
                TO WS-2335-CAT-65-PCT-PREM-RATE-X

      $IF DEBUG-SW DEFINED
              DISPLAY '65% ADM1 RATE = ',
              WS-2335-CAT-65-PCT-PREM-RATE-X
              UPON CONSOLE
      $END
           ELSE
      *       NO ADM1 REC FOUND
              MOVE 11009 TO WS-8000-ERROR-CODE
              MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO ERROR-BASE-PREM-RT
              MOVE WS-LITERAL-BASE-PREM-RT TO WS-8000-FIELD-NAME1
              MOVE 'NOT FOUND' TO WS-8000-BAD-DATA1
      *       *** SEARCH KEY USED IS IN CORR-DATA1
              MOVE 'ADM1' TO WS-8000-TABLE-NAME
              MOVE 2335 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF.

       2335-LOOKUP-ADM1-RATE-EXIT.
           EXIT.


       2335-LOOKUP-ADM1G-RATE.

           INITIALIZE WS-7507-INPUT-KEY
           MOVE WS-2335-CROP-YEAR TO WS-7507-INPUT-CROP-YR
           MOVE WS-2335-RATE-STATE TO WS-7507-INPUT-STATE-CD
           MOVE WS-2335-RATE-COUNTY TO WS-7507-INPUT-COUNTY-CD
           MOVE WS-2335-CROP-CD TO WS-7507-INPUT-CROP-CD
           MOVE WS-2335-INS-PLAN-CD TO WS-7507-INPUT-INSURANCE-PLAN
           MOVE WS-2335-PRACTICE-CD TO WS-7507-INPUT-PRACTICE-CD
           MOVE WS-2335-TYPE-CD TO WS-7507-INPUT-TYPE-CD

      *    *** SET UP ERROR STRING IN CASE ADM1 NOT FOUND
           STRING 'ADM1G KEY = '
               DELIMITED BY SIZE
               WS-7507-INPUT-KEY
               DELIMITED BY SIZE
               INTO WS-8000-CORR-DATA1
           END-STRING

           PERFORM 7507-LOOKUP-ADM1G
              THRU 7507-LOOKUP-ADM1G-EXIT

           IF MATCH-FOUND-7507
      *       *** CLEAR THE ERROR SET ABOVE
              MOVE SPACES TO WS-8000-CORR-DATA1

              IF WS-2335-CROP-CD = WS-LITERAL-FORAGE-PROD
      *          *** 65% RATE IS ALWAYS BASE-RATE-01
                 MOVE WS-7507-BASE-RATE-01
                   TO WS-2335-CAT-65-PCT-PREM-RATE
                 MOVE WS-2335-CAT-65-PCT-PREM-RATE
                   TO WS-2335-CAT-65-PCT-PREM-RATE-X
              END-IF

              EVALUATE WS-2335-CVG-LVL-PCT
                 WHEN WS-7507-COVERAGE-LEVEL-01
                    MOVE WS-7507-BASE-RATE-01 TO WS-2335-ADM1G-RATE

                 WHEN WS-7507-COVERAGE-LEVEL-02
                    MOVE WS-7507-BASE-RATE-02 TO WS-2335-ADM1G-RATE

                 WHEN WS-7507-COVERAGE-LEVEL-03
                    MOVE WS-7507-BASE-RATE-03 TO WS-2335-ADM1G-RATE

                 WHEN WS-7507-COVERAGE-LEVEL-04
                    MOVE WS-7507-BASE-RATE-04 TO WS-2335-ADM1G-RATE

                 WHEN WS-7507-COVERAGE-LEVEL-05
                    MOVE WS-7507-BASE-RATE-05 TO WS-2335-ADM1G-RATE

                 WHEN WS-7507-COVERAGE-LEVEL-06
                    MOVE WS-7507-BASE-RATE-06 TO WS-2335-ADM1G-RATE

                 WHEN OTHER
                    MOVE WS-LITERAL-YES TO ERROR-BASE-PREM-RT
                    MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
                    MOVE 008 TO WS-8000-SHORT-ERROR
                    MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
                    MOVE WS-LITERAL-CVG-LVL-PCT TO WS-8000-FIELD-NAME1
                    MOVE WS-2335-CVG-LVL-PCT TO WS-8000-BAD-DATA1
                    MOVE 'NO BASE RT FOUND FOR THIS ADM1G CVG%'
                      TO WS-8000-CORR-DATA1
                    MOVE 2335 TO WS-8000-PARAGRAPH-NO
                    PERFORM 8000-RECORD-TRAN-ERROR
                       THRU 8000-RECORD-TRAN-ERROR-EXIT
                    GO TO 2335-LOOKUP-ADM1G-RATE-EXIT
              END-EVALUATE

              MOVE WS-2335-ADM1G-RATE TO WS-2335-ADM1-RATE-PCT
              MOVE WS-2335-ADM1G-RATE TO WS-2335-ADM1-RATE-PCT-X

              IF WS-2335-ADM1G-RATE = ZERO
                 MOVE 11009 TO WS-8000-ERROR-CODE
                 MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                 MOVE WS-LITERAL-YES TO ERROR-BASE-PREM-RT
                 MOVE WS-LITERAL-BASE-PREM-RT TO WS-8000-FIELD-NAME1
                 MOVE 'RATE = ZERO' TO WS-8000-BAD-DATA1
      *          *** SEARCH KEY USED IS IN CORR-DATA1
                 MOVE 'ADM1G' TO WS-8000-TABLE-NAME
                 MOVE 2335 TO WS-8000-PARAGRAPH-NO
                 PERFORM 8000-RECORD-TRAN-ERROR
                    THRU 8000-RECORD-TRAN-ERROR-EXIT
              END-IF

      $IF DEBUG-SW DEFINED
              DISPLAY 'ADM1G RATE     = ', WS-2335-ADM1-RATE-PCT-X
              UPON CONSOLE
              DISPLAY 'ADM1G 65% RATE = ',
              WS-2335-CAT-65-PCT-PREM-RATE-X
              UPON CONSOLE
      $END
           ELSE
      *       NO ADM1G REC FOUND
              MOVE 11009 TO WS-8000-ERROR-CODE
              MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO ERROR-BASE-PREM-RT
              MOVE WS-LITERAL-BASE-PREM-RT TO WS-8000-FIELD-NAME1
              MOVE 'NOT FOUND' TO WS-8000-BAD-DATA1
      *       *** SEARCH KEY USED IS IN CORR-DATA1
              MOVE 'ADM1G' TO WS-8000-TABLE-NAME
              MOVE 2335 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF.

       2335-LOOKUP-ADM1G-RATE-EXIT.
           EXIT.

       2335-FIND-AVOCADO-RATE.

           INITIALIZE WS-7550-INPUT-KEY
           MOVE WS-2335-CROP-YEAR TO WS-7550-INPUT-CROP-YR
           MOVE WS-2335-RATE-STATE TO WS-7550-INPUT-STATE-CD
           MOVE WS-2335-RATE-COUNTY TO WS-7550-INPUT-COUNTY-CD
           MOVE WS-2335-CROP-CD TO WS-7550-INPUT-CROP-CD
           MOVE WS-2335-INS-PLAN-CD TO WS-7550-INPUT-INSURANCE-PLAN
           MOVE WS-2335-PRACTICE-CD TO WS-7550-INPUT-PRACTICE-CD
           MOVE WS-2335-TYPE-CD TO WS-7550-INPUT-TYPE-CD
           MOVE WS-2335-RATE-CLASS TO WS-7550-INPUT-RATE-CLASS
      *    *** SET UP NOT FOUND ERROR
           MOVE WS-7550-INPUT-KEY
             TO WS-8000-CORR-DATA1
           PERFORM 7550-LOOKUP-ADMAR
              THRU 7550-LOOKUP-ADMAR-EXIT
           IF INPUT-ERROR-7550
              MOVE SPACES TO WS-8000-CORR-DATA1
              MOVE WS-LITERAL-YES TO ERROR-BASE-PREM-RT
              GO TO 2335-FIND-AVOCADO-RATE-EXIT
           END-IF
           IF NOT MATCH-FOUND-7550
              MOVE 11009 TO WS-8000-ERROR-CODE
              MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO ERROR-BASE-PREM-RT
              MOVE WS-LITERAL-BASE-PREM-RT TO WS-8000-FIELD-NAME1
              MOVE 'ADMAR NOT FOUND' TO WS-8000-BAD-DATA1
      *       *** SEARCH KEY USED IS IN CORR-DATA1
              MOVE 'ADMAR' TO WS-8000-TABLE-NAME
              MOVE 2335 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           ELSE
      *       *** CLEAR ERROR ***
              MOVE SPACES TO WS-8000-CORR-DATA1

      *       *** GET RATE DATA FOR CVG LVL ***
              EVALUATE WS-2335-CVG-LVL-PCT
               WHEN WS-7550-CVG-LVL-01
                  MOVE WS-7550-BASE-PREM-RT-01 TO WS-2335-ADMAR-RATE
               WHEN WS-7550-CVG-LVL-02
                  MOVE WS-7550-BASE-PREM-RT-02 TO WS-2335-ADMAR-RATE
               WHEN WS-7550-CVG-LVL-03
                  MOVE WS-7550-BASE-PREM-RT-03 TO WS-2335-ADMAR-RATE
               WHEN WS-7550-CVG-LVL-04
                  MOVE WS-7550-BASE-PREM-RT-04 TO WS-2335-ADMAR-RATE
               WHEN WS-7550-CVG-LVL-05
                  MOVE WS-7550-BASE-PREM-RT-05 TO WS-2335-ADMAR-RATE
               WHEN WS-7550-CVG-LVL-06
                  MOVE WS-7550-BASE-PREM-RT-06 TO WS-2335-ADMAR-RATE
               WHEN WS-7550-CVG-LVL-07
                  MOVE WS-7550-BASE-PREM-RT-07 TO WS-2335-ADMAR-RATE
               WHEN WS-7550-CVG-LVL-08
                  MOVE WS-7550-BASE-PREM-RT-08 TO WS-2335-ADMAR-RATE
               WHEN WS-7550-CVG-LVL-09
                  MOVE WS-7550-BASE-PREM-RT-09 TO WS-2335-ADMAR-RATE
               WHEN WS-7550-CVG-LVL-10
                  MOVE WS-7550-BASE-PREM-RT-10 TO WS-2335-ADMAR-RATE
               WHEN WS-7550-CVG-LVL-11
                  MOVE WS-7550-BASE-PREM-RT-11 TO WS-2335-ADMAR-RATE
               WHEN WS-7550-CVG-LVL-12
                  MOVE WS-7550-BASE-PREM-RT-12 TO WS-2335-ADMAR-RATE
               WHEN WS-7550-CVG-LVL-13
                  MOVE WS-7550-BASE-PREM-RT-13 TO WS-2335-ADMAR-RATE
               WHEN WS-7550-CVG-LVL-14
                  MOVE WS-7550-BASE-PREM-RT-14 TO WS-2335-ADMAR-RATE
               WHEN WS-7550-CVG-LVL-15
                  MOVE WS-7550-BASE-PREM-RT-15 TO WS-2335-ADMAR-RATE
               WHEN WS-7550-CVG-LVL-16
                  MOVE WS-7550-BASE-PREM-RT-16 TO WS-2335-ADMAR-RATE
               WHEN OTHER
                   IF CAT-COVERAGE
                   MOVE WS-7550-BASE-PREM-RT-01
                     TO WS-2335-ADMAR-RATE
                 ELSE
                   MOVE WS-LITERAL-YES TO ERROR-BASE-PREM-RT
                   MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
                   MOVE 044 TO WS-8000-SHORT-ERROR
                   MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
                   MOVE WS-LITERAL-CVG-LVL-PCT TO WS-8000-FIELD-NAME1
                   MOVE WS-2335-CVG-LVL-PCT TO WS-8000-BAD-DATA1
                   MOVE 'NO BASE RT FOUND FOR THIS ADMAR CVG%'
                     TO WS-8000-CORR-DATA1
                   MOVE 2335 TO WS-8000-PARAGRAPH-NO
                   PERFORM 8000-RECORD-TRAN-ERROR
                      THRU 8000-RECORD-TRAN-ERROR-EXIT
                   GO TO 2335-FIND-AVOCADO-RATE-EXIT
              END-EVALUATE

              MOVE WS-2335-ADMAR-RATE TO WS-2335-ADMAR-RATE-X
      $IF DEBUG-SW DEFINED
           DISPLAY 'ADMAR RATE = $ ', WS-2335-ADMAR-RATE-X
           UPON CONSOLE
      $END

              IF NOT CAT-COVERAGE
                 GO TO 2335-FIND-AVOCADO-RATE-EXIT
              END-IF

      *       *** GET RATE DATA FOR CAT COVERAGE ***
              EVALUATE 65
               WHEN WS-7550-CVG-LVL-01
                  MOVE WS-7550-BASE-PREM-RT-01
                    TO WS-2335-CAT-65-PCT-PREM-RATE
               WHEN WS-7550-CVG-LVL-02
                  MOVE WS-7550-BASE-PREM-RT-02
                    TO WS-2335-CAT-65-PCT-PREM-RATE
               WHEN WS-7550-CVG-LVL-03
                  MOVE WS-7550-BASE-PREM-RT-03
                    TO WS-2335-CAT-65-PCT-PREM-RATE
               WHEN WS-7550-CVG-LVL-04
                  MOVE WS-7550-BASE-PREM-RT-04
                    TO WS-2335-CAT-65-PCT-PREM-RATE
               WHEN WS-7550-CVG-LVL-05
                  MOVE WS-7550-BASE-PREM-RT-05
                    TO WS-2335-CAT-65-PCT-PREM-RATE
               WHEN WS-7550-CVG-LVL-06
                  MOVE WS-7550-BASE-PREM-RT-06
                    TO WS-2335-CAT-65-PCT-PREM-RATE
               WHEN WS-7550-CVG-LVL-07
                  MOVE WS-7550-BASE-PREM-RT-07
                    TO WS-2335-CAT-65-PCT-PREM-RATE
               WHEN WS-7550-CVG-LVL-08
                  MOVE WS-7550-BASE-PREM-RT-08
                    TO WS-2335-CAT-65-PCT-PREM-RATE
               WHEN WS-7550-CVG-LVL-09
                  MOVE WS-7550-BASE-PREM-RT-09
                    TO WS-2335-CAT-65-PCT-PREM-RATE
               WHEN WS-7550-CVG-LVL-10
                  MOVE WS-7550-BASE-PREM-RT-10
                    TO WS-2335-CAT-65-PCT-PREM-RATE
               WHEN WS-7550-CVG-LVL-11
                  MOVE WS-7550-BASE-PREM-RT-11
                    TO WS-2335-CAT-65-PCT-PREM-RATE
               WHEN WS-7550-CVG-LVL-12
                  MOVE WS-7550-BASE-PREM-RT-12
                    TO WS-2335-CAT-65-PCT-PREM-RATE
               WHEN WS-7550-CVG-LVL-13
                  MOVE WS-7550-BASE-PREM-RT-13
                    TO WS-2335-CAT-65-PCT-PREM-RATE
               WHEN WS-7550-CVG-LVL-14
                  MOVE WS-7550-BASE-PREM-RT-14
                    TO WS-2335-CAT-65-PCT-PREM-RATE
               WHEN WS-7550-CVG-LVL-15
                  MOVE WS-7550-BASE-PREM-RT-15
                    TO WS-2335-CAT-65-PCT-PREM-RATE
               WHEN WS-7550-CVG-LVL-16
                  MOVE WS-7550-BASE-PREM-RT-16
                    TO WS-2335-CAT-65-PCT-PREM-RATE
               WHEN OTHER
                  MOVE WS-LITERAL-YES TO ERROR-BASE-PREM-RT
                  MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
                  MOVE 044 TO WS-8000-SHORT-ERROR
                  MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
                  MOVE WS-LITERAL-CVG-LVL-PCT TO WS-8000-FIELD-NAME1
                  MOVE WS-2335-CVG-LVL-PCT TO WS-8000-BAD-DATA1
                  MOVE 'NO BASE RT FOUND FOR THIS ADMAR CVG%'
                    TO WS-8000-CORR-DATA1
                  MOVE 2335 TO WS-8000-PARAGRAPH-NO
                  PERFORM 8000-RECORD-TRAN-ERROR
                     THRU 8000-RECORD-TRAN-ERROR-EXIT
                  GO TO 2335-FIND-AVOCADO-RATE-EXIT
              END-EVALUATE
              MOVE WS-2335-CAT-65-PCT-PREM-RATE
                TO WS-2335-CAT-65-PCT-PREM-RATE-X
      $IF DEBUG-SW DEFINED
              DISPLAY '65% ADM1 RATE = ',
              WS-2335-CAT-65-PCT-PREM-RATE-X
              UPON CONSOLE
      $END

           END-IF.

       2335-FIND-AVOCADO-RATE-EXIT.
           EXIT.


       2335-LOOKUP-ADMIR-RATE.

           INITIALIZE WS-7570-INPUT-KEY
           MOVE WS-2335-CROP-YEAR TO WS-7570-INPUT-CROP-YR
           MOVE WS-2335-RATE-STATE TO WS-7570-INPUT-STATE-CD
           MOVE WS-2335-RATE-COUNTY TO WS-7570-INPUT-COUNTY-CD
           MOVE WS-2335-CROP-CD TO WS-7570-INPUT-CROP-CD
           MOVE WS-2335-INS-PLAN-CD TO WS-7570-INPUT-INSURANCE-PLAN
           MOVE WS-2335-PRACTICE-CD TO WS-7570-INPUT-PRACTICE-CD
           MOVE WS-2335-TYPE-CD TO WS-7570-INPUT-TYPE-CD
           MOVE WS-2335-RATE-CLASS TO WS-7570-INPUT-RATE-CLASS
      *    *** SET UP ERROR STRING IN CASE ADMIR NOT FOUND
           STRING 'ADMIR KEY = '
               DELIMITED BY SIZE
               WS-7570-INPUT-KEY
               DELIMITED BY SIZE
               INTO WS-8000-CORR-DATA1
           END-STRING

           PERFORM 7570-LOOKUP-ADMIR
              THRU 7570-LOOKUP-ADMIR-EXIT

           IF MATCH-FOUND-7570
      *       *** CLEAR THE ERROR SET ABOVE
              MOVE SPACES TO WS-8000-CORR-DATA1

              EVALUATE WS-2335-CVG-LVL-PCT
                WHEN WS-7570-COVERAGE-LVL-01
                   MOVE WS-7570-BASE-PREMIUM-RATE-01
                     TO WS-2335-ADMIR-RATE
                WHEN WS-7570-COVERAGE-LVL-02
                   MOVE WS-7570-BASE-PREMIUM-RATE-02
                     TO WS-2335-ADMIR-RATE
                WHEN WS-7570-COVERAGE-LVL-03
                   MOVE WS-7570-BASE-PREMIUM-RATE-03
                     TO WS-2335-ADMIR-RATE
                WHEN WS-7570-COVERAGE-LVL-04
                   MOVE WS-7570-BASE-PREMIUM-RATE-04
                     TO WS-2335-ADMIR-RATE
                WHEN WS-7570-COVERAGE-LVL-05
                   MOVE WS-7570-BASE-PREMIUM-RATE-05
                     TO WS-2335-ADMIR-RATE
                WHEN WS-7570-COVERAGE-LVL-06
                   MOVE WS-7570-BASE-PREMIUM-RATE-06
                     TO WS-2335-ADMIR-RATE
                WHEN WS-7570-COVERAGE-LVL-07
                   MOVE WS-7570-BASE-PREMIUM-RATE-07
                     TO WS-2335-ADMIR-RATE
                WHEN WS-7570-COVERAGE-LVL-08
                   MOVE WS-7570-BASE-PREMIUM-RATE-08
                     TO WS-2335-ADMIR-RATE
                WHEN WS-7570-COVERAGE-LVL-09
                   MOVE WS-7570-BASE-PREMIUM-RATE-09
                     TO WS-2335-ADMIR-RATE
                WHEN WS-7570-COVERAGE-LVL-10
                   MOVE WS-7570-BASE-PREMIUM-RATE-10
                     TO WS-2335-ADMIR-RATE
                WHEN WS-7570-COVERAGE-LVL-11
                   MOVE WS-7570-BASE-PREMIUM-RATE-11
                     TO WS-2335-ADMIR-RATE
                WHEN WS-7570-COVERAGE-LVL-12
                   MOVE WS-7570-BASE-PREMIUM-RATE-12
                     TO WS-2335-ADMIR-RATE
                WHEN WS-7570-COVERAGE-LVL-13
                   MOVE WS-7570-BASE-PREMIUM-RATE-13
                     TO WS-2335-ADMIR-RATE
                WHEN WS-7570-COVERAGE-LVL-14
                   MOVE WS-7570-BASE-PREMIUM-RATE-14
                     TO WS-2335-ADMIR-RATE
                WHEN WS-7570-COVERAGE-LVL-15
                   MOVE WS-7570-BASE-PREMIUM-RATE-15
                     TO WS-2335-ADMIR-RATE
                WHEN WS-7570-COVERAGE-LVL-16
                   MOVE WS-7570-BASE-PREMIUM-RATE-16
                     TO WS-2335-ADMIR-RATE
                WHEN OTHER
                   MOVE WS-LITERAL-YES TO ERROR-BASE-PREM-RT
                   MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
                   MOVE 044 TO WS-8000-SHORT-ERROR
                   MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
                   MOVE WS-LITERAL-CVG-LVL-PCT TO WS-8000-FIELD-NAME1
                   MOVE WS-2335-CVG-LVL-PCT TO WS-8000-BAD-DATA1
                   MOVE 'NO BASE PREM RT FOUND FOR ADMIR CVG%'
                     TO WS-8000-CORR-DATA1
                   MOVE 2335 TO WS-8000-PARAGRAPH-NO
                   PERFORM 8000-RECORD-TRAN-ERROR
                      THRU 8000-RECORD-TRAN-ERROR-EXIT
                   GO TO 2335-LOOKUP-ADMIR-RATE-EXIT
              END-EVALUATE

              MOVE WS-2335-ADMIR-RATE TO WS-2335-ADMIR-RATE-X
      $IF DEBUG-SW DEFINED
              DISPLAY 'ADMIR RATE = ', WS-2335-ADMIR-RATE-X
              UPON CONSOLE
      $END

              EVALUATE 50
                WHEN WS-7570-COVERAGE-LVL-01
                   MOVE WS-7570-BASE-PREMIUM-RATE-01
                     TO WS-2335-IP-50-PCT-PREM-RATE
                WHEN WS-7570-COVERAGE-LVL-02
                   MOVE WS-7570-BASE-PREMIUM-RATE-02
                     TO WS-2335-IP-50-PCT-PREM-RATE
                WHEN WS-7570-COVERAGE-LVL-03
                   MOVE WS-7570-BASE-PREMIUM-RATE-03
                     TO WS-2335-IP-50-PCT-PREM-RATE
                WHEN WS-7570-COVERAGE-LVL-04
                   MOVE WS-7570-BASE-PREMIUM-RATE-04
                     TO WS-2335-IP-50-PCT-PREM-RATE
                WHEN WS-7570-COVERAGE-LVL-05
                   MOVE WS-7570-BASE-PREMIUM-RATE-05
                     TO WS-2335-IP-50-PCT-PREM-RATE
                WHEN WS-7570-COVERAGE-LVL-06
                   MOVE WS-7570-BASE-PREMIUM-RATE-06
                     TO WS-2335-IP-50-PCT-PREM-RATE
                WHEN WS-7570-COVERAGE-LVL-07
                   MOVE WS-7570-BASE-PREMIUM-RATE-07
                     TO WS-2335-IP-50-PCT-PREM-RATE
                WHEN WS-7570-COVERAGE-LVL-08
                   MOVE WS-7570-BASE-PREMIUM-RATE-08
                     TO WS-2335-IP-50-PCT-PREM-RATE
                WHEN WS-7570-COVERAGE-LVL-09
                   MOVE WS-7570-BASE-PREMIUM-RATE-09
                     TO WS-2335-IP-50-PCT-PREM-RATE
                WHEN WS-7570-COVERAGE-LVL-10
                   MOVE WS-7570-BASE-PREMIUM-RATE-10
                     TO WS-2335-IP-50-PCT-PREM-RATE
                WHEN WS-7570-COVERAGE-LVL-11
                   MOVE WS-7570-BASE-PREMIUM-RATE-11
                     TO WS-2335-IP-50-PCT-PREM-RATE
                WHEN WS-7570-COVERAGE-LVL-12
                   MOVE WS-7570-BASE-PREMIUM-RATE-12
                     TO WS-2335-IP-50-PCT-PREM-RATE
                WHEN WS-7570-COVERAGE-LVL-13
                   MOVE WS-7570-BASE-PREMIUM-RATE-13
                     TO WS-2335-IP-50-PCT-PREM-RATE
                WHEN WS-7570-COVERAGE-LVL-14
                   MOVE WS-7570-BASE-PREMIUM-RATE-14
                     TO WS-2335-IP-50-PCT-PREM-RATE
                WHEN WS-7570-COVERAGE-LVL-15
                   MOVE WS-7570-BASE-PREMIUM-RATE-15
                     TO WS-2335-IP-50-PCT-PREM-RATE
                WHEN WS-7570-COVERAGE-LVL-16
                   MOVE WS-7570-BASE-PREMIUM-RATE-16
                     TO WS-2335-IP-50-PCT-PREM-RATE
                WHEN OTHER
                   MOVE WS-LITERAL-YES TO ERROR-BASE-PREM-RT
                   MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
                   MOVE 044 TO WS-8000-SHORT-ERROR
                   MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
                   MOVE WS-LITERAL-CVG-LVL-PCT TO WS-8000-FIELD-NAME1
                   MOVE WS-2335-CVG-LVL-PCT TO WS-8000-BAD-DATA1
                   MOVE 'NO BASE PREM RT FOUND FOR ADMIR 50%'
                     TO WS-8000-CORR-DATA1
                   MOVE 2335 TO WS-8000-PARAGRAPH-NO
                   PERFORM 8000-RECORD-TRAN-ERROR
                      THRU 8000-RECORD-TRAN-ERROR-EXIT
                   GO TO 2335-LOOKUP-ADMIR-RATE-EXIT
              END-EVALUATE

              MOVE WS-2335-IP-50-PCT-PREM-RATE
                TO WS-2335-IP-50-PCT-PREM-RATE-X
      $IF DEBUG-SW DEFINED
              DISPLAY 'ADMIR 50% RATE = ',
              WS-2335-IP-50-PCT-PREM-RATE-X
              UPON CONSOLE
      $END

           ELSE
      *       NO ADMIR REC FOUND
              MOVE 11009 TO WS-8000-ERROR-CODE
              MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO ERROR-BASE-PREM-RT
              MOVE WS-LITERAL-BASE-PREM-RT TO WS-8000-FIELD-NAME1
              MOVE 'NOT FOUND' TO WS-8000-BAD-DATA1
      *       *** SEARCH KEY USED IS IN CORR-DATA1
              MOVE 'ADMIR' TO WS-8000-TABLE-NAME
              MOVE 2335 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF.

       2335-LOOKUP-ADMIR-RATE-EXIT.
           EXIT.
       2335-FIND-RATE-DIFF.

      $IF ISAM-SW DEFINED
           INITIALIZE WS-7510-INPUT-KEY
           MOVE WS-2335-CROP-CD TO WS-7510-INPUT-CROP-CD
           move ws-2335-ins-plan-cd
             to ws-7510-input-insurance-plan
           MOVE WS-2335-CROP-YEAR TO WS-7510-INPUT-CROP-YR
           MOVE WS-2335-RATE-STATE TO WS-7510-INPUT-STATE-CD
           MOVE WS-2335-RATE-COUNTY TO WS-7510-INPUT-COUNTY-CD
           MOVE WS-2335-PRACTICE-CD TO WS-7510-INPUT-PRACTICE-CD
           MOVE WS-2335-TYPE-CD TO WS-7510-INPUT-TYPE-CD

      *    *** SET UP ERROR STRING IN CASE ADM2 NOT FOUND
           STRING 'ADM2 KEY = '
               DELIMITED BY SIZE
               WS-7510-INPUT-KEY
               DELIMITED BY SIZE
               INTO WS-8000-CORR-DATA1
           END-STRING

           PERFORM 7510-LOOKUP-ADM2
              THRU 7510-LOOKUP-ADM2-EXIT

           IF MATCH-FOUND-7510
      *    *** CLEAR THE ERROR SET ABOVE
              MOVE SPACES TO WS-8000-CORR-DATA1

              IF ws-2335-cvg-LVL-PCT > 75 THEN
                 EVALUATE 75
                  WHEN WS-7510-COVERAGE-LVL1
                    MOVE WS-7510-RATE-DIFFERENTIAL1
                      TO WS-2335-ELECT-RATE-DIFF
                  WHEN WS-7510-COVERAGE-LVL2
                    MOVE WS-7510-RATE-DIFFERENTIAL2
                      TO WS-2335-ELECT-RATE-DIFF
                  WHEN WS-7510-COVERAGE-LVL3
                    MOVE WS-7510-RATE-DIFFERENTIAL3
                      TO WS-2335-ELECT-RATE-DIFF
                  WHEN WS-7510-COVERAGE-LVL4
                    MOVE WS-7510-RATE-DIFFERENTIAL4
                      TO WS-2335-ELECT-RATE-DIFF
                  WHEN WS-7510-COVERAGE-LVL5
                    MOVE WS-7510-RATE-DIFFERENTIAL5
                      TO WS-2335-ELECT-RATE-DIFF
                  WHEN WS-7510-COVERAGE-LVL6
                    MOVE WS-7510-RATE-DIFFERENTIAL6
                      TO WS-2335-ELECT-RATE-DIFF
                  WHEN WS-7510-COVERAGE-LVL7
                    MOVE WS-7510-RATE-DIFFERENTIAL7
                      TO WS-2335-ELECT-RATE-DIFF
                  WHEN WS-7510-COVERAGE-LVL8
                    MOVE WS-7510-RATE-DIFFERENTIAL8
                      TO WS-2335-ELECT-RATE-DIFF
                  WHEN WS-7510-COVERAGE-LVL9
                    MOVE WS-7510-RATE-DIFFERENTIAL9
                      TO WS-2335-ELECT-RATE-DIFF
                  WHEN WS-7510-COVERAGE-LVL10
                    MOVE WS-7510-RATE-DIFFERENTIAL10
                      TO WS-2335-ELECT-RATE-DIFF
                  WHEN WS-7510-COVERAGE-LVL11
                    MOVE WS-7510-RATE-DIFFERENTIAL11
                      TO WS-2335-ELECT-RATE-DIFF
                  WHEN WS-7510-COVERAGE-LVL12
                    MOVE WS-7510-RATE-DIFFERENTIAL12
                      TO WS-2335-ELECT-RATE-DIFF
                  WHEN WS-7510-COVERAGE-LVL13
                    MOVE WS-7510-RATE-DIFFERENTIAL13
                      TO WS-2335-ELECT-RATE-DIFF
                  WHEN WS-7510-COVERAGE-LVL14
                    MOVE WS-7510-RATE-DIFFERENTIAL14
                      TO WS-2335-ELECT-RATE-DIFF
                  WHEN WS-7510-COVERAGE-LVL15
                    MOVE WS-7510-RATE-DIFFERENTIAL15
                      TO WS-2335-ELECT-RATE-DIFF
                  WHEN WS-7510-COVERAGE-LVL16
                    MOVE WS-7510-RATE-DIFFERENTIAL16
                      TO WS-2335-ELECT-RATE-DIFF
                  WHEN OTHER
                    MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                    MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
                    MOVE 15 TO WS-8000-SHORT-ERROR
                    MOVE WS-LITERAL-YES TO error-base-prem-rt
                    MOVE 'PRICE ELECTION %' TO WS-8000-FIELD-NAME1
                    MOVE '75' TO WS-8000-BAD-DATA1
                    MOVE SPACES TO WS-8000-CORR-DATA1
                    MOVE 2335 TO WS-8000-PARAGRAPH-NO
                    PERFORM 8000-RECORD-TRAN-ERROR
                       THRU 8000-RECORD-TRAN-ERROR-EXIT
                    GO TO 2335-FIND-RATE-DIFF-EXIT
                 END-EVALUATE

                 IF WS-2335-ELECT-RATE-DIFF > ZEROS

      $IF DEBUG-SW DEFINED
           DISPLAY '2335-CALCULATING ELECTED RATE DIFF > 75%'
           UPON CONSOLE
      $END

      *          *** COMPUTE THE 100% COVERAGE RATE DIFFERENTIAL
                    COMPUTE WS-2335-100-PCT-RT-DIFF =
                       ((WS-2335-ELECT-RATE-DIFF * 4) / 3)
                    ON SIZE ERROR
                       MOVE 2335 TO WS-8020-PARAGRAPH-NO
                       MOVE 9017 TO WS-8020-INT-ERROR-NO
                       MOVE '100% RATE DIFF' TO WS-8020-FIELD-NAME
                       MOVE SPACES TO WS-8020-BAD-DATA
                       MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                       PERFORM 8020-RECORD-INT-ERROR
                          THRU 8020-RECORD-INT-ERROR-EXIT
                    END-COMPUTE

      $IF DEBUG-SW DEFINED
           MOVE WS-2335-100-PCT-RT-DIFF
             TO WS-2335-100-PCT-RT-DIFF-X
           DISPLAY '100% CVG RATE DIFF = ', WS-2335-100-PCT-RT-DIFF-X
           UPON CONSOLE
      $END

      *          *** AND MULTIPLY IT BY THE ELECTED COVERAGE LEVEL
                    COMPUTE WS-2335-ELECT-RATE-DIFF =
                     (ws-2335-cvg-LVL-PCT / 100)
                     * WS-2335-100-PCT-RT-DIFF
                    ON SIZE ERROR
                       MOVE 2335 TO WS-8020-PARAGRAPH-NO
                       MOVE 9017 TO WS-8020-INT-ERROR-NO
                       MOVE 'ELECTED RATE DIFF' TO WS-8020-FIELD-NAME
                       MOVE SPACES TO WS-8020-BAD-DATA
                       MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                       PERFORM 8020-RECORD-INT-ERROR
                          THRU 8020-RECORD-INT-ERROR-EXIT
                    END-COMPUTE

                    IF WS-2335-ELECT-RATE-DIFF > 1.00
                       MOVE 1.00 TO WS-2335-ELECT-RATE-DIFF
                    END-IF

      $IF DEBUG-SW DEFINED
           DISPLAY 'ELECTED RATE DIFF = ', WS-2335-ELECT-RATE-DIFF
           UPON CONSOLE
      $END

                 END-IF

      *    *** COVERAGE LEVEL IS <= 75 SO THE CORRECT
      *    *** RATE DIFFERENTIAL SHOULD BE IN THE TABLE
              ELSE
                 EVALUATE ws-2335-cvg-LVL-PCT
                  WHEN WS-7510-COVERAGE-LVL1
                    MOVE WS-7510-RATE-DIFFERENTIAL1
                      TO WS-2335-ELECT-RATE-DIFF
                  WHEN WS-7510-COVERAGE-LVL2
                    MOVE WS-7510-RATE-DIFFERENTIAL2
                      TO WS-2335-ELECT-RATE-DIFF
                  WHEN WS-7510-COVERAGE-LVL3
                    MOVE WS-7510-RATE-DIFFERENTIAL3
                      TO WS-2335-ELECT-RATE-DIFF
                  WHEN WS-7510-COVERAGE-LVL4
                    MOVE WS-7510-RATE-DIFFERENTIAL4
                      TO WS-2335-ELECT-RATE-DIFF
                  WHEN WS-7510-COVERAGE-LVL5
                    MOVE WS-7510-RATE-DIFFERENTIAL5
                      TO WS-2335-ELECT-RATE-DIFF
                  WHEN WS-7510-COVERAGE-LVL6
                    MOVE WS-7510-RATE-DIFFERENTIAL6
                      TO WS-2335-ELECT-RATE-DIFF
                  WHEN WS-7510-COVERAGE-LVL7
                    MOVE WS-7510-RATE-DIFFERENTIAL7
                      TO WS-2335-ELECT-RATE-DIFF
                  WHEN WS-7510-COVERAGE-LVL8
                    MOVE WS-7510-RATE-DIFFERENTIAL8
                      TO WS-2335-ELECT-RATE-DIFF
                  WHEN WS-7510-COVERAGE-LVL9
                    MOVE WS-7510-RATE-DIFFERENTIAL9
                      TO WS-2335-ELECT-RATE-DIFF
                  WHEN WS-7510-COVERAGE-LVL10
                    MOVE WS-7510-RATE-DIFFERENTIAL10
                      TO WS-2335-ELECT-RATE-DIFF
                  WHEN WS-7510-COVERAGE-LVL11
                    MOVE WS-7510-RATE-DIFFERENTIAL11
                      TO WS-2335-ELECT-RATE-DIFF
                  WHEN WS-7510-COVERAGE-LVL12
                    MOVE WS-7510-RATE-DIFFERENTIAL12
                      TO WS-2335-ELECT-RATE-DIFF
                  WHEN WS-7510-COVERAGE-LVL13
                    MOVE WS-7510-RATE-DIFFERENTIAL13
                      TO WS-2335-ELECT-RATE-DIFF
                  WHEN WS-7510-COVERAGE-LVL14
                    MOVE WS-7510-RATE-DIFFERENTIAL14
                      TO WS-2335-ELECT-RATE-DIFF
                  WHEN WS-7510-COVERAGE-LVL15
                    MOVE WS-7510-RATE-DIFFERENTIAL15
                      TO WS-2335-ELECT-RATE-DIFF
                  WHEN WS-7510-COVERAGE-LVL16
                    MOVE WS-7510-RATE-DIFFERENTIAL16
                      TO WS-2335-ELECT-RATE-DIFF
                  WHEN OTHER
                    MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                    MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
                    MOVE 28 TO WS-8000-SHORT-ERROR
                    MOVE WS-LITERAL-YES TO error-base-prem-rt
                    MOVE 'COVERAGE LEVEL %' TO WS-8000-FIELD-NAME1
                    MOVE ws-2335-cvg-LVL-PCT
                      TO WS-8000-BAD-DATA1
                    MOVE SPACES TO WS-8000-CORR-DATA1
                    MOVE 2335 TO WS-8000-PARAGRAPH-NO
                    PERFORM 8000-RECORD-TRAN-ERROR
                       THRU 8000-RECORD-TRAN-ERROR-EXIT
                    GO TO 2335-FIND-RATE-DIFF-EXIT
                 END-EVALUATE
              END-IF
           ELSE
      *       NO ADM2 REC FOUND
              MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 09 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-YES TO error-base-prem-rt
              MOVE 'RATE DIFF' TO WS-8000-FIELD-NAME1
              MOVE 'ADM2 KEY' TO WS-8000-BAD-DATA1
      *       *** SEARCH KEY USED IS IN CORR-DATA1
              MOVE 2335 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
              GO TO 2335-FIND-RATE-DIFF-EXIT
           END-IF.

      $END

       2335-FIND-RATE-DIFF-EXIT.

       2335-PROCESS-SBI-TBL.

           IF WS-0010-TBL-ID-NUM(WS-0010-SBI-INT-INDEX) NUMERIC
             IF WS-0010-TBL-ID-NUM(WS-0010-SBI-INT-INDEX) > 0
               INITIALIZE WS-7555-INPUT-KEY
               MOVE WS-2335-RATE-STATE TO WS-7555-INPUT-STATE-CD
               MOVE WS-2335-CROP-YEAR TO WS-7555-INPUT-CROP-YR
               MOVE WS-2335-RATE-COUNTY TO WS-7555-INPUT-COUNTY-CD
               MOVE WS-2335-CROP-CD TO WS-7555-INPUT-CROP-CD
               move ws-2335-ins-plan-cd
                   to ws-7555-input-insurance-plan
               MOVE WS-2335-TYPE-CD TO WS-7555-INPUT-TYPE-CD
               MOVE WS-2335-PRACTICE-CD TO WS-7555-INPUT-PRACTICE-CD
               MOVE WS-0010-TBL-ID-NUM(WS-0010-SBI-INT-INDEX)
                   TO WS-7555-INPUT-ID-NUM
               PERFORM 7555-LOOKUP-ADMSSN
                   THRU 7555-LOOKUP-ADMSSN-EXIT

               IF MATCH-FOUND-7555
      $IF DEBUG-SW DEFINED
                  DISPLAY 'NCS RECORD FOUND, RAW RATE= ' ws-7555-rate
                  UPON CONSOLE
      $END
                  if ws-7555-rate > ws-2335-ncs-rate
                     move ws-7555-rate   to ws-2335-ncs-rate
                     MOVE WS-LITERAL-YES TO WS-2335-NCS-RATE-FOUND-FLAG
                  end-if
               end-if
             end-if
           end-if.

       2335-PROCESS-SBI-TBL-EXIT.

