      *****************************************************************
      * File:      IF2340.CBL
      * Author:    Laura Dittamo
      * Date:      10/18/95
      * Purpose:   This routine validates the Yield/Quota against the
      *            Rate Class.
      *
      * INSURANCE PLAN OR CROP            REQUIRED EDIT
      *
      *
      * Dollar Amt Ins (Ins Plan Cd=50)   Yield Must equal zeros
      *
      * Florida Fruit Trees               Yield Must equal zeros
      * (Ins Plan Cd=40)
      *
      * Group Crops (Ins Plan Cd=12)      Yield Must equal zeros
      *
      * Hybrid Sorghum (Ins Plan = 55)    Yield must be greater than zero
      * or Corn Seed
      *
      * Peanuts (Ins Plan = 10)           Must equal adjusted Maximum
      *                                   Guaranteed Coverage
      *                                   if Quota = zero
      *
      * Guarantee Tobacco(Ins Plan Cd=30) Must equal adjusted Maximum
      *                                   Guaranteed Coverage
      *
      * Quota Tobacco (Ins Plan Cd=70)    Yield must equal zero
      *
      * All other APH crops               Yield must be greater than zero
      * (Also CRC/IP/RA)                  Input Yield should match approved
      *                                   APH Yield from Type 15
      *                                   This check is not done in
      *                                   this module.
      *****************************************************************

       2340-VAL-YIELD-W-RATE-CLS.

      $IF DEBUG-SW DEFINED
           DISPLAY '2340-VALIDATE YIELD AGAINST RATE CLASS'
           UPON CONSOLE
      $END

      *****************************************************
      *    INITIALIZE LOCAL & OUTPUT WORKING STORAGE      *
      *****************************************************

           INITIALIZE WS-2340-WORK

      *****************************************************
      *         CHECK PRE-CONDITIONS                      *
      *****************************************************

           IF ERROR-CROP-CD = WS-LITERAL-YES OR
              ERROR-INSUR-PLAN-CD = WS-LITERAL-YES OR
              ERROR-RATE-COUNTY = WS-LITERAL-YES OR
              ERROR-RATE-STATE = WS-LITERAL-YES OR
              ERROR-CROP-YR = WS-LITERAL-YES OR
              ERROR-CROP-TYPE = WS-LITERAL-YES OR
              ERROR-PRACTICE-CD = WS-LITERAL-YES OR
              ERROR-RATE-CLASS = WS-LITERAL-YES OR
              ERROR-ID-NO = WS-LITERAL-YES OR
              ERROR-ID-TYPE = WS-LITERAL-YES OR
              ERROR-CVG-LVL-PCT = WS-LITERAL-YES OR
              ERROR-YLD-QUOTA = WS-LITERAL-YES OR
              ERROR-OPT-CD = WS-LITERAL-YES
              MOVE WS-LITERAL-YES TO ERROR-YLD-QUOTA
              GO TO 2340-VAL-YIELD-W-RATE-CLS-EXIT
           END-IF

      *****************************************************
      *             SETUP DISPLAY FIELDS                  *
      *****************************************************
           MOVE WS-2340-YIELD TO WS-2340-YIELD-X

      $IF DEBUG-SW DEFINED
           DISPLAY 'INPUT YIELD = ', WS-2340-YIELD-X
           UPON CONSOLE
      $END

      *****************************************************
      *             BEGIN VALIDATION                      *
      *****************************************************

           IF WS-2340-INS-PLAN-CD = WS-LITERAL-DOLLAR-AMT OR
              WS-2340-INS-PLAN-CD = WS-LITERAL-FLORIDA-FRUIT OR
              WS-2340-INS-PLAN-CD = WS-LITERAL-ARC or
              WS-2340-INS-PLAN-CD = WS-LITERAL-GRP
              IF WS-2340-YIELD = ZEROS
                 CONTINUE
              ELSE
                 MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                 MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
                 MOVE 022 TO WS-8000-SHORT-ERROR
                 MOVE WS-LITERAL-YES TO ERROR-YLD-QUOTA
                 MOVE WS-LITERAL-YLD-QUOTA TO WS-8000-FIELD-NAME1
                 MOVE WS-2340-YIELD-X TO WS-8000-BAD-DATA1
                 MOVE '0' TO WS-8000-CORR-DATA1
                 MOVE 2340 TO WS-8000-PARAGRAPH-NO
                 PERFORM 8000-RECORD-TRAN-ERROR
                    THRU 8000-RECORD-TRAN-ERROR-EXIT
                 GO TO 2340-VAL-YIELD-W-RATE-CLS-EXIT
              END-IF
           ELSE
      **      YIELD MUST BE GREATER THAN ZERO
              IF WS-2340-YIELD = ZEROS
                 MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                 MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
                 MOVE 005 TO WS-8000-SHORT-ERROR
                 MOVE WS-LITERAL-YES TO ERROR-YLD-QUOTA
                 MOVE WS-LITERAL-YLD-QUOTA TO WS-8000-FIELD-NAME1
                 MOVE WS-2340-YIELD-X TO WS-8000-BAD-DATA1
                 MOVE '> 0.0' TO WS-8000-CORR-DATA1
                 MOVE 2340 TO WS-8000-PARAGRAPH-NO
                 PERFORM 8000-RECORD-TRAN-ERROR
                    THRU 8000-RECORD-TRAN-ERROR-EXIT
                 GO TO 2340-VAL-YIELD-W-RATE-CLS-EXIT
              END-IF
           END-IF

      **************************************************
      *  IF THE CROP IS NOT GUARANTEED TOBACCO OR
      *  NON-QUOTA PEANUTS NO FURTHER VALIDATION IS NECESSARY.
      **************************************************
           IF (WS-2340-INS-PLAN-CD = WS-LITERAL-PEANUTS-PLAN AND
              NON-QUOTA-PEANUTS-0009) OR
              WS-2340-INS-PLAN-CD = WS-LITERAL-GUARANTEE-TOBACCO
              CONTINUE
           ELSE
              GO TO 2340-VAL-YIELD-W-RATE-CLS-EXIT
           END-IF


      *****************************************************
      *       LOOKUP YIELDS & VALIDATE                    *
      *****************************************************

           IF WS-2340-TYPE-CD IS EQUAL SPACES
              MOVE '997' TO WS-2340-TYPE-CD
           END-IF

      $IF ISAM-SW DEFINED

      * ADM LOOKUP FOR PEANUTS AND GUARANTEED TOBACCO
      * CHECK WHETHER THIS PRODUCER HAS AN NCS YIELD FACTOR
      * APPLY THIS FACTOR TO THE MAX GUARANTEE COVERAGE FROM ADM1
           PERFORM 2340-LOOKUP-NCS-YIELD
              THRU 2340-LOOKUP-NCS-YIELD-EXIT
      * LOOKUP YIELD DATA IN ADM1
      * YIELD, DOLLAR AMOUNT, GUARANTEE AND RATE DATA
           PERFORM 2340-LOOKUP-ADM1-YIELD
              THRU 2340-LOOKUP-ADM1-YIELD-EXIT


           IF ERROR-YLD-QUOTA = WS-LITERAL-YES
              GO TO 2340-VAL-YIELD-W-RATE-CLS-EXIT
           END-IF

      ****************************************************************
      * THE YIELD FOR GUARANTEED TOBACCO AND PEANUTS MUST EQUAL      *
      * THE MAXIMUM GUARANTEE COVERAGE * THE COVERAGE LEVEL PERCENT. *                              *
      ****************************************************************
           IF WS-2340-YIELD NOT = WS-2340-ADJUSTED-MAX-GUAR-CVG
              MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 025 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-YES TO ERROR-YLD-QUOTA
              MOVE WS-LITERAL-YLD-QUOTA TO WS-8000-FIELD-NAME1
              MOVE WS-2340-YIELD-X TO WS-8000-BAD-DATA1
              MOVE WS-2340-ADJ-MAX-GUAR-CVG-X
                TO WS-8000-CORR-DATA1
              MOVE 'YLD-DOL AMT-GUAR-RT' TO WS-8000-TABLE-NAME
              MOVE 2340 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF.
      $END


       2340-VAL-YIELD-W-RATE-CLS-EXIT.
           EXIT.



      $IF ISAM-SW DEFINED

       2340-LOOKUP-NCS-YIELD.

      *    IF WS-2340-ID-TYPE <> WS-LITERAL-SSN
           IF WS-2340-ID-NUM = ZEROS
              MOVE 1 TO WS-2340-NCS-YIELD-FACTOR
              GO TO 2340-LOOKUP-NCS-YIELD-EXIT
           END-IF

           INITIALIZE WS-7555-INPUT-KEY
           MOVE WS-2340-ID-NUM TO WS-7555-INPUT-ID-NUM
           MOVE WS-2340-CROP-YEAR TO WS-7555-INPUT-CROP-YR
           MOVE WS-2340-RATE-STATE TO WS-7555-INPUT-STATE-CD
           MOVE WS-2340-RATE-COUNTY TO WS-7555-INPUT-COUNTY-CD
           MOVE WS-2340-CROP-CD TO WS-7555-INPUT-CROP-CD
           MOVE WS-2340-INS-PLAN-CD TO WS-7555-INPUT-INSURANCE-PLAN
           MOVE WS-2340-TYPE-CD TO WS-7555-INPUT-TYPE-CD
           MOVE WS-2340-PRACTICE-CD TO WS-7555-INPUT-PRACTICE-CD
           MOVE WS-2340-OPTION-CD TO WS-7555-INPUT-OPTION-CD

           PERFORM 7555-LOOKUP-ADMSSN
              THRU 7555-LOOKUP-ADMSSN-EXIT

           IF MATCH-FOUND-7555
              IF WS-7555-RECORD-TYPE-SFX = 5
                 MOVE WS-7555-YIELD-FACTOR
                   TO WS-2340-NCS-YIELD-FACTOR
              ELSE
                 MOVE 1 TO WS-2340-NCS-YIELD-FACTOR
              END-IF
           ELSE
              MOVE 1 TO WS-2340-NCS-YIELD-FACTOR
           END-IF

           MOVE WS-2340-NCS-YIELD-FACTOR
             TO WS-2340-NCS-YIELD-FACTOR-X.

      $IF DEBUG-SW DEFINED
           DISPLAY 'NCS YIELD FACTOR = ', WS-2340-NCS-YIELD-FACTOR-X
           UPON CONSOLE.
      $END

       2340-LOOKUP-NCS-YIELD-EXIT.
           EXIT.


       2340-LOOKUP-ADM1-YIELD.

           INITIALIZE WS-7505-INPUT-KEY
      *    *** LOOKUP WILL DETERMINE CORRECT SUFFIX
           MOVE WS-2340-CROP-YEAR TO WS-7505-INPUT-CROP-YR
           MOVE WS-2340-RATE-STATE TO WS-7505-INPUT-STATE-CD
           MOVE WS-2340-RATE-COUNTY TO WS-7505-INPUT-COUNTY-CD
           MOVE WS-2340-CROP-CD TO WS-7505-INPUT-CROP-CD
           MOVE WS-2340-INS-PLAN-CD TO WS-7505-INPUT-INSURANCE-PLAN
           MOVE WS-2340-PRACTICE-CD TO WS-7505-INPUT-PRACTICE-CD
           MOVE WS-2340-TYPE-CD TO WS-7505-INPUT-TYPE-CD
           MOVE WS-2340-RATE-CLASS TO WS-7505-INPUT-RATE-CLASS
      *    *** SET UP ERROR STRING IN CASE ADM1 NOT FOUND
           STRING 'SEARCHED WITH = '
               DELIMITED BY SIZE
               WS-7505-INPUT-KEY
               DELIMITED BY SIZE
               INTO WS-8000-CORR-DATA1
           END-STRING

           PERFORM 7505-LOOKUP-ADM1
              THRU 7505-LOOKUP-ADM1-EXIT

           IF MATCH-FOUND-7505
      *       *** CLEAR THE ERROR SET ABOVE
              MOVE SPACES TO WS-8000-CORR-DATA1

              MOVE WS-7505-MAX-GUARANTEED-CVG
                TO WS-2340-MAX-GUARANTEED-CVG
              MOVE WS-2340-MAX-GUARANTEED-CVG
                TO WS-2340-MAX-GUARANTEED-CVG-X


              COMPUTE WS-2340-ADJUSTED-MAX-GUAR-CVG ROUNDED =
                 WS-2340-NCS-YIELD-FACTOR * WS-2340-MAX-GUARANTEED-CVG
              ON SIZE ERROR
                 MOVE 2340 TO WS-8020-PARAGRAPH-NO
                 MOVE 90017 TO WS-8020-INT-ERROR-NO
                 MOVE 'WS-2340-ADJUSTED-MAX-GUAR-CVG'
                   TO WS-8020-FIELD-NAME
                 MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                 PERFORM 8020-RECORD-INT-ERROR
                    THRU 8020-RECORD-INT-ERROR-EXIT
              END-COMPUTE
              MOVE WS-2340-ADJUSTED-MAX-GUAR-CVG
                TO WS-2340-ADJ-MAX-GUAR-CVG-X

      $IF DEBUG-SW DEFINED
           DISPLAY 'ADM MAX COVERAGE = ',
           WS-2340-MAX-GUARANTEED-CVG-X UPON CONSOLE
           DISPLAY 'NCS YIELD FACTOR = ', WS-2340-NCS-YIELD-FACTOR-X
           UPON CONSOLE
           DISPLAY 'ADJUSTED MAX CVG = ',
           WS-2340-ADJ-MAX-GUAR-CVG-X UPON CONSOLE
      $END
           ELSE
      **      NO MAX GUARANTEED COVERAGE FOUND;
      **      MARK YIELD INVALID
              MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 009 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-YES TO ERROR-YLD-QUOTA
              MOVE WS-LITERAL-YLD-QUOTA TO WS-8000-FIELD-NAME1
              MOVE WS-2340-YIELD-X TO WS-8000-BAD-DATA1
              MOVE 'ADM1 REC' TO WS-8000-FIELD-NAME1
              MOVE 'NOT FOUND' TO WS-8000-BAD-DATA1
      *       *** SEARCH KEY USED IS IN CORR-DATA1
              MOVE 'ADM1' TO WS-8000-TABLE-NAME
              MOVE 2340 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF.


       2340-LOOKUP-ADM1-YIELD-EXIT.
           EXIT.

      $END


