      *****************************************************************
      * File:      IF2342.CBL
      * Author:    Laura Dittamo
      * Date:      03/15/96
      * Purpose:   This routine looks up the Min and Max Yield
      *            Quantities for APH (which includes normal APH,
      *            APH Rice, and APH Prevented Planting), IP and CRC.
      *            These values are stored for later use by the inter-
      *            record modules.
      *****************************************************************

       2342-LOOKUP-YIELD-QTY.

      $IF DEBUG-SW DEFINED
           DISPLAY '2342-LOOKING UP YIELD QUANTITY'
           UPON CONSOLE
      $END

      **********************************************
      *     INITIALIZE LOCAL & OUTPUT WS           *
      **********************************************

           INITIALIZE WS-2342-WORK
           INITIALIZE WS-2342-OUTPUT

      **********************************************
      *            CHECK PRE-CONDITIONS            *
      **********************************************

           IF ERROR-CROP-CD = WS-LITERAL-YES OR
              ERROR-INSUR-PLAN-CD = WS-LITERAL-YES OR
              ERROR-RATE-COUNTY = WS-LITERAL-YES OR
              ERROR-RATE-STATE = WS-LITERAL-YES OR
              ERROR-CROP-YR = WS-LITERAL-YES OR
              ERROR-CROP-TYPE = WS-LITERAL-YES OR
              ERROR-PRACTICE-CD = WS-LITERAL-YES OR
              ERROR-RATE-CLASS = WS-LITERAL-YES OR
              ERROR-ID-TYPE = WS-LITERAL-YES OR
              ERROR-NCS-FCIC-2-FL = WS-LITERAL-YES OR
              ERROR-ID-NO = WS-LITERAL-YES OR
              ERROR-OPT-CD = WS-LITERAL-YES
              GO TO 2342-LOOKUP-YIELD-QTY-EXIT
           END-IF

      **********************************************
      *            NORMAL PROCESSING               *
      **********************************************


           EVALUATE WS-2342-INS-PLAN-CD
              WHEN WS-LITERAL-IP
      *          ** NO ADM1 RECS FOR IP SO NO EDIT.
                 GO TO 2342-LOOKUP-YIELD-QTY-EXIT
              WHEN WS-LITERAL-CRC
                 CONTINUE
              WHEN WS-LITERAL-APH-AREA-SPAN
                 CONTINUE
              WHEN WS-LITERAL-APH-AREA-PLAN
                 CONTINUE
              WHEN WS-LITERAL-APH
                 CONTINUE
              WHEN OTHER
                 GO TO 2342-LOOKUP-YIELD-QTY-EXIT
            END-EVALUATE

      **********************************************
      *              LOOKUP YIELDS                 *
      **********************************************
           PERFORM 2342-LOOKUP-YIELDS
              THRU 2342-LOOKUP-YIELDS-EXIT.

       2342-LOOKUP-YIELD-QTY-EXIT.
           EXIT.


      $IF ISAM-SW DEFINED

       2342-LOOKUP-YIELDS.

           IF WS-2342-TYPE-CD = SPACES OR
              WS-2342-TYPE-CD = ZEROS
              MOVE '997' TO WS-2342-TYPE-CD
           END-IF

      *    LOOKUP NCS YIELD FACTOR IN ADMSSN
           PERFORM 2342-LOOKUP-NCS-YIELD
              THRU 2342-LOOKUP-NCS-YIELD-EXIT
      *    LOOKUP YIELD DATA IN ADM1
      *    YIELD, DOLLAR AMOUNT, GUARANTEE AND RATE DATA
           PERFORM 2342-LOOKUP-ADM1-YIELD
              THRU 2342-LOOKUP-ADM1-YIELD-EXIT

           IF MATCH-FOUND-7505
              COMPUTE WS-2342-LOW-YLD-QTY ROUNDED =
                   (WS-2342-NCS-YIELD-FACTOR * WS-7505-LOW-YIELD)
                 ON SIZE ERROR
                    MOVE 2342 TO WS-8020-PARAGRAPH-NO
                    MOVE 90017 TO WS-8020-INT-ERROR-NO
                    MOVE 'WS-2342-LOW-YLD-QTY'
                      TO WS-8020-FIELD-NAME
                    COMPUTE WS-2342-INTEGER-ERROR =
                       WS-2342-LOW-YLD-QTY * 100
                    END-COMPUTE
                    MOVE WS-2342-INTEGER-ERROR
                      TO WS-8020-BAD-DATA
                    MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                    PERFORM 8020-RECORD-INT-ERROR
                       THRU 8020-RECORD-INT-ERROR-EXIT
              END-COMPUTE

              COMPUTE WS-2342-HIGH-YLD-QTY ROUNDED =
                   (WS-2342-NCS-YIELD-FACTOR * WS-7505-HIGH-YIELD)
                 ON SIZE ERROR
                    MOVE 2342 TO WS-8020-PARAGRAPH-NO
                    MOVE 90017 TO WS-8020-INT-ERROR-NO
                    MOVE 'WS-2342-HIGH-YLD-QTY'
                      TO WS-8020-FIELD-NAME
                    COMPUTE WS-2342-INTEGER-ERROR =
                       WS-2342-HIGH-YLD-QTY * 100
                    END-COMPUTE
                    MOVE WS-2342-INTEGER-ERROR
                      TO WS-8020-BAD-DATA
                    MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                    PERFORM 8020-RECORD-INT-ERROR
                       THRU 8020-RECORD-INT-ERROR-EXIT
              END-COMPUTE

              MOVE WS-LITERAL-YES TO WS-2342-UPDATE-MADE

           END-IF.


       2342-LOOKUP-YIELDS-EXIT.
           EXIT.


       2342-LOOKUP-NCS-YIELD.
      *    *** Default to 1.00 if applicable an NCS rate will override
           MOVE 1 TO WS-2342-NCS-YIELD-FACTOR

      *    IF WS-2342-ID-TYPE <> WS-LITERAL-SSN
           IF WS-2342-ID-NUM = ZEROS
              move 1 to WS-2560-NCS-YIELD-FACTOR
              GO TO 2342-LOOKUP-NCS-YIELD-EXIT
           END-IF

           INITIALIZE WS-7555-INPUT-KEY
           MOVE WS-2342-ID-NUM TO WS-7555-INPUT-ID-NUM
           MOVE WS-2342-CROP-YEAR TO WS-7555-INPUT-CROP-YR
           MOVE WS-2342-RATE-STATE TO WS-7555-INPUT-STATE-CD
           MOVE WS-2342-RATE-COUNTY TO WS-7555-INPUT-COUNTY-CD
           MOVE WS-2342-CROP-CD TO WS-7555-INPUT-CROP-CD
           MOVE WS-2342-INS-PLAN-CD TO WS-7555-INPUT-INSURANCE-PLAN
           MOVE WS-2342-TYPE-CD TO WS-7555-INPUT-TYPE-CD
           MOVE WS-2342-PRACTICE-CD TO WS-7555-INPUT-PRACTICE-CD
           MOVE WS-2342-OPTION-CD TO WS-7555-INPUT-OPTION-CD
           PERFORM 7555-LOOKUP-ADMSSN
              THRU 7555-LOOKUP-ADMSSN-EXIT

           IF MATCH-FOUND-7555
              IF WS-7555-RECORD-TYPE-SFX = 5
                 MOVE WS-7555-YIELD-FACTOR TO WS-2342-NCS-YIELD-FACTOR
              END-IF
           END-IF.

       2342-LOOKUP-NCS-YIELD-EXIT.
           EXIT.


       2342-LOOKUP-ADM1-YIELD.
           INITIALIZE WS-7505-INPUT-KEY
      *    *** LOOKUP WILL DETERMINE CORRECT SUFFIX
           MOVE WS-2342-CROP-YEAR TO WS-7505-INPUT-CROP-YR
           MOVE WS-2342-RATE-STATE TO WS-7505-INPUT-STATE-CD
           MOVE WS-2342-RATE-COUNTY TO WS-7505-INPUT-COUNTY-CD
           MOVE WS-2342-CROP-CD TO WS-7505-INPUT-CROP-CD
           MOVE WS-2342-INS-PLAN-CD TO WS-7505-INPUT-INSURANCE-PLAN
           MOVE WS-2342-PRACTICE-CD TO WS-7505-INPUT-PRACTICE-CD
           MOVE WS-2342-TYPE-CD TO WS-7505-INPUT-TYPE-CD
           MOVE WS-2342-RATE-CLASS TO WS-7505-INPUT-RATE-CLASS

           PERFORM 7505-LOOKUP-ADM1
              THRU 7505-LOOKUP-ADM1-EXIT

           IF MATCH-FOUND-7505
              MOVE SPACES TO WS-8000-CORR-DATA1
           ELSE
      **      NO MIN/MAX YIELD QUANTITIES FOUND;
      **      INVALID RATE CLASS
              MOVE WS-LITERAL-IF  TO WS-8000-ERROR-TYPE
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 009 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-YES TO ERROR-RATE-CLASS
              MOVE 'ADM1 REC' TO WS-8000-FIELD-NAME1
              MOVE 'NOT FOUND' TO WS-8000-BAD-DATA1
              STRING 'SEARCHED WITH = '
               DELIMITED BY SIZE
               WS-7505-INPUT-KEY
               DELIMITED BY SIZE
               INTO WS-8000-CORR-DATA1
              END-STRING
              MOVE 'ADM1' TO WS-8000-TABLE-NAME
              MOVE 2342 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF.


       2342-LOOKUP-ADM1-YIELD-EXIT.
           EXIT.

      $END



