
      ***************************************************************
      * File:      IF2350.CBL
      * Author:    Mike Ray
      * Date:      12/13/95
      * Purpose:   Validates the input premium against the premium
      *            calculation in M-13.
      ***************************************************************

       2350-VAL-PREMIUM.

      $IF DEBUG-SW DEFINED
           DISPLAY '2350-VALIDATING PREMIUM'
           UPON CONSOLE
      $END


      *****************************************************
      *    INITIALIZE LOCAL VARIABLES                     *
      *****************************************************
           INITIALIZE WS-2350-OUTPUT
           INITIALIZE WS-2350-LOCAL

      *****************************************************
      *    SET UP DISPLAY FIELDS                          *
      *****************************************************

      *****************************************************
      *    CHECK PRECONDITIONS                            *
      *****************************************************
           IF ERROR-TOT-PREM = WS-LITERAL-YES OR
              ERROR-LIAB = WS-LITERAL-YES OR
              ERROR-TOTAL-GUARANTEE = WS-LITERAL-YES OR
              ERROR-INSUR-PLAN-CD = WS-LITERAL-YES OR
              ERROR-PREM-RT-SURCHG = WS-LITERAL-YES OR
              ERROR-CROP-CD = WS-LITERAL-YES OR
              ERROR-RO = WS-LITERAL-YES OR
              ERROR-CVG-FL = WS-LITERAL-YES
              MOVE WS-LITERAL-YES TO ERROR-TOT-PREM
              GO TO 2350-VAL-PREMIUM-EXIT
           END-IF

      *****************************************************
      *            CHECK INPUT FIELDS                     *
      *****************************************************
           IF WS-2350-RATE-MAP-AREA-FCTR = ZEROS
              MOVE WS-LITERAL-YES TO ERROR-TOT-PREM
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE 'WS-2350-MAP-FACTOR' TO WS-8000-FIELD-NAME1
              MOVE ZERO TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 2350 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-2350-TYPE-PRACT-OPT-FCTR = ZEROS
              MOVE WS-LITERAL-YES TO ERROR-TOT-PREM
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE 'WS-2350-TYPE-PRACT-FCTR' TO WS-8000-FIELD-NAME1
              MOVE ZERO TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 2350 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-2350-OPTION-FCTR = ZEROS
              MOVE WS-LITERAL-YES TO ERROR-TOT-PREM
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE 'WS-2350-OPT-FACTOR' TO WS-8000-FIELD-NAME1
              MOVE ZERO TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 2350 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
          END-IF

           IF WS-2350-EXPERIENCE-FCTR = ZEROS
              MOVE WS-LITERAL-YES TO ERROR-TOT-PREM
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE 'WS-2350-EXPER-FACTOR' TO WS-8000-FIELD-NAME1
              MOVE ZERO TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 2350 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF ERROR-TOT-PREM = WS-LITERAL-YES
              GO TO 2350-VAL-PREMIUM-EXIT
           END-IF


      *****************************************************
      *       DETERMINE PREMIUM SURCHARGE FACTOR          *
      *****************************************************
           EVALUATE WS-2350-PREM-RATE-SURCHARGE
               WHEN 'Y'
                  MOVE 0.05 TO WS-2350-PREM-SURCHARGE-PCT
               WHEN 'G'
                  MOVE 0.05 TO WS-2350-PREM-SURCHARGE-PCT
               WHEN 'P'
                 if ws-2350-crop-cd = ws-literal-peppers
                  move 0.30 to ws-2350-prem-surcharge-pct
                 else
                  MOVE 0.05 TO WS-2350-PREM-SURCHARGE-PCT
                 end-if
               WHEN SPACES
                  MOVE 0.00 TO WS-2350-PREM-SURCHARGE-PCT
               WHEN OTHER
                  MOVE WS-LITERAL-YES TO ERROR-TOT-PREM
                  MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
                  MOVE 044 TO WS-8000-SHORT-ERROR
                  MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
                  MOVE 'WS-2350-PREM-RT-SRCHG-FLG'
                    TO WS-8000-FIELD-NAME1
                  MOVE WS-2350-PREM-RATE-SURCHARGE
                    TO WS-8000-BAD-DATA1
                  MOVE 'NO LOGIC FOR THIS VALUE'
                    TO WS-8000-CORR-DATA1
                  MOVE 2350 TO WS-8000-PARAGRAPH-NO
                  PERFORM 8000-RECORD-TRAN-ERROR
                     THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-EVALUATE

      $IF DEBUG-SW DEFINED
           MOVE WS-2350-PREM-SURCHARGE-PCT
             TO WS-2350-PREM-SURCHARGE-PCT-X
           DISPLAY 'PREMIUM SURCHARGE % = ',
           WS-2350-PREM-SURCHARGE-PCT-X UPON CONSOLE
      $END

      *************************************************************
      *    DETERMINE WHICH FORMULA TO USE AND CALCULATE PREMIUM   *
      *************************************************************

      *    *** TREAT ALL APH PLANS AS PLAIN APH
      *    *** TREAT ALL YLD BASED $ PLANS AS PLAIN YLDDLR
           EVALUATE WS-2350-INS-PLAN
               WHEN WS-LITERAL-APH-AREA-PLAN
                  MOVE WS-LITERAL-APH TO WS-2350-INS-PLAN
               WHEN WS-LITERAL-APH-AREA-SPAN
                  MOVE WS-LITERAL-APH TO WS-2350-INS-PLAN
               WHEN OTHER
                  CONTINUE
           END-EVALUATE


           EVALUATE WS-2350-INS-PLAN
               WHEN WS-LITERAL-APH
                  IF ERROR-BASE-PREM-RT = WS-LITERAL-YES
                     OR ERROR-MAP-AREA = WS-LITERAL-YES
                     OR ERROR-TYPE-PRACTICE-OPT-CD = WS-LITERAL-YES
                     OR ERROR-OPT-CD = WS-LITERAL-YES
                     OR ERROR-UNIT-OPT-CD = WS-LITERAL-YES
                     OR ERROR-EXPER-FCTR = WS-LITERAL-YES
                     MOVE WS-LITERAL-YES TO ERROR-TOT-PREM
                     GO TO 2350-VAL-PREMIUM-EXIT
                  END-IF
                  INITIALIZE WS-4405-INPUT
                  MOVE WS-2350-PREMIUM-LIABILITY
                    TO WS-4405-PREMIUM-LIABILITY
                  MOVE WS-2350-BASE-PREMIUM-RATE
                    TO WS-4405-BASE-PREMIUM-RATE
                  MOVE WS-2350-RATE-MAP-AREA-FCTR
                    TO WS-4405-RATE-MAP-AREA-FCTR
                  MOVE WS-2350-TYPE-PRACT-OPT-FCTR
                    TO WS-4405-TYPE-PRACT-OPT-FCTR
                  MOVE WS-2350-OPTION-FCTR
                    TO WS-4405-OPTION-FCTR
                  MOVE WS-2350-EXPERIENCE-FCTR
                    TO WS-4405-EXPERIENCE-FCTR
                  MOVE WS-2350-PREM-SURCHARGE-PCT
                    TO WS-4405-PREM-SURCHARGE-PCT
                  MOVE WS-2350-NCS-FCIC-2-FL 
                    TO ws-4405-ncs-fcic-2-fl
                  move ws-2350-alt-premium-liability
                    to ws-4405-alt-premium-liability
                  PERFORM 4405-CALC-APH-PREMIUM
                     THRU 4405-CALC-APH-PREMIUM-EXIT
                  IF CALC-ERROR-4405
                     MOVE WS-LITERAL-YES TO ERROR-TOT-PREM
                     GO TO 2350-VAL-PREMIUM-EXIT
                  END-IF
                  MOVE WS-4405-TOTAL-PREMIUM
                    TO WS-2350-TOTAL-PREMIUM
                  MOVE WS-4405-alt-TOTAL-PREMIUM
                    TO WS-2350-alt-TOTAL-PREMIUM
                  IF CAT-COVERAGE
                     INITIALIZE WS-4405-INPUT
                     move ws-2350-alt-premium-liability
                       to ws-4405-alt-premium-liability
                     MOVE WS-2350-CAT-65-100-LIABILITY
                       TO WS-4405-PREMIUM-LIABILITY
                     MOVE WS-2350-CAT-65-PCT-BASE-RATE
                       TO WS-4405-BASE-PREMIUM-RATE
                     MOVE WS-2350-RATE-MAP-AREA-FCTR
                       TO WS-4405-RATE-MAP-AREA-FCTR
                     MOVE WS-2350-TYPE-PRACT-OPT-FCTR
                       TO WS-4405-TYPE-PRACT-OPT-FCTR
                     MOVE WS-2350-OPTION-FCTR
                       TO WS-4405-OPTION-FCTR
                     MOVE WS-2350-EXPERIENCE-FCTR
                       TO WS-4405-EXPERIENCE-FCTR
                     MOVE WS-2350-PREM-SURCHARGE-PCT
                       TO WS-4405-PREM-SURCHARGE-PCT
                     PERFORM 4405-CALC-APH-PREMIUM
                        THRU 4405-CALC-APH-PREMIUM-EXIT
                     IF CALC-ERROR-4405
                        MOVE WS-LITERAL-YES TO ERROR-TOT-PREM
                        GO TO 2350-VAL-PREMIUM-EXIT
                     END-IF
                     MOVE WS-4405-TOTAL-PREMIUM
                       TO WS-2350-CAT-65-100-PREMIUM
                  END-IF


               WHEN WS-LITERAL-PEANUTS-PLAN
                  IF ERROR-BASE-PREM-RT = WS-LITERAL-YES
                     OR ERROR-MAP-AREA = WS-LITERAL-YES
                     OR ERROR-TYPE-PRACTICE-OPT-CD = WS-LITERAL-YES
                     OR ERROR-OPT-CD = WS-LITERAL-YES
                     OR ERROR-UNIT-OPT-CD = WS-LITERAL-YES
                     OR ERROR-EXPER-FCTR = WS-LITERAL-YES
                     MOVE WS-LITERAL-YES TO ERROR-TOT-PREM
                     GO TO 2350-VAL-PREMIUM-EXIT
                  END-IF
                  INITIALIZE WS-4410-INPUT
                  MOVE WS-2350-PREMIUM-LIABILITY
                    TO WS-4410-PREMIUM-LIABILITY
                  MOVE WS-2350-BASE-PREMIUM-RATE
                    TO WS-4410-BASE-PREMIUM-RATE
                  MOVE WS-2350-RATE-MAP-AREA-FCTR
                    TO WS-4410-RATE-MAP-AREA-FCTR
                  MOVE WS-2350-TYPE-PRACT-OPT-FCTR
                    TO WS-4410-TYPE-PRACT-OPT-FCTR
                  MOVE WS-2350-OPTION-FCTR
                    TO WS-4410-OPTION-FCTR
                  MOVE WS-2350-EXPERIENCE-FCTR
                    TO WS-4410-EXPERIENCE-FCTR
                  MOVE WS-2350-PREM-SURCHARGE-PCT
                    TO WS-4410-PREM-SURCHARGE-PCT
                  PERFORM 4410-CALC-QUOTA-PNUT-PREM
                     THRU 4410-CALC-QUOTA-PNUT-PREM-EXIT
                  IF CALC-ERROR-4410
                     MOVE WS-LITERAL-YES TO ERROR-TOT-PREM
                     GO TO 2350-VAL-PREMIUM-EXIT
                  END-IF
                  MOVE WS-4410-TOTAL-PREMIUM
                    TO WS-2350-TOTAL-PREMIUM
                  IF CAT-COVERAGE
                     INITIALIZE WS-4410-INPUT
                     MOVE WS-2350-CAT-65-100-LIABILITY
                       TO WS-4410-PREMIUM-LIABILITY
                     MOVE WS-2350-CAT-65-PCT-BASE-RATE
                       TO WS-4410-BASE-PREMIUM-RATE
                     MOVE WS-2350-RATE-MAP-AREA-FCTR
                       TO WS-4410-RATE-MAP-AREA-FCTR
                     MOVE WS-2350-TYPE-PRACT-OPT-FCTR
                       TO WS-4410-TYPE-PRACT-OPT-FCTR
                     MOVE WS-2350-OPTION-FCTR
                       TO WS-4410-OPTION-FCTR
                     MOVE WS-2350-EXPERIENCE-FCTR
                       TO WS-4410-EXPERIENCE-FCTR
                     MOVE WS-2350-PREM-SURCHARGE-PCT
                       TO WS-4410-PREM-SURCHARGE-PCT
                     PERFORM 4410-CALC-QUOTA-PNUT-PREM
                        THRU 4410-CALC-QUOTA-PNUT-PREM-EXIT
                     IF CALC-ERROR-4410
                        MOVE WS-LITERAL-YES TO ERROR-TOT-PREM
                        GO TO 2350-VAL-PREMIUM-EXIT
                     END-IF
                     MOVE WS-4410-TOTAL-PREMIUM
                       TO WS-2350-CAT-65-100-PREMIUM
                  END-IF


               WHEN WS-LITERAL-FLORIDA-FRUIT
                  IF ERROR-BASE-PREM-RT = WS-LITERAL-YES
                     MOVE WS-LITERAL-YES TO ERROR-TOT-PREM
                     GO TO 2350-VAL-PREMIUM-EXIT
                  END-IF
                  INITIALIZE WS-4450-INPUT
                  MOVE WS-2350-TOTAL-LIABILITY
                    TO WS-4450-TOTAL-LIABILITY
                  MOVE WS-2350-BASE-PREMIUM-RATE
                    TO WS-4450-BASE-PREMIUM-RATE
                  MOVE WS-2350-PREM-SURCHARGE-PCT
                    TO WS-4450-PREM-SURCHARGE-PCT
                  PERFORM 4450-CALC-FL-FRUIT-PREM
                     THRU 4450-CALC-FL-FRUIT-PREM-EXIT
                  IF CALC-ERROR-4450
                     MOVE WS-LITERAL-YES TO ERROR-TOT-PREM
                     GO TO 2350-VAL-PREMIUM-EXIT
                  END-IF
                  MOVE WS-4450-TOTAL-PREMIUM
                    TO WS-2350-TOTAL-PREMIUM
                  IF CAT-COVERAGE
                     INITIALIZE WS-4450-INPUT
                     MOVE WS-2350-CAT-65-100-LIABILITY
                       TO WS-4450-TOTAL-LIABILITY
                     MOVE WS-2350-CAT-65-PCT-BASE-RATE
                       TO WS-4450-BASE-PREMIUM-RATE
                     MOVE WS-2350-PREM-SURCHARGE-PCT
                       TO WS-4450-PREM-SURCHARGE-PCT
                     PERFORM 4450-CALC-FL-FRUIT-PREM
                        THRU 4450-CALC-FL-FRUIT-PREM-EXIT
                     IF CALC-ERROR-4450
                        MOVE WS-LITERAL-YES TO ERROR-TOT-PREM
                        GO TO 2350-VAL-PREMIUM-EXIT
                     END-IF
                     MOVE WS-4450-TOTAL-PREMIUM
                       TO WS-2350-CAT-65-100-PREMIUM
                  END-IF


               WHEN WS-LITERAL-DOLLAR-AMT
                  IF WS-2350-CROP-CD = WS-LITERAL-CITRUS-TREES      OR
                      WS-2350-CROP-CD = WS-LITERAL-CITRUS-TREES-I   OR
                      WS-2350-CROP-CD = WS-LITERAL-CITRUS-TREES-II  OR
                      WS-2350-CROP-CD = WS-LITERAL-CITRUS-TREES-III OR
                      WS-2350-CROP-CD = WS-LITERAL-CITRUS-TREES-IV  OR
                      WS-2350-CROP-CD = WS-LITERAL-CITRUS-TREES-V   OR
                      WS-2350-CROP-CD = WS-LITERAL-MAC-TREES
                     IF ERROR-BASE-PREM-RT = WS-LITERAL-YES
                        OR ERROR-MAP-AREA = WS-LITERAL-YES
                        OR ERROR-OPT-CD = WS-LITERAL-YES
                        OR ERROR-UNIT-OPT-CD = WS-LITERAL-YES
                        OR ERROR-EXPER-FCTR = WS-LITERAL-YES
                        MOVE WS-LITERAL-YES TO ERROR-TOT-PREM
                        GO TO 2350-VAL-PREMIUM-EXIT
                     END-IF
                     INITIALIZE WS-4420-INPUT
                     MOVE WS-2350-PREMIUM-LIABILITY
                       TO WS-4420-PREMIUM-LIABILITY
                     MOVE WS-2350-BASE-PREMIUM-RATE
                       TO WS-4420-BASE-PREMIUM-RATE
                     MOVE WS-2350-RATE-MAP-AREA-FCTR
                       TO WS-4420-RATE-MAP-AREA-FCTR
                     MOVE WS-2350-OPTION-FCTR
                       TO WS-4420-OPTION-FCTR
                     MOVE WS-2350-EXPERIENCE-FCTR
                       TO WS-4420-EXPERIENCE-FCTR
                     MOVE WS-2350-PREM-SURCHARGE-PCT
                       TO WS-4420-PREM-SURCHARGE-PCT
                     PERFORM 4420-CALC-CITMAC-PREM
                        THRU 4420-CALC-CITMAC-PREM-EXIT
                     IF CALC-ERROR-4420
                        MOVE WS-LITERAL-YES TO ERROR-TOT-PREM
                        GO TO 2350-VAL-PREMIUM-EXIT
                     END-IF
                     MOVE WS-4420-TOTAL-PREMIUM
                       TO WS-2350-TOTAL-PREMIUM
                     IF CAT-COVERAGE
                        INITIALIZE WS-4420-INPUT
                        MOVE WS-2350-CAT-65-100-LIABILITY
                          TO WS-4420-PREMIUM-LIABILITY
                        MOVE WS-2350-CAT-65-PCT-BASE-RATE
                          TO WS-4420-BASE-PREMIUM-RATE
                        MOVE WS-2350-RATE-MAP-AREA-FCTR
                          TO WS-4420-RATE-MAP-AREA-FCTR
                        MOVE WS-2350-OPTION-FCTR
                          TO WS-4420-OPTION-FCTR
                        MOVE WS-2350-EXPERIENCE-FCTR
                          TO WS-4420-EXPERIENCE-FCTR
                        MOVE WS-2350-PREM-SURCHARGE-PCT
                          TO WS-4420-PREM-SURCHARGE-PCT
                        PERFORM 4420-CALC-CITMAC-PREM
                           THRU 4420-CALC-CITMAC-PREM-EXIT
                        IF CALC-ERROR-4420
                           MOVE WS-LITERAL-YES TO ERROR-TOT-PREM
                           GO TO 2350-VAL-PREMIUM-EXIT
                        END-IF
                        MOVE WS-4420-TOTAL-PREMIUM
                          TO WS-2350-CAT-65-100-PREMIUM
                     END-IF
                  ELSE
                     IF ERROR-BASE-PREM-RT = WS-LITERAL-YES
                        OR ERROR-MAP-AREA = WS-LITERAL-YES
                        OR ERROR-TYPE-PRACTICE-OPT-CD = WS-LITERAL-YES
                        OR ERROR-OPT-CD = WS-LITERAL-YES
                        OR ERROR-UNIT-OPT-CD = WS-LITERAL-YES
                        OR ERROR-EXPER-FCTR = WS-LITERAL-YES
                        MOVE WS-LITERAL-YES TO ERROR-TOT-PREM
                        GO TO 2350-VAL-PREMIUM-EXIT
                     END-IF
                     INITIALIZE WS-4415-INPUT
                     MOVE WS-2350-PREMIUM-LIABILITY
                       TO WS-4415-PREMIUM-LIABILITY
                     MOVE WS-2350-BASE-PREMIUM-RATE
                       TO WS-4415-BASE-PREMIUM-RATE
                     MOVE WS-2350-RATE-MAP-AREA-FCTR
                       TO WS-4415-RATE-MAP-AREA-FCTR
                     MOVE WS-2350-TYPE-PRACT-OPT-FCTR
                       TO WS-4415-TYPE-PRACT-OPT-FCTR
                     MOVE WS-2350-OPTION-FCTR
                       TO WS-4415-OPTION-FCTR
                     MOVE WS-2350-EXPERIENCE-FCTR
                       TO WS-4415-EXPERIENCE-FCTR
                     MOVE WS-2350-PREM-SURCHARGE-PCT
                       TO WS-4415-PREM-SURCHARGE-PCT
                     PERFORM 4415-CALC-DOLLAR-PREM
                        THRU 4415-CALC-DOLLAR-PREM-EXIT
                     IF CALC-ERROR-4415
                        MOVE WS-LITERAL-YES TO ERROR-TOT-PREM
                        GO TO 2350-VAL-PREMIUM-EXIT
                     END-IF
                     MOVE WS-4415-TOTAL-PREMIUM
                       TO WS-2350-TOTAL-PREMIUM
                     IF CAT-COVERAGE
                        INITIALIZE WS-4415-INPUT
                        MOVE WS-2350-CAT-65-100-LIABILITY
                          TO WS-4415-PREMIUM-LIABILITY
                        MOVE WS-2350-CAT-65-PCT-BASE-RATE
                          TO WS-4415-BASE-PREMIUM-RATE
                        MOVE WS-2350-RATE-MAP-AREA-FCTR
                          TO WS-4415-RATE-MAP-AREA-FCTR
                        MOVE WS-2350-TYPE-PRACT-OPT-FCTR
                          TO WS-4415-TYPE-PRACT-OPT-FCTR
                        MOVE WS-2350-OPTION-FCTR
                          TO WS-4415-OPTION-FCTR
                        MOVE WS-2350-EXPERIENCE-FCTR
                          TO WS-4415-EXPERIENCE-FCTR
                        MOVE WS-2350-PREM-SURCHARGE-PCT
                          TO WS-4415-PREM-SURCHARGE-PCT
                        PERFORM 4415-CALC-DOLLAR-PREM
                           THRU 4415-CALC-DOLLAR-PREM-EXIT
                        IF CALC-ERROR-4415
                           MOVE WS-LITERAL-YES TO ERROR-TOT-PREM
                           GO TO 2350-VAL-PREMIUM-EXIT
                        END-IF
                        MOVE WS-4415-TOTAL-PREMIUM
                          TO WS-2350-CAT-65-100-PREMIUM
                     END-IF
                  END-IF


               WHEN WS-LITERAL-YLD-BASED-DOL-AMT
                  IF ERROR-BASE-PREM-RT = WS-LITERAL-YES
                     OR ERROR-MAP-AREA = WS-LITERAL-YES
                     OR ERROR-TYPE-PRACTICE-OPT-CD = WS-LITERAL-YES
                     OR ERROR-OPT-CD = WS-LITERAL-YES
                     OR ERROR-UNIT-OPT-CD = WS-LITERAL-YES
                     OR ERROR-EXPER-FCTR = WS-LITERAL-YES
                     MOVE WS-LITERAL-YES TO ERROR-TOT-PREM
                     GO TO 2350-VAL-PREMIUM-EXIT
                  END-IF
                  INITIALIZE WS-4425-INPUT
                  move WS-2350-alt-PREMIUM-liability
                    to ws-4425-alt-premium-liability
                  MOVE WS-2350-PREMIUM-LIABILITY
                    TO WS-4425-PREMIUM-LIABILITY
                  MOVE WS-2350-BASE-PREMIUM-RATE
                    TO WS-4425-BASE-PREMIUM-RATE
                  MOVE WS-2350-RATE-MAP-AREA-FCTR
                    TO WS-4425-RATE-MAP-AREA-FCTR
                  MOVE WS-2350-TYPE-PRACT-OPT-FCTR
                    TO WS-4425-TYPE-PRACT-OPT-FCTR
                  MOVE WS-2350-OPTION-FCTR
                    TO WS-4425-OPTION-FCTR
                  MOVE WS-2350-EXPERIENCE-FCTR
                    TO WS-4425-EXPERIENCE-FCTR
                  MOVE WS-2350-PREM-SURCHARGE-PCT
                    TO WS-4425-PREM-SURCHARGE-PCT
                  PERFORM 4425-CALC-YLDDLR-PREM
                     THRU 4425-CALC-YLDDLR-PREM-EXIT
                  IF CALC-ERROR-4425
                     MOVE WS-LITERAL-YES TO ERROR-TOT-PREM
                     GO TO 2350-VAL-PREMIUM-EXIT
                  END-IF
                  MOVE WS-4425-TOTAL-PREMIUM
                    TO WS-2350-TOTAL-PREMIUM
                  MOVE WS-4425-ALT-TOTAL-PREMIUM
                    TO WS-2350-ALT-TOTAL-PREMIUM
                  IF CAT-COVERAGE
                     INITIALIZE WS-4425-INPUT
                     move WS-2350-alt-PREMIUM-liability
                       to ws-4425-alt-premium-liability
                     MOVE WS-2350-CAT-65-100-LIABILITY
                       TO WS-4425-PREMIUM-LIABILITY
                     MOVE WS-2350-CAT-65-PCT-BASE-RATE
                       TO WS-4425-BASE-PREMIUM-RATE
                     MOVE WS-2350-RATE-MAP-AREA-FCTR
                       TO WS-4425-RATE-MAP-AREA-FCTR
                     MOVE WS-2350-TYPE-PRACT-OPT-FCTR
                       TO WS-4425-TYPE-PRACT-OPT-FCTR
                     MOVE WS-2350-OPTION-FCTR
                       TO WS-4425-OPTION-FCTR
                     MOVE WS-2350-EXPERIENCE-FCTR
                       TO WS-4425-EXPERIENCE-FCTR
                     MOVE WS-2350-PREM-SURCHARGE-PCT
                       TO WS-4425-PREM-SURCHARGE-PCT
                     PERFORM 4425-CALC-YLDDLR-PREM
                        THRU 4425-CALC-YLDDLR-PREM-EXIT
                     IF CALC-ERROR-4425
                        MOVE WS-LITERAL-YES TO ERROR-TOT-PREM
                        GO TO 2350-VAL-PREMIUM-EXIT
                     END-IF
                     MOVE WS-4425-TOTAL-PREMIUM
                       TO WS-2350-CAT-65-100-PREMIUM
                  END-IF

               WHEN WS-LITERAL-ARC
                  IF ERROR-BASE-PREM-RT = WS-LITERAL-YES OR
                     ERROR-OPT-CD = WS-LITERAL-YES
                     MOVE WS-LITERAL-YES TO ERROR-TOT-PREM
                     GO TO 2350-VAL-PREMIUM-EXIT
                  END-IF
                  INITIALIZE WS-4465-INPUT
                  MOVE WS-2350-TOTAL-LIABILITY
                    TO WS-4465-TOTAL-LIABILITY
                  MOVE WS-2350-BASE-PREMIUM-RATE
                    TO WS-4465-BASE-PREMIUM-RATE
                  MOVE WS-2350-OPTION-FCTR
                    TO WS-4465-OPTION-FCTR
                  PERFORM 4465-CALC-AVOCADO-PREM
                     THRU 4465-CALC-AVOCADO-PREM-EXIT
                  IF CALC-ERROR-4465
                     MOVE WS-LITERAL-YES TO ERROR-TOT-PREM
                     GO TO 2350-VAL-PREMIUM-EXIT
                  END-IF
                  MOVE WS-4465-TOTAL-PREMIUM
                    TO WS-2350-TOTAL-PREMIUM
                  IF CAT-COVERAGE
                     INITIALIZE WS-4465-INPUT
                     MOVE WS-2350-CAT-65-100-LIABILITY
                       TO WS-4465-TOTAL-LIABILITY
                     MOVE WS-2350-CAT-65-PCT-BASE-RATE
                       TO WS-4465-BASE-PREMIUM-RATE
                     MOVE WS-2350-OPTION-FCTR
                       TO WS-4465-OPTION-FCTR
                     PERFORM 4465-CALC-AVOCADO-PREM
                        THRU 4465-CALC-AVOCADO-PREM-EXIT
                     IF CALC-ERROR-4465
                        MOVE WS-LITERAL-YES TO ERROR-TOT-PREM
                        GO TO 2350-VAL-PREMIUM-EXIT
                     END-IF
                     MOVE WS-4465-TOTAL-PREMIUM
                       TO WS-2350-CAT-65-100-PREMIUM
                  END-IF


               WHEN WS-LITERAL-QUOTA-TOBACCO
                  IF ERROR-BASE-PREM-RT = WS-LITERAL-YES
                     OR ERROR-MAP-AREA = WS-LITERAL-YES
                     OR ERROR-TYPE-PRACTICE-OPT-CD = WS-LITERAL-YES
                     OR ERROR-OPT-CD = WS-LITERAL-YES
                     OR ERROR-UNIT-OPT-CD = WS-LITERAL-YES
                     OR ERROR-EXPER-FCTR = WS-LITERAL-YES
                     MOVE WS-LITERAL-YES TO ERROR-TOT-PREM
                     GO TO 2350-VAL-PREMIUM-EXIT
                  END-IF
                  INITIALIZE WS-4440-INPUT
                  MOVE WS-2350-PREMIUM-LIABILITY
                    TO WS-4440-PREMIUM-LIABILITY
                  MOVE WS-2350-BASE-PREMIUM-RATE
                    TO WS-4440-BASE-PREMIUM-RATE
                  MOVE WS-2350-RATE-MAP-AREA-FCTR
                    TO WS-4440-RATE-MAP-AREA-FCTR
                  MOVE WS-2350-TYPE-PRACT-OPT-FCTR
                    TO WS-4440-TYPE-PRACT-OPT-FCTR
                  MOVE WS-2350-OPTION-FCTR
                    TO WS-4440-OPTION-FCTR
                  MOVE WS-2350-EXPERIENCE-FCTR
                    TO WS-4440-EXPERIENCE-FCTR
                  MOVE WS-2350-PREM-SURCHARGE-PCT
                    TO WS-4440-PREM-SURCHARGE-PCT
                  PERFORM 4440-CALC-QTOBACCO-PREM
                     THRU 4440-CALC-QTOBACCO-PREM-EXIT
                  IF CALC-ERROR-4440
                     MOVE WS-LITERAL-YES TO ERROR-TOT-PREM
                     GO TO 2350-VAL-PREMIUM-EXIT
                  END-IF
                  MOVE WS-4440-TOTAL-PREMIUM
                    TO WS-2350-TOTAL-PREMIUM
                  IF CAT-COVERAGE
                     INITIALIZE WS-4440-INPUT
                     MOVE WS-2350-CAT-65-100-LIABILITY
                       TO WS-4440-PREMIUM-LIABILITY
                     MOVE WS-2350-CAT-65-PCT-BASE-RATE
                       TO WS-4440-BASE-PREMIUM-RATE
                     MOVE WS-2350-RATE-MAP-AREA-FCTR
                       TO WS-4440-RATE-MAP-AREA-FCTR
                     MOVE WS-2350-TYPE-PRACT-OPT-FCTR
                       TO WS-4440-TYPE-PRACT-OPT-FCTR
                     MOVE WS-2350-OPTION-FCTR
                       TO WS-4440-OPTION-FCTR
                     MOVE WS-2350-EXPERIENCE-FCTR
                       TO WS-4440-EXPERIENCE-FCTR
                     MOVE WS-2350-PREM-SURCHARGE-PCT
                       TO WS-4440-PREM-SURCHARGE-PCT
                     PERFORM 4440-CALC-QTOBACCO-PREM
                        THRU 4440-CALC-QTOBACCO-PREM-EXIT
                     IF CALC-ERROR-4440
                        MOVE WS-LITERAL-YES TO ERROR-TOT-PREM
                        GO TO 2350-VAL-PREMIUM-EXIT
                     END-IF
                     MOVE WS-4440-TOTAL-PREMIUM
                       TO WS-2350-CAT-65-100-PREMIUM
                  END-IF

               WHEN WS-LITERAL-GUARANTEE-TOBACCO
                  IF ERROR-BASE-PREM-RT = WS-LITERAL-YES
                     OR ERROR-MAP-AREA = WS-LITERAL-YES
                     OR ERROR-TYPE-PRACTICE-OPT-CD = WS-LITERAL-YES
                     OR ERROR-OPT-CD = WS-LITERAL-YES
                     OR ERROR-UNIT-OPT-CD = WS-LITERAL-YES
                     OR ERROR-EXPER-FCTR = WS-LITERAL-YES
                     MOVE WS-LITERAL-YES TO ERROR-TOT-PREM
                     GO TO 2350-VAL-PREMIUM-EXIT
                  END-IF
                  INITIALIZE WS-4435-INPUT
                  MOVE WS-2350-PREMIUM-LIABILITY
                    TO WS-4435-PREMIUM-LIABILITY
                  MOVE WS-2350-BASE-PREMIUM-RATE
                    TO WS-4435-BASE-PREMIUM-RATE
                  MOVE WS-2350-RATE-MAP-AREA-FCTR
                    TO WS-4435-RATE-MAP-AREA-FCTR
                  MOVE WS-2350-TYPE-PRACT-OPT-FCTR
                    TO WS-4435-TYPE-PRACT-OPT-FCTR
                  MOVE WS-2350-OPTION-FCTR
                    TO WS-4435-OPTION-FCTR
                  MOVE WS-2350-EXPERIENCE-FCTR
                    TO WS-4435-EXPERIENCE-FCTR
                  MOVE WS-2350-PREM-SURCHARGE-PCT
                    TO WS-4435-PREM-SURCHARGE-PCT
                  PERFORM 4435-CALC-GTOBACCO-PREM
                     THRU 4435-CALC-GTOBACCO-PREM-EXIT
                  IF CALC-ERROR-4435
                     MOVE WS-LITERAL-YES TO ERROR-TOT-PREM
                     GO TO 2350-VAL-PREMIUM-EXIT
                  END-IF
                  MOVE WS-4435-TOTAL-PREMIUM
                    TO WS-2350-TOTAL-PREMIUM
                  IF CAT-COVERAGE
                     INITIALIZE WS-4435-INPUT
                     MOVE WS-2350-CAT-65-100-LIABILITY
                       TO WS-4435-PREMIUM-LIABILITY
                     MOVE WS-2350-CAT-65-PCT-BASE-RATE
                       TO WS-4435-BASE-PREMIUM-RATE
                     MOVE WS-2350-RATE-MAP-AREA-FCTR
                       TO WS-4435-RATE-MAP-AREA-FCTR
                     MOVE WS-2350-TYPE-PRACT-OPT-FCTR
                       TO WS-4435-TYPE-PRACT-OPT-FCTR
                     MOVE WS-2350-OPTION-FCTR
                       TO WS-4435-OPTION-FCTR
                     MOVE WS-2350-EXPERIENCE-FCTR
                       TO WS-4435-EXPERIENCE-FCTR
                     MOVE WS-2350-PREM-SURCHARGE-PCT
                       TO WS-4435-PREM-SURCHARGE-PCT
                     PERFORM 4435-CALC-GTOBACCO-PREM
                        THRU 4435-CALC-GTOBACCO-PREM-EXIT
                     IF CALC-ERROR-4435
                        MOVE WS-LITERAL-YES TO ERROR-TOT-PREM
                        GO TO 2350-VAL-PREMIUM-EXIT
                     END-IF
                     MOVE WS-4435-TOTAL-PREMIUM
                       TO WS-2350-CAT-65-100-PREMIUM
                  END-IF


               WHEN WS-LITERAL-GRP
                  IF ERROR-BASE-PREM-RT = WS-LITERAL-YES
                     OR ERROR-MAP-AREA = WS-LITERAL-YES
                     OR ERROR-TYPE-PRACTICE-OPT-CD = WS-LITERAL-YES
                     OR ERROR-OPT-CD = WS-LITERAL-YES
                     OR ERROR-UNIT-OPT-CD = WS-LITERAL-YES
                     OR ERROR-EXPER-FCTR = WS-LITERAL-YES
                     OR ERROR-CROP-YR = WS-LITERAL-YES
                     OR ERROR-RATE-STATE = WS-LITERAL-YES
                     OR ERROR-RATE-COUNTY = WS-LITERAL-YES
                     OR ERROR-CROP-TYPE = WS-LITERAL-YES
                     OR ERROR-PRACTICE-CD = WS-LITERAL-YES
                     OR ERROR-CVG-LVL-PCT = WS-LITERAL-YES

                     MOVE WS-LITERAL-YES TO ERROR-TOT-PREM
                     GO TO 2350-VAL-PREMIUM-EXIT
                  END-IF
                  INITIALIZE WS-4430-INPUT
                  MOVE WS-2350-PREMIUM-LIABILITY
                    TO WS-4430-PREMIUM-LIABILITY
                  MOVE WS-2350-BASE-PREMIUM-RATE
                    TO WS-4430-BASE-PREMIUM-RATE
                  MOVE WS-2350-RATE-MAP-AREA-FCTR
                    TO WS-4430-RATE-MAP-AREA-FCTR
                  MOVE WS-2350-TYPE-PRACT-OPT-FCTR
                    TO WS-4430-TYPE-PRACT-OPT-FCTR
                  MOVE WS-2350-OPTION-FCTR
                    TO WS-4430-OPTION-FCTR
                  MOVE WS-2350-EXPERIENCE-FCTR
                    TO WS-4430-EXPERIENCE-FCTR
                  MOVE WS-2350-PREM-SURCHARGE-PCT
                    TO WS-4430-PREM-SURCHARGE-PCT
                  MOVE WS-2350-CROP-YEAR TO WS-4430-CROP-YEAR
                  MOVE WS-2350-RATE-STATE TO WS-4430-RATE-STATE
                  MOVE WS-2350-RATE-COUNTY TO WS-4430-RATE-COUNTY
                  MOVE WS-2350-INS-PLAN TO WS-4430-INS-PLAN
                  MOVE WS-2350-CROP-CD TO WS-4430-CROP-CD
                  MOVE WS-2350-INS-PLAN TO WS-4430-INS-PLAN
                  MOVE WS-2350-PRACTICE-CD TO WS-4430-PRACTICE-CD
                  MOVE WS-2350-TYPE-CD TO WS-4430-TYPE-CD
                  MOVE WS-2350-CVG-LVL-PCT TO WS-4430-CVG-LVL-PCT
                  PERFORM 4430-CALC-GRP-PREMIUM
                     THRU 4430-CALC-GRP-PREMIUM-EXIT
                  IF CALC-ERROR-4430
                     MOVE WS-LITERAL-YES TO ERROR-TOT-PREM
                     GO TO 2350-VAL-PREMIUM-EXIT
                  END-IF
                  MOVE WS-4430-TOTAL-PREMIUM
                    TO WS-2350-TOTAL-PREMIUM
                  IF CAT-COVERAGE
                     INITIALIZE WS-4430-INPUT
                     MOVE WS-2350-CAT-65-100-LIABILITY
                       TO WS-4430-PREMIUM-LIABILITY
                     MOVE WS-2350-CAT-65-PCT-BASE-RATE
                       TO WS-4430-BASE-PREMIUM-RATE
                     MOVE WS-2350-RATE-MAP-AREA-FCTR
                       TO WS-4430-RATE-MAP-AREA-FCTR
                     MOVE WS-2350-TYPE-PRACT-OPT-FCTR
                       TO WS-4430-TYPE-PRACT-OPT-FCTR
                     MOVE WS-2350-OPTION-FCTR
                       TO WS-4430-OPTION-FCTR
                     MOVE WS-2350-EXPERIENCE-FCTR
                       TO WS-4430-EXPERIENCE-FCTR
                     MOVE WS-2350-PREM-SURCHARGE-PCT
                       TO WS-4430-PREM-SURCHARGE-PCT
                     MOVE WS-2350-CROP-YEAR TO WS-4430-CROP-YEAR
                     MOVE WS-2350-RATE-STATE TO WS-4430-RATE-STATE
                     MOVE WS-2350-RATE-COUNTY TO WS-4430-RATE-COUNTY
                     MOVE WS-2350-INS-PLAN TO WS-4430-INS-PLAN
                     MOVE WS-2350-CROP-CD TO WS-4430-CROP-CD
                     MOVE WS-2350-INS-PLAN TO WS-4430-INS-PLAN
                     MOVE WS-2350-PRACTICE-CD TO WS-4430-PRACTICE-CD
                     MOVE WS-2350-TYPE-CD TO WS-4430-TYPE-CD
                     MOVE 65 TO WS-4430-CVG-LVL-PCT
                     PERFORM 4430-CALC-GRP-PREMIUM
                        THRU 4430-CALC-GRP-PREMIUM-EXIT
                     IF CALC-ERROR-4430
                        MOVE WS-LITERAL-YES TO ERROR-TOT-PREM
                        GO TO 2350-VAL-PREMIUM-EXIT
                     END-IF
                     MOVE WS-4430-TOTAL-PREMIUM
                       TO WS-2350-CAT-65-100-PREMIUM
                  END-IF

               WHEN WS-LITERAL-CRC
                  IF ERROR-BASE-PREM-RT = WS-LITERAL-YES
                     OR ERROR-CROP-YR = WS-LITERAL-YES
                     OR ERROR-MAP-AREA = WS-LITERAL-YES
                     OR ERROR-TYPE-PRACTICE-OPT-CD = WS-LITERAL-YES
                     OR ERROR-OPT-CD = WS-LITERAL-YES
                     OR ERROR-UNIT-OPT-CD = WS-LITERAL-YES
                     OR ERROR-EXPER-FCTR = WS-LITERAL-YES
                     OR ERROR-PRICE-ELECTION = WS-LITERAL-YES
                     OR ERROR-REPORTED-ACRES = WS-LITERAL-YES
                     OR ERROR-INSURED-SHARE = WS-LITERAL-YES
                     OR ERROR-RATE-CLASS = WS-LITERAL-YES
                     OR ERROR-RATE-STATE = WS-LITERAL-YES
                     OR ERROR-RATE-COUNTY = WS-LITERAL-YES
                     OR ERROR-CROP-TYPE = WS-LITERAL-YES
                     OR ERROR-PRACTICE-CD = WS-LITERAL-YES
                     OR ERROR-CVG-LVL-PCT = WS-LITERAL-YES
                     OR ERROR-GUARANTEE-PER-ACRE = WS-LITERAL-YES
                     OR ERROR-CROP-YR = WS-LITERAL-YES

                     MOVE WS-LITERAL-YES TO ERROR-TOT-PREM
                     GO TO 2350-VAL-PREMIUM-EXIT
                  END-IF

      *           **********************************************
      *           *           LOOKUP CRC FACTORS               *
      *           **********************************************
                  PERFORM 2350-LOOKUP-CRC-FACTORS
                     THRU 2350-LOOKUP-CRC-FACTORS-EXIT
                  IF WS-2350-CRC-RATE-FACTOR = ZEROS
                     MOVE WS-LITERAL-YES TO ERROR-TOT-PREM
                     GO TO 2350-VAL-PREMIUM-EXIT
                  END-IF

      *           **********************************************
      *           *           CALCULATE CRC PREMIUM            *
      *           **********************************************
                  INITIALIZE WS-4445-INPUT
                  MOVE WS-2350-PREMIUM-GPA
                    TO WS-4445-PREMIUM-GPA
                  MOVE WS-2350-BASE-PREMIUM-RATE
                    TO WS-4445-BASE-PREMIUM-RATE
                  MOVE WS-2350-LOW-PRICE-FACTOR
                    TO WS-4445-LOW-PRICE-FCTR
                  MOVE WS-2350-HIGH-PRICE-FACTOR
                    TO WS-4445-HIGH-PRICE-FCTR
                  MOVE WS-2350-CRC-RATE-FACTOR
                    TO WS-4445-CRC-RATE-FACTOR
                  MOVE WS-2350-BASE-PRICE
                    TO WS-4445-BASE-PRICE
                  MOVE WS-2350-ACRES TO WS-4445-ACRES
                  MOVE WS-2350-INSURED-SHARE
                    TO WS-4445-INSURED-SHARE
                  MOVE WS-2350-RATE-MAP-AREA-FCTR
                    TO WS-4445-RATE-MAP-AREA-FCTR
                  MOVE WS-2350-TYPE-PRACT-OPT-FCTR
                    TO WS-4445-TYPE-PRACT-OPT-FCTR
                  MOVE WS-2350-OPTION-FCTR
                    TO WS-4445-OPTION-FCTR
                  MOVE WS-2350-EXPERIENCE-FCTR
                    TO WS-4445-EXPERIENCE-FCTR
                  MOVE WS-2350-PREM-SURCHARGE-PCT
                    TO WS-4445-PREM-SURCHARGE-PCT
                  PERFORM 4445-CALC-CRC-PREMIUM
                     THRU 4445-CALC-CRC-PREMIUM-EXIT
                  IF CALC-ERROR-4445
                     MOVE WS-LITERAL-YES TO ERROR-TOT-PREM
                     GO TO 2350-VAL-PREMIUM-EXIT
                  END-IF
                  MOVE WS-4445-TOTAL-PREMIUM
                    TO WS-2350-TOTAL-PREMIUM

      *           **********************************************
      *           *           CALCULATE APH PREMIUM            *
      *           *        - USED TO DETERMINE SUBSIDY -       *
      *           **********************************************

                  PERFORM 2350-LOOKUP-APH-RATE
                     THRU 2350-LOOKUP-APH-RATE-EXIT
                  IF WS-2350-CRC-APH-RATE = ZEROS
                     MOVE WS-LITERAL-YES TO ERROR-TOT-PREM
                     GO TO 2350-VAL-PREMIUM-EXIT
                  END-IF

                  INITIALIZE WS-4405-INPUT
                  MOVE WS-2300-CRC-APH-LIABILITY
                    TO WS-4405-PREMIUM-LIABILITY
                  MOVE WS-2350-CRC-APH-RATE
                    TO WS-4405-BASE-PREMIUM-RATE
                  MOVE WS-2350-RATE-MAP-AREA-FCTR
                    TO WS-4405-RATE-MAP-AREA-FCTR
                  MOVE WS-2350-TYPE-PRACT-OPT-FCTR
                    TO WS-4405-TYPE-PRACT-OPT-FCTR
                  MOVE WS-2350-OPTION-FCTR
                    TO WS-4405-OPTION-FCTR
                  MOVE WS-2350-EXPERIENCE-FCTR
                    TO WS-4405-EXPERIENCE-FCTR
                  MOVE WS-2350-PREM-SURCHARGE-PCT
                    TO WS-4405-PREM-SURCHARGE-PCT
                  PERFORM 4405-CALC-APH-PREMIUM
                     THRU 4405-CALC-APH-PREMIUM-EXIT
                  IF CALC-ERROR-4405
                     MOVE WS-LITERAL-YES TO ERROR-TOT-PREM
                     GO TO 2350-VAL-PREMIUM-EXIT
                  END-IF
                  MOVE WS-4405-TOTAL-PREMIUM
                    TO WS-2350-CRC-APH-PREMIUM

               WHEN WS-LITERAL-IP
                  IF ERROR-BASE-PREM-RT = WS-LITERAL-YES
                     MOVE WS-LITERAL-YES TO ERROR-TOT-PREM
                     GO TO 2350-VAL-PREMIUM-EXIT
                  END-IF
                  INITIALIZE WS-4470-INPUT
                  MOVE WS-2350-TOTAL-LIABILITY
                    TO WS-4470-TOTAL-LIABILITY
                  MOVE WS-2350-BASE-PREMIUM-RATE
                    TO WS-4470-BASE-PREMIUM-RATE
                  MOVE WS-2350-PREM-SURCHARGE-PCT
                    TO WS-4470-PREM-SURCHARGE-PCT
                  PERFORM 4470-CALC-IP-PREMIUM
                     THRU 4470-CALC-IP-PREMIUM-EXIT
                  IF CALC-ERROR-4470
                     MOVE WS-LITERAL-YES TO ERROR-TOT-PREM
                     GO TO 2350-VAL-PREMIUM-EXIT
                  END-IF
                  MOVE WS-4470-TOTAL-PREMIUM
                    TO WS-2350-TOTAL-PREMIUM


               WHEN WS-LITERAL-RA
                  IF ERROR-BASE-PREM-RT = WS-LITERAL-YES OR
                     ERROR-UNIT-OPT-CD = WS-LITERAL-YES OR
                     ERROR-REPORTED-ACRES = WS-LITERAL-YES OR
                     ERROR-INSURED-SHARE = WS-LITERAL-YES OR
                     ERROR-UNIT-PREM-ADJ-FACTOR = WS-LITERAL-YES OR
                     ERROR-WHOLE-FARM-DISCOUNT-FCTR = WS-LITERAL-YES
                     MOVE WS-LITERAL-YES TO ERROR-TOT-PREM
                     GO TO 2350-VAL-PREMIUM-EXIT
                  END-IF
                  INITIALIZE WS-4455-INPUT
                  MOVE WS-2350-BASE-PREMIUM-RATE
                    TO WS-4455-BASE-PREMIUM-RATE
                  MOVE WS-2350-ACRES TO WS-4455-ACRES
                  MOVE WS-2350-INSURED-SHARE
                    TO WS-4455-INSURED-SHARE
                  MOVE WS-2350-UNIT-PREM-ADJ-FCTR
                    TO WS-4455-UNIT-PREM-ADJ-FCTR
                  MOVE WS-2350-WFARM-DISCOUNT-FCTR
                    TO WS-4455-WFARM-DISCOUNT-FCTR
                  PERFORM 4455-CALC-RA-PREMIUM
                     THRU 4455-CALC-RA-PREMIUM-EXIT
                  IF CALC-ERROR-4455
                     MOVE WS-LITERAL-YES TO ERROR-TOT-PREM
                     GO TO 2350-VAL-PREMIUM-EXIT
                  END-IF
                  MOVE WS-4455-TOTAL-PREMIUM
                    TO WS-2350-TOTAL-PREMIUM

      *           **********************************************
      *           *           CALCULATE APH PREMIUM            *
      *           *        - USED TO DETERMINE SUBSIDY -       *
      *           **********************************************
                  move ws-literal-aph to ws-2350-ins-plan
                  move 'R05' to WS-2350-RATE-CLASS 
                  PERFORM 2350-LOOKUP-APH-RATE
                     THRU 2350-LOOKUP-APH-RATE-EXIT
                  IF WS-2350-CRC-APH-RATE = ZEROS
                     MOVE WS-LITERAL-YES TO ERROR-TOT-PREM
                     GO TO 2350-VAL-PREMIUM-EXIT
                  END-IF
                  INITIALIZE WS-4405-INPUT
                  MOVE WS-2300-CRC-APH-LIABILITY
                    TO WS-4405-PREMIUM-LIABILITY
                  MOVE WS-2350-CRC-APH-RATE
                    TO WS-4405-BASE-PREMIUM-RATE
                  MOVE WS-2350-RATE-MAP-AREA-FCTR
                    TO WS-4405-RATE-MAP-AREA-FCTR
                  MOVE WS-2350-TYPE-PRACT-OPT-FCTR
                    TO WS-4405-TYPE-PRACT-OPT-FCTR
                  MOVE WS-2350-OPTION-FCTR
                    TO WS-4405-OPTION-FCTR
                  MOVE WS-2350-EXPERIENCE-FCTR
                    TO WS-4405-EXPERIENCE-FCTR
                  MOVE WS-2350-PREM-SURCHARGE-PCT
                    TO WS-4405-PREM-SURCHARGE-PCT
                  PERFORM 4405-CALC-APH-PREMIUM
                     THRU 4405-CALC-APH-PREMIUM-EXIT
                  IF CALC-ERROR-4405
                     MOVE WS-LITERAL-YES TO ERROR-TOT-PREM
                     GO TO 2350-VAL-PREMIUM-EXIT
                  END-IF
                  MOVE WS-4405-TOTAL-PREMIUM
                    TO WS-2350-CRC-APH-PREMIUM

               WHEN OTHER
                  MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
                  MOVE 042 TO WS-8000-SHORT-ERROR
                  MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                  MOVE WS-LITERAL-YES TO ERROR-TOT-PREM
                  MOVE WS-LITERAL-INSURE-PLAN-CD
                    TO WS-8000-FIELD-NAME1
                  MOVE WS-2350-INS-PLAN TO WS-8000-BAD-DATA1
                  MOVE 'VALID INS PLAN' TO WS-8000-CORR-DATA1
                  MOVE 2350 TO WS-8000-PARAGRAPH-NO
                  PERFORM 8000-RECORD-TRAN-ERROR
                     THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-EVALUATE.

           IF ERROR-TOT-PREM = WS-LITERAL-YES
              GO TO 2350-VAL-PREMIUM-EXIT
           END-IF


      $IF DEBUG-SW DEFINED
           DISPLAY 'INPUT PREMIUM = ', WS-2350-INPUT-TOTAL-PREMIUM
           UPON CONSOLE
           DISPLAY 'CALC  PREMIUM = ', WS-2350-TOTAL-PREMIUM
           UPON CONSOLE
           IF CAT-COVERAGE
              DISPLAY 'CAT 65/100 PREMIUM = ',
              WS-2350-CAT-65-100-PREMIUM UPON CONSOLE
           END-IF
      $END

      *****************************************************
      *    SPECIAL CASE FOR PREMIUM RATE SURCHARGE = 'P'  *
      *****************************************************
           IF WS-2350-PREM-RATE-SURCHARGE = 'P'
              IF (WS-2350-INPUT-TOTAL-PREMIUM >
                 (WS-2350-PREMIUM-X-30-PCT - 3))  AND
                 (WS-2350-INPUT-TOTAL-PREMIUM <
                 (WS-2350-PREMIUM-X-30-PCT + 3))
                 MOVE WS-2350-PREMIUM-X-30-PCT
                   TO WS-2350-TOTAL-PREMIUM
                 GO TO 2350-VAL-PREMIUM-EXIT
              END-IF

      *       *** TRY PREMIUM WITH 50% SURCHARGE ***
              COMPUTE WS-2350-PREMIUM-X-50-PCT ROUNDED =
                 (WS-2350-TOTAL-PREMIUM / 1.3 * 1.50)
                 ON SIZE ERROR
                    MOVE 2350 TO WS-8020-PARAGRAPH-NO
                    MOVE 90017 TO WS-8020-INT-ERROR-NO
                    MOVE 'PREMIUM * SURCHARGE'
                      TO WS-8020-FIELD-NAME
                    MOVE WS-2350-PREMIUM-X-50-PCT
                      TO WS-8020-BAD-DATA
                    MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                    PERFORM 8020-RECORD-INT-ERROR
                       THRU 8020-RECORD-INT-ERROR-EXIT
              END-COMPUTE

      $IF DEBUG-SW DEFINED
           DISPLAY 'PREMIUM WITH 50% SURCHARGE minus 30% SURCHARGE = ',
           WS-2350-PREMIUM-X-50-PCT UPON CONSOLE
      $END
              IF (WS-2350-INPUT-TOTAL-PREMIUM >
                 (WS-2350-PREMIUM-X-50-PCT - 3))  AND
                 (WS-2350-INPUT-TOTAL-PREMIUM <
                 (WS-2350-PREMIUM-X-50-PCT + 3))
                 MOVE WS-2350-PREMIUM-X-50-PCT
                   TO WS-2350-TOTAL-PREMIUM
                 GO TO 2350-VAL-PREMIUM-EXIT
              ELSE
                 MOVE 11051 TO WS-8000-ERROR-CODE
                 MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                 MOVE WS-LITERAL-YES TO ERROR-TOT-PREM
                 MOVE WS-LITERAL-TOT-PREM TO WS-8000-FIELD-NAME1
                 MOVE WS-2350-INPUT-TOTAL-PREMIUM
                   TO WS-8000-BAD-DATA1
                 STRING WS-2350-PREMIUM-X-30-PCT
                   DELIMITED BY SIZE
                   ' OR '
                   DELIMITED BY SIZE
                   WS-2350-PREMIUM-X-50-PCT
                   DELIMITED BY SIZE
                   INTO WS-8000-CORR-DATA1
                 END-STRING
                 MOVE 2350 TO WS-8000-PARAGRAPH-NO
                 PERFORM 8000-RECORD-TRAN-ERROR
                    THRU 8000-RECORD-TRAN-ERROR-EXIT
              END-IF
              GO TO 2350-VAL-PREMIUM-EXIT
           END-IF


      *****************************************************
      *    NORMAL PREMIUMS AND SINGLE SURCHARGE CALCS     *
      *    CHECK INPUT PREMIUM AGAINST CALCULATION        *
      *****************************************************


           IF (WS-2350-INPUT-TOTAL-PREMIUM <
              (WS-2350-TOTAL-PREMIUM - 3))  OR
              (WS-2350-INPUT-TOTAL-PREMIUM >
              (WS-2350-TOTAL-PREMIUM + 3))
           if (WS-2350-INPUT-TOTAL-PREMIUM <
              (WS-2350-alt-TOTAL-PREMIUM - 3))  OR
              (WS-2350-INPUT-TOTAL-PREMIUM >
              (WS-2350-alt-TOTAL-PREMIUM + 3))
      *       *** PREMIUM IS OUT OF TOLERANCE
              MOVE 11051 TO WS-8000-ERROR-CODE
              MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO ERROR-TOT-PREM
              MOVE WS-LITERAL-TOT-PREM TO WS-8000-FIELD-NAME1
              MOVE WS-2350-INPUT-TOTAL-PREMIUM
                TO WS-8000-BAD-DATA1
              MOVE WS-2350-TOTAL-PREMIUM TO WS-8000-CORR-DATA1
              MOVE 2350 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           end-if
           END-IF.



       2350-VAL-PREMIUM-EXIT.
           EXIT.


       2350-LOOKUP-CRC-FACTORS.

           INITIALIZE WS-7575-INPUT-KEY
           MOVE WS-2350-CROP-YEAR-YY
             TO WS-7575-INPUT-CROP-YR
           MOVE WS-2350-RATE-STATE
             TO WS-7575-INPUT-STATE-CD
           MOVE WS-2350-RATE-COUNTY
             TO WS-7575-INPUT-COUNTY-CD
           MOVE WS-2350-CROP-CD
             TO WS-7575-INPUT-CROP-CD
           MOVE WS-2350-INS-PLAN TO WS-7575-INPUT-INS-PLAN
           MOVE WS-2350-PRACTICE-CD
             TO WS-7575-INPUT-PRACTICE-CD
           MOVE WS-2350-TYPE-CD TO WS-7575-INPUT-TYPE-CD
           MOVE WS-2350-RATE-CLASS TO WS-7575-INPUT-RATE-CLASS

      *    *** SET UP ERROR STRING IN CASE 'ADMC NOT FOUND
           STRING 'ADMC KEY = '
               DELIMITED BY SIZE
               WS-7575-INPUT-KEY
               DELIMITED BY SIZE
               INTO WS-8000-CORR-DATA1
           END-STRING

           PERFORM 7575-LOOKUP-ADMC
              THRU 7575-LOOKUP-ADMC-EXIT

           IF MATCH-FOUND-7575
      *       *** CLEAR THE ERROR SET ABOVE
              MOVE SPACES TO WS-8000-CORR-DATA1

              MOVE WS-7575-LOW-PRICE-FACTOR
                TO WS-2350-LOW-PRICE-FACTOR
              MOVE WS-7575-HIGH-PRICE-FACTOR
                TO WS-2350-HIGH-PRICE-FACTOR
      * SELECT THE APPROPRIATE CRC RATE FACTOR BASED ON THE COVERAGE
      * LEVEL PERCENT
              IF WS-2350-LOW-PRICE-FACTOR > 0 AND
                 WS-2350-HIGH-PRICE-FACTOR > 0
                 EVALUATE WS-2350-CVG-LVL-PCT
                   WHEN WS-7575-COVERAGE-LVL1
                     MOVE WS-7575-CRC-RATE-FACTOR1
                       TO WS-2350-CRC-RATE-FACTOR
                   WHEN WS-7575-COVERAGE-LVL2
                     MOVE WS-7575-CRC-RATE-FACTOR2
                       TO WS-2350-CRC-RATE-FACTOR
                   WHEN WS-7575-COVERAGE-LVL3
                     MOVE WS-7575-CRC-RATE-FACTOR3
                       TO WS-2350-CRC-RATE-FACTOR
                   WHEN WS-7575-COVERAGE-LVL4
                     MOVE WS-7575-CRC-RATE-FACTOR4
                       TO WS-2350-CRC-RATE-FACTOR
                   WHEN WS-7575-COVERAGE-LVL5
                     MOVE WS-7575-CRC-RATE-FACTOR5
                       TO WS-2350-CRC-RATE-FACTOR
                   WHEN WS-7575-COVERAGE-LVL6
                     MOVE WS-7575-CRC-RATE-FACTOR6
                       TO WS-2350-CRC-RATE-FACTOR
                   WHEN WS-7575-COVERAGE-LVL7
                     MOVE WS-7575-CRC-RATE-FACTOR7
                       TO WS-2350-CRC-RATE-FACTOR
                   WHEN WS-7575-COVERAGE-LVL8
                     MOVE WS-7575-CRC-RATE-FACTOR8
                       TO WS-2350-CRC-RATE-FACTOR
                   WHEN WS-7575-COVERAGE-LVL9
                     MOVE WS-7575-CRC-RATE-FACTOR9
                       TO WS-2350-CRC-RATE-FACTOR
                   WHEN WS-7575-COVERAGE-LVL10
                     MOVE WS-7575-CRC-RATE-FACTOR10
                       TO WS-2350-CRC-RATE-FACTOR
                   WHEN WS-7575-COVERAGE-LVL11
                     MOVE WS-7575-CRC-RATE-FACTOR11
                       TO WS-2350-CRC-RATE-FACTOR
                   WHEN WS-7575-COVERAGE-LVL12
                     MOVE WS-7575-CRC-RATE-FACTOR12
                       TO WS-2350-CRC-RATE-FACTOR
                   WHEN WS-7575-COVERAGE-LVL13
                     MOVE WS-7575-CRC-RATE-FACTOR13
                       TO WS-2350-CRC-RATE-FACTOR
                   WHEN WS-7575-COVERAGE-LVL14
                     MOVE WS-7575-CRC-RATE-FACTOR14
                       TO WS-2350-CRC-RATE-FACTOR
                   WHEN WS-7575-COVERAGE-LVL15
                     MOVE WS-7575-CRC-RATE-FACTOR15
                       TO WS-2350-CRC-RATE-FACTOR
                   WHEN WS-7575-COVERAGE-LVL16
                     MOVE WS-7575-CRC-RATE-FACTOR16
                       TO WS-2350-CRC-RATE-FACTOR
                   WHEN OTHER
                     MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                     MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
                     MOVE 015 TO WS-8000-SHORT-ERROR
                     MOVE WS-LITERAL-YES TO ERROR-CVG-LVL-PCT
                     MOVE 'COVERAGE LVL %' TO WS-8000-FIELD-NAME1
                     MOVE WS-2350-CVG-LVL-PCT TO WS-8000-BAD-DATA1
                     MOVE 'INVALID CVG LVL %' TO WS-8000-CORR-DATA1
                     MOVE 2350 TO WS-8000-PARAGRAPH-NO
                     PERFORM 8000-RECORD-TRAN-ERROR
                        THRU 8000-RECORD-TRAN-ERROR-EXIT
                     MOVE WS-LITERAL-YES TO ERROR-TOT-PREM
                 END-EVALUATE
              ELSE
      *       low and/or high price factor = 0
                   MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                   MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
                   MOVE 093 TO WS-8000-SHORT-ERROR
                   MOVE WS-LITERAL-YES TO ERROR-TOT-PREM
                   MOVE 'CRC FACTORS' TO WS-8000-FIELD-NAME1
                   MOVE '0.000' TO WS-8000-BAD-DATA1
                   MOVE '> 0.000' TO WS-8000-CORR-DATA1
                   MOVE 2350 TO WS-8000-PARAGRAPH-NO
                   PERFORM 8000-RECORD-TRAN-ERROR
                      THRU 8000-RECORD-TRAN-ERROR-EXIT
           ELSE
      *       NO ADMC REC FOUND
              MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 009 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-YES TO ERROR-TOT-PREM
              MOVE 'CRC FACTORS' TO WS-8000-FIELD-NAME1
              MOVE 'ADMC KEY' TO WS-8000-BAD-DATA1
      *       *** SEARCH KEY USED IS IN CORR-DATA1
              MOVE 2350 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF.


       2350-LOOKUP-CRC-FACTORS-EXIT.
           EXIT.




       2350-LOOKUP-APH-RATE.

           INITIALIZE WS-7505-INPUT-KEY
           MOVE WS-2350-CROP-YEAR-YY TO WS-7505-INPUT-CROP-YR
           MOVE WS-2350-RATE-STATE TO WS-7505-INPUT-STATE-CD
           MOVE WS-2350-RATE-COUNTY TO WS-7505-INPUT-COUNTY-CD
           MOVE WS-2350-CROP-CD TO WS-7505-INPUT-CROP-CD
           MOVE WS-2350-INS-PLAN TO WS-7505-INPUT-INSURANCE-PLAN
           MOVE WS-2350-PRACTICE-CD TO WS-7505-INPUT-PRACTICE-CD
           MOVE WS-2350-TYPE-CD TO WS-7505-INPUT-TYPE-CD
           MOVE WS-2350-RATE-CLASS TO WS-7505-INPUT-RATE-CLASS

      *    *** SET UP ERROR STRING IN CASE ADM1 NOT FOUND
           STRING 'ADM1 KEY = '
               DELIMITED BY SIZE
               WS-7505-INPUT-KEY
               DELIMITED BY SIZE
               INTO WS-8000-CORR-DATA1
           END-STRING

           PERFORM 7505-LOOKUP-ADM1
              THRU 7505-LOOKUP-ADM1-EXIT

           IF MATCH-FOUND-7505
      *       *** CLEAR THE ERROR SET ABOVE
              MOVE SPACES TO WS-8000-CORR-DATA1

              EVALUATE WS-2350-CVG-LVL-PCT
                WHEN WS-7505-COVERAGE-LEVEL-01
                   MOVE WS-7505-BASE-PREMIUM-RATE-01
                     TO WS-2350-CRC-APH-RATE
                WHEN WS-7505-COVERAGE-LEVEL-02
                   MOVE WS-7505-BASE-PREMIUM-RATE-02
                     TO WS-2350-CRC-APH-RATE
                WHEN WS-7505-COVERAGE-LEVEL-03
                   MOVE WS-7505-BASE-PREMIUM-RATE-03
                     TO WS-2350-CRC-APH-RATE
                WHEN WS-7505-COVERAGE-LEVEL-04
                   MOVE WS-7505-BASE-PREMIUM-RATE-04
                     TO WS-2350-CRC-APH-RATE
                WHEN WS-7505-COVERAGE-LEVEL-05
                   MOVE WS-7505-BASE-PREMIUM-RATE-05
                     TO WS-2350-CRC-APH-RATE
                WHEN WS-7505-COVERAGE-LEVEL-06
                   MOVE WS-7505-BASE-PREMIUM-RATE-06
                     TO WS-2350-CRC-APH-RATE
                WHEN WS-7505-COVERAGE-LEVEL-07
                   MOVE WS-7505-BASE-PREMIUM-RATE-07
                     TO WS-2350-CRC-APH-RATE
                WHEN WS-7505-COVERAGE-LEVEL-08
                   MOVE WS-7505-BASE-PREMIUM-RATE-08
                     TO WS-2350-CRC-APH-RATE
                WHEN WS-7505-COVERAGE-LEVEL-09
                   MOVE WS-7505-BASE-PREMIUM-RATE-09
                     TO WS-2350-CRC-APH-RATE
                WHEN WS-7505-COVERAGE-LEVEL-10
                   MOVE WS-7505-BASE-PREMIUM-RATE-10
                     TO WS-2350-CRC-APH-RATE
                WHEN WS-7505-COVERAGE-LEVEL-11
                   MOVE WS-7505-BASE-PREMIUM-RATE-11
                     TO WS-2350-CRC-APH-RATE
                WHEN WS-7505-COVERAGE-LEVEL-12
                   MOVE WS-7505-BASE-PREMIUM-RATE-12
                     TO WS-2350-CRC-APH-RATE
                WHEN WS-7505-COVERAGE-LEVEL-13
                   MOVE WS-7505-BASE-PREMIUM-RATE-13
                     TO WS-2350-CRC-APH-RATE
                WHEN WS-7505-COVERAGE-LEVEL-14
                   MOVE WS-7505-BASE-PREMIUM-RATE-14
                     TO WS-2350-CRC-APH-RATE
                WHEN WS-7505-COVERAGE-LEVEL-15
                   MOVE WS-7505-BASE-PREMIUM-RATE-15
                     TO WS-2350-CRC-APH-RATE
                WHEN WS-7505-COVERAGE-LEVEL-16
                   MOVE WS-7505-BASE-PREMIUM-RATE-16
                     TO WS-2350-CRC-APH-RATE
                WHEN OTHER
                   MOVE WS-LITERAL-YES TO ERROR-TOT-PREM
                   MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
                   MOVE 044 TO WS-8000-SHORT-ERROR
                   MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
                   MOVE 'WS-2350-CVG-LEVEL' TO WS-8000-FIELD-NAME1
                   MOVE WS-2350-CVG-LVL-PCT TO WS-8000-BAD-DATA1
                   MOVE 'NO BASE PREMIUM RT IN ADM1 FOR THIS CVG%'
                     TO WS-8000-CORR-DATA1
                   MOVE 2350 TO WS-8000-PARAGRAPH-NO
                   PERFORM 8000-RECORD-TRAN-ERROR
                      THRU 8000-RECORD-TRAN-ERROR-EXIT
                   GO TO 2350-LOOKUP-APH-RATE-EXIT
              END-EVALUATE
           ELSE
      *       NO ADM1 REC FOUND
              MOVE 11009 TO WS-8000-ERROR-CODE
              MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO ERROR-TOT-PREM
              MOVE WS-LITERAL-BASE-PREM-RT TO WS-8000-FIELD-NAME1
              MOVE 'NOT FOUND' TO WS-8000-BAD-DATA1
      *       *** SEARCH KEY USED IS IN CORR-DATA1
              MOVE 'ADM1' TO WS-8000-TABLE-NAME
              MOVE 2350 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF.

       2350-LOOKUP-APH-RATE-EXIT.
           EXIT.
