
      ***************************************************************
      * File:      IF2355.CBL
      * Author:    Mike Ray
      * Date:      12/13/95
      * Purpose:   Validates the input producer premium against the
      *            producer premium calculation in M-13.
      ***************************************************************

       2355-VAL-PROD-PREMIUM.

      $IF DEBUG-SW DEFINED
           DISPLAY '2355-VALIDATING PRODUCER PREMIUM'
           UPON CONSOLE
      $END


      *****************************************************
      *    INITIALIZE LOCAL VARIABLES                     *
      *****************************************************
           INITIALIZE WS-2355-LOCAL
           INITIALIZE WS-2355-OUTPUT

      *****************************************************
      *    CHECK PRECONDITIONS                            *
      *****************************************************
           IF ERROR-TOT-PREM = WS-LITERAL-YES OR
              ERROR-PROD-PREM = WS-LITERAL-YES OR
              ERROR-INSUR-PLAN-CD = WS-LITERAL-YES
              MOVE WS-LITERAL-YES TO ERROR-PROD-PREM
              GO TO 2355-VAL-PROD-PREMIUM-EXIT
           END-IF

      *****************************************************
      *    CHECK FOR PROD PREM > 0 ON CAT POLICIES        *
      *****************************************************

           IF CAT-COVERAGE AND
              WS-2355-INPUT-PROD-PREMIUM <> 0
                 MOVE 11108 TO WS-8000-ERROR-CODE
                 MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                 MOVE WS-LITERAL-YES TO ERROR-PROD-PREM
                 MOVE WS-LITERAL-PROD-PREM TO WS-8000-FIELD-NAME1
                 MOVE WS-2355-INPUT-PROD-PREMIUM
                   TO WS-2355-ERROR-PREM
                 MOVE WS-2355-ERROR-PREM
                   TO WS-8000-BAD-DATA1
                 MOVE '= 0'
                   TO WS-8000-CORR-DATA1
                 MOVE 2355 TO WS-8000-PARAGRAPH-NO
                 PERFORM 8000-RECORD-TRAN-ERROR
                    THRU 8000-RECORD-TRAN-ERROR-EXIT
                 GO TO 2355-VAL-PROD-PREMIUM-EXIT
           END-IF

      *****************************************************
      *    BYPASS THIS EDIT FOR IP CROPS and GRP plans    *
      *    and NCS-flag = '3'                             *
      *****************************************************

           IF WS-2355-INS-PLAN = WS-LITERAL-IP
              or ws-2355-ins-plan = ws-literal-grp
              or WS-0009-NCS-FCIC-2-FLG = WS-LITERAL-33-SUPP-RATE
              GO TO 2355-VAL-PROD-PREMIUM-EXIT
           END-IF

      *************************************************************
      *             CALCULATE PRODUCER PREMIUM                    *
      *************************************************************
      $IF DEBUG-SW DEFINED
           DISPLAY 'INPUT PRODUCER PREMIUM = ',
           WS-2355-INPUT-PROD-PREMIUM
           UPON CONSOLE
      $END

           EVALUATE WS-2355-INS-PLAN
              WHEN WS-LITERAL-CRC
                 COMPUTE WS-2355-PROD-PREMIUM ROUNDED =
                     WS-2355-TOTAL-PREMIUM -
                     (WS-2355-CRC-APH-PREMIUM
                     * WS-2355-SUBSIDY-FCTR)
                     ON SIZE ERROR
                         MOVE 2355 TO WS-8020-PARAGRAPH-NO
                         MOVE 90017 TO WS-8020-INT-ERROR-NO
                         MOVE 'PREMIUM - SUBSIDY'
                         TO WS-8020-FIELD-NAME
                         MOVE WS-2355-TOTAL-PREMIUM
                         TO WS-2355-ERROR-PREM
                         MOVE WS-2355-ERROR-PREM
                         TO WS-8020-BAD-DATA
                         MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                         PERFORM 8020-RECORD-INT-ERROR
                             THRU 8020-RECORD-INT-ERROR-EXIT
                 END-COMPUTE

              WHEN WS-LITERAL-GRP
                 COMPUTE WS-2355-PROD-PREMIUM ROUNDED =
                     WS-2355-TOTAL-PREMIUM
                     - WS-2355-GRP-SUBSIDY
                     ON SIZE ERROR
                         MOVE 2355 TO WS-8020-PARAGRAPH-NO
                         MOVE 90017 TO WS-8020-INT-ERROR-NO
                         MOVE 'TOT PREM - GRP SUBSIDY'
                           TO WS-8020-FIELD-NAME
                         MOVE WS-2355-TOTAL-PREMIUM
                           TO WS-2355-ERROR-PREM
                         MOVE WS-2355-ERROR-PREM
                           TO WS-8020-BAD-DATA
                         MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                         PERFORM 8020-RECORD-INT-ERROR
                            THRU 8020-RECORD-INT-ERROR-EXIT
                 END-COMPUTE

              WHEN WS-LITERAL-IP
                 COMPUTE WS-2355-PROD-PREMIUM ROUNDED =
                     WS-2355-TOTAL-PREMIUM
                     - WS-2355-IP-SUBSIDY
                     ON SIZE ERROR
                         MOVE 2355 TO WS-8020-PARAGRAPH-NO
                         MOVE 90017 TO WS-8020-INT-ERROR-NO
                         MOVE 'TOT PREM - IP SUBSIDY'
                           TO WS-8020-FIELD-NAME
                         MOVE WS-2355-TOTAL-PREMIUM
                           TO WS-2355-ERROR-PREM
                         MOVE WS-2355-ERROR-PREM
                           TO WS-8020-BAD-DATA
                         MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                         PERFORM 8020-RECORD-INT-ERROR
                            THRU 8020-RECORD-INT-ERROR-EXIT
                 END-COMPUTE

              WHEN WS-LITERAL-RA
                 COMPUTE WS-2355-RA-SUBSIDY ROUNDED =
                     WS-2355-TOTAL-PREMIUM
                     * WS-2355-RA-SUBSIDY-FCTR
                     ON SIZE ERROR
                         MOVE 2355 TO WS-8020-PARAGRAPH-NO
                         MOVE 90017 TO WS-8020-INT-ERROR-NO
                         MOVE 'RA SUBSIDY'
                           TO WS-8020-FIELD-NAME
                         MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                         PERFORM 8020-RECORD-INT-ERROR
                            THRU 8020-RECORD-INT-ERROR-EXIT
                 END-COMPUTE
                 COMPUTE WS-2355-APH-SUBSIDY ROUNDED =
                     WS-2355-CRC-APH-PREMIUM
                     * WS-2355-SUBSIDY-FCTR
                     ON SIZE ERROR
                         MOVE 2355 TO WS-8020-PARAGRAPH-NO
                         MOVE 90017 TO WS-8020-INT-ERROR-NO
                         MOVE 'APH SUBSIDY'
                           TO WS-8020-FIELD-NAME
                         MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                         PERFORM 8020-RECORD-INT-ERROR
                            THRU 8020-RECORD-INT-ERROR-EXIT
                 END-COMPUTE
                 MOVE WS-2355-RA-SUBSIDY TO WS-2355-RA-SUBSIDY-X
                 MOVE WS-2355-APH-SUBSIDY TO WS-2355-APH-SUBSIDY-X
      $IF DEBUG-SW DEFINED
           DISPLAY 'RA SUBSIDY  = $',
           WS-2355-RA-SUBSIDY-X UPON CONSOLE
           DISPLAY 'APH SUBSIDY = $',
           WS-2355-APH-SUBSIDY-X UPON CONSOLE
      $END
                 IF WS-2355-APH-SUBSIDY < WS-2355-RA-SUBSIDY
                    MOVE WS-2355-APH-SUBSIDY TO WS-2355-RA-SUBSIDY
                    MOVE WS-2355-RA-SUBSIDY TO WS-2355-RA-SUBSIDY-X
                 END-IF
                 COMPUTE WS-2355-PROD-PREMIUM ROUNDED =
                     WS-2355-TOTAL-PREMIUM
                     - WS-2355-RA-SUBSIDY
                     ON SIZE ERROR
                         MOVE 2355 TO WS-8020-PARAGRAPH-NO
                         MOVE 90017 TO WS-8020-INT-ERROR-NO
                         MOVE 'TOT PREM - SUBSIDY'
                           TO WS-8020-FIELD-NAME
                         PERFORM 8020-RECORD-INT-ERROR
                            THRU 8020-RECORD-INT-ERROR-EXIT
                 END-COMPUTE

              WHEN OTHER
                 COMPUTE WS-2355-PROD-PREMIUM ROUNDED =
                     WS-2355-TOTAL-PREMIUM
                     * (1 - WS-2355-SUBSIDY-FCTR)
                     ON SIZE ERROR
                         MOVE 2355 TO WS-8020-PARAGRAPH-NO
                         MOVE 90017 TO WS-8020-INT-ERROR-NO
                         MOVE 'TOT PREM * (1-SUBSIDY FCTR)'
                         TO WS-8020-FIELD-NAME
                         MOVE WS-2355-TOTAL-PREMIUM
                         TO WS-2355-ERROR-PREM
                         MOVE WS-2355-ERROR-PREM
                         TO WS-8020-BAD-DATA
                         MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                         PERFORM 8020-RECORD-INT-ERROR
                            THRU 8020-RECORD-INT-ERROR-EXIT
                 END-COMPUTE
              END-EVALUATE

      *****************************************************
      *    CHECK INPUT PROD PREMIUM AGAINST CALCULATION   *
      *****************************************************

      $IF DEBUG-SW DEFINED
           DISPLAY 'CALC PRODUCER PREMIUM  = ',
           WS-2355-PROD-PREMIUM
           UPON CONSOLE
      $END

           IF WS-2355-INPUT-PROD-PREMIUM <> WS-2355-PROD-PREMIUM
              IF CAT-COVERAGE
                 MOVE WS-2355-PROD-PREMIUM
                   TO WS-2355-INPUT-PROD-PREMIUM
              ELSE
                 IF (WS-2355-INPUT-PROD-PREMIUM <
                    (WS-2355-PROD-PREMIUM - 3)) OR
                    (WS-2355-INPUT-PROD-PREMIUM >
                    (WS-2355-PROD-PREMIUM + 3))
      *             *** PRODUCER PREMIUM IS OUT OF TOLERANCE
                    MOVE 11052 TO WS-8000-ERROR-CODE
                    MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                    MOVE WS-LITERAL-YES TO ERROR-PROD-PREM
                    MOVE WS-LITERAL-PROD-PREM TO WS-8000-FIELD-NAME1
                    MOVE WS-2355-INPUT-PROD-PREMIUM
                      TO WS-2355-ERROR-PREM
                    MOVE WS-2355-ERROR-PREM
                      TO WS-8000-BAD-DATA1
                    MOVE WS-2355-PROD-PREMIUM
                      TO WS-2355-ERROR-PREM
                    MOVE WS-2355-ERROR-PREM
                      TO WS-8000-CORR-DATA1
                    MOVE 2355 TO WS-8000-PARAGRAPH-NO
                    PERFORM 8000-RECORD-TRAN-ERROR
                       THRU 8000-RECORD-TRAN-ERROR-EXIT
                 END-IF
              END-IF
           END-IF.


       2355-VAL-PROD-PREMIUM-EXIT.
           EXIT.



