      *****************************************************************
      * FILE:      IF2380.CBL
      * AUTHOR:    MIKE RAY
      * DATE:      02/01/97
      * PURPOSE:   VALIDATION FOR GUARANTEE REDUCTION FLAG
      *
      *          IF 'PP', LOOKUP THE CROP IN ADMO TO SEE IF
      *          PREVENTED PLANTING IS AVAILABLE AS AN OPTION.
      *          IF NOT FOUND, TRY ADMR.
      *****************************************************************

       2380-VAL-GUAR-RED-FLG.

      $IF DEBUG-SW DEFINED
           DISPLAY '2380-VALIDATING GUARANTEE REDUCTION FLAG'
           UPON CONSOLE
      $END

      ****************************************************************
      *      INITIALIZE LOCAL WORKING STORAGE                        *
      ****************************************************************
           INITIALIZE WS-2380-WORK

      ****************************************************************
      *            CHECK THE PRE-CONDITIONS BEFORE THE EDIT          *
      ****************************************************************
           IF ERROR-CROP-CD = WS-LITERAL-YES OR
              ERROR-CROP-YR = WS-LITERAL-YES OR
              ERROR-INSUR-PLAN-CD = WS-LITERAL-YES OR
              ERROR-RATE-STATE = WS-LITERAL-YES OR
              ERROR-RATE-COUNTY = WS-LITERAL-YES OR
              ERROR-PRACTICE-CD = WS-LITERAL-YES OR
              ERROR-CROP-TYPE = WS-LITERAL-YES OR
              ERROR-RO = WS-LITERAL-YES OR
              ERROR-GUAR-RED-FLG = WS-LITERAL-YES
              MOVE WS-LITERAL-YES TO ERROR-GUAR-RED-FLG
              GO TO 2380-VAL-GUAR-RED-FLG-EXIT
           END-IF

      $IF DEBUG-SW DEFINED
           DISPLAY 'GUARANTEE RED FLAG = ',
           WS-2380-GUARANTEE-RED-FLG
           UPON CONSOLE
      $END

      **********************************************
      *       TRANSLATE PREVENTED PLANTING PLANS   *
      **********************************************
           EVALUATE WS-2380-GUARANTEE-RED-FLG
              WHEN WS-LITERAL-PP
      *          ** DETERMINE WHETHER PREV PLANT OPT IS AVAILABLE
                 PERFORM 2380-VAL-PREV-PLANT-OPT
                    THRU 2380-VAL-PREV-PLANT-OPT-EXIT
              WHEN WS-LITERAL-LPO
      *          ** DETERMINE WHETHER LATE PLANT OPT IS AVAILABLE
                 PERFORM 2380-VAL-LATE-PLANT-OPT
                    THRU 2380-VAL-LATE-PLANT-OPT-EXIT
           END-EVALUATE.

       2380-VAL-GUAR-RED-FLG-EXIT.
           EXIT.


      $IF ISAM-SW DEFINED

       2380-VAL-PREV-PLANT-OPT.

      *****************************************************************
      *    Sugar beets (0039) and dry beans (0047) in Arizona and in  *
      *    California cannot have prevented planting.                 *
      *****************************************************************
           IF WS-2380-CROP-CD = WS-LITERAL-SUGAR-BEETS OR
              WS-2380-CROP-CD = WS-LITERAL-DRY-BEANS
              IF WS-2380-RATE-STATE = WS-LITERAL-ARIZONA OR
                 WS-2380-RATE-STATE = WS-LITERAL-CALIFORNIA
                 MOVE WS-LITERAL-IF  TO WS-8000-ERROR-TYPE
                 MOVE WS-TRAN-TYPE   TO WS-8000-ERROR-TRAN-TYPE
                 MOVE 040            TO WS-8000-SHORT-ERROR
                 MOVE WS-LITERAL-YES TO ERROR-GUAR-RED-FLG
                 MOVE WS-LITERAL-GUAR-RED-FLG   TO WS-8000-FIELD-NAME1
                 MOVE WS-2380-GUARANTEE-RED-FLG TO WS-8000-BAD-DATA1
                 MOVE 2380                      TO WS-8000-PARAGRAPH-NO
                 PERFORM 8000-RECORD-TRAN-ERROR
                    THRU 8000-RECORD-TRAN-ERROR-EXIT
                 GO TO 2380-VAL-PREV-PLANT-OPT-EXIT
              END-IF
           END-IF

      *****************************************************************
      *       LOOKUP PREVENTED PLANTING OPTION IN ADMO                *
      * THREE ATTEMPTS ARE MADE TO FIND THE PREVENTED PLANTING OPT    *
      *  1. 'BUPP  ' - PREVENTED PLANTING WITH A BASIC UNIT DISCOUNT  *
      *  2. '  PP  ' - PREVENTED PLANTING WITH NO BASIC UNIT DISCOUNT *
      *  3. 'PP    ' - PREVENTED PLANTING ALSO WITH NO BASIC UNIT DISC*
      * LOOKUP PP OPTION IN THE ADMR TABLE                            *
      *  4. 'PP    ' - PP OPTION ONLY (ADMR)                          *
      *****************************************************************

      *    *** PREVENTED PLANTED IP CROPS CANNOT HAVE BU (BYPASS LOOKUP)
           IF WS-2380-INSURANCE-PLAN-ID NOT = WS-LITERAL-IP

      *       1. LOOKUP PP OPTION WITH BASIC UNIT DISCOUNT
              INITIALIZE WS-7535-INPUT-KEY
              MOVE WS-2380-CROP-YEAR TO WS-7535-INPUT-CROP-YR
              MOVE WS-2380-RATE-STATE TO WS-7535-INPUT-STATE-CD
              MOVE WS-2380-CROP-CD TO WS-7535-INPUT-CROP-CD
              MOVE WS-2380-RATE-COUNTY TO WS-7535-INPUT-COUNTY-CD
              MOVE WS-2380-INSURANCE-PLAN-ID
                TO WS-7535-INPUT-INSURANCE-PLAN
              MOVE 'BUPP    ' TO WS-7535-INPUT-OPTION-CD
      *       *** SET UP ERROR STRING IN CASE ADMO NOT FOUND
              STRING 'ADMO KEY = '
                  DELIMITED BY SIZE
                  WS-7535-INPUT-KEY
                  DELIMITED BY SIZE
                  INTO WS-8000-CORR-DATA1
              END-STRING
              PERFORM 7535-LOOKUP-ADMO
                 THRU 7535-LOOKUP-ADMO-EXIT

              IF MATCH-FOUND-7535
      *          *** CLEAR THE ERROR SET ABOVE
                 MOVE SPACES TO WS-8000-CORR-DATA1
                 GO TO 2380-VAL-PREV-PLANT-OPT-EXIT
              END-IF

           END-IF

      *    2. LOOKUP PP OPTION WITHOUT BASIC UNIT DISCOUNT
           INITIALIZE WS-7535-INPUT-KEY
           MOVE WS-2380-CROP-YEAR TO WS-7535-INPUT-CROP-YR
           MOVE WS-2380-RATE-STATE TO WS-7535-INPUT-STATE-CD
           MOVE WS-2380-CROP-CD TO WS-7535-INPUT-CROP-CD
           MOVE WS-2380-RATE-COUNTY TO WS-7535-INPUT-COUNTY-CD
           MOVE WS-2380-INSURANCE-PLAN-ID
             TO WS-7535-INPUT-INSURANCE-PLAN
           MOVE '  PP    ' TO WS-7535-INPUT-OPTION-CD
      *    *** SET UP ERROR STRING IN CASE ADMO NOT FOUND
           STRING 'ADMO KEY = '
               DELIMITED BY SIZE
               WS-7535-INPUT-KEY
               DELIMITED BY SIZE
               INTO WS-8000-CORR-DATA1
           END-STRING
           PERFORM 7535-LOOKUP-ADMO
              THRU 7535-LOOKUP-ADMO-EXIT

           IF MATCH-FOUND-7535
      *       *** CLEAR THE ERROR SET ABOVE
              MOVE SPACES TO WS-8000-CORR-DATA1
              GO TO 2380-VAL-PREV-PLANT-OPT-EXIT
           END-IF

      *    3. LOOKUP PP OPTION WITHOUT BASIC UNIT DISCOUNT AGAIN
           INITIALIZE WS-7535-INPUT-KEY
           MOVE WS-2380-CROP-YEAR TO WS-7535-INPUT-CROP-YR
           MOVE WS-2380-RATE-STATE TO WS-7535-INPUT-STATE-CD
           MOVE WS-2380-CROP-CD TO WS-7535-INPUT-CROP-CD
           MOVE WS-2380-RATE-COUNTY TO WS-7535-INPUT-COUNTY-CD
           MOVE WS-2380-INSURANCE-PLAN-ID
             TO WS-7535-INPUT-INSURANCE-PLAN
           MOVE 'PP      ' TO WS-7535-INPUT-OPTION-CD
      *    *** SET UP ERROR STRING IN CASE ADMO NOT FOUND
           STRING 'ADMO KEY = '
               DELIMITED BY SIZE
               WS-7535-INPUT-KEY
               DELIMITED BY SIZE
               INTO WS-8000-CORR-DATA1
           END-STRING
           PERFORM 7535-LOOKUP-ADMO
              THRU 7535-LOOKUP-ADMO-EXIT

           IF MATCH-FOUND-7535
      *       *** CLEAR THE ERROR SET ABOVE
              MOVE SPACES TO WS-8000-CORR-DATA1
              GO TO 2380-VAL-PREV-PLANT-OPT-EXIT
           END-IF

      *    4. LOOKUP PP OPTION IN THE ADMR TABLE
           INITIALIZE WS-7540-INPUT-KEY
           MOVE WS-2380-CROP-YEAR TO WS-7540-INPUT-CROP-YR
           MOVE WS-2380-RATE-STATE TO WS-7540-INPUT-STATE-CD
           MOVE WS-2380-RATE-COUNTY TO WS-7540-INPUT-COUNTY-CD
           MOVE WS-2380-CROP-CD TO WS-7540-INPUT-CROP-CD
           MOVE WS-2380-INSURANCE-PLAN-ID
             TO WS-7540-INPUT-INSURANCE-PLAN
           MOVE WS-2380-PRACTICE-CD TO WS-7540-INPUT-PRACTICE-CD
           MOVE WS-2380-TYPE-CD TO WS-7540-INPUT-TYPE-CD
           MOVE 'PP      ' TO WS-7540-INPUT-OPTION-CD
           MOVE WS-2380-RATE-CLASS TO WS-7540-INPUT-RATE-CLASS
      *    *** SET UP ERROR STRING IN CASE ADMR NOT FOUND
           STRING 'ADMR KEY = '
               DELIMITED BY SIZE
               WS-7540-INPUT-KEY
               DELIMITED BY SIZE
               INTO WS-8000-CORR-DATA1
           END-STRING
           PERFORM 7540-LOOKUP-ADMR
              THRU 7540-LOOKUP-ADMR-EXIT

           IF MATCH-FOUND-7540
      *       *** CLEAR THE ERROR SET ABOVE
              MOVE SPACES TO WS-8000-CORR-DATA1
              GO TO 2380-VAL-PREV-PLANT-OPT-EXIT
           END-IF

      *****************************************************
      *  THIS CROP-STATE-COUNTY COMBINATION CANNOT USE    *
      *  A PREVENTED PLANTING OPTION                      *
      *****************************************************
           MOVE WS-LITERAL-IF  TO WS-8000-ERROR-TYPE
           MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
           MOVE 040 TO WS-8000-SHORT-ERROR
           MOVE WS-LITERAL-YES TO ERROR-GUAR-RED-FLG
           MOVE WS-LITERAL-GUAR-RED-FLG TO WS-8000-FIELD-NAME1
           MOVE WS-2380-GUARANTEE-RED-FLG TO WS-8000-BAD-DATA1
      *    *** SEARCH KEY USED IS IN CORR-DATA1
           MOVE 2380 TO WS-8000-PARAGRAPH-NO
           PERFORM 8000-RECORD-TRAN-ERROR
              THRU 8000-RECORD-TRAN-ERROR-EXIT.


       2380-VAL-PREV-PLANT-OPT-EXIT.
           EXIT.

      $END

       2380-VAL-LATE-PLANT-OPT.

      *****************************************************
      *  SEE IF CROP/TYPE ALLOWS LATE PLANTING.           *
      *****************************************************
           MOVE WS-LITERAL-YES TO WS-2380-LPO-AVAILABLE

           EVALUATE WS-2380-CROP-CD
               WHEN WS-LITERAL-BARLEY
                  CONTINUE
               WHEN WS-LITERAL-CANNING-BEANS
                  CONTINUE
               WHEN WS-LITERAL-CANOLA
                  CONTINUE
               WHEN WS-LITERAL-CORN
                  CONTINUE
               WHEN WS-LITERAL-COTTON
                  CONTINUE
               WHEN WS-LITERAL-DRY-BEANS
                  CONTINUE
               WHEN WS-LITERAL-DRY-PEAS
                  CONTINUE
               WHEN WS-LITERAL-FLAX
                  CONTINUE
               WHEN WS-LITERAL-GRAIN-SORGHUM
                  CONTINUE
               WHEN WS-LITERAL-GREEN-PEAS
                  CONTINUE
               WHEN WS-LITERAL-HYBRID-CORN-SEED
                  CONTINUE
               WHEN WS-LITERAL-HYBRID-SORGHUM-SEED
                  CONTINUE
               WHEN WS-LITERAL-MILLET
                  CONTINUE
               WHEN WS-LITERAL-OATS
                  CONTINUE
               WHEN WS-LITERAL-ONIONS
                  CONTINUE
               WHEN WS-LITERAL-PEANUTS
                  CONTINUE
               WHEN WS-LITERAL-POPCORN
                  CONTINUE
               WHEN WS-LITERAL-POTATOES
                  CONTINUE
               WHEN WS-LITERAL-RICE
                  CONTINUE
               WHEN WS-LITERAL-RYE
                  CONTINUE
               WHEN WS-LITERAL-SAFFLOWER
                  CONTINUE
               WHEN WS-LITERAL-SOYBEANS
                  CONTINUE
               WHEN WS-LITERAL-SUGAR-BEETS
                  CONTINUE
               WHEN WS-LITERAL-SUNFLOWERS
                  CONTINUE
               WHEN WS-LITERAL-SWEET-CORN
                  CONTINUE
               WHEN WS-LITERAL-TOBACCO
               WHEN WS-LITERAL-FLUE-CURED-TOBACCO
               WHEN WS-LITERAL-FIRE-CURED-TOBACCO
               WHEN WS-LITERAL-BURLEY-TOBACCO
               WHEN WS-LITERAL-MARYLAND-TOBACCO
               WHEN WS-LITERAL-DARK-AIR-TOBACCO
               WHEN WS-LITERAL-CIGAR-FILL-TOBACCO
               WHEN WS-LITERAL-CIGAR-BINDR-TOBACCO
               WHEN WS-LITERAL-CIGAR-WRAPR-TOBACCO
                  CONTINUE
               WHEN WS-LITERAL-TOMATOES
                  CONTINUE
               WHEN WS-LITERAL-WHEAT
                  IF WS-2380-SEED-CYCLE-CD = WS-LITERAL-FALL
                     MOVE WS-LITERAL-NO TO WS-2380-LPO-AVAILABLE
                  END-IF
               WHEN OTHER
                  MOVE WS-LITERAL-NO TO WS-2380-LPO-AVAILABLE
           END-EVALUATE

           IF WS-2380-LPO-AVAILABLE = WS-LITERAL-NO
              MOVE WS-LITERAL-IF  TO WS-8000-ERROR-TYPE
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 040 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-YES TO ERROR-GUAR-RED-FLG
              MOVE WS-LITERAL-GUAR-RED-FLG TO WS-8000-FIELD-NAME1
              MOVE WS-2380-GUARANTEE-RED-FLG TO WS-8000-BAD-DATA1
              MOVE 2380 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF.

       2380-VAL-LATE-PLANT-OPT-EXIT.
           EXIT.
