      *************************************************************
      *  File   : IF2390.CBL
      *  Author : MIKE RAY
      *  Date   : 02/01/97
      *  Purpose: VALIDATE GUARANTEE REDUCTION PERCENT
      *
      *           IF LATE PLANTING APPLIES:
      *              MUST EQUAL LPO REDUCTION PERCENT CALCULATED
      *              IN IF2320.
      *
      *           IF PREVENTED PLANTING APPLIES:
      *
      *
      *           IF NO GUARANTEE REDUCTION APPLIES:
      *              MUST EQUAL ZERO.
      *************************************************************

       2390-VAL-GUAR-RED-PCT.

      $IF DEBUG-SW DEFINED
          DISPLAY '2390-VALIDATING GUARANTEE REDUCTION PERCENT'
          UPON CONSOLE
      $END

      **********************************************
      *            CHECK PRE-CONDITIONS            *
      **********************************************
           IF ERROR-CROP-CD       = WS-LITERAL-YES OR
              ERROR-INSUR-PLAN-CD = WS-LITERAL-YES OR
              ERROR-GUAR-RED-FLG  = WS-LITERAL-YES OR
              ERROR-GUAR-RED-PCT  = WS-LITERAL-YES
              MOVE WS-LITERAL-YES TO ERROR-GUAR-RED-PCT
              GO TO 2390-VAL-GUAR-RED-PCT-EXIT
           END-IF

      **********************************************
      *     INITIALIZE LOCAL VARIABLES             *
      **********************************************
           INITIALIZE WS-2390-WORK

      **********************************************
      *        SET UP DISPLAY FIELDS               *
      **********************************************
           MOVE WS-2390-GUARANTEE-RED-PCT
             TO WS-2390-GUARANTEE-RED-PCT-X
           MOVE WS-2390-LPO-REDUCTION-PCT
             TO WS-2390-LPO-REDUCTION-PCT-X

      $IF DEBUG-SW DEFINED
           DISPLAY 'INPUT GUARANTEE REDUCTION FLG = ',
           WS-2390-GUARANTEE-RED-FLG
           UPON CONSOLE
           DISPLAY 'INPUT GUARANTEE REDUCTION PCT = ',
           WS-2390-GUARANTEE-RED-PCT-X
           UPON CONSOLE
           DISPLAY 'INPUT LPO REDUCTION PCT       = ',
           WS-2390-LPO-REDUCTION-PCT-X
           UPON CONSOLE
      $END

      **********************************************
      *           NORMAL PROCESSING                *
      **********************************************
           EVALUATE WS-2390-GUARANTEE-RED-FLG
               WHEN WS-LITERAL-LPO
                  IF WS-2390-GUARANTEE-RED-PCT <>
                     WS-2390-LPO-REDUCTION-PCT
                     MOVE WS-LITERAL-YES TO ERROR-GUAR-RED-PCT
                     MOVE WS-LITERAL-IF  TO WS-8000-ERROR-TYPE
                     MOVE 2390  TO WS-8000-PARAGRAPH-NO
                     MOVE 11101 TO WS-8000-ERROR-CODE
                     MOVE WS-LITERAL-GUAR-RED-PCT
                       TO WS-8000-FIELD-NAME1
                     MOVE WS-2390-GUARANTEE-RED-PCT-X
                       TO WS-8000-BAD-DATA1
                     MOVE WS-2390-LPO-REDUCTION-PCT-X
                       TO WS-8000-CORR-DATA1
                     PERFORM 8000-RECORD-TRAN-ERROR
                        THRU 8000-RECORD-TRAN-ERROR-EXIT
                  END-IF

               WHEN WS-LITERAL-PP
                  PERFORM 2390-CHECK-PP-REDUCTION
                     THRU 2390-CHECK-PP-REDUCTION-EXIT

               WHEN SPACES
                  IF WS-2390-GUARANTEE-RED-PCT <> ZEROS
                     MOVE WS-LITERAL-YES TO ERROR-GUAR-RED-PCT
                     MOVE WS-LITERAL-IF  TO WS-8000-ERROR-TYPE
                     MOVE 2390  TO WS-8000-PARAGRAPH-NO
                     MOVE 11007 TO WS-8000-ERROR-CODE
                     MOVE WS-LITERAL-GUAR-RED-PCT
                       TO WS-8000-FIELD-NAME1
                     MOVE WS-2390-GUARANTEE-RED-PCT-X
                       TO WS-8000-BAD-DATA1
                     MOVE '0.000'
                       TO WS-8000-CORR-DATA1
                     PERFORM 8000-RECORD-TRAN-ERROR
                        THRU 8000-RECORD-TRAN-ERROR-EXIT
                  END-IF

               WHEN OTHER
                  CONTINUE
           END-EVALUATE.


       2390-VAL-GUAR-RED-PCT-EXIT.
           EXIT.


      *=============================================================*
      *   CHECK PREVENTED PLANTING REDUCTION                        *
      *=============================================================*

       2390-CHECK-PP-REDUCTION.

           EVALUATE WS-2390-INS-PLAN-CD
               WHEN WS-LITERAL-YLD-BASED-DOL-AMT
                  EVALUATE WS-2390-CROP-CD
                      WHEN WS-LITERAL-HYBRID-CORN-SEED
                         IF WS-2390-GUARANTEE-RED-PCT = .200 OR
                            WS-2390-GUARANTEE-RED-PCT = .400
                            GO TO 2390-CHECK-PP-REDUCTION-EXIT
                         ELSE
                            MOVE .200 TO WS-2390-PP-REDUCTION1-X
                            MOVE .400 TO WS-2390-PP-REDUCTION2-X
                         END-IF
                      WHEN WS-LITERAL-HYBRID-SORGHUM-SEED
                         IF WS-2390-GUARANTEE-RED-PCT = .250 OR
                            WS-2390-GUARANTEE-RED-PCT = .500
                            GO TO 2390-CHECK-PP-REDUCTION-EXIT
                         ELSE
                            MOVE .250 TO WS-2390-PP-REDUCTION1-X
                            MOVE .500 TO WS-2390-PP-REDUCTION2-X
                         END-IF
                      WHEN OTHER
                         MOVE WS-LITERAL-YES TO ERROR-GUAR-RED-PCT
                         MOVE WS-TRAN-TYPE   TO WS-8000-ERROR-TRAN-TYPE
                         MOVE 044 TO WS-8000-SHORT-ERROR
                         MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
                         MOVE 'INS PLAN CD' TO WS-8000-FIELD-NAME1
                         MOVE WS-2390-INS-PLAN-CD TO WS-8000-BAD-DATA1
                         MOVE 'MISSING PREVENTED PLANTING LOGIC'
                           TO WS-8000-CORR-DATA1
                         MOVE 2390 TO WS-8000-PARAGRAPH-NO
                         PERFORM 8000-RECORD-TRAN-ERROR
                            THRU 8000-RECORD-TRAN-ERROR-EXIT
                         GO TO 2390-CHECK-PP-REDUCTION-EXIT
                  END-EVALUATE

               WHEN WS-LITERAL-APH-AREA-SPAN
               WHEN WS-LITERAL-APH-AREA-PLAN
               WHEN WS-LITERAL-APH
               WHEN WS-LITERAL-IP
               WHEN WS-LITERAL-CRC
               WHEN WS-LITERAL-RA
                  EVALUATE WS-2390-CROP-CD
                     WHEN WS-LITERAL-RICE
                     WHEN WS-LITERAL-COTTON
                     WHEN WS-LITERAL-COTTON-XTRA-LONG
                     WHEN WS-LITERAL-SUGAR-BEETS
                       IF WS-2390-GUARANTEE-RED-PCT = .175 OR
                          WS-2390-GUARANTEE-RED-PCT = .350
                          GO TO 2390-CHECK-PP-REDUCTION-EXIT
                       ELSE
                          MOVE .175 TO WS-2390-PP-REDUCTION1-X
                          MOVE .350 TO WS-2390-PP-REDUCTION2-X
                       END-IF

                     WHEN WS-LITERAL-WHEAT
                     WHEN WS-LITERAL-CANOLA
                     WHEN WS-LITERAL-OATS
                     WHEN WS-LITERAL-FLAX
                     WHEN WS-LITERAL-CORN
                     WHEN WS-LITERAL-GRAIN-SORGHUM
                     WHEN WS-LITERAL-SUNFLOWERS
                     WHEN WS-LITERAL-SOYBEANS
                     WHEN WS-LITERAL-BARLEY
                     WHEN WS-LITERAL-RYE
                     WHEN WS-LITERAL-DRY-BEANS
                        IF WS-2390-GUARANTEE-RED-PCT = .250 OR
                           WS-2390-GUARANTEE-RED-PCT = .500
                           GO TO 2390-CHECK-PP-REDUCTION-EXIT
                        ELSE
                           MOVE .250 TO WS-2390-PP-REDUCTION1-X
                           MOVE .500 TO WS-2390-PP-REDUCTION2-X
                        END-IF

                     WHEN OTHER
      *                 *** THIS LOGIC CATCHES VALID PP CROPS
      *                 *** WHICH WE HAVE NOT CODED FACTORS FOR.
                        MOVE WS-LITERAL-YES TO ERROR-GUAR-RED-PCT
                        MOVE WS-TRAN-TYPE   TO WS-8000-ERROR-TRAN-TYPE
                        MOVE 044 TO WS-8000-SHORT-ERROR
                        MOVE WS-LITERAL-PR  TO WS-8000-ERROR-TYPE
                        MOVE WS-LITERAL-GUAR-RED-PCT
                          TO WS-8000-FIELD-NAME1
                        MOVE WS-2390-GUARANTEE-RED-PCT-X
                          TO WS-8000-BAD-DATA1
                        MOVE 'MISSING PREVENTED PLANTING %'
                          TO WS-8000-CORR-DATA1
                        MOVE 2390 TO WS-8000-PARAGRAPH-NO
                        PERFORM 8000-RECORD-TRAN-ERROR
                           THRU 8000-RECORD-TRAN-ERROR-EXIT
                        GO TO 2390-CHECK-PP-REDUCTION-EXIT
                  END-EVALUATE

               WHEN OTHER
                  MOVE WS-LITERAL-YES      TO ERROR-GUAR-RED-PCT
                  MOVE WS-TRAN-TYPE        TO WS-8000-ERROR-TRAN-TYPE
                  MOVE 044                 TO WS-8000-SHORT-ERROR
                  MOVE WS-LITERAL-PR       TO WS-8000-ERROR-TYPE
                  MOVE 'INS PLAN CD'       TO WS-8000-FIELD-NAME1
                  MOVE WS-2390-INS-PLAN-CD TO WS-8000-BAD-DATA1
                  MOVE 'MISSING PREVENTED PLANTING LOGIC'
                                           TO WS-8000-CORR-DATA1
                  MOVE 2390                TO WS-8000-PARAGRAPH-NO
                  PERFORM 8000-RECORD-TRAN-ERROR
                     THRU 8000-RECORD-TRAN-ERROR-EXIT
                  GO TO 2390-CHECK-PP-REDUCTION-EXIT
           END-EVALUATE

      *    *****************************************************
      *    *  RECORD INVALID PP REDUCTION PCT ERROR            *
      *    *****************************************************
           MOVE WS-LITERAL-YES TO ERROR-GUAR-RED-PCT
           MOVE WS-LITERAL-IF  TO WS-8000-ERROR-TYPE
           MOVE 2390  TO WS-8000-PARAGRAPH-NO
           MOVE 11102 TO WS-8000-ERROR-CODE
           MOVE WS-LITERAL-GUAR-RED-PCT     TO WS-8000-FIELD-NAME1
           MOVE WS-2390-GUARANTEE-RED-PCT-X TO WS-8000-BAD-DATA1
           STRING WS-2390-PP-REDUCTION1-X
               DELIMITED BY SIZE ' OR '
               DELIMITED BY SIZE WS-2390-PP-REDUCTION2-X
               DELIMITED BY SIZE INTO WS-8000-CORR-DATA1
           END-STRING
           PERFORM 8000-RECORD-TRAN-ERROR
              THRU 8000-RECORD-TRAN-ERROR-EXIT.


       2390-CHECK-PP-REDUCTION-EXIT.
           EXIT.
