
      ***************************************************************
      * File:      IF2480.CBL
      * Author:    Mike Ray
      * Date:      11/08/95
      * Purpose:   Calculates Producer Premium factor and price
      *            election %.
      ***************************************************************

       2480-CALC-SUBSIDY.

      $IF DEBUG-SW DEFINED
           DISPLAY '2480-CALCULATING SUBSIDY % OR AMOUNT'
           UPON CONSOLE
      $END


      *****************************************************
      *    INITIALIZE LOCAL AND OUTPUT VARIABLES          *
      *****************************************************
           INITIALIZE WS-2480-LOCAL
           INITIALIZE WS-2480-OUTPUT

      *****************************************************
      *    CHECK PRE-CONDITIONS                           *
      *****************************************************
           IF ERROR-CVG-LVL-PCT = WS-LITERAL-YES
              OR ERROR-INSUR-PLAN-CD = WS-LITERAL-YES
              OR ERROR-DOLLAR-AMT-INSUR = WS-LITERAL-YES
              OR ERROR-PRICE-ELECTION = WS-LITERAL-YES
              OR ERROR-RATE-STATE = WS-LITERAL-YES
              OR ERROR-RATE-COUNTY = WS-LITERAL-YES
              OR ERROR-CROP-CD = WS-LITERAL-YES
              OR ERROR-PRACTICE-CD = WS-LITERAL-YES
              OR ERROR-CROP-TYPE = WS-LITERAL-YES
              OR ERROR-RATE-CLASS = WS-LITERAL-YES
              OR ERROR-MAP-AREA = WS-LITERAL-YES
              OR ERROR-CROP-YR = WS-LITERAL-YES
              OR ERROR-QUOTA = WS-LITERAL-YES
              OR ERROR-CVG-FL = WS-LITERAL-YES
              MOVE WS-LITERAL-YES TO ERROR-PROD-PREM
              GO TO 2480-CALC-SUBSIDY-EXIT
           END-IF

           IF CAT-COVERAGE
             IF WS-2480-INS-PLAN-CD = WS-LITERAL-ARC
                MOVE 30 TO WS-2480-COVERAGE-LVL-PCT
                MOVE 100 TO WS-2480-PRICE-ELECTION
             ELSE
                MOVE 50 TO WS-2480-COVERAGE-LVL-PCT
                MOVE ZEROS TO WS-2480-PRICE-ELECTION
             END-IF
           END-IF

           IF WS-2480-COVERAGE-LVL-PCT IS NOT NUMERIC
              MOVE WS-LITERAL-YES TO ERROR-PROD-PREM
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE 'WS-2480-COVERAGE-LVL-PCT' TO WS-8000-FIELD-NAME1
              MOVE 'NOT NUMERIC' TO WS-8000-BAD-DATA1
              MOVE 'SHOULD HAVE BEEN TRAPPED BY FV'
                TO WS-8000-CORR-DATA1
              MOVE 2480 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-2480-PRICE-ELECTION IS NOT NUMERIC
              MOVE WS-LITERAL-YES TO ERROR-PROD-PREM
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE 'WS-2480-PRICE-ELECTION' TO WS-8000-FIELD-NAME1
              MOVE 'NOT NUMERIC' TO WS-8000-BAD-DATA1
              MOVE 'SHOULD HAVE BEEN TRAPPED BY FV'
                TO WS-8000-CORR-DATA1
              MOVE 2480 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-2480-CROP-YEAR IS NOT NUMERIC
              MOVE WS-LITERAL-YES TO ERROR-PROD-PREM
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE 'WS-2480-CROP-YR' TO WS-8000-FIELD-NAME1
              MOVE 'NOT NUMERIC' TO WS-8000-BAD-DATA1
              MOVE 'SHOULD HAVE BEEN TRAPPED BY FV'
                TO WS-8000-CORR-DATA1
              MOVE 2480 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-2480-STATE-CD IS NOT NUMERIC
              MOVE WS-LITERAL-YES TO ERROR-PROD-PREM
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE 'WS-2480-STATE-CD' TO WS-8000-FIELD-NAME1
              MOVE 'NOT NUMERIC' TO WS-8000-BAD-DATA1
              MOVE 'SHOULD HAVE BEEN TRAPPED BY FV'
                TO WS-8000-CORR-DATA1
              MOVE 2480 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-2480-COUNTY-CD IS NOT NUMERIC
              MOVE WS-LITERAL-YES TO ERROR-PROD-PREM
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE 'WS-2480-COUNTY-CD' TO WS-8000-FIELD-NAME1
              MOVE 'NOT NUMERIC' TO WS-8000-BAD-DATA1
              MOVE 'SHOULD HAVE BEEN TRAPPED BY FV'
                TO WS-8000-CORR-DATA1
              MOVE 2480 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-2480-TYPE-CD = ZEROS
              MOVE 997 TO WS-2480-TYPE-CD
           END-IF

           IF ERROR-PROD-PREM = WS-LITERAL-YES
              GO TO 2480-CALC-SUBSIDY-EXIT
           END-IF

      *****************************************************
      *    CALCULATION FOR INCOME PROTECTION              *
      *****************************************************
           IF WS-2480-INS-PLAN-CD = WS-LITERAL-IP
              PERFORM 2480-CALC-IP-SUBSIDY
                 THRU 2480-CALC-IP-SUBSIDY-EXIT
              GO TO 2480-CALC-SUBSIDY-EXIT
           END-IF

      *****************************************************
      *    CALCULATION FOR REVENUE ASSURANCE              *
      *****************************************************
           IF WS-2480-INS-PLAN-CD = WS-LITERAL-RA
              IF ERROR-REVENUE-CVG-LVL = WS-LITERAL-YES
                 MOVE WS-LITERAL-YES TO ERROR-PROD-PREM
                 GO TO 2480-CALC-SUBSIDY-EXIT
              END-IF

              COMPUTE WS-2480-RA-SUBSIDY-FACTOR ROUNDED =
                 2.965 -
                 (0.0574 * WS-2480-REVENUE-CVG-LEVEL-PCT * 100) +
                 (0.00028 *
                 (WS-2480-REVENUE-CVG-LEVEL-PCT * 100) ** 2)
                 ON SIZE ERROR
                    MOVE 2480 TO WS-8020-PARAGRAPH-NO
                    MOVE 90017 TO WS-8020-INT-ERROR-NO
                    MOVE 'RA SUBS FCTR' TO WS-8020-FIELD-NAME
                    MOVE SPACES TO WS-8020-BAD-DATA
                    MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                    PERFORM 8020-RECORD-INT-ERROR
                       THRU 8020-RECORD-INT-ERROR-EXIT
              END-COMPUTE

      $IF DEBUG-SW DEFINED
              MOVE WS-2480-RA-SUBSIDY-FACTOR
                TO WS-2480-RA-SUBSIDY-FACTOR-X
              DISPLAY 'RA SUBSIDY FACTOR = ',
              WS-2480-RA-SUBSIDY-FACTOR-X
              UPON CONSOLE
      $END

      *       *** SET UP FIELDS TO ALLOW CORRECT CALCULATION OF THE
      *       *** 65/100 SUBSIDY FACTOR
              MOVE 65 TO WS-2480-COVERAGE-LVL-PCT
           END-IF

      *****************************************************
      *         CALCULATION FOR GRP                       *
      *****************************************************
           IF WS-2480-INS-PLAN-CD = WS-LITERAL-GRP
              IF ERROR-REPORTED-ACRES = WS-LITERAL-YES OR
                 ERROR-INSURED-SHARE = WS-LITERAL-YES
                 MOVE WS-LITERAL-YES TO ERROR-PROD-PREM
                 GO TO 2480-CALC-SUBSIDY-EXIT
              END-IF

              MOVE WS-2480-REPORTED-ACRES
                TO WS-2480-REPORTED-ACRES-X
              MOVE WS-2480-INS-SHARE
                TO WS-2480-INS-SHARE-X
              PERFORM 2480-CALC-GRP-SUBSIDY
                 THRU 2480-CALC-GRP-SUBSIDY-EXIT
              GO TO 2480-CALC-SUBSIDY-EXIT
           END-IF

      *****************************************************
      *    CALCULATE PRICE ELECTION PERCENT               *
      *****************************************************
           IF (WS-2480-CROP-CD = WS-LITERAL-POTATOES AND
               WS-2480-TYPE-PRACTICE-OPTION = 'CS')
                   move 100 to ws-2480-price-election-pct
           else
              PERFORM 2480-CALC-PRICE-ELECT-PCT
                 THRU 2480-CALC-PRICE-ELECT-PCT-EXIT
           end-if

      $IF DEBUG-SW DEFINED
           DISPLAY 'PRICE ELECTION % = ', WS-2480-PRICE-ELECTION-PCT
           UPON CONSOLE
      $END
           IF ERROR-PROD-PREM = WS-LITERAL-YES
              GO TO 2480-CALC-SUBSIDY-EXIT
           END-IF

      *****************************************************
      *    CALCULATE SUBSIDY FACTOR                       *
      *****************************************************
           PERFORM 2480-CALC-SUBSIDY-FCTR
              THRU 2480-CALC-SUBSIDY-FCTR-EXIT
           IF ERROR-PROD-PREM = WS-LITERAL-YES
              GO TO 2480-CALC-SUBSIDY-EXIT
           END-IF.



       2480-CALC-SUBSIDY-EXIT.
           EXIT.



      *========================================================*
      *    PRICE ELECTION % CALCULATIONS                       *
      *========================================================*

       2480-CALC-PRICE-ELECT-PCT.

      $IF DEBUG-SW DEFINED
           DISPLAY '2480-CALCULATING PRICE ELECTION %'
           UPON CONSOLE
      $END

      *****************************************************
      *    CAT COVERAGE IS ALWAYS 60% PRICE ELECTION      *
      *****************************************************
           IF CAT-COVERAGE
              MOVE 60 TO WS-2480-PRICE-ELECTION-PCT
              GO TO 2480-CALC-PRICE-ELECT-PCT-EXIT
           END-IF

      *****************************************************
      *    CRC COVERAGE IS ALWAYS 100% PRICE ELECTION     *
      *     IP COVERAGE IS ALWAYS 100% PRICE ELECTION     *
      *****************************************************
           IF WS-2480-INS-PLAN-CD = WS-LITERAL-CRC OR
              WS-2480-INS-PLAN-CD = WS-LITERAL-IP OR
              WS-2480-INS-PLAN-CD = WS-LITERAL-FLORIDA-FRUIT OR
              WS-2480-INS-PLAN-CD = WS-LITERAL-RA
              MOVE 100 TO WS-2480-PRICE-ELECTION-PCT
              GO TO 2480-CALC-PRICE-ELECT-PCT-EXIT
           END-IF

      *****************************************************
      *    DOLLAR CROPS CALCULATION                       *
      *****************************************************

           IF WS-2480-INS-PLAN-CD = WS-LITERAL-DOLLAR-AMT
              EVALUATE WS-2480-CROP-CD
      *        *** RAISINS ARE ALWAYS 100% PRICE ELECTION
               WHEN WS-LITERAL-RAISINS
                  MOVE 100 TO WS-2480-PRICE-ELECTION-PCT
      *        *** NURSERY ALWAYS 100% PRICE ELECTION
               WHEN WS-LITERAL-NURSERY
                  MOVE 100 TO WS-2480-PRICE-ELECTION-PCT
               WHEN OTHER
                  IF WS-2480-ADM-DOLLAR-AMT-INS = ZEROS
                     MOVE WS-LITERAL-YES TO ERROR-PROD-PREM
                     MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
                     MOVE 042 TO WS-8000-SHORT-ERROR
                     MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
                     MOVE 'WS-2480-ADM-DOLLAR-AMT-INS'
                       TO WS-8000-FIELD-NAME1
                     MOVE ZEROS TO WS-8000-BAD-DATA1
                     MOVE '> ZERO'
                       TO WS-8000-CORR-DATA1
                     MOVE 2480 TO WS-8000-PARAGRAPH-NO
                     PERFORM 8000-RECORD-TRAN-ERROR
                        THRU 8000-RECORD-TRAN-ERROR-EXIT
                     GO TO 2480-CALC-PRICE-ELECT-PCT-EXIT
                  END-IF

                  IF WS-2480-CROP-CD = WS-LITERAL-CITRUS-TREES-I OR
                     WS-2480-CROP-CD = WS-LITERAL-CITRUS-TREES-II OR
                     WS-2480-CROP-CD = WS-LITERAL-CITRUS-TREES-III OR
                     WS-2480-CROP-CD = WS-LITERAL-CITRUS-TREES-IV OR
                     WS-2480-CROP-CD = WS-LITERAL-CITRUS-TREES-V
                     MULTIPLY WS-T11-PERCENT-ELECTION BY 100
                       GIVING WS-2480-PRICE-ELECTION-PCT
                     GO TO 2480-CALC-PRICE-ELECT-PCT-EXIT
                  END-IF

      *           *** RECALCULATE $AMT IN WHOLE CENT FOR SELECTIVE
      *           *** COVERAGE LEVEL. NEEDED TO DETERMINE THE CORRECT
      *           *** PRICE ELECTION PERCENTAGE. (09/24/97) KT.......
                  COMPUTE WS-2480-CALC-DOLLAR-AMT-INS ROUNDED =
                         (WS-2480-COVERAGE-LVL-PCT * .01) *
                          WS-2480-ADM-DOLLAR-AMT-INS
                  ON SIZE ERROR
                     MOVE 2480 TO WS-8020-PARAGRAPH-NO
                     MOVE 90017 TO WS-8020-INT-ERROR-NO
                     MOVE '$AMT/REF $AMT' TO WS-8020-FIELD-NAME
                     MOVE SPACES TO WS-8020-BAD-DATA
                     MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                     PERFORM 8020-RECORD-INT-ERROR
                        THRU 8020-RECORD-INT-ERROR-EXIT
                  END-COMPUTE

                  IF WS-2480-DOLLAR-AMT-INS NOT =
                     WS-2480-CALC-DOLLAR-AMT-INS AND
                     WS-2480-DOLLAR-AMT-INS =
                     WS-2480-CALC-DOLLAR-AMT-WHOLE

                     COMPUTE WS-2480-PRICE-ELECTION-PCT ROUNDED =
                            (WS-2480-CALC-DOLLAR-AMT-INS /
                            (WS-2480-COVERAGE-LVL-PCT * .01)) /
                             WS-2480-ADM-DOLLAR-AMT-INS * 100
                        ON SIZE ERROR
                           MOVE 2480 TO WS-8020-PARAGRAPH-NO
                           MOVE 90017 TO WS-8020-INT-ERROR-NO
                           MOVE '$AMT% / CVG%' TO WS-8020-FIELD-NAME
                           MOVE SPACES TO WS-8020-BAD-DATA
                           MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                           PERFORM 8020-RECORD-INT-ERROR
                           THRU 8020-RECORD-INT-ERROR-EXIT
                     END-COMPUTE
                  ELSE
                     COMPUTE WS-2480-PRICE-ELECTION-PCT ROUNDED =
                            (WS-2480-DOLLAR-AMT-INS /
                            (WS-2480-COVERAGE-LVL-PCT * .01)) /
                             WS-2480-ADM-DOLLAR-AMT-INS * 100
                        ON SIZE ERROR
                           MOVE 2480 TO WS-8020-PARAGRAPH-NO
                           MOVE 90017 TO WS-8020-INT-ERROR-NO
                           MOVE '$AMT% / CVG%' TO WS-8020-FIELD-NAME
                           MOVE SPACES TO WS-8020-BAD-DATA
                           MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                           PERFORM 8020-RECORD-INT-ERROR
                              THRU 8020-RECORD-INT-ERROR-EXIT
                     END-COMPUTE
                  END-IF
                  IF WS-2480-PRICE-ELECTION-PCT > 100
                     MOVE 100 TO WS-2480-PRICE-ELECTION-PCT
                  END-IF
              END-EVALUATE

      $IF DEBUG-SW DEFINED
           DISPLAY 'PRICE ELECTION  % = ', WS-2480-PRICE-ELECTION-PCT
           UPON CONSOLE
      $END
              GO TO 2480-CALC-PRICE-ELECT-PCT-EXIT
           END-IF

      *****************************************************
      *    OTHER CROPS CALCULATION                        *
      *****************************************************

           if (ws-2480-crop-cd = ws-literal-dry-beans
               and ws-2480-type-cd = '062')
                   continue
           else
               PERFORM 2480-LOOKUP-PRICE
                   THRU 2480-LOOKUP-PRICE-EXIT
           end-if

           IF ERROR-PROD-PREM = WS-LITERAL-YES
              GO TO 2480-CALC-PRICE-ELECT-PCT-EXIT
           END-IF

           if ws-7520-contract-price-code = 'CP'
              or ws-2480-type-cd = '062'
              compute WS-2480-PRICE-ELECTION-PCT =
                  WS-T11-PERCENT-ELECTION * 100
              go to 2480-CALC-price-elect-pct-exit
           end-if

           COMPUTE WS-2480-PRICE-ELECTION-PCT ROUNDED =
              ((WS-2480-PRICE-ELECTION / WS-2480-MARKET-PRICE)
              * 100)
           ON SIZE ERROR
              MOVE 2480 TO WS-8020-PARAGRAPH-NO
              MOVE 90017 TO WS-8020-INT-ERROR-NO
              MOVE 'PRICE EL/MKT PRICE' TO WS-8020-FIELD-NAME
              MOVE SPACES TO WS-8020-BAD-DATA
              MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
              PERFORM 8020-RECORD-INT-ERROR
                 THRU 8020-RECORD-INT-ERROR-EXIT
           END-COMPUTE.


      $IF DEBUG-SW DEFINED
           DISPLAY 'PRICE ELECTION  % = ', WS-2480-PRICE-ELECTION-PCT
           UPON CONSOLE.
      $END

       2480-CALC-PRICE-ELECT-PCT-EXIT.
           EXIT.


       2480-LOOKUP-PRICE.

      *****************************************************
      *    LOOKUP HIGH PRICE FOR CROP                     *
      *****************************************************
           INITIALIZE WS-7520-INPUT-KEY
           MOVE WS-2480-CROP-YEAR TO WS-7520-INPUT-CROP-YR
           MOVE WS-2480-STATE-CD TO WS-7520-INPUT-STATE-CD
           MOVE WS-2480-COUNTY-CD TO WS-7520-INPUT-COUNTY-CD
           MOVE WS-2480-CROP-CD TO WS-7520-INPUT-CROP-CD
           MOVE WS-2480-INS-PLAN-CD
             TO WS-7520-INPUT-INSURANCE-PLAN
           MOVE WS-2480-PRACTICE-CD TO WS-7520-INPUT-PRACTICE-CD
           MOVE WS-2480-TYPE-CD TO WS-7520-INPUT-TYPE-CD
           EVALUATE WS-2480-CROP-CD
               WHEN WS-LITERAL-PEANUTS
      *           HOW DO YOU KNOW IF PEANUTS ARE QUOTA?
      *           CHECK PEANUT QUOTA FIELD
                  IF WS-2480-PEANUT-QUOTA IS NOT NUMERIC
      *              ** NOT QUOTA
      *              MOVE 002 TO WS-7520-INPUT-INDEX
                     MOVE 000 TO WS-7520-INPUT-INDEX
                  ELSE
                     IF WS-2480-PEANUT-QUOTA > ZEROS
      *              ** QUOTA
      *                 MOVE 001 TO WS-7520-INPUT-INDEX
                        MOVE 000 TO WS-7520-INPUT-INDEX
                     ELSE
      *              ** NOT QUOTA
      *                 MOVE 002 TO WS-7520-INPUT-INDEX
                        MOVE 000 TO WS-7520-INPUT-INDEX
                     END-IF
                  END-IF

               WHEN WS-LITERAL-GRAPES
                  IF WS-2480-STATE-CD = WS-LITERAL-CALIFORNIA
                     IF WS-2480-TYPE-CD = '071'
                        OR WS-2480-TYPE-CD = '072'
                        OR (WS-2480-TYPE-CD = '073'
                       AND WS-2480-STATE-CD = WS-LITERAL-TEXAS)
      *                ASSUME 001 IS THE CORRECT PRICE INDEX TO USE
                       MOVE 001 TO WS-7520-INPUT-INDEX
                     ELSE
                        IF WS-2480-CRUSH-DISTRICT NUMERIC
                           MOVE WS-2480-CRUSH-DISTRICT
                             TO WS-2480-CRUSH-DISTRICT-9
                           MOVE WS-2480-CRUSH-DISTRICT-9
                             TO WS-7520-INPUT-INDEX
                        ELSE
                           MOVE 11002 TO WS-8000-ERROR-CODE
                           MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                           MOVE WS-LITERAL-CRUSH-DISTRICT
                             TO WS-8000-FIELD-NAME1
                           MOVE WS-2480-CRUSH-DISTRICT
                             TO WS-8000-BAD-DATA1
                           MOVE 2480 TO WS-8000-PARAGRAPH-NO
                           PERFORM 8000-RECORD-TRAN-ERROR
                              THRU 8000-RECORD-TRAN-ERROR-EXIT
                           GO TO 2480-LOOKUP-PRICE-EXIT
                        END-IF
                     END-IF
                  ELSE
                     MOVE ZEROS TO WS-7520-INPUT-INDEX
                  END-IF
               WHEN OTHER
                  MOVE ZEROS TO WS-7520-INPUT-INDEX
           END-EVALUATE
           PERFORM 7520-LOOKUP-ADM4
              THRU 7520-LOOKUP-ADM4-EXIT

           IF MATCH-FOUND-7520
            if ws-7520-contract-price-code = 'CP'
               go to 2480-LOOKUP-PRICE-EXIT
            end-if
              MOVE ZEROS TO WS-2480-MARKET-PRICE
      *       ** PRICE 03 = MARKET PRICE FOR APH CROPS
      *       ** price 04 & 05 quota & non-quota peanuts
      *       ** PRICE 08 = SPRING MARKET PRICE FOR CRC/IP
      *       ** PRICE 09 = HARVEST MARKET PRICE FOR CRC/IP
              EVALUATE WS-2480-INS-PLAN-CD
               WHEN WS-LITERAL-IP
               WHEN WS-LITERAL-CRC
               when ws-literal-peanuts-plan
               when ws-literal-quota-tobacco
                  MOVE WS-LITERAL-NO
                    TO WS-2480-APH-CROP-FLAG
               WHEN OTHER
                  MOVE WS-LITERAL-YES
                    TO WS-2480-APH-CROP-FLAG
              END-EVALUATE

              IF WS-2480-APH-CROP-FLAG = WS-LITERAL-YES

      *----------Price acception for Malt Barley option A and B
                 IF WS-2480-CROP-CD = WS-LITERAL-BARLEY
                    EVALUATE WS-T11-TYPE-PRAC-OPT-CD
                       WHEN WS-LITERAL-MALT-BARLEY-OPT-A
                          MOVE 0.50 TO WS-2480-MARKET-PRICE

                          GO TO 2480-LOOKUP-PRICE-EXIT

                       WHEN WS-LITERAL-MALT-BARLEY-OPT-B
                          MULTIPLY WS-T11-PRICE-ELECTION
                                BY WS-T11-PERCENT-ELECTION
                            GIVING WS-2480-PRICE-ELECTION ROUNDED
                          MOVE WS-T11-PRICE-ELECTION
                            TO WS-2480-MARKET-PRICE

                          GO TO 2480-LOOKUP-PRICE-EXIT
                    END-EVALUATE
                 END-IF

                 IF WS-7520-CAT-PRICE > WS-2480-MARKET-PRICE
                    MOVE WS-7520-CAT-PRICE
                      TO WS-2480-MARKET-PRICE
                 ELSE
                    MOVE WS-LITERAL-YES TO ERROR-PROD-PREM
                    MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
                    MOVE 009 TO WS-8000-SHORT-ERROR
                    MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                    MOVE 'ADM4 CAT PRICE'
                      TO WS-8000-FIELD-NAME1
                    MOVE ZEROS TO WS-8000-BAD-DATA1
                    MOVE '> ZERO'
                      TO WS-8000-CORR-DATA1
                    MOVE 2480 TO WS-8000-PARAGRAPH-NO
                    PERFORM 8000-RECORD-TRAN-ERROR
                       THRU 8000-RECORD-TRAN-ERROR-EXIT
                    GO TO 2480-LOOKUP-PRICE-EXIT
                 END-IF

                 IF WS-7520-ESTABLISHED-HIGH-PRICE
                    > WS-2480-MARKET-PRICE
                    MOVE WS-7520-ESTABLISHED-HIGH-PRICE
                      TO WS-2480-MARKET-PRICE
                 END-IF

                 IF WS-7520-MARKET-PRICE > WS-2480-MARKET-PRICE
                    MOVE WS-7520-MARKET-PRICE
                      TO WS-2480-MARKET-PRICE
                 ELSE
                    GO TO 2480-LOOKUP-PRICE-EXIT
                 END-IF
              ELSE
      *          **** THIS IS A CRC OR IP or peanuts CROP ***
      ***************************************************************
      ********  MODIFICATION FOR 1997  ******************************
      ***************************************************************

                 EVALUATE WS-2480-INS-PLAN-CD 
                  when ws-literal-quota-tobacco

                   IF WS-7520-SUPPORT-PRICE > WS-2480-MARKET-PRICE
                      MOVE WS-7520-SUPPORT-PRICE
                        TO WS-2480-MARKET-PRICE
                   ELSE
                      MOVE WS-LITERAL-YES TO ERROR-PROD-PREM
                      MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
                      MOVE 009 TO WS-8000-SHORT-ERROR
                      MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                      MOVE 'ADM4 SUPPORT PRICE'
                        TO WS-8000-FIELD-NAME1
                      MOVE ZEROS TO WS-8000-BAD-DATA1
                      MOVE '> ZERO'
                        TO WS-8000-CORR-DATA1
                      MOVE 2480 TO WS-8000-PARAGRAPH-NO
                      PERFORM 8000-RECORD-TRAN-ERROR
                         THRU 8000-RECORD-TRAN-ERROR-EXIT
                      GO TO 2480-LOOKUP-PRICE-EXIT
                   END-IF

                  WHEN WS-LITERAL-IP

                   IF WS-7520-PRE-SALES-PRICE > WS-2480-MARKET-PRICE
                      MOVE WS-7520-PRE-SALES-PRICE
                        TO WS-2480-MARKET-PRICE
                   ELSE
                      MOVE WS-LITERAL-YES TO ERROR-PROD-PREM
                      MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
                      MOVE 009 TO WS-8000-SHORT-ERROR
                      MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                      MOVE 'ADM4 PRE-SALES PRICE'
                        TO WS-8000-FIELD-NAME1
                      MOVE ZEROS TO WS-8000-BAD-DATA1
                      MOVE '> ZERO'
                        TO WS-8000-CORR-DATA1
                      MOVE 2480 TO WS-8000-PARAGRAPH-NO
                      PERFORM 8000-RECORD-TRAN-ERROR
                         THRU 8000-RECORD-TRAN-ERROR-EXIT
                      GO TO 2480-LOOKUP-PRICE-EXIT
                   END-IF
                   IF WS-7520-HARVEST-PRICE > WS-2480-MARKET-PRICE
                      MOVE WS-7520-HARVEST-PRICE
                        TO WS-2480-MARKET-PRICE
                   END-IF

                  WHEN WS-LITERAL-peanuts-plan

                   IF ws-2480-peanut-quota > 0
                      MOVE WS-7520-QUOTA-PRICE
                        TO WS-2480-MARKET-PRICE
                   else
                      MOVE WS-7520-NON-QUOTA-PRICE
                        TO WS-2480-MARKET-PRICE
                   END-IF

                  WHEN WS-LITERAL-CRC
                   IF WS-7520-SPRING-MARKET-PRICE
                      > WS-2480-MARKET-PRICE
                      MOVE WS-7520-SPRING-MARKET-PRICE
                        TO WS-2480-MARKET-PRICE
                   ELSE
                      MOVE WS-LITERAL-YES TO ERROR-PROD-PREM
                      MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
                      MOVE 009 TO WS-8000-SHORT-ERROR
                      MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                      MOVE 'ADM4 SPRING MKT PRICE'
                        TO WS-8000-FIELD-NAME1
                      MOVE ZEROS TO WS-8000-BAD-DATA1
                      MOVE '> ZERO'
                        TO WS-8000-CORR-DATA1
                      MOVE 2480 TO WS-8000-PARAGRAPH-NO
                      PERFORM 8000-RECORD-TRAN-ERROR
                         THRU 8000-RECORD-TRAN-ERROR-EXIT
                      GO TO 2480-LOOKUP-PRICE-EXIT
                   END-IF
                   IF WS-7520-HARVEST-MARKET-PRICE >
                      WS-2480-MARKET-PRICE
                      MOVE WS-7520-HARVEST-MARKET-PRICE
                        TO WS-2480-MARKET-PRICE
                   END-IF
                end-evaluate
              END-IF

           ELSE
              MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
              MOVE 11009 TO WS-8000-ERROR-CODE
              MOVE WS-LITERAL-YES TO ERROR-PROD-PREM
              MOVE 'ADM4 KEY =' TO WS-8000-FIELD-NAME1
              MOVE WS-7520-INPUT-KEY TO WS-8000-BAD-DATA1
              MOVE SPACES TO WS-8000-CORR-DATA1
              MOVE 2480 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF.


       2480-LOOKUP-PRICE-EXIT.
           EXIT.


      *========================================================*
      *    SUBSIDY FACTOR CALCULATIONS                         *
      *========================================================*

       2480-CALC-SUBSIDY-FCTR.

      $IF DEBUG-SW DEFINED
           DISPLAY '2480-CALCULATING SUBSIDY FACTOR'
           UPON CONSOLE
      $END

      *****************************************************
      *    CAT COVERAGE IS ALWAYS 100% SUBSIDY FACTOR     *
      *****************************************************
           IF CAT-COVERAGE
              MOVE ZERO TO WS-2480-SUBSIDY-FACTOR
              GO TO 2480-CALC-SUBSIDY-FCTR-EXIT
           END-IF


      *****************************************************
      *    LOOKUP RATE DIFFERENTIALS FOR CAT & ELECTION   *
      *****************************************************
           PERFORM 2480-FIND-RATE-DIFF
              THRU 2480-FIND-RATE-DIFF-EXIT

           IF ERROR-PROD-PREM = WS-LITERAL-YES
              GO TO 2480-CALC-SUBSIDY-FCTR-EXIT
           END-IF

           IF WS-2480-CAT-RATE-DIFF = ZEROS
              MOVE WS-LITERAL-YES TO ERROR-PROD-PREM
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE 'WS-2480-CAT-RATE-DIFF'
                TO WS-8000-FIELD-NAME1
              MOVE ZEROS TO WS-8000-BAD-DATA1
              MOVE '> ZERO'
                TO WS-8000-CORR-DATA1
              MOVE 2480 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
              GO TO 2480-CALC-SUBSIDY-FCTR-EXIT
           END-IF

           IF WS-2480-ELECT-RATE-DIFF = ZEROS
              MOVE WS-LITERAL-YES TO ERROR-PROD-PREM
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE 'WS-2480-ELECT-RATE-DIFF'
                TO WS-8000-FIELD-NAME1
              MOVE ZEROS TO WS-8000-BAD-DATA1
              MOVE '> ZERO'
                TO WS-8000-CORR-DATA1
              MOVE 2480 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
              GO TO 2480-CALC-SUBSIDY-FCTR-EXIT
           END-IF


      $IF DEBUG-SW DEFINED
           DISPLAY 'COVERAGE LVL % = ', WS-2480-COVERAGE-LVL-PCT
           UPON CONSOLE
      $END

           COMPUTE WS-2480-SUBSIDY-COVERAGE-PCT ROUNDED =
              ((WS-2480-COVERAGE-LVL-PCT / 100)
              * (WS-2480-PRICE-ELECTION-PCT / 100))
              ON SIZE ERROR
                 MOVE 2480 TO WS-8020-PARAGRAPH-NO
                 MOVE 90017 TO WS-8020-INT-ERROR-NO
                 MOVE 'CVG LVL% * PRICE%' TO WS-8020-FIELD-NAME
                 MOVE SPACES TO WS-8020-BAD-DATA
                 MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                 PERFORM 8020-RECORD-INT-ERROR
                    THRU 8020-RECORD-INT-ERROR-EXIT
           END-COMPUTE

      $IF DEBUG-SW DEFINED
           MOVE WS-2480-SUBSIDY-COVERAGE-PCT
             TO WS-2480-SUBSIDY-COVERAGE-PCT-X
           DISPLAY 'CALC SUBSIDY CVG % = ',
           WS-2480-SUBSIDY-COVERAGE-PCT-X
           UPON CONSOLE
      $END

           IF WS-2480-SUBSIDY-COVERAGE-PCT < 0.650
              IF WS-0009-COVERAGE-FLG <> 'L'
                 MOVE WS-LITERAL-YES TO ERROR-PROD-PREM
                 MOVE 11039 TO WS-8000-ERROR-CODE
                 MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                 MOVE WS-LITERAL-CVG-FL TO WS-8000-FIELD-NAME1
                 MOVE WS-0009-COVERAGE-FLG TO WS-8000-BAD-DATA1
                 STRING 'CVG LVL % '
                    DELIMITED BY SIZE WS-2480-COVERAGE-LVL-PCT
                    DELIMITED BY SIZE ' = CVG FLAG "L" '
                    DELIMITED BY SIZE INTO WS-8000-CORR-DATA1
                 END-STRING
                 MOVE 2480 TO WS-8000-PARAGRAPH-NO
                 PERFORM 8000-RECORD-TRAN-ERROR
                    THRU 8000-RECORD-TRAN-ERROR-EXIT
                 GO TO 2480-CALC-SUBSIDY-FCTR-EXIT
              END-IF
      *       ** LIMITED SUBSIDY
              MOVE 0.60 TO WS-2480-SUBSIDY-PRICE-EL-PCT
           ELSE
              IF WS-0009-COVERAGE-FLG <> 'A'
                 MOVE WS-LITERAL-YES TO ERROR-PROD-PREM
                 MOVE 11039 TO WS-8000-ERROR-CODE
                 MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                 MOVE WS-LITERAL-CVG-FL TO WS-8000-FIELD-NAME1
                 MOVE WS-0009-COVERAGE-FLG TO WS-8000-BAD-DATA1
                 STRING 'CVG LVL % '
                    DELIMITED BY SIZE WS-2480-COVERAGE-LVL-PCT
                    DELIMITED BY SIZE ' = CVG FLAG "A" '
                    DELIMITED BY SIZE INTO WS-8000-CORR-DATA1
                 END-STRING
                 MOVE 2480 TO WS-8000-PARAGRAPH-NO
                 PERFORM 8000-RECORD-TRAN-ERROR
                    THRU 8000-RECORD-TRAN-ERROR-EXIT
                 GO TO 2480-CALC-SUBSIDY-FCTR-EXIT
              END-IF
      *       ** MAXIMUM SUBSIDY
              MOVE 0.75 TO WS-2480-SUBSIDY-PRICE-EL-PCT
           END-IF

      $IF DEBUG-SW DEFINED
           IF WS-2480-SUBSIDY-PRICE-EL-PCT = 0.60
              DISPLAY 'LIMITED SUBSIDY (60%)'
              UPON CONSOLE
           ELSE
              DISPLAY 'MAXIMUM SUBSIDY (75%)'
              UPON CONSOLE
           END-IF
      $END

           COMPUTE WS-2480-SUBSIDY-FACTOR ROUNDED =
              (0.5 * WS-2480-SUBSIDY-PRICE-EL-PCT
               * WS-2480-CAT-RATE-DIFF) /
              ((WS-2480-COVERAGE-LVL-PCT / 100)
              * (WS-2480-PRICE-ELECTION-PCT / 100)
              * WS-2480-ELECT-RATE-DIFF)
              ON SIZE ERROR
                 MOVE 2480 TO WS-8020-PARAGRAPH-NO
                 MOVE WS-LITERAL-YES TO ERROR-PROD-PREM
                 MOVE 90017 TO WS-8020-INT-ERROR-NO
                 MOVE 'SUBSIDY FCTR' TO WS-8020-FIELD-NAME
                 MOVE SPACES TO WS-8020-BAD-DATA
                 MOVE WS-LITERAL-NO TO WS-8020-ABORT-PROGRAM
                 PERFORM 8020-RECORD-INT-ERROR
                    THRU 8020-RECORD-INT-ERROR-EXIT
           END-COMPUTE

           IF WS-2480-SUBSIDY-FACTOR = 1.000
              MOVE WS-LITERAL-YES TO ERROR-PROD-PREM
              MOVE 11092 TO WS-8000-ERROR-CODE
              MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-CVG-FL
                TO WS-8000-FIELD-NAME1
              MOVE WS-0009-COVERAGE-FLG
                TO WS-8000-BAD-DATA1
              STRING 'CVG LVL % '
               DELIMITED BY SIZE
               WS-2480-COVERAGE-LVL-PCT
               DELIMITED BY SIZE
               ' PRICE ELECTION % '
               DELIMITED BY SIZE
               WS-2480-PRICE-ELECTION-PCT
               DELIMITED BY SIZE
               INTO WS-8000-CORR-DATA1
              END-STRING
              MOVE 2480 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF.

      $IF DEBUG-SW DEFINED
           MOVE WS-2480-SUBSIDY-FACTOR TO WS-2480-SUBSIDY-FACTOR-X
           DISPLAY 'SUBSIDY FACTOR = ', WS-2480-SUBSIDY-FACTOR-X
           UPON CONSOLE.
      $END


       2480-CALC-SUBSIDY-FCTR-EXIT.
           EXIT.


       2480-FIND-RATE-DIFF.

           INITIALIZE WS-7510-INPUT-KEY
           MOVE WS-2480-CROP-CD TO WS-7510-INPUT-CROP-CD
      *    *** SOME INSURANCE PLANS DO NOT HAVE THEIR OWN RATE
      *    *** FACTORS IN ADM2; THEY USE APH RATE FACTORS
           EVALUATE WS-2480-INS-PLAN-CD
               WHEN WS-LITERAL-CRC
                  MOVE WS-LITERAL-APH
                    TO WS-7510-INPUT-INSURANCE-PLAN
               WHEN OTHER
                  MOVE WS-2480-INS-PLAN-CD
                    TO WS-7510-INPUT-INSURANCE-PLAN
           END-EVALUATE
           MOVE WS-2480-CROP-YEAR TO WS-7510-INPUT-CROP-YR
           MOVE WS-2480-STATE-CD TO WS-7510-INPUT-STATE-CD
           MOVE WS-2480-COUNTY-CD TO WS-7510-INPUT-COUNTY-CD
           MOVE WS-2480-PRACTICE-CD TO WS-7510-INPUT-PRACTICE-CD
           MOVE WS-2480-TYPE-CD TO WS-7510-INPUT-TYPE-CD
      *    *** SET UP ERROR STRING IN CASE ADM2 NOT FOUND
           STRING 'ADM2 KEY = '
               DELIMITED BY SIZE
               WS-7510-INPUT-KEY
               DELIMITED BY SIZE
               INTO WS-8000-CORR-DATA1
           END-STRING
           PERFORM 7510-LOOKUP-ADM2
              THRU 7510-LOOKUP-ADM2-EXIT

           IF MATCH-FOUND-7510
      *       *** CLEAR THE ERROR SET ABOVE
              if WS-2480-INS-PLAN-CD = WS-LITERAL-RA
                 move 1 to WS-2480-CAT-RATE-DIFF
                 move 1 to WS-2480-ELECT-RATE-DIFF
                 go to 2480-FIND-RATE-DIFF-EXIT
              else
                 MOVE SPACES TO WS-8000-CORR-DATA1
              end-if
      *       *** find Rate Differential for CAT coverage level (50)
              EVALUATE 50
               WHEN WS-7510-COVERAGE-LVL1
                 MOVE WS-7510-RATE-DIFFERENTIAL1
                   TO WS-2480-CAT-RATE-DIFF
               WHEN WS-7510-COVERAGE-LVL2
                 MOVE WS-7510-RATE-DIFFERENTIAL2
                   TO WS-2480-CAT-RATE-DIFF
               WHEN WS-7510-COVERAGE-LVL3
                 MOVE WS-7510-RATE-DIFFERENTIAL3
                   TO WS-2480-CAT-RATE-DIFF
               WHEN WS-7510-COVERAGE-LVL4
                 MOVE WS-7510-RATE-DIFFERENTIAL4
                   TO WS-2480-CAT-RATE-DIFF
               WHEN WS-7510-COVERAGE-LVL5
                 MOVE WS-7510-RATE-DIFFERENTIAL5
                   TO WS-2480-CAT-RATE-DIFF
               WHEN WS-7510-COVERAGE-LVL6
                 MOVE WS-7510-RATE-DIFFERENTIAL6
                   TO WS-2480-CAT-RATE-DIFF
               WHEN WS-7510-COVERAGE-LVL7
                 MOVE WS-7510-RATE-DIFFERENTIAL7
                   TO WS-2480-CAT-RATE-DIFF
               WHEN WS-7510-COVERAGE-LVL8
                 MOVE WS-7510-RATE-DIFFERENTIAL8
                   TO WS-2480-CAT-RATE-DIFF
               WHEN WS-7510-COVERAGE-LVL9
                 MOVE WS-7510-RATE-DIFFERENTIAL9
                   TO WS-2480-CAT-RATE-DIFF
               WHEN WS-7510-COVERAGE-LVL10
                 MOVE WS-7510-RATE-DIFFERENTIAL10
                   TO WS-2480-CAT-RATE-DIFF
               WHEN WS-7510-COVERAGE-LVL11
                 MOVE WS-7510-RATE-DIFFERENTIAL11
                   TO WS-2480-CAT-RATE-DIFF
               WHEN WS-7510-COVERAGE-LVL12
                 MOVE WS-7510-RATE-DIFFERENTIAL12
                   TO WS-2480-CAT-RATE-DIFF
               WHEN WS-7510-COVERAGE-LVL13
                 MOVE WS-7510-RATE-DIFFERENTIAL13
                   TO WS-2480-CAT-RATE-DIFF
               WHEN WS-7510-COVERAGE-LVL14
                 MOVE WS-7510-RATE-DIFFERENTIAL14
                   TO WS-2480-CAT-RATE-DIFF
               WHEN WS-7510-COVERAGE-LVL15
                 MOVE WS-7510-RATE-DIFFERENTIAL15
                   TO WS-2480-CAT-RATE-DIFF
               WHEN WS-7510-COVERAGE-LVL16
                 MOVE WS-7510-RATE-DIFFERENTIAL16
                   TO WS-2480-CAT-RATE-DIFF
               WHEN OTHER
                 MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                 MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
                 MOVE 015 TO WS-8000-SHORT-ERROR
                 MOVE WS-LITERAL-YES TO ERROR-PROD-PREM
                 MOVE 'PRICE ELECTION %' TO WS-8000-FIELD-NAME1
                 MOVE '50' TO WS-8000-BAD-DATA1
                 MOVE SPACES TO WS-8000-CORR-DATA1
                 MOVE 2480 TO WS-8000-PARAGRAPH-NO
                 PERFORM 8000-RECORD-TRAN-ERROR
                    THRU 8000-RECORD-TRAN-ERROR-EXIT
                 GO TO 2480-FIND-RATE-DIFF-EXIT
              END-EVALUATE

      $IF DEBUG-SW DEFINED
           DISPLAY 'CAT RATE DIFFERENTIAL = ', WS-2480-CAT-RATE-DIFF
           UPON CONSOLE
           DISPLAY 'COVERAGE LEVEL PCT    = ',
           WS-2480-COVERAGE-LVL-PCT UPON CONSOLE
      $END
      *       *** find Rate Differential for submitted coverage level
              EVALUATE WS-2480-COVERAGE-LVL-PCT
                WHEN WS-7510-COVERAGE-LVL1
                  MOVE WS-7510-RATE-DIFFERENTIAL1
                    TO WS-2480-ELECT-RATE-DIFF
                WHEN WS-7510-COVERAGE-LVL2
                  MOVE WS-7510-RATE-DIFFERENTIAL2
                    TO WS-2480-ELECT-RATE-DIFF
                WHEN WS-7510-COVERAGE-LVL3
                  MOVE WS-7510-RATE-DIFFERENTIAL3
                    TO WS-2480-ELECT-RATE-DIFF
                WHEN WS-7510-COVERAGE-LVL4
                  MOVE WS-7510-RATE-DIFFERENTIAL4
                    TO WS-2480-ELECT-RATE-DIFF
                WHEN WS-7510-COVERAGE-LVL5
                  MOVE WS-7510-RATE-DIFFERENTIAL5
                    TO WS-2480-ELECT-RATE-DIFF
                WHEN WS-7510-COVERAGE-LVL6
                  MOVE WS-7510-RATE-DIFFERENTIAL6
                    TO WS-2480-ELECT-RATE-DIFF
                WHEN WS-7510-COVERAGE-LVL7
                  MOVE WS-7510-RATE-DIFFERENTIAL7
                    TO WS-2480-ELECT-RATE-DIFF
                WHEN WS-7510-COVERAGE-LVL8
                  MOVE WS-7510-RATE-DIFFERENTIAL8
                    TO WS-2480-ELECT-RATE-DIFF
                WHEN WS-7510-COVERAGE-LVL9
                  MOVE WS-7510-RATE-DIFFERENTIAL9
                    TO WS-2480-ELECT-RATE-DIFF
                WHEN WS-7510-COVERAGE-LVL10
                  MOVE WS-7510-RATE-DIFFERENTIAL10
                    TO WS-2480-ELECT-RATE-DIFF
                WHEN WS-7510-COVERAGE-LVL11
                  MOVE WS-7510-RATE-DIFFERENTIAL11
                    TO WS-2480-ELECT-RATE-DIFF
                WHEN WS-7510-COVERAGE-LVL12
                  MOVE WS-7510-RATE-DIFFERENTIAL12
                    TO WS-2480-ELECT-RATE-DIFF
                WHEN WS-7510-COVERAGE-LVL13
                  MOVE WS-7510-RATE-DIFFERENTIAL13
                    TO WS-2480-ELECT-RATE-DIFF
                WHEN WS-7510-COVERAGE-LVL14
                  MOVE WS-7510-RATE-DIFFERENTIAL14
                    TO WS-2480-ELECT-RATE-DIFF
                WHEN WS-7510-COVERAGE-LVL15
                  MOVE WS-7510-RATE-DIFFERENTIAL15
                    TO WS-2480-ELECT-RATE-DIFF
                WHEN WS-7510-COVERAGE-LVL16
                  MOVE WS-7510-RATE-DIFFERENTIAL16
                    TO WS-2480-ELECT-RATE-DIFF
                WHEN OTHER
                  MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                  MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
                  MOVE 015 TO WS-8000-SHORT-ERROR
                  MOVE WS-LITERAL-YES TO ERROR-PROD-PREM
                  MOVE 'PRICE ELECTION %' TO WS-8000-FIELD-NAME1
                  MOVE WS-2480-PRICE-ELECTION-PCT
                    TO WS-8000-BAD-DATA1
                  MOVE SPACES TO WS-8000-CORR-DATA1
                  MOVE 2480 TO WS-8000-PARAGRAPH-NO
                  PERFORM 8000-RECORD-TRAN-ERROR
                     THRU 8000-RECORD-TRAN-ERROR-EXIT
                  GO TO 2480-FIND-RATE-DIFF-EXIT
              END-EVALUATE
           ELSE
      *       NO ADM2 REC FOUND
              MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 009 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-YES TO ERROR-PROD-PREM
              MOVE 'RATE DIFF' TO WS-8000-FIELD-NAME1
              MOVE 'ADM2 KEY' TO WS-8000-BAD-DATA1
      *       *** SEARCH KEY USED IS IN CORR-DATA1
              MOVE 2480 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
              GO TO 2480-FIND-RATE-DIFF-EXIT
           END-IF.

       2480-FIND-RATE-DIFF-EXIT.
           EXIT.


      *========================================================*
      *    GRP SUBSIDY CALCULATIONS                            *
      *========================================================*
       2480-CALC-GRP-SUBSIDY.

      $IF DEBUG-SW DEFINED
           DISPLAY '2480-CALCULATING GRP SUBSIDY'
           UPON CONSOLE
      $END

      *    *** LOOKUP SUBSIDY PER ACRE FROM ADM1G ***
           PERFORM 2480-LOOKUP-ADM1G-SUBSIDY
              THRU 2480-LOOKUP-ADM1G-SUBSIDY-EXIT

           IF ERROR-PROD-PREM = WS-LITERAL-YES
              GO TO 2480-CALC-GRP-SUBSIDY-EXIT
           END-IF

      $IF DEBUG-SW DEFINED
           DISPLAY 'GRP SUBSIDY/ACRE  = $',
           WS-2480-GRP-SUBSIDY-PER-ACRE
           UPON CONSOLE
           DISPLAY 'REPORTED ACRES    = ',
           WS-2480-REPORTED-ACRES-X
           UPON CONSOLE
           DISPLAY 'INSURED SHARE     = ',
           WS-2480-INS-SHARE-X
           UPON CONSOLE
      $END

      *    *** COMPUTE GRP SUBSIDY ***
           COMPUTE WS-2480-GRP-SUBSIDY ROUNDED =
              WS-2480-GRP-SUBSIDY-PER-ACRE *
              WS-2480-REPORTED-ACRES *
              WS-2480-INS-SHARE
              ON SIZE ERROR
                 MOVE 2480 TO WS-8020-PARAGRAPH-NO
                 MOVE 90017 TO WS-8020-INT-ERROR-NO
                 MOVE 'GRP SUBSIDY'
                   TO WS-8020-FIELD-NAME
                 MOVE WS-LITERAL-YES
                   TO WS-8020-ABORT-PROGRAM
                 PERFORM 8020-RECORD-INT-ERROR
                    THRU 8020-RECORD-INT-ERROR-EXIT
           END-COMPUTE.

      $IF DEBUG-SW DEFINED
           DISPLAY 'GRP SUBSIDY       = $',
           WS-2480-GRP-SUBSIDY
           UPON CONSOLE.
      $END


       2480-CALC-GRP-SUBSIDY-EXIT.
           EXIT.


       2480-LOOKUP-ADM1G-SUBSIDY.

           INITIALIZE WS-7507-INPUT-KEY
           MOVE WS-2480-CROP-YEAR TO WS-7507-INPUT-CROP-YR
           MOVE WS-2480-STATE-CD TO WS-7507-INPUT-STATE-CD
           MOVE WS-2480-COUNTY-CD TO WS-7507-INPUT-COUNTY-CD
           MOVE WS-2480-CROP-CD TO WS-7507-INPUT-CROP-CD
           MOVE WS-2480-INS-PLAN-CD TO WS-7507-INPUT-INSURANCE-PLAN
           MOVE WS-2480-PRACTICE-CD TO WS-7507-INPUT-PRACTICE-CD
           MOVE WS-2480-TYPE-CD TO WS-7507-INPUT-TYPE-CD

      *    *** SET UP ERROR STRING IN CASE ADM1 NOT FOUND
           STRING 'ADM1G KEY = '
               DELIMITED BY SIZE
               WS-7507-INPUT-KEY
               DELIMITED BY SIZE
               INTO WS-8000-CORR-DATA1
           END-STRING

           PERFORM 7507-LOOKUP-ADM1G
              THRU 7507-LOOKUP-ADM1G-EXIT

           IF MATCH-FOUND-7507
      *       *** CLEAR THE ERROR SET ABOVE
              MOVE SPACES TO WS-8000-CORR-DATA1

              IF CAT-COVERAGE
                 COMPUTE WS-2480-GRP-SUBSIDY-PER-ACRE ROUNDED =
                     WS-7507-MAXIMUM-LIABILITY * .65
                 END-COMPUTE
                 GO TO 2480-LOOKUP-ADM1G-SUBSIDY-EXIT
              END-IF

              EVALUATE WS-2480-COVERAGE-LVL-PCT
                  WHEN < 80
                     MOVE WS-7507-LIMITED-SUBSIDY
                       TO WS-2480-GRP-SUBSIDY-PER-ACRE

                  WHEN 80
                      IF WS-2480-DOLLAR-AMT-INS
                          >= WS-7507-MAXIMUM-SUBSIDY-80-PCT
                          MOVE WS-7507-MAXIMUM-SUBSIDY
                              TO WS-2480-GRP-SUBSIDY-PER-ACRE
                      ELSE
                         MOVE WS-7507-LIMITED-SUBSIDY
                           TO WS-2480-GRP-SUBSIDY-PER-ACRE
                      END-IF
                  WHEN 85
                      IF WS-2480-DOLLAR-AMT-INS
                          >= WS-7507-MAXIMUM-SUBSIDY-85-PCT
                          MOVE WS-7507-MAXIMUM-SUBSIDY
                              TO WS-2480-GRP-SUBSIDY-PER-ACRE
                      ELSE
                         MOVE WS-7507-LIMITED-SUBSIDY
                           TO WS-2480-GRP-SUBSIDY-PER-ACRE
                      END-IF
                  WHEN 90
                      IF WS-2480-DOLLAR-AMT-INS
                          >= WS-7507-MAXIMUM-SUBSIDY-90-PCT
                          MOVE WS-7507-MAXIMUM-SUBSIDY
                              TO WS-2480-GRP-SUBSIDY-PER-ACRE
                      ELSE
                         MOVE WS-7507-LIMITED-SUBSIDY
                           TO WS-2480-GRP-SUBSIDY-PER-ACRE
                      END-IF
              END-EVALUATE

           ELSE
      *       NO ADM1G REC FOUND
              MOVE 11009 TO WS-8000-ERROR-CODE
              MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO ERROR-PROD-PREM
              MOVE 'GRP SUBSIDY' TO WS-8000-FIELD-NAME1
              MOVE 'NOT FOUND' TO WS-8000-BAD-DATA1
      *       *** SEARCH KEY USED IS IN CORR-DATA1
              MOVE 'ADM1G' TO WS-8000-TABLE-NAME
              MOVE 2480 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF.

       2480-LOOKUP-ADM1G-SUBSIDY-EXIT.
           EXIT.



       2480-CALC-IP-SUBSIDY.

      $IF DEBUG-SW DEFINED
           DISPLAY '2480-CALCULATING IP SUBSIDY'
           UPON CONSOLE
      $END

      $IF DEBUG-SW DEFINED
           MOVE WS-2480-YIELD TO WS-2480-YIELD-X
           MOVE WS-2480-PRICE-ELECTION TO WS-2480-PRICE-ELECTION-X
           MOVE WS-2480-REPORTED-ACRES TO WS-2480-REPORTED-ACRES-X
           MOVE WS-2480-INS-SHARE TO WS-2480-INS-SHARE-X
           MOVE WS-2480-IP-50-PCT-PREM-RATE
             TO WS-2480-IP-50-PCT-PREM-RATE-X
           DISPLAY 'YIELD = ', WS-2480-YIELD-X
           UPON CONSOLE
           DISPLAY 'PRICE = ', WS-2480-PRICE-ELECTION-X
           UPON CONSOLE
           DISPLAY 'ACRES = ' , WS-2480-REPORTED-ACRES-X
           UPON CONSOLE
           DISPLAY 'SHARE = ', WS-2480-INS-SHARE-X
           UPON CONSOLE
           DISPLAY 'IP 50% BASE PREMIUM RATE = ',
           WS-2480-IP-50-PCT-PREM-RATE-X UPON CONSOLE
      $END

           COMPUTE WS-2480-IP-100PCT-DOLLAR-AMT ROUNDED =
              WS-2480-YIELD * WS-2480-PRICE-ELECTION *
              (WS-2480-REPORTED-ACRES * WS-2480-INS-SHARE)
              ON SIZE ERROR
                 MOVE 2480 TO WS-8020-PARAGRAPH-NO
                 MOVE 90017 TO WS-8020-INT-ERROR-NO
                 MOVE 'IP 100% $AMT' TO WS-8020-FIELD-NAME
                 MOVE SPACES TO WS-8020-BAD-DATA
                 MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                 PERFORM 8020-RECORD-INT-ERROR
                    THRU 8020-RECORD-INT-ERROR-EXIT
           END-COMPUTE
           COMPUTE WS-2480-IP-50PCT-DOLLAR-AMT ROUNDED =
              WS-2480-IP-100PCT-DOLLAR-AMT * 0.50
              ON SIZE ERROR
                 MOVE 2480 TO WS-8020-PARAGRAPH-NO
                 MOVE 90017 TO WS-8020-INT-ERROR-NO
                 MOVE 'IP 50% $AMT' TO WS-8020-FIELD-NAME
                 MOVE SPACES TO WS-8020-BAD-DATA
                 MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                 PERFORM 8020-RECORD-INT-ERROR
                    THRU 8020-RECORD-INT-ERROR-EXIT
           END-COMPUTE
           COMPUTE WS-2480-IP-50PCT-PREMIUM ROUNDED =
              WS-2480-IP-50PCT-DOLLAR-AMT *
              WS-2480-IP-50-PCT-PREM-RATE
              ON SIZE ERROR
                 MOVE 2480 TO WS-8020-PARAGRAPH-NO
                 MOVE 90017 TO WS-8020-INT-ERROR-NO
                 MOVE 'IP 50% PREM' TO WS-8020-FIELD-NAME
                 MOVE SPACES TO WS-8020-BAD-DATA
                 MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                 PERFORM 8020-RECORD-INT-ERROR
                    THRU 8020-RECORD-INT-ERROR-EXIT
           END-COMPUTE
           IF WS-2480-COVERAGE-LVL-PCT < 65
              MOVE 0.60 TO WS-2480-IP-SUBSIDY-PCT
           ELSE
              MOVE 0.75 TO WS-2480-IP-SUBSIDY-PCT
           END-IF
           MOVE WS-2480-IP-SUBSIDY-PCT
             TO WS-2480-IP-SUBSIDY-PCT-X
           COMPUTE WS-2480-IP-SUBSIDY ROUNDED =
              WS-2480-IP-50PCT-PREMIUM * WS-2480-IP-SUBSIDY-PCT
              ON SIZE ERROR
                 MOVE 2480 TO WS-8020-PARAGRAPH-NO
                 MOVE 90017 TO WS-8020-INT-ERROR-NO
                 MOVE 'IP SUBSIDY' TO WS-8020-FIELD-NAME
                 MOVE SPACES TO WS-8020-BAD-DATA
                 MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                 PERFORM 8020-RECORD-INT-ERROR
                    THRU 8020-RECORD-INT-ERROR-EXIT
           END-COMPUTE.

      $IF DEBUG-SW DEFINED
           DISPLAY 'IP 100% DOLLAR AMOUNT OF INS = $',
           WS-2480-IP-100PCT-DOLLAR-AMT UPON CONSOLE
           DISPLAY 'IP 50% DOLLAR AMOUNT OF INS  = $',
           WS-2480-IP-50PCT-DOLLAR-AMT UPON CONSOLE
           DISPLAY 'IP 50% PREMIUM  = $',
           WS-2480-IP-50PCT-PREMIUM UPON CONSOLE
           DISPLAY 'IP SUBSIDY % = ', WS-2480-IP-SUBSIDY-PCT-X
           UPON CONSOLE
           DISPLAY 'IP SUBSIDY = $', WS-2480-IP-SUBSIDY
           UPON CONSOLE.
      $END


       2480-CALC-IP-SUBSIDY-EXIT.
           EXIT.
