      ***************************************************************
      * File:      IF2505.CBL
      * Author:    Laura Dittamo
      * Date:      02/07/96
      * Purpose:
      *    This routine validates the Yield Limitation Flag.
      *
      *    If Yield Limitation Flag = 5, 6, 7, or 8,
      *       - the producer must not be classified under NCS
      *       - the policy must not be under CAT Coverage
      *         (Coverage Flag = 'C')
      *       - the yield record must be for a Category B or selected
      *         Category C crop.
      *
      * Modifications:
      *
      * 12/24/96  A policy CAN have CAT coverage with YLF of 3.
      *           (per Keith instructions)                 jlh.
      ***************************************************************

       2505-VAL-YLD-LIMIT-FLAG.

      $IF DEBUG-SW DEFINED
           DISPLAY '2505-VALIDATING YIELD LIMITATION FLAG'
           UPON CONSOLE
      $END

      **********************************************
      *            CHECK PRE-CONDITIONS            *
      **********************************************

           IF ERROR-CROP-CD = WS-LITERAL-YES
              OR ERROR-CVG-FL = WS-LITERAL-YES
              OR ERROR-NCS-YLD-FCTR = WS-LITERAL-YES
              OR ERROR-NCS-EXCEPTION-FLAG = WS-LITERAL-YES
              OR ERROR-YLD-LIMIT-FL = WS-LITERAL-YES

              MOVE WS-LITERAL-YES TO ERROR-YLD-LIMIT-FL
              GO TO 2505-VAL-YLD-LIMIT-FLAG-EXIT
           END-IF

      **********************************************
      *            NORMAL PROCESSING               *
      **********************************************

           IF WS-2505-YIELD-LIMIT-FLG = 3
              OR WS-2505-YIELD-LIMIT-FLG = 5
              OR WS-2505-YIELD-LIMIT-FLG = 6
              OR WS-2505-YIELD-LIMIT-FLG = 7
              OR WS-2505-YIELD-LIMIT-FLG = 8
      **************************************************
      *   DETERMINE WHETHER THIS PRODUCER IS CLASSIFIED
      *   UNDER NCS.  NCS PRODUCERS MAY NOT HAVE THE
      *   YIELD LIMITATION FLAG SET TO 3, 5, 6, 7, OR 8
      **************************************************
              IF WS-2505-NCS-PRODUCER = WS-LITERAL-YES
                 MOVE WS-LITERAL-YES TO ERROR-YLD-LIMIT-FL
                 MOVE 15050 TO WS-8000-ERROR-CODE
                 MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE

                 MOVE WS-LITERAL-YLD-LIMIT-FL TO WS-8000-FIELD-NAME1
                 MOVE WS-2505-YIELD-LIMIT-FLG TO WS-8000-BAD-DATA1
                 MOVE '1, 2, 4' TO WS-8000-CORR-DATA1

                 MOVE 2505 TO WS-8000-PARAGRAPH-NO
                 PERFORM 8000-RECORD-TRAN-ERROR
                    THRU 8000-RECORD-TRAN-ERROR-EXIT
              END-IF

      **************************************************
      *   DETERMINE WHETHER THIS POLICY IS UNDER CAT
      *   COVERAGE.  CAT POLICIES MAY NOT HAVE THE
      *   YIELD LIMITATION FLAG SET  5, 6, 7, OR 8
      **************************************************
              IF WS-2505-COVERAGE-FLG = WS-LITERAL-CAT
                 AND (WS-2505-YIELD-LIMIT-FLG = 5
                   OR WS-2505-YIELD-LIMIT-FLG = 6
                   OR WS-2505-YIELD-LIMIT-FLG = 7
                   OR WS-2505-YIELD-LIMIT-FLG = 8)
                 MOVE WS-LITERAL-YES TO ERROR-YLD-LIMIT-FL
                 MOVE 15051 TO WS-8000-ERROR-CODE
                 MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE

                 MOVE WS-LITERAL-YLD-LIMIT-FL TO WS-8000-FIELD-NAME1
                 MOVE WS-2505-YIELD-LIMIT-FLG TO WS-8000-BAD-DATA1
                 MOVE '1, 2, 3, 4' TO WS-8000-CORR-DATA1

                 MOVE WS-LITERAL-CVG-FL TO WS-8000-FIELD-NAME2
                 MOVE SPACES TO WS-8000-BAD-DATA2
                 MOVE WS-2505-COVERAGE-FLG TO WS-8000-CORR-DATA2

                 MOVE 2505 TO WS-8000-PARAGRAPH-NO
                 PERFORM 8000-RECORD-TRAN-ERROR
                    THRU 8000-RECORD-TRAN-ERROR-EXIT
              END-IF

      **************************************************
      *   WHEN THE YIELD LIMITATION FLAG IS SET TO
      *   3, 5, 6, 7, OR 8, THE CROP MUST BE IN EITHER
      *   CATEGORY B OR A SPECIFIED CROP IN CATEGORY C.
      **************************************************

              IF CATEGORY-B-CROP-0009
                 OR
                 (CATEGORY-C-CROP-0009
                 AND WS-2505-CROP-CD <> WS-LITERAL-BLUEBERRIES
                 AND WS-2505-CROP-CD <> WS-LITERAL-APPLES
                 AND WS-2505-CROP-CD <> WS-LITERAL-PEACHES)
                 GO TO 2505-VAL-YLD-LIMIT-FLAG-EXIT
              ELSE
                 MOVE WS-LITERAL-YES TO ERROR-YLD-LIMIT-FL
                 MOVE 15093 TO WS-8000-ERROR-CODE
                 MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                 MOVE WS-LITERAL-YLD-LIMIT-FL TO WS-8000-FIELD-NAME1
                 MOVE WS-2505-YIELD-LIMIT-FLG TO WS-8000-BAD-DATA1
                 MOVE '1, 2, 4' TO WS-8000-CORR-DATA1
                 MOVE 2505 TO WS-8000-PARAGRAPH-NO
                 PERFORM 8000-RECORD-TRAN-ERROR
                    THRU 8000-RECORD-TRAN-ERROR-EXIT
              END-IF
           END-IF.


       2505-VAL-YLD-LIMIT-FLAG-EXIT.
           EXIT.

