      ****************************************************************
      *  File   : IF2515.CBL
      *  Author : Mike Ray
      *  Date   : 02/12/96
      *  Purpose: VALIDATE YIELD TYPE SEQUENCING
      ****************************************************************

       2515-VAL-YIELD-TY-SEQ.

      $IF DEBUG-SW DEFINED
          DISPLAY '2515-VALIDATING YIELD TYPE SEQUENCING'
          UPON CONSOLE
      $END

      **************************************************
      *    INITIALIZE LOCAL & OUTPUT VARIABLE          *
      **************************************************
           INITIALIZE WS-2515-LOCAL
           INITIALIZE WS-2515-OUTPUT

      **********************************************
      *            CHECK PRE-CONDITIONS            *
      **********************************************
           IF ERROR-CROP-CD = WS-LITERAL-YES OR
              ERROR-YLD-IND = WS-LITERAL-YES OR
              ERROR-YLD-TYPE-YR1 = WS-LITERAL-YES OR
              ERROR-YLD-TYPE-YR2 = WS-LITERAL-YES OR
              ERROR-YLD-TYPE-YR3 = WS-LITERAL-YES OR
              ERROR-YLD-TYPE-YR4 = WS-LITERAL-YES OR
              ERROR-YLD-TYPE-YR5 = WS-LITERAL-YES OR
              ERROR-YLD-TYPE-YR6 = WS-LITERAL-YES OR
              ERROR-YLD-TYPE-YR7 = WS-LITERAL-YES OR
              ERROR-YLD-TYPE-YR8 = WS-LITERAL-YES OR
              ERROR-YLD-TYPE-YR9 = WS-LITERAL-YES OR
              ERROR-YLD-TYPE-YR10 = WS-LITERAL-YES

              MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR1
              MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR2
              MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR3
              MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR4
              MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR5
              MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR6
              MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR7
              MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR8
              MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR9
              MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR10
              GO TO 2515-VAL-YIELD-TY-SEQ-EXIT
           END-IF


      **************************************************
      *        COUNT YIELD YEARS BY YIELD TYPE         *
      **************************************************

           SET WS-2515-YIELD-TYPE-INDEX TO 1
           PERFORM 2515-COUNT-YIELD-TYPES
              THRU 2515-COUNT-YIELD-TYPES-EXIT
              WITH TEST AFTER
           VARYING WS-2515-YIELD-TYPE-INT-INDEX FROM 1 BY 1
             UNTIL WS-2515-YIELD-TYPE-INT-INDEX = 10

      **************************************************
      * IF ANY ADDED LAND OR ADDED TYPE/PRACTICE       *
      * YIELDS EXIST SET THE REFERENCE UNIT REQUIRED   *
      * FLAG TO INDICATE THAT YIELD FLOORS MAY BE      *
      * BASED ON A REFERENCE UNIT YIELD RECORD. THE    *
      * APPROVED YIELD EDIT WILL DETERMINE WHETHER OR  *
      * NOT A REFERENCE UNIT IS NEEDED FOR SURE AND IF *
      * SO, WHAT YIELD FLOOR PCT/YEARS OF ACTUALS IT   *
      * MUST HAVE.                                     *
      **************************************************
           IF WS-2515-SPECIAL-C-COUNT > ZERO OR
              WS-2515-SPECIAL-L-COUNT > ZERO
              MOVE WS-LITERAL-YES TO WS-2515-REFERENCE-UNIT-REQ
           ELSE
              MOVE WS-LITERAL-NO TO WS-2515-REFERENCE-UNIT-REQ
           END-IF

      **************************************************
      *       VALIDATE YIELD TYPE COUNT LIMITS         *
      **************************************************
           PERFORM 2515-VAL-YLD-TYPE-COUNTS
              THRU 2515-VAL-YLD-TYPE-COUNTS-EXIT

           IF ERROR-YLD-TYPE-YR1 = WS-LITERAL-YES OR
              ERROR-YLD-TYPE-YR2 = WS-LITERAL-YES OR
              ERROR-YLD-TYPE-YR3 = WS-LITERAL-YES OR
              ERROR-YLD-TYPE-YR4 = WS-LITERAL-YES OR
              ERROR-YLD-TYPE-YR5 = WS-LITERAL-YES OR
              ERROR-YLD-TYPE-YR6 = WS-LITERAL-YES OR
              ERROR-YLD-TYPE-YR7 = WS-LITERAL-YES OR
              ERROR-YLD-TYPE-YR8 = WS-LITERAL-YES OR
              ERROR-YLD-TYPE-YR9 = WS-LITERAL-YES OR
              ERROR-YLD-TYPE-YR10 = WS-LITERAL-YES
              GO TO 2515-VAL-YIELD-TY-SEQ-EXIT
           END-IF


      **************************************************
      *       VALIDATE YIELD TYPE PRECEDENCE RULES     *
      **************************************************

      *    *** PRECEDENCE RULES ONLY APPLY TO H YIELDS
           IF WS-2515-110-PCT-H-PILOT-COUNT > ZEROS AND
              WS-2515-110-PCT-H-PILOT-COUNT < 4
              MOVE SPACES TO WS-2515-HOLD-YIELD-TYPE
              SET WS-2515-YIELD-TYPE-INDEX TO 10
              PERFORM 2515-VAL-PRECEDENCE
                 THRU 2515-VAL-PRECEDENCE-EXIT
                 WITH TEST AFTER
              VARYING WS-2515-YIELD-TYPE-INT-INDEX FROM 10 BY -1
                UNTIL WS-2515-YIELD-TYPE-INT-INDEX = 1

              IF ERROR-YLD-TYPE-YR1 = WS-LITERAL-YES OR
                 ERROR-YLD-TYPE-YR2 = WS-LITERAL-YES OR
                 ERROR-YLD-TYPE-YR3 = WS-LITERAL-YES OR
                 ERROR-YLD-TYPE-YR4 = WS-LITERAL-YES OR
                 ERROR-YLD-TYPE-YR5 = WS-LITERAL-YES OR
                 ERROR-YLD-TYPE-YR6 = WS-LITERAL-YES OR
                 ERROR-YLD-TYPE-YR7 = WS-LITERAL-YES OR
                 ERROR-YLD-TYPE-YR8 = WS-LITERAL-YES OR
                 ERROR-YLD-TYPE-YR9 = WS-LITERAL-YES OR
                 ERROR-YLD-TYPE-YR10 = WS-LITERAL-YES
                 GO TO 2515-VAL-YIELD-TY-SEQ-EXIT
              END-IF
           END-IF
      **************************************************
      *       VALIDATE YIELD TYPE SUCCESSOR RULES      *
      **************************************************
           MOVE SPACES TO WS-2515-HOLD-YIELD-TYPE
           SET WS-2515-YIELD-TYPE-INDEX TO 1
           PERFORM 2515-VAL-SUCCESSORS
              THRU 2515-VAL-SUCCESSORS-EXIT
              WITH TEST AFTER
           VARYING WS-2515-YIELD-TYPE-INT-INDEX FROM 1 BY 1
             UNTIL WS-2515-YIELD-TYPE-INT-INDEX = 10

           IF ERROR-YLD-TYPE-YR1 = WS-LITERAL-YES OR
              ERROR-YLD-TYPE-YR2 = WS-LITERAL-YES OR
              ERROR-YLD-TYPE-YR3 = WS-LITERAL-YES OR
              ERROR-YLD-TYPE-YR4 = WS-LITERAL-YES OR
              ERROR-YLD-TYPE-YR5 = WS-LITERAL-YES OR
              ERROR-YLD-TYPE-YR6 = WS-LITERAL-YES OR
              ERROR-YLD-TYPE-YR7 = WS-LITERAL-YES OR
              ERROR-YLD-TYPE-YR8 = WS-LITERAL-YES OR
              ERROR-YLD-TYPE-YR9 = WS-LITERAL-YES OR
              ERROR-YLD-TYPE-YR10 = WS-LITERAL-YES
              GO TO 2515-VAL-YIELD-TY-SEQ-EXIT
           END-IF.

      **************************************************
      *       VALIDATE YIELD TYPE POSITION RULES       *
      **************************************************
      *    PERFORM 2515-VAL-POSITIONS
      *       THRU 2515-VAL-POSITIONS-EXIT.


       2515-VAL-YIELD-TY-SEQ-EXIT.
           EXIT.


       2515-COUNT-YIELD-TYPES.

           SET WS-2515-YIELD-TYPE-INDEX
            TO WS-2515-YIELD-TYPE-INT-INDEX

      $IF DEBUG-SW DEFINED
           DISPLAY 'YEAR ', WS-2515-YIELD-TYPE-INT-INDEX, ' TYPE ',
           WS-2515-TBL-YIELD-TYPE(WS-2515-YIELD-TYPE-INDEX)
           UPON CONSOLE
      $END

           EVALUATE WS-2515-TBL-YIELD-TYPE(WS-2515-YIELD-TYPE-INDEX)
               WHEN WS-LITERAL-A-YLD
                  ADD 1 TO WS-2515-ACTUAL-COUNT
               WHEN WS-LITERAL-C-YLD
                  ADD 1 TO WS-2515-SPECIAL-C-COUNT
               WHEN WS-LITERAL-E-YLD
                  ADD 1 TO WS-2515-80-PCT-E-COUNT
               WHEN WS-LITERAL-F-YLD
                  ADD 1 TO WS-2515-RSO-ASSIGNED-F-COUNT
               WHEN WS-LITERAL-J-YLD
                  ADD 1 TO WS-2515-TEMP-ACTUAL-J-COUNT
               WHEN WS-LITERAL-N-YLD
                  ADD 1 TO WS-2515-90-PCT-N-COUNT
               WHEN WS-LITERAL-P-YLD
                  ADD 1 TO WS-2515-75-PCT-P-COUNT

               WHEN WS-LITERAL-R-YLD
                  NEXT SENTENCE

               WHEN WS-LITERAL-S-YLD
                  ADD 1 TO WS-2515-65-PCT-S-COUNT
               WHEN WS-LITERAL-T-YLD
                  ADD 1 TO WS-2515-TRANSITIONAL-COUNT
               WHEN SPACES
                  ADD 1 TO WS-2515-BLANK-COUNT
               WHEN WS-LITERAL-H-YLD
                  ADD 1 TO WS-2515-110-PCT-H-PILOT-COUNT
               WHEN WS-LITERAL-I-YLD
                  ADD 1 TO WS-2515-100-PCT-NEW-I-COUNT
               WHEN WS-LITERAL-L-YLD
                  ADD 1 TO WS-2515-SPECIAL-L-COUNT
               WHEN WS-LITERAL-X-YLD
                  ADD 1 TO WS-2515-80-PCT-NEW-X-COUNT
               WHEN WS-LITERAL-Z-YLD
                  ADD 1 TO WS-2515-ZERO-ACRES-COUNT
                  ADD 1 TO WS-2515-BLANK-COUNT
               WHEN WS-LITERAL-D-YLD
                  ADD 1 TO WS-2515-TRANSITIONAL-COUNT
               WHEN OTHER
                  MOVE 15008 TO WS-8000-ERROR-CODE
                  MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                  EVALUATE WS-2515-YIELD-TYPE-INDEX
                     WHEN 1
                        MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR1
                        MOVE WS-LITERAL-YLD-TYPE-YR1
                          TO WS-8000-FIELD-NAME1
                     WHEN 2
                        MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR2
                        MOVE WS-LITERAL-YLD-TYPE-YR2
                          TO WS-8000-FIELD-NAME1
                     WHEN 3
                        MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR3
                        MOVE WS-LITERAL-YLD-TYPE-YR3
                          TO WS-8000-FIELD-NAME1
                     WHEN 4
                        MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR4
                        MOVE WS-LITERAL-YLD-TYPE-YR4
                          TO WS-8000-FIELD-NAME1
                     WHEN 5
                        MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR5
                        MOVE WS-LITERAL-YLD-TYPE-YR5
                          TO WS-8000-FIELD-NAME1
                     WHEN 6
                        MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR6
                        MOVE WS-LITERAL-YLD-TYPE-YR6
                          TO WS-8000-FIELD-NAME1
                     WHEN 7
                        MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR7
                        MOVE WS-LITERAL-YLD-TYPE-YR7
                          TO WS-8000-FIELD-NAME1
                     WHEN 8
                        MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR8
                        MOVE WS-LITERAL-YLD-TYPE-YR8
                          TO WS-8000-FIELD-NAME1
                     WHEN 9
                        MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR9
                        MOVE WS-LITERAL-YLD-TYPE-YR9
                          TO WS-8000-FIELD-NAME1
                     WHEN 10
                        MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR10
                        MOVE WS-LITERAL-YLD-TYPE-YR10
                          TO WS-8000-FIELD-NAME1
                     WHEN OTHER
                        MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
                        MOVE 044 TO WS-8000-SHORT-ERROR
                        MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
                        MOVE 'YLD TYPE TBL IDX'
                          TO WS-8000-FIELD-NAME1
                        SET WS-2515-INTEGER-ERROR
                         TO WS-2515-YIELD-TYPE-INDEX
                        MOVE WS-2515-INTEGER-ERROR
                          TO WS-8000-BAD-DATA1
                        MOVE 'YIELD TYPE TABLE INDEX OUT OF BOUNDS'
                          TO WS-8000-CORR-DATA1
                        MOVE 2515 TO WS-8000-PARAGRAPH-NO
                        PERFORM 8000-RECORD-TRAN-ERROR
                           THRU 8000-RECORD-TRAN-ERROR-EXIT
                        GO TO 2515-COUNT-YIELD-TYPES-EXIT
                  END-EVALUATE
                  MOVE WS-2515-TBL-YIELD-TYPE
                       (WS-2515-YIELD-TYPE-INDEX)
                    TO WS-8000-BAD-DATA1
                  MOVE SPACES TO WS-8000-CORR-DATA1
                  MOVE WS-LITERAL-CROP-CD TO WS-8000-FIELD-NAME2
                  MOVE WS-0009-CROP-CATEGORIES TO WS-8000-BAD-DATA2
                  MOVE SPACES TO WS-8000-CORR-DATA2
                  MOVE SPACES TO WS-8000-FIELD-NAME3
                  MOVE SPACES TO WS-8000-BAD-DATA3
                  MOVE SPACES TO WS-8000-CORR-DATA3
                  MOVE 2515 TO WS-8000-PARAGRAPH-NO
                  PERFORM 8000-RECORD-TRAN-ERROR
                     THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-EVALUATE.


       2515-COUNT-YIELD-TYPES-EXIT.
           EXIT.



       2515-VAL-YLD-TYPE-COUNTS.

      $IF DEBUG-SW DEFINED
          DISPLAY '2515-VALIDATING YIELD TYPE COUNTS'
          UPON CONSOLE
      $END

      *    **** FOUR YEARS OF YIELD DATA ARE REQUIRED, SO THE NUMBER OF
      *    **** BLANK YIELD TYPES CANNOT BE > SIX UNLESS THE YIELD
      *    **** INDICATOR SHOWS THAT THIS IS A MASTER YIELD OR AN
      *    **** RSO ASSIGNED YIELD
      *    **** ZEROS (TYPE Z) ARE COUNTED AS BLANKS FOR THIS PURPOSE
           IF WS-2515-BLANK-COUNT > 06
              IF WS-2515-YIELD-INDICATOR = WS-LITERAL-MASTER-YIELD OR
                 WS-2515-YIELD-INDICATOR = WS-LITERAL-RSO-ASSIGNED-YLD
                 CONTINUE
              ELSE
                 MOVE 15057 TO WS-8000-ERROR-CODE
                 MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR1
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR2
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR3
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR4
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR5
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR6
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR7
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR8
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR9
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR10
                 MOVE 'BLANK YLD TYPES' TO WS-8000-FIELD-NAME1
                 MOVE WS-2515-BLANK-COUNT
                   TO WS-8000-BAD-DATA1
                 MOVE '<= 6' TO WS-8000-CORR-DATA1
                 MOVE 2515 TO WS-8000-PARAGRAPH-NO
                 PERFORM 8000-RECORD-TRAN-ERROR
                    THRU 8000-RECORD-TRAN-ERROR-EXIT
              END-IF
           END-IF

      *    **** YIELD TYPE S MAY OCCUR ZERO TIMES OR 4 TIMES
           IF WS-2515-65-PCT-S-COUNT > ZEROS
              IF WS-2515-65-PCT-S-COUNT NOT = 04
                 MOVE 15053 TO WS-8000-ERROR-CODE
                 MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR1
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR2
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR3
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR4
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR5
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR6
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR7
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR8
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR9
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR10
                 MOVE 'YLD TYPE S COUNT' TO WS-8000-FIELD-NAME1
                 MOVE WS-2515-65-PCT-S-COUNT TO WS-8000-BAD-DATA1
                 MOVE '4' TO WS-8000-CORR-DATA1
                 MOVE 2515 TO WS-8000-PARAGRAPH-NO
                 PERFORM 8000-RECORD-TRAN-ERROR
                    THRU 8000-RECORD-TRAN-ERROR-EXIT
              END-IF
           END-IF

      *    **** YIELD TYPE I MAY OCCUR ZERO TIMES OR 2-4 TIMES
           IF WS-2515-100-PCT-NEW-I-COUNT > ZEROS
              IF (WS-2515-100-PCT-NEW-I-COUNT < 02) OR
                 (WS-2515-100-PCT-NEW-I-COUNT > 04)
                 MOVE 15054 TO WS-8000-ERROR-CODE
                 MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR1
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR2
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR3
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR4
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR5
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR6
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR7
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR8
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR9
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR10
                 MOVE 'YLD TYPE I COUNT' TO WS-8000-FIELD-NAME1
                 MOVE WS-2515-100-PCT-NEW-I-COUNT TO WS-8000-BAD-DATA1
                 MOVE '2-4' TO WS-8000-CORR-DATA1
                 MOVE 2515 TO WS-8000-PARAGRAPH-NO
                 PERFORM 8000-RECORD-TRAN-ERROR
                    THRU 8000-RECORD-TRAN-ERROR-EXIT
              END-IF
           END-IF

      *    **** YIELD TYPE H MAY OCCUR ZERO TIMES OR 1-4 TIMES
           IF WS-2515-110-PCT-H-PILOT-COUNT > ZEROS
              IF WS-2515-110-PCT-H-PILOT-COUNT > 04
                 MOVE 15054 TO WS-8000-ERROR-CODE
                 MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR1
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR2
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR3
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR4
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR5
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR6
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR7
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR8
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR9
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR10
                 MOVE 'YLD TYPE H COUNT' TO WS-8000-FIELD-NAME1
                 MOVE WS-2515-110-PCT-H-PILOT-COUNT TO WS-8000-BAD-DATA1
                 MOVE '2-4' TO WS-8000-CORR-DATA1
                 MOVE 2515 TO WS-8000-PARAGRAPH-NO
                 PERFORM 8000-RECORD-TRAN-ERROR
                    THRU 8000-RECORD-TRAN-ERROR-EXIT
              END-IF
           END-IF

      *    **** YIELD TYPE X MAY OCCUR ZERO TIMES OR 4 TIMES
           IF WS-2515-80-PCT-NEW-X-COUNT > ZEROS
              IF WS-2515-80-PCT-NEW-X-COUNT NOT = 04
                 MOVE 15053 TO WS-8000-ERROR-CODE
                 MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR1
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR2
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR3
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR4
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR5
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR6
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR7
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR8
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR9
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR10
                 MOVE 'YLD TYPE X COUNT' TO WS-8000-FIELD-NAME1
                 MOVE WS-2515-80-PCT-NEW-X-COUNT TO WS-8000-BAD-DATA1
                 MOVE '4' TO WS-8000-CORR-DATA1
                 MOVE 2515 TO WS-8000-PARAGRAPH-NO
                 PERFORM 8000-RECORD-TRAN-ERROR
                    THRU 8000-RECORD-TRAN-ERROR-EXIT
              END-IF
           END-IF

      *    **** YIELD TYPE C MAY OCCUR ZERO TIMES OR 2-4 TIMES
           IF WS-2515-SPECIAL-C-COUNT > ZEROS
              IF (WS-2515-SPECIAL-C-COUNT < 02) OR
                 (WS-2515-SPECIAL-C-COUNT > 04)
                 MOVE 15054 TO WS-8000-ERROR-CODE
                 MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR1
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR2
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR3
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR4
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR5
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR6
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR7
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR8
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR9
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR10
                 MOVE 'YLD TYPE C COUNT' TO WS-8000-FIELD-NAME1
                 MOVE WS-2515-SPECIAL-C-COUNT TO WS-8000-BAD-DATA1
                 MOVE '2-4' TO WS-8000-CORR-DATA1
                 MOVE 2515 TO WS-8000-PARAGRAPH-NO
                 PERFORM 8000-RECORD-TRAN-ERROR
                    THRU 8000-RECORD-TRAN-ERROR-EXIT
              END-IF
           END-IF

      *    **** YIELD TYPE L MAY OCCUR ZERO TIMES OR 2-4 TIMES
           IF WS-2515-SPECIAL-L-COUNT > ZEROS
              IF (WS-2515-SPECIAL-L-COUNT < 02) OR
                 (WS-2515-SPECIAL-L-COUNT > 04)
                 MOVE 15054 TO WS-8000-ERROR-CODE
                 MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR1
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR2
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR3
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR4
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR5
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR6
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR7
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR8
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR9
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR10
                 MOVE 'YLD TYPE L COUNT' TO WS-8000-FIELD-NAME1
                 MOVE WS-2515-SPECIAL-L-COUNT TO WS-8000-BAD-DATA1
                 MOVE '2-4' TO WS-8000-CORR-DATA1
                 MOVE 2515 TO WS-8000-PARAGRAPH-NO
                 PERFORM 8000-RECORD-TRAN-ERROR
                    THRU 8000-RECORD-TRAN-ERROR-EXIT
              END-IF
           END-IF

      *    **** YIELD TYPE F MAY OCCUR ZERO TIMES OR 1-4 TIMES
           IF WS-2515-RSO-ASSIGNED-F-COUNT > ZEROS
              IF WS-2515-RSO-ASSIGNED-F-COUNT > 04
                 MOVE 15055 TO WS-8000-ERROR-CODE
                 MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR1
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR2
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR3
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR4
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR5
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR6
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR7
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR8
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR9
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR10
                 MOVE 'YLD TYPE F COUNT' TO WS-8000-FIELD-NAME1
                 MOVE WS-2515-RSO-ASSIGNED-F-COUNT
                   TO WS-8000-BAD-DATA1
                 MOVE '1-4' TO WS-8000-CORR-DATA1
                 MOVE 2515 TO WS-8000-PARAGRAPH-NO
                 PERFORM 8000-RECORD-TRAN-ERROR
                    THRU 8000-RECORD-TRAN-ERROR-EXIT
              END-IF
           END-IF

      *    **** YIELD TYPE J MAY OCCUR ZERO TIMES OR ONE TIME
           IF WS-2515-TEMP-ACTUAL-J-COUNT > ZEROS
              IF WS-2515-TEMP-ACTUAL-J-COUNT > 01
                 MOVE 15056 TO WS-8000-ERROR-CODE
                 MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR1
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR2
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR3
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR4
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR5
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR6
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR7
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR8
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR9
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR10
                 MOVE 'YLD TYPE J COUNT' TO WS-8000-FIELD-NAME1
                 MOVE WS-2515-TEMP-ACTUAL-J-COUNT
                   TO WS-8000-BAD-DATA1
                 MOVE '1' TO WS-8000-CORR-DATA1
                 MOVE 2515 TO WS-8000-PARAGRAPH-NO
                 PERFORM 8000-RECORD-TRAN-ERROR
                    THRU 8000-RECORD-TRAN-ERROR-EXIT
              END-IF
           END-IF

      *    **** YIELD TYPE N MAY OCCUR ZERO TIMES OR 2 TIMES
      *    **** IF THE YIELD INDICATOR = L (LAG YEAR FOR SUGAR CANE)
      *    **** THEN THE YIELD TYPE MAY OCCUR ZERO OR 3 TIMES
           IF WS-2515-90-PCT-N-COUNT > ZEROS
              IF WS-2515-YIELD-INDICATOR = WS-LITERAL-SCANE-LAG-YEAR
                 MOVE 3 TO WS-2515-COUNT-LIMIT
              ELSE
                 MOVE 2 TO WS-2515-COUNT-LIMIT
              END-IF
              IF WS-2515-90-PCT-N-COUNT NOT = WS-2515-COUNT-LIMIT
                 MOVE 15058 TO WS-8000-ERROR-CODE
                 MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR1
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR2
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR3
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR4
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR5
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR6
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR7
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR8
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR9
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR10
                 MOVE 'YLD TYPE N COUNT' TO WS-8000-FIELD-NAME1
                 MOVE WS-2515-90-PCT-N-COUNT
                   TO WS-8000-BAD-DATA1
                 MOVE WS-2515-COUNT-LIMIT TO WS-8000-CORR-DATA1
                 MOVE 2515 TO WS-8000-PARAGRAPH-NO
                 PERFORM 8000-RECORD-TRAN-ERROR
                    THRU 8000-RECORD-TRAN-ERROR-EXIT
              END-IF
           END-IF


      *    **** YIELD TYPE E MAY OCCUR ZERO TIMES OR 3 TIMES
      *    **** IF THE YIELD INDICATOR = L (LAG YEAR FOR SUGAR CANE)
      *    **** THEN THE YIELD TYPE MAY OCCUR ZERO OR 4 TIMES
           IF WS-2515-80-PCT-E-COUNT > ZEROS
              IF WS-2515-YIELD-INDICATOR = WS-LITERAL-SCANE-LAG-YEAR
                 MOVE 4 TO WS-2515-COUNT-LIMIT
              ELSE
                 MOVE 3 TO WS-2515-COUNT-LIMIT
              END-IF
              IF WS-2515-80-PCT-E-COUNT NOT = WS-2515-COUNT-LIMIT
                 MOVE 15058 TO WS-8000-ERROR-CODE
                 MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR1
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR2
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR3
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR4
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR5
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR6
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR7
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR8
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR9
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR10
                 MOVE 'YLD TYPE E COUNT' TO WS-8000-FIELD-NAME1
                 MOVE WS-2515-80-PCT-E-COUNT
                   TO WS-8000-BAD-DATA1
                 MOVE WS-2515-COUNT-LIMIT TO WS-8000-CORR-DATA1
                 MOVE 2515 TO WS-8000-PARAGRAPH-NO
                 PERFORM 8000-RECORD-TRAN-ERROR
                    THRU 8000-RECORD-TRAN-ERROR-EXIT
              END-IF
           END-IF

      *    **** IF THE NCS FLAG IS SET, NO EDIT FOR YIELD TYPE T
      *    **** IF THE NCS FLAG IS NOT SET, YIELD TYPE T MAY OCCUR
      *    **** OCCUR ZERO TIMES OR 1 TIME
      *    **** IF THE YIELD INDICATOR = L (LAG YEAR FOR SUGAR CANE)
      *    **** THEN THE YIELD TYPE MAY OCCUR ZERO OR 1-2 TIMES
           IF WS-2515-TRANSITIONAL-COUNT > ZEROS
              IF WS-2515-NCS-FLAG = WS-LITERAL-YES
                 CONTINUE
              ELSE
                 IF WS-2515-YIELD-INDICATOR
                    = WS-LITERAL-SCANE-LAG-YEAR
                    MOVE 2 TO WS-2515-COUNT-LIMIT
                 ELSE
                    MOVE 1 TO WS-2515-COUNT-LIMIT
                 END-IF
                 IF NOT (WS-2515-TRANSITIONAL-COUNT
                     <= WS-2515-COUNT-LIMIT)
                    MOVE 15058 TO WS-8000-ERROR-CODE
                    MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                    MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR1
                    MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR2
                    MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR3
                    MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR4
                    MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR5
                    MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR6
                    MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR7
                    MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR8
                    MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR9
                    MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR10
                    MOVE 'YLD TYPE T COUNT' TO WS-8000-FIELD-NAME1
                    MOVE WS-2515-TRANSITIONAL-COUNT
                      TO WS-8000-BAD-DATA1
                    MOVE WS-2515-COUNT-LIMIT TO WS-8000-CORR-DATA1
                    MOVE 2515 TO WS-8000-PARAGRAPH-NO
                    PERFORM 8000-RECORD-TRAN-ERROR
                       THRU 8000-RECORD-TRAN-ERROR-EXIT
                 END-IF
              END-IF
           END-IF.


       2515-VAL-YLD-TYPE-COUNTS-EXIT.
           EXIT.


       2515-VAL-PRECEDENCE.

           SET WS-2515-YIELD-TYPE-INDEX
            TO WS-2515-YIELD-TYPE-INT-INDEX

      *       **** SKIP ZERO ACREAGE RECORDS WITHOUT UPDATING
      *       **** THE HELD YIELD TYPE
           IF WS-2515-TBL-YIELD-TYPE
              (WS-2515-YIELD-TYPE-INDEX) = WS-LITERAL-Z-YLD
              GO TO 2515-VAL-PRECEDENCE-EXIT
           END-IF

           EVALUATE WS-2515-HOLD-YIELD-TYPE

      *             **** YIELD TYPE P MUST BE PRECEDED BY A YIELD TYPE A
               WHEN WS-LITERAL-P-YLD
                  IF WS-2515-TBL-YIELD-TYPE
                     (WS-2515-YIELD-TYPE-INDEX)
                     = WS-LITERAL-Z-YLD
      *              **** ZERO ACREAGE CAN BE SKIPPED
                     GO TO 2515-VAL-PRECEDENCE-EXIT
                  END-IF
                  IF WS-2515-TBL-YIELD-TYPE
                     (WS-2515-YIELD-TYPE-INDEX)
                     NOT = WS-LITERAL-A-YLD
      *              **** NOT PRECEDED BY AN ACTUAL YIELD
                     MOVE 15059 TO WS-8000-ERROR-CODE
                     PERFORM 2515-SET-ERROR
                        THRU 2515-SET-ERROR-EXIT
                     MOVE WS-2515-TBL-YIELD-TYPE
                     (WS-2515-YIELD-TYPE-INDEX)
                       TO WS-8000-BAD-DATA1
                     MOVE WS-LITERAL-A-YLD
                       TO WS-8000-CORR-DATA1
                     MOVE 2515 TO WS-8000-PARAGRAPH-NO
                     PERFORM 8000-RECORD-TRAN-ERROR
                        THRU 8000-RECORD-TRAN-ERROR-EXIT
      *              *** THIS PREVENTS THE ERROR FROM
      *              *** BEING REPEATED FOR EACH REMAINING
      *              *** YIELD TYPE
                     MOVE WS-2515-TBL-YIELD-TYPE
                          (WS-2515-YIELD-TYPE-INDEX)
                       TO WS-2515-HOLD-YIELD-TYPE
                     GO TO 2515-VAL-PRECEDENCE-EXIT
                  END-IF
                  MOVE WS-2515-TBL-YIELD-TYPE
                       (WS-2515-YIELD-TYPE-INDEX)
                    TO WS-2515-HOLD-YIELD-TYPE


               WHEN OTHER
                  MOVE WS-2515-TBL-YIELD-TYPE
                       (WS-2515-YIELD-TYPE-INDEX)
                    TO WS-2515-HOLD-YIELD-TYPE
           END-EVALUATE.


       2515-VAL-PRECEDENCE-EXIT.
           EXIT.





       2515-VAL-SUCCESSORS.

           SET WS-2515-YIELD-TYPE-INDEX
            TO WS-2515-YIELD-TYPE-INT-INDEX

      *       **** IT IS INVALID TO HAVE SPACES AFTER ANY OTHER
      *       **** YIELD TYPE
           IF (WS-2515-HOLD-YIELD-TYPE NOT = SPACES) AND
              (WS-2515-TBL-YIELD-TYPE (WS-2515-YIELD-TYPE-INDEX)
              = SPACES)
              MOVE 15060 TO WS-8000-ERROR-CODE
              PERFORM 2515-SET-ERROR
                 THRU 2515-SET-ERROR-EXIT
              MOVE SPACES
                TO WS-8000-BAD-DATA1
              MOVE WS-2515-YIELD-TYPES
                TO WS-8000-BAD-DATA2
              MOVE 'MUST NOT BE BLANK' TO WS-8000-CORR-DATA1
              MOVE 'PREV YLD TYPE' TO WS-8000-FIELD-NAME2
              MOVE WS-2515-HOLD-YIELD-TYPE TO WS-8000-CORR-DATA2
              MOVE 2515 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
              GO TO 2515-VAL-SUCCESSORS-EXIT
           END-IF

      *       **** SKIP ZERO ACREAGE RECORDS WITHOUT UPDATING
      *       **** THE HELD YIELD TYPE
           IF (WS-2515-TBL-YIELD-TYPE(WS-2515-YIELD-TYPE-INDEX)
               = WS-LITERAL-Z-YLD)
               GO TO 2515-VAL-SUCCESSORS-EXIT
           END-IF

           EVALUATE WS-2515-HOLD-YIELD-TYPE

      *        **** YIELD TYPE C MUST BE FOLLOWED BY A C, A, J, OR P
               WHEN WS-LITERAL-C-YLD
                  IF (WS-2515-TBL-YIELD-TYPE(WS-2515-YIELD-TYPE-INDEX)
                     NOT = WS-LITERAL-A-YLD) AND
                     (WS-2515-TBL-YIELD-TYPE(WS-2515-YIELD-TYPE-INDEX)
                     NOT = WS-LITERAL-J-YLD) AND
                     (WS-2515-TBL-YIELD-TYPE(WS-2515-YIELD-TYPE-INDEX)
                     NOT = WS-LITERAL-P-YLD) AND
                     (WS-2515-TBL-YIELD-TYPE(WS-2515-YIELD-TYPE-INDEX)
                     NOT = WS-LITERAL-C-YLD)
                     MOVE 15060 TO WS-8000-ERROR-CODE
                     PERFORM 2515-SET-ERROR
                        THRU 2515-SET-ERROR-EXIT
                     MOVE WS-2515-TBL-YIELD-TYPE
                          (WS-2515-YIELD-TYPE-INDEX)
                       TO WS-8000-BAD-DATA1
                     MOVE 'E, A, J, P' TO WS-8000-CORR-DATA1
                     MOVE 2515 TO WS-8000-PARAGRAPH-NO
                     PERFORM 8000-RECORD-TRAN-ERROR
                        THRU 8000-RECORD-TRAN-ERROR-EXIT
                     GO TO 2515-VAL-SUCCESSORS-EXIT
                  END-IF

      *        **** YIELD TYPE E MUST BE FOLLOWED BY AN E, A, J, OR P
               WHEN WS-LITERAL-E-YLD
                  IF (WS-2515-TBL-YIELD-TYPE(WS-2515-YIELD-TYPE-INDEX)
                     NOT = WS-LITERAL-A-YLD) AND
                     (WS-2515-TBL-YIELD-TYPE(WS-2515-YIELD-TYPE-INDEX)
                     NOT = WS-LITERAL-J-YLD) AND
                     (WS-2515-TBL-YIELD-TYPE(WS-2515-YIELD-TYPE-INDEX)
                     NOT = WS-LITERAL-P-YLD) AND
                     (WS-2515-TBL-YIELD-TYPE(WS-2515-YIELD-TYPE-INDEX)
                     NOT = WS-LITERAL-E-YLD)
                     MOVE 15060 TO WS-8000-ERROR-CODE
                     PERFORM 2515-SET-ERROR
                        THRU 2515-SET-ERROR-EXIT
                     MOVE WS-2515-TBL-YIELD-TYPE
                          (WS-2515-YIELD-TYPE-INDEX)
                       TO WS-8000-BAD-DATA1
                     MOVE 'E, A, J, P' TO WS-8000-CORR-DATA1
                     MOVE 2515 TO WS-8000-PARAGRAPH-NO
                     PERFORM 8000-RECORD-TRAN-ERROR
                        THRU 8000-RECORD-TRAN-ERROR-EXIT
                     GO TO 2515-VAL-SUCCESSORS-EXIT
                  END-IF

      *        **** YIELD TYPE F MUST BE FOLLOWED BY AN F, A, J, OR P
               WHEN WS-LITERAL-F-YLD
                  IF (WS-2515-TBL-YIELD-TYPE(WS-2515-YIELD-TYPE-INDEX)
                     NOT = WS-LITERAL-A-YLD) AND
                     (WS-2515-TBL-YIELD-TYPE(WS-2515-YIELD-TYPE-INDEX)
                     NOT = WS-LITERAL-J-YLD) AND
                     (WS-2515-TBL-YIELD-TYPE(WS-2515-YIELD-TYPE-INDEX)
                     NOT = WS-LITERAL-P-YLD) AND
                     (WS-2515-TBL-YIELD-TYPE(WS-2515-YIELD-TYPE-INDEX)
                     NOT = WS-LITERAL-F-YLD)
                     MOVE 15060 TO WS-8000-ERROR-CODE
                     PERFORM 2515-SET-ERROR
                        THRU 2515-SET-ERROR-EXIT
                     MOVE WS-2515-TBL-YIELD-TYPE
                          (WS-2515-YIELD-TYPE-INDEX)
                       TO WS-8000-BAD-DATA1
                     MOVE 'F, A, J, P' TO WS-8000-CORR-DATA1
                     MOVE 2515 TO WS-8000-PARAGRAPH-NO
                     PERFORM 8000-RECORD-TRAN-ERROR
                        THRU 8000-RECORD-TRAN-ERROR-EXIT
                     GO TO 2515-VAL-SUCCESSORS-EXIT
                  END-IF

      *        **** YIELD TYPE N MUST BE FOLLOWED BY AN N, A, J, OR P
               WHEN WS-LITERAL-N-YLD
                  IF (WS-2515-TBL-YIELD-TYPE(WS-2515-YIELD-TYPE-INDEX)
                     NOT = WS-LITERAL-A-YLD) AND
                     (WS-2515-TBL-YIELD-TYPE(WS-2515-YIELD-TYPE-INDEX)
                     NOT = WS-LITERAL-J-YLD) AND
                     (WS-2515-TBL-YIELD-TYPE(WS-2515-YIELD-TYPE-INDEX)
                     NOT = WS-LITERAL-P-YLD) AND
                     (WS-2515-TBL-YIELD-TYPE(WS-2515-YIELD-TYPE-INDEX)
                     NOT = WS-LITERAL-N-YLD)
                     MOVE 15060 TO WS-8000-ERROR-CODE
                     PERFORM 2515-SET-ERROR
                        THRU 2515-SET-ERROR-EXIT
                     MOVE WS-2515-TBL-YIELD-TYPE
                          (WS-2515-YIELD-TYPE-INDEX)
                       TO WS-8000-BAD-DATA1
                     MOVE 'N, A, J, P' TO WS-8000-CORR-DATA1
                     MOVE 2515 TO WS-8000-PARAGRAPH-NO
                     PERFORM 8000-RECORD-TRAN-ERROR
                        THRU 8000-RECORD-TRAN-ERROR-EXIT
                     GO TO 2515-VAL-SUCCESSORS-EXIT
                  END-IF

      *        **** YIELD TYPE T MUST BE FOLLOWED BY A T, D, A, J, OR P
               WHEN WS-LITERAL-T-YLD
                  IF (WS-2515-TBL-YIELD-TYPE(WS-2515-YIELD-TYPE-INDEX)
                     NOT = WS-LITERAL-A-YLD) AND
                     (WS-2515-TBL-YIELD-TYPE(WS-2515-YIELD-TYPE-INDEX)
                     NOT = WS-LITERAL-J-YLD) AND
                     (WS-2515-TBL-YIELD-TYPE(WS-2515-YIELD-TYPE-INDEX)
                     NOT = WS-LITERAL-P-YLD) AND
                     (WS-2515-TBL-YIELD-TYPE(WS-2515-YIELD-TYPE-INDEX)
                     NOT = WS-LITERAL-T-YLD) AND
                     (WS-2515-TBL-YIELD-TYPE(WS-2515-YIELD-TYPE-INDEX)
                     NOT = WS-LITERAL-D-YLD)
                     MOVE 15060 TO WS-8000-ERROR-CODE
                     PERFORM 2515-SET-ERROR
                        THRU 2515-SET-ERROR-EXIT
                     MOVE WS-2515-TBL-YIELD-TYPE
                          (WS-2515-YIELD-TYPE-INDEX)
                       TO WS-8000-BAD-DATA1
                     MOVE 'T, D, A, J, P' TO WS-8000-CORR-DATA1
                     MOVE 2515 TO WS-8000-PARAGRAPH-NO
                     PERFORM 8000-RECORD-TRAN-ERROR
                        THRU 8000-RECORD-TRAN-ERROR-EXIT
                     GO TO 2515-VAL-SUCCESSORS-EXIT
                  END-IF

      *        **** YIELD TYPE D MUST BE FOLLOWED BY A T, D, A, J, OR P
               WHEN WS-LITERAL-D-YLD
                  IF (WS-2515-TBL-YIELD-TYPE(WS-2515-YIELD-TYPE-INDEX)
                     NOT = WS-LITERAL-A-YLD) AND
                     (WS-2515-TBL-YIELD-TYPE(WS-2515-YIELD-TYPE-INDEX)
                     NOT = WS-LITERAL-J-YLD) AND
                     (WS-2515-TBL-YIELD-TYPE(WS-2515-YIELD-TYPE-INDEX)
                     NOT = WS-LITERAL-P-YLD) AND
                     (WS-2515-TBL-YIELD-TYPE(WS-2515-YIELD-TYPE-INDEX)
                     NOT = WS-LITERAL-T-YLD) AND
                     (WS-2515-TBL-YIELD-TYPE(WS-2515-YIELD-TYPE-INDEX)
                     NOT = WS-LITERAL-D-YLD)
                     MOVE 15060 TO WS-8000-ERROR-CODE
                     PERFORM 2515-SET-ERROR
                        THRU 2515-SET-ERROR-EXIT
                     MOVE WS-2515-TBL-YIELD-TYPE
                          (WS-2515-YIELD-TYPE-INDEX)
                       TO WS-8000-BAD-DATA1
                     MOVE 'T, D, A, J, P' TO WS-8000-CORR-DATA1
                     MOVE 2515 TO WS-8000-PARAGRAPH-NO
                     PERFORM 8000-RECORD-TRAN-ERROR
                        THRU 8000-RECORD-TRAN-ERROR-EXIT
                     GO TO 2515-VAL-SUCCESSORS-EXIT
                  END-IF

      *        **** YIELD TYPE H MUST BE FOLLOWED BY AN H, A, J, OR P
               WHEN WS-LITERAL-H-YLD
                  IF (WS-2515-TBL-YIELD-TYPE(WS-2515-YIELD-TYPE-INDEX)
                     NOT = WS-LITERAL-A-YLD) AND
                     (WS-2515-TBL-YIELD-TYPE(WS-2515-YIELD-TYPE-INDEX)
                     NOT = WS-LITERAL-J-YLD) AND
                     (WS-2515-TBL-YIELD-TYPE(WS-2515-YIELD-TYPE-INDEX)
                     NOT = WS-LITERAL-P-YLD) AND
                     (WS-2515-TBL-YIELD-TYPE(WS-2515-YIELD-TYPE-INDEX)
                     NOT = WS-LITERAL-H-YLD)
                     MOVE 15060 TO WS-8000-ERROR-CODE
                     PERFORM 2515-SET-ERROR
                        THRU 2515-SET-ERROR-EXIT
                     MOVE WS-2515-TBL-YIELD-TYPE
                          (WS-2515-YIELD-TYPE-INDEX)
                       TO WS-8000-BAD-DATA1
                     MOVE 'H, A, J, P' TO WS-8000-CORR-DATA1
                     MOVE 2515 TO WS-8000-PARAGRAPH-NO
                     PERFORM 8000-RECORD-TRAN-ERROR
                        THRU 8000-RECORD-TRAN-ERROR-EXIT
                     GO TO 2515-VAL-SUCCESSORS-EXIT
                  END-IF

      *        **** YIELD TYPE I MUST BE FOLLOWED BY AN I, A, J, OR P
               WHEN WS-LITERAL-I-YLD
                  IF (WS-2515-TBL-YIELD-TYPE(WS-2515-YIELD-TYPE-INDEX)
                     NOT = WS-LITERAL-A-YLD) AND
                     (WS-2515-TBL-YIELD-TYPE(WS-2515-YIELD-TYPE-INDEX)
                     NOT = WS-LITERAL-J-YLD) AND
                     (WS-2515-TBL-YIELD-TYPE(WS-2515-YIELD-TYPE-INDEX)
                     NOT = WS-LITERAL-P-YLD) AND
                     (WS-2515-TBL-YIELD-TYPE(WS-2515-YIELD-TYPE-INDEX)
                     NOT = WS-LITERAL-I-YLD)
                     MOVE 15060 TO WS-8000-ERROR-CODE
                     PERFORM 2515-SET-ERROR
                        THRU 2515-SET-ERROR-EXIT
                     MOVE WS-2515-TBL-YIELD-TYPE
                          (WS-2515-YIELD-TYPE-INDEX)
                       TO WS-8000-BAD-DATA1
                     MOVE 'I, A, J, P' TO WS-8000-CORR-DATA1
                     MOVE 2515 TO WS-8000-PARAGRAPH-NO
                     PERFORM 8000-RECORD-TRAN-ERROR
                        THRU 8000-RECORD-TRAN-ERROR-EXIT
                     GO TO 2515-VAL-SUCCESSORS-EXIT
                  END-IF

      *        **** YIELD TYPE L MUST BE FOLLOWED BY AN L, A, J, OR P
               WHEN WS-LITERAL-L-YLD
                  IF (WS-2515-TBL-YIELD-TYPE(WS-2515-YIELD-TYPE-INDEX)
                     NOT = WS-LITERAL-A-YLD) AND
                     (WS-2515-TBL-YIELD-TYPE(WS-2515-YIELD-TYPE-INDEX)
                     NOT = WS-LITERAL-J-YLD) AND
                     (WS-2515-TBL-YIELD-TYPE(WS-2515-YIELD-TYPE-INDEX)
                     NOT = WS-LITERAL-P-YLD) AND
                     (WS-2515-TBL-YIELD-TYPE(WS-2515-YIELD-TYPE-INDEX)
                     NOT = WS-LITERAL-L-YLD)
                     MOVE 15060 TO WS-8000-ERROR-CODE
                     PERFORM 2515-SET-ERROR
                        THRU 2515-SET-ERROR-EXIT
                     MOVE WS-2515-TBL-YIELD-TYPE
                          (WS-2515-YIELD-TYPE-INDEX)
                       TO WS-8000-BAD-DATA1
                     MOVE 'L, A, J, P' TO WS-8000-CORR-DATA1
                     MOVE 2515 TO WS-8000-PARAGRAPH-NO
                     PERFORM 8000-RECORD-TRAN-ERROR
                        THRU 8000-RECORD-TRAN-ERROR-EXIT
                     GO TO 2515-VAL-SUCCESSORS-EXIT
                  END-IF
           END-EVALUATE

           MOVE WS-2515-TBL-YIELD-TYPE(WS-2515-YIELD-TYPE-INDEX)
             TO WS-2515-HOLD-YIELD-TYPE.


       2515-VAL-SUCCESSORS-EXIT.
           EXIT.


       2515-VAL-POSITIONS.

      $IF DEBUG-SW DEFINED
          DISPLAY '2515-VALIDATING YIELD TYPE POSITIONS'
          UPON CONSOLE
      $END


           IF (WS-2515-YIELD-TYPE10 = SPACES) OR
              (WS-2515-YIELD-TYPE9  = SPACES) OR
              (WS-2515-YIELD-TYPE8  = SPACES) OR
              (WS-2515-YIELD-TYPE7  = SPACES)
              MOVE 15062 TO WS-8000-ERROR-CODE
              MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR7
              MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR8
              MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR9
              MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR10
              MOVE WS-LITERAL-YLD-TYPE-YR10 TO WS-8000-FIELD-NAME1
              MOVE WS-2515-YIELD-TYPE10 TO WS-8000-BAD-DATA1
              MOVE WS-LITERAL-YLD-TYPE-YR9 TO WS-8000-FIELD-NAME2
              MOVE WS-2515-YIELD-TYPE9 TO WS-8000-BAD-DATA2
              MOVE WS-LITERAL-YLD-TYPE-YR8 TO WS-8000-FIELD-NAME3
              MOVE WS-2515-YIELD-TYPE8 TO WS-8000-BAD-DATA3
              MOVE 2515 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
              GO TO 2515-VAL-POSITIONS-EXIT
           END-IF


      *       *** ALL YIELD TYPE S MUST BE IN THE MOST RECENT FOUR YRS
           IF WS-2515-65-PCT-S-COUNT = 4 THEN
              IF WS-2515-YIELD-TYPE10 NOT = WS-LITERAL-S-YLD OR
                 WS-2515-YIELD-TYPE9 NOT = WS-LITERAL-S-YLD OR
                 WS-2515-YIELD-TYPE8 NOT = WS-LITERAL-S-YLD OR
                 WS-2515-YIELD-TYPE7 NOT = WS-LITERAL-S-YLD
                 MOVE 15061 TO WS-8000-ERROR-CODE
                 MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR7
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR8
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR9
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR10
                 MOVE WS-LITERAL-YLD-TYPE-YR10 TO WS-8000-FIELD-NAME1
                 MOVE WS-2515-YIELD-TYPE10 TO WS-8000-BAD-DATA1
                 MOVE WS-LITERAL-S-YLD TO WS-8000-CORR-DATA1
                 MOVE WS-LITERAL-YLD-TYPE-YR9 TO WS-8000-FIELD-NAME2
                 MOVE WS-2515-YIELD-TYPE9 TO WS-8000-BAD-DATA2
                 MOVE WS-LITERAL-S-YLD TO WS-8000-CORR-DATA2
                 MOVE WS-LITERAL-YLD-TYPE-YR8 TO WS-8000-FIELD-NAME3
                 MOVE WS-2515-YIELD-TYPE8 TO WS-8000-BAD-DATA3
                 MOVE WS-LITERAL-S-YLD TO WS-8000-CORR-DATA3
                 MOVE 2515 TO WS-8000-PARAGRAPH-NO
                 PERFORM 8000-RECORD-TRAN-ERROR
                    THRU 8000-RECORD-TRAN-ERROR-EXIT
                 GO TO 2515-VAL-POSITIONS-EXIT
              END-IF
           END-IF

      *       *** ALL YIELD TYPE I MUST BE IN THE MOST RECENT FOUR YRS
           IF WS-2515-100-PCT-NEW-I-COUNT > 0 THEN
              IF WS-2515-100-PCT-NEW-I-COUNT = 4 THEN
                 IF WS-2515-YIELD-TYPE10 NOT
                    = WS-LITERAL-I-YLD OR
                    WS-2515-YIELD-TYPE9 NOT
                    = WS-LITERAL-I-YLD OR
                    WS-2515-YIELD-TYPE8 NOT
                    = WS-LITERAL-I-YLD OR
                    WS-2515-YIELD-TYPE7 NOT
                    = WS-LITERAL-I-YLD
                    MOVE 15061 TO WS-8000-ERROR-CODE
                    MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                    MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR7
                    MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR8
                    MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR9
                    MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR10
                    MOVE WS-LITERAL-YLD-TYPE-YR10
                      TO WS-8000-FIELD-NAME1
                    MOVE WS-2515-YIELD-TYPE10
                      TO WS-8000-BAD-DATA1
                    MOVE WS-LITERAL-I-YLD
                      TO WS-8000-CORR-DATA1
                    MOVE WS-LITERAL-YLD-TYPE-YR9
                      TO WS-8000-FIELD-NAME2
                    MOVE WS-2515-YIELD-TYPE9
                      TO WS-8000-BAD-DATA2
                    MOVE WS-LITERAL-I-YLD
                      TO WS-8000-CORR-DATA2
                    MOVE WS-LITERAL-YLD-TYPE-YR8
                      TO WS-8000-FIELD-NAME3
                    MOVE WS-2515-YIELD-TYPE8
                      TO WS-8000-BAD-DATA3
                    MOVE WS-LITERAL-I-YLD
                      TO WS-8000-CORR-DATA3
                    MOVE 2515 TO WS-8000-PARAGRAPH-NO
                    PERFORM 8000-RECORD-TRAN-ERROR
                       THRU 8000-RECORD-TRAN-ERROR-EXIT
                    GO TO 2515-VAL-POSITIONS-EXIT
                 END-IF

      *          **** IF THERE ARE LESS THAN 4 I RECORDS, THE
      *          **** MOST RECENT ONE MUST BE AN A, J, OR P.
              ELSE
                 IF (WS-2515-YIELD-TYPE10 NOT
                    = WS-LITERAL-A-YLD) AND
                    (WS-2515-YIELD-TYPE10 NOT
                    = WS-LITERAL-J-YLD) AND
                    (WS-2515-YIELD-TYPE10 NOT
                    = WS-LITERAL-P-YLD)
                    MOVE 15061 TO WS-8000-ERROR-CODE
                    MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                    MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR7
                    MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR8
                    MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR9
                    MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR10
                    MOVE WS-LITERAL-YLD-TYPE-YR10
                      TO WS-8000-FIELD-NAME1
                    MOVE WS-2515-YIELD-TYPE10
                      TO WS-8000-BAD-DATA1
                    MOVE 'A, J, P'
                      TO WS-8000-CORR-DATA1
                    MOVE WS-LITERAL-YLD-TYPE-YR9
                      TO WS-8000-FIELD-NAME2
                    MOVE WS-2515-YIELD-TYPE9
                      TO WS-8000-BAD-DATA2
                    MOVE WS-LITERAL-YLD-TYPE-YR8
                      TO WS-8000-FIELD-NAME3
                    MOVE WS-2515-YIELD-TYPE8
                      TO WS-8000-BAD-DATA3
                    MOVE 2515 TO WS-8000-PARAGRAPH-NO
                    PERFORM 8000-RECORD-TRAN-ERROR
                       THRU 8000-RECORD-TRAN-ERROR-EXIT
                    GO TO 2515-VAL-POSITIONS-EXIT
              END-IF
           END-IF

      *       *** ALL YIELD TYPE H MUST BE IN THE MOST RECENT FOUR YRS
           IF WS-2515-110-PCT-H-PILOT-COUNT > 0 THEN
              IF WS-2515-110-PCT-H-PILOT-COUNT = 4 THEN
                 IF WS-2515-YIELD-TYPE10 NOT
                    = WS-LITERAL-H-YLD OR
                    WS-2515-YIELD-TYPE9 NOT
                    = WS-LITERAL-H-YLD OR
                    WS-2515-YIELD-TYPE8 NOT
                    = WS-LITERAL-H-YLD OR
                    WS-2515-YIELD-TYPE7 NOT
                    = WS-LITERAL-H-YLD
                    MOVE 15061 TO WS-8000-ERROR-CODE
                    MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                    MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR7
                    MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR8
                    MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR9
                    MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR10
                    MOVE WS-LITERAL-YLD-TYPE-YR10
                      TO WS-8000-FIELD-NAME1
                    MOVE WS-2515-YIELD-TYPE10
                      TO WS-8000-BAD-DATA1
                    MOVE WS-LITERAL-H-YLD
                      TO WS-8000-CORR-DATA1
                    MOVE WS-LITERAL-YLD-TYPE-YR9
                      TO WS-8000-FIELD-NAME2
                    MOVE WS-2515-YIELD-TYPE9
                      TO WS-8000-BAD-DATA2
                    MOVE WS-LITERAL-H-YLD
                      TO WS-8000-CORR-DATA2
                    MOVE WS-LITERAL-YLD-TYPE-YR8
                      TO WS-8000-FIELD-NAME3
                    MOVE WS-2515-YIELD-TYPE8
                      TO WS-8000-BAD-DATA3
                    MOVE WS-LITERAL-H-YLD
                      TO WS-8000-CORR-DATA3
                    MOVE 2515 TO WS-8000-PARAGRAPH-NO
                    PERFORM 8000-RECORD-TRAN-ERROR
                       THRU 8000-RECORD-TRAN-ERROR-EXIT
                    GO TO 2515-VAL-POSITIONS-EXIT
                 END-IF

      *          **** IF THERE ARE LESS THAN 4 H RECORDS, THE
      *          **** MOST RECENT ONE MUST BE AN A, J, OR P.
              ELSE
                 IF (WS-2515-YIELD-TYPE10 NOT
                    = WS-LITERAL-A-YLD) AND
                    (WS-2515-YIELD-TYPE10 NOT
                    = WS-LITERAL-J-YLD) AND
                    (WS-2515-YIELD-TYPE10 NOT
                    = WS-LITERAL-P-YLD)
                    MOVE 15061 TO WS-8000-ERROR-CODE
                    MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                    MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR7
                    MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR8
                    MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR9
                    MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR10
                    MOVE WS-LITERAL-YLD-TYPE-YR10
                      TO WS-8000-FIELD-NAME1
                    MOVE WS-2515-YIELD-TYPE10
                      TO WS-8000-BAD-DATA1
                    MOVE 'A, J, P'
                      TO WS-8000-CORR-DATA1
                    MOVE WS-LITERAL-YLD-TYPE-YR9
                      TO WS-8000-FIELD-NAME2
                    MOVE WS-2515-YIELD-TYPE9
                      TO WS-8000-BAD-DATA2
                    MOVE WS-LITERAL-YLD-TYPE-YR8
                      TO WS-8000-FIELD-NAME3
                    MOVE WS-2515-YIELD-TYPE8
                      TO WS-8000-BAD-DATA3
                    MOVE 2515 TO WS-8000-PARAGRAPH-NO
                    PERFORM 8000-RECORD-TRAN-ERROR
                       THRU 8000-RECORD-TRAN-ERROR-EXIT
                    GO TO 2515-VAL-POSITIONS-EXIT
              END-IF
           END-IF

      *       *** ALL YIELD TYPE X MUST BE IN THE MOST RECENT FOUR YRS
           IF WS-2515-80-PCT-NEW-X-COUNT = 4 THEN
              IF WS-2515-YIELD-TYPE10 NOT = WS-LITERAL-X-YLD OR
                 WS-2515-YIELD-TYPE9 NOT = WS-LITERAL-X-YLD OR
                 WS-2515-YIELD-TYPE8 NOT = WS-LITERAL-X-YLD OR
                 WS-2515-YIELD-TYPE7 NOT = WS-LITERAL-X-YLD
                 MOVE 15061 TO WS-8000-ERROR-CODE
                 MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR7
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR8
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR9
                 MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR10
                 MOVE WS-LITERAL-YLD-TYPE-YR10 TO WS-8000-FIELD-NAME1
                 MOVE WS-2515-YIELD-TYPE10 TO WS-8000-BAD-DATA1
                 MOVE WS-LITERAL-X-YLD TO WS-8000-CORR-DATA1
                 MOVE WS-LITERAL-YLD-TYPE-YR9 TO WS-8000-FIELD-NAME2
                 MOVE WS-2515-YIELD-TYPE9 TO WS-8000-BAD-DATA2
                 MOVE WS-LITERAL-X-YLD TO WS-8000-CORR-DATA2
                 MOVE WS-LITERAL-YLD-TYPE-YR8 TO WS-8000-FIELD-NAME3
                 MOVE WS-2515-YIELD-TYPE8 TO WS-8000-BAD-DATA3
                 MOVE WS-LITERAL-X-YLD TO WS-8000-CORR-DATA3
                 MOVE 2515 TO WS-8000-PARAGRAPH-NO
                 PERFORM 8000-RECORD-TRAN-ERROR
                    THRU 8000-RECORD-TRAN-ERROR-EXIT
                 GO TO 2515-VAL-POSITIONS-EXIT
              END-IF
           END-IF


      *       *** ALL YIELD TYPE C MUST BE IN THE MOST RECENT FOUR YRS
           IF WS-2515-SPECIAL-C-COUNT > 0 THEN
              IF WS-2515-SPECIAL-C-COUNT = 4 THEN
                 IF WS-2515-YIELD-TYPE10 NOT
                    = WS-LITERAL-C-YLD OR
                    WS-2515-YIELD-TYPE9 NOT
                    = WS-LITERAL-C-YLD OR
                    WS-2515-YIELD-TYPE8 NOT
                    = WS-LITERAL-C-YLD OR
                    WS-2515-YIELD-TYPE7 NOT
                    = WS-LITERAL-C-YLD
                    MOVE 15061 TO WS-8000-ERROR-CODE
                    MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                    MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR7
                    MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR8
                    MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR9
                    MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR10
                    MOVE WS-LITERAL-YLD-TYPE-YR10
                      TO WS-8000-FIELD-NAME1
                    MOVE WS-2515-YIELD-TYPE10
                      TO WS-8000-BAD-DATA1
                    MOVE WS-LITERAL-C-YLD
                      TO WS-8000-CORR-DATA1
                    MOVE WS-LITERAL-YLD-TYPE-YR9
                      TO WS-8000-FIELD-NAME2
                    MOVE WS-2515-YIELD-TYPE9
                      TO WS-8000-BAD-DATA2
                    MOVE WS-LITERAL-C-YLD
                      TO WS-8000-CORR-DATA2
                    MOVE WS-LITERAL-YLD-TYPE-YR8
                      TO WS-8000-FIELD-NAME3
                    MOVE WS-2515-YIELD-TYPE8
                      TO WS-8000-BAD-DATA3
                    MOVE WS-LITERAL-C-YLD
                      TO WS-8000-CORR-DATA3
                    MOVE 2515 TO WS-8000-PARAGRAPH-NO
                    PERFORM 8000-RECORD-TRAN-ERROR
                       THRU 8000-RECORD-TRAN-ERROR-EXIT
                    GO TO 2515-VAL-POSITIONS-EXIT
                 END-IF

      *          **** IF THERE ARE LESS THAN 4 C RECORDS, THE
      *          **** MOST RECENT ONE MUST BE AN A, J, OR P.
              ELSE
                 IF (WS-2515-YIELD-TYPE10 NOT
                    = WS-LITERAL-A-YLD) AND
                    (WS-2515-YIELD-TYPE10 NOT
                    = WS-LITERAL-J-YLD) AND
                    (WS-2515-YIELD-TYPE10 NOT
                    = WS-LITERAL-P-YLD)
                    MOVE 15061 TO WS-8000-ERROR-CODE
                    MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                    MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR7
                    MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR8
                    MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR9
                    MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR10
                    MOVE WS-LITERAL-YLD-TYPE-YR10
                      TO WS-8000-FIELD-NAME1
                    MOVE WS-2515-YIELD-TYPE10
                      TO WS-8000-BAD-DATA1
                    MOVE 'A, J, P'
                      TO WS-8000-CORR-DATA1
                    MOVE WS-LITERAL-YLD-TYPE-YR9
                      TO WS-8000-FIELD-NAME2
                    MOVE WS-2515-YIELD-TYPE9
                      TO WS-8000-BAD-DATA2
                    MOVE WS-LITERAL-YLD-TYPE-YR8
                      TO WS-8000-FIELD-NAME3
                    MOVE WS-2515-YIELD-TYPE8
                      TO WS-8000-BAD-DATA3
                    MOVE 2515 TO WS-8000-PARAGRAPH-NO
                    PERFORM 8000-RECORD-TRAN-ERROR
                       THRU 8000-RECORD-TRAN-ERROR-EXIT
                    GO TO 2515-VAL-POSITIONS-EXIT
              END-IF
           END-IF



      *       *** ALL YIELD TYPE F MUST BE IN THE MOST RECENT FOUR YRS
           IF WS-2515-RSO-ASSIGNED-F-COUNT > 0 THEN
              IF WS-2515-RSO-ASSIGNED-F-COUNT = 4 THEN
                 IF WS-2515-YIELD-TYPE10 NOT
                    = WS-LITERAL-F-YLD OR
                    WS-2515-YIELD-TYPE9 NOT
                    = WS-LITERAL-F-YLD OR
                    WS-2515-YIELD-TYPE8 NOT
                    = WS-LITERAL-F-YLD OR
                    WS-2515-YIELD-TYPE7 NOT
                    = WS-LITERAL-F-YLD
                    MOVE 15061 TO WS-8000-ERROR-CODE
                    MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                    MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR7
                    MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR8
                    MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR9
                    MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR10
                    MOVE WS-LITERAL-YLD-TYPE-YR10
                      TO WS-8000-FIELD-NAME1
                    MOVE WS-2515-YIELD-TYPE10
                      TO WS-8000-BAD-DATA1
                    MOVE WS-LITERAL-F-YLD
                      TO WS-8000-CORR-DATA1
                    MOVE WS-LITERAL-YLD-TYPE-YR9
                      TO WS-8000-FIELD-NAME2
                    MOVE WS-2515-YIELD-TYPE9
                      TO WS-8000-BAD-DATA2
                    MOVE WS-LITERAL-F-YLD
                      TO WS-8000-CORR-DATA2
                    MOVE WS-LITERAL-YLD-TYPE-YR8
                      TO WS-8000-FIELD-NAME3
                    MOVE WS-2515-YIELD-TYPE8
                      TO WS-8000-BAD-DATA3
                    MOVE WS-LITERAL-F-YLD
                      TO WS-8000-CORR-DATA3
                    MOVE 2515 TO WS-8000-PARAGRAPH-NO
                    PERFORM 8000-RECORD-TRAN-ERROR
                       THRU 8000-RECORD-TRAN-ERROR-EXIT
                    GO TO 2515-VAL-POSITIONS-EXIT
                 END-IF

      *          **** IF THERE ARE LESS THAN 4 F RECORDS, THE
      *          **** MOST RECENT ONE MUST BE AN A, J, OR P.
              ELSE
                 IF (WS-2515-YIELD-TYPE10 NOT
                    = WS-LITERAL-A-YLD) AND
                    (WS-2515-YIELD-TYPE10 NOT
                    = WS-LITERAL-J-YLD) AND
                    (WS-2515-YIELD-TYPE10 NOT
                    = WS-LITERAL-P-YLD)
                    MOVE 15061 TO WS-8000-ERROR-CODE
                    MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                    MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR7
                    MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR8
                    MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR9
                    MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR10
                    MOVE WS-LITERAL-YLD-TYPE-YR10
                      TO WS-8000-FIELD-NAME1
                    MOVE WS-2515-YIELD-TYPE10
                      TO WS-8000-BAD-DATA1
                    MOVE 'A, J, P'
                      TO WS-8000-CORR-DATA1
                    MOVE WS-LITERAL-YLD-TYPE-YR9
                      TO WS-8000-FIELD-NAME2
                    MOVE WS-2515-YIELD-TYPE9
                      TO WS-8000-BAD-DATA2
                    MOVE WS-LITERAL-YLD-TYPE-YR8
                      TO WS-8000-FIELD-NAME3
                    MOVE WS-2515-YIELD-TYPE8
                      TO WS-8000-BAD-DATA3
                    MOVE 2515 TO WS-8000-PARAGRAPH-NO
                    PERFORM 8000-RECORD-TRAN-ERROR
                       THRU 8000-RECORD-TRAN-ERROR-EXIT
                    GO TO 2515-VAL-POSITIONS-EXIT
              END-IF
           END-IF


      *       *** ALL YIELD TYPE L MUST BE IN THE MOST RECENT FOUR YRS
           IF WS-2515-SPECIAL-L-COUNT > 0 THEN
              IF WS-2515-SPECIAL-L-COUNT = 4 THEN
                 IF WS-2515-YIELD-TYPE10 NOT
                    = WS-LITERAL-L-YLD OR
                    WS-2515-YIELD-TYPE9 NOT
                    = WS-LITERAL-L-YLD OR
                    WS-2515-YIELD-TYPE8 NOT
                    = WS-LITERAL-L-YLD OR
                    WS-2515-YIELD-TYPE7 NOT
                    = WS-LITERAL-L-YLD
                    MOVE 15061 TO WS-8000-ERROR-CODE
                    MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                    MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR7
                    MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR8
                    MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR9
                    MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR10
                    MOVE WS-LITERAL-YLD-TYPE-YR10
                      TO WS-8000-FIELD-NAME1
                    MOVE WS-2515-YIELD-TYPE10
                      TO WS-8000-BAD-DATA1
                    MOVE WS-LITERAL-L-YLD
                      TO WS-8000-CORR-DATA1
                    MOVE WS-LITERAL-YLD-TYPE-YR9
                      TO WS-8000-FIELD-NAME2
                    MOVE WS-2515-YIELD-TYPE9
                      TO WS-8000-BAD-DATA2
                    MOVE WS-LITERAL-L-YLD
                      TO WS-8000-CORR-DATA2
                    MOVE WS-LITERAL-YLD-TYPE-YR8
                      TO WS-8000-FIELD-NAME3
                    MOVE WS-2515-YIELD-TYPE8
                      TO WS-8000-BAD-DATA3
                    MOVE WS-LITERAL-L-YLD
                      TO WS-8000-CORR-DATA3
                    MOVE 2515 TO WS-8000-PARAGRAPH-NO
                    PERFORM 8000-RECORD-TRAN-ERROR
                       THRU 8000-RECORD-TRAN-ERROR-EXIT
                    GO TO 2515-VAL-POSITIONS-EXIT
                 END-IF

      *          **** IF THERE ARE LESS THAN 4 L RECORDS, THE
      *          **** MOST RECENT ONE MUST BE AN A, J, OR P.
              ELSE
                 IF (WS-2515-YIELD-TYPE10 NOT
                    = WS-LITERAL-A-YLD) AND
                    (WS-2515-YIELD-TYPE10 NOT
                    = WS-LITERAL-J-YLD) AND
                    (WS-2515-YIELD-TYPE10 NOT
                    = WS-LITERAL-P-YLD)
                    MOVE 15061 TO WS-8000-ERROR-CODE
                    MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                    MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR7
                    MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR8
                    MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR9
                    MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR10
                    MOVE WS-LITERAL-YLD-TYPE-YR10
                      TO WS-8000-FIELD-NAME1
                    MOVE WS-2515-YIELD-TYPE10
                      TO WS-8000-BAD-DATA1
                    MOVE 'A, J, P'
                      TO WS-8000-CORR-DATA1
                    MOVE WS-LITERAL-YLD-TYPE-YR9
                      TO WS-8000-FIELD-NAME2
                    MOVE WS-2515-YIELD-TYPE9
                      TO WS-8000-BAD-DATA2
                    MOVE WS-LITERAL-YLD-TYPE-YR8
                      TO WS-8000-FIELD-NAME3
                    MOVE WS-2515-YIELD-TYPE8
                      TO WS-8000-BAD-DATA3
                    MOVE 2515 TO WS-8000-PARAGRAPH-NO
                    PERFORM 8000-RECORD-TRAN-ERROR
                       THRU 8000-RECORD-TRAN-ERROR-EXIT
                    GO TO 2515-VAL-POSITIONS-EXIT
              END-IF
           END-IF.


       2515-VAL-POSITIONS-EXIT.
           EXIT.


       2515-SET-ERROR.

           MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
           EVALUATE WS-2515-YIELD-TYPE-INDEX
                WHEN 1
                   MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR1
                   MOVE WS-LITERAL-YLD-TYPE-YR1
                     TO WS-8000-FIELD-NAME1
                WHEN 2
                   MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR2
                   MOVE WS-LITERAL-YLD-TYPE-YR2
                     TO WS-8000-FIELD-NAME1
                WHEN 3
                   MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR3
                   MOVE WS-LITERAL-YLD-TYPE-YR3
                     TO WS-8000-FIELD-NAME1
                WHEN 4
                   MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR4
                   MOVE WS-LITERAL-YLD-TYPE-YR4
                     TO WS-8000-FIELD-NAME1
                WHEN 5
                   MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR5
                   MOVE WS-LITERAL-YLD-TYPE-YR5
                     TO WS-8000-FIELD-NAME1
                WHEN 6
                   MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR6
                   MOVE WS-LITERAL-YLD-TYPE-YR6
                     TO WS-8000-FIELD-NAME1
                WHEN 7
                   MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR7
                   MOVE WS-LITERAL-YLD-TYPE-YR7
                     TO WS-8000-FIELD-NAME1
                WHEN 8
                   MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR8
                   MOVE WS-LITERAL-YLD-TYPE-YR8
                     TO WS-8000-FIELD-NAME1
                WHEN 9
                   MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR9
                   MOVE WS-LITERAL-YLD-TYPE-YR9
                     TO WS-8000-FIELD-NAME1
                WHEN 10
                   MOVE WS-LITERAL-YES TO ERROR-YLD-TYPE-YR10
                   MOVE WS-LITERAL-YLD-TYPE-YR10
                     TO WS-8000-FIELD-NAME1
                WHEN OTHER
                   MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
                   MOVE 044 TO WS-8000-SHORT-ERROR
                   MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
                   MOVE 'YLD TYPE TBL IDX'
                     TO WS-8000-FIELD-NAME1
                   SET WS-2515-INTEGER-ERROR
                    TO WS-2515-YIELD-TYPE-INDEX
                   MOVE WS-2515-INTEGER-ERROR
                     TO WS-8000-BAD-DATA1
                   MOVE 'YIELD TYPE TABLE INDEX OUT OF BOUNDS'
                     TO WS-8000-CORR-DATA1
                   MOVE 2515 TO WS-8000-PARAGRAPH-NO
                   PERFORM 8000-RECORD-TRAN-ERROR
                      THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-EVALUATE.

       2515-SET-ERROR-EXIT.
           EXIT.
