      *****************************************************************
      *  File   : IF2520.CBL
      *  Author : MIKE RAY
      *  Date   : 02/10/97
      *  Purpose: VALIDATE UNIT PREMIUM ADJUSTMENT FACTOR
      *           IF ENTERPRISE OR WHOLE FARM UNITS, DEPENDS UPON THE
      *           NUMBER OF SECTIONS. IF BASIC UNITS, MUST BE 1.000.
      *           IF OPTIONAL UNITS, DEPENDS UPON CROP AS FOLLOWS:
      *              CORN = 1.220  SOYBEANS = 1.300
      *****************************************************************

       2520-VAL-UNIT-PREM-ADJ.

      $IF DEBUG-SW DEFINED
          DISPLAY '2520-VALIDATING UNIT PREMIUM ADJUSTMENT FACTOR'
          UPON CONSOLE
      $END

      **********************************************
      *            CHECK PRE-CONDITIONS            *
      **********************************************
           IF ERROR-UNIT-PREM-ADJ-FACTOR = WS-LITERAL-YES OR
              ERROR-UNIT-OPT-CD = WS-LITERAL-YES OR
              ERROR-CROP-CD = WS-LITERAL-YES OR
              ERROR-NBR-OF-SECTIONS = WS-LITERAL-YES
              MOVE WS-LITERAL-YES TO ERROR-UNIT-PREM-ADJ-FACTOR
              GO TO 2520-VAL-UNIT-PREM-ADJ-EXIT
           END-IF

      **********************************************
      *    SET UP DISPLAY FIELDS                   *
      **********************************************
           INITIALIZE WS-2520-WORK
           MOVE WS-2520-UNIT-PREM-ADJ-FCTR
             TO WS-2520-UNIT-PREM-ADJ-FCTR-X
           MOVE WS-2520-WFARM-DISCOUNT-FCTR
             TO WS-2520-WFARM-DISCOUNT-FCTR-X

      $IF DEBUG-SW DEFINED
           DISPLAY 'INPUT UNIT PREMIUM ADJ FCTR = ',
           WS-2520-UNIT-PREM-ADJ-FCTR-X
           UPON CONSOLE
           DISPLAY 'INPUT WHOLE FARM DISCOUNT   = ',
           WS-2520-WFARM-DISCOUNT-FCTR-X
           UPON CONSOLE
      $END

      **********************************************
      *    MUST BE ZERO IF NOT REVENUE ASSURANCE   *
      **********************************************
           IF WS-2520-INS-PLAN-CD <> WS-LITERAL-RA
              IF WS-2520-UNIT-PREM-ADJ-FCTR <> ZERO
                 MOVE 11007 TO WS-8000-ERROR-CODE
                 MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                 MOVE WS-LITERAL-YES
                   TO ERROR-UNIT-PREM-ADJ-FACTOR
                 MOVE WS-LITERAL-UNIT-PREM-ADJ-FCTR
                   TO WS-8000-FIELD-NAME1
                 MOVE WS-2520-UNIT-PREM-ADJ-FCTR-X
                   TO WS-8000-BAD-DATA1
                 MOVE '0.0000' TO WS-8000-CORR-DATA1
                 MOVE 2520 TO WS-8000-PARAGRAPH-NO
                 PERFORM 8000-RECORD-TRAN-ERROR
                    THRU 8000-RECORD-TRAN-ERROR-EXIT
              END-IF
              IF WS-2520-NUMBER-OF-SECTIONS <> ZERO
                 MOVE 11007 TO WS-8000-ERROR-CODE
                 MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                 MOVE WS-LITERAL-YES
                   TO ERROR-NBR-OF-SECTIONS
                 MOVE WS-LITERAL-NBR-OF-SECTIONS
                   TO WS-8000-FIELD-NAME1
                 MOVE WS-2520-NUMBER-OF-SECTIONS
                   TO WS-8000-BAD-DATA1
                 MOVE '00' TO WS-8000-CORR-DATA1
                 MOVE 2520 TO WS-8000-PARAGRAPH-NO
                 PERFORM 8000-RECORD-TRAN-ERROR
                    THRU 8000-RECORD-TRAN-ERROR-EXIT
              END-IF
              IF WS-2520-WFARM-DISCOUNT-FCTR <> ZERO
                 MOVE 11007 TO WS-8000-ERROR-CODE
                 MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                 MOVE WS-LITERAL-YES
                   TO ERROR-WHOLE-FARM-DISCOUNT-FCTR
                 MOVE WS-LITERAL-WHOLE-FARM-DISC
                   TO WS-8000-FIELD-NAME1
                 MOVE WS-2520-WFARM-DISCOUNT-FCTR-X
                   TO WS-8000-BAD-DATA1
                 MOVE '0.000' TO WS-8000-CORR-DATA1
                 MOVE 2520 TO WS-8000-PARAGRAPH-NO
                 PERFORM 8000-RECORD-TRAN-ERROR
                    THRU 8000-RECORD-TRAN-ERROR-EXIT
              END-IF
              GO TO 2520-VAL-UNIT-PREM-ADJ-EXIT
           END-IF

      **********************************************
      *    DETERMINE CORRECT ADJUSTMENT            *
      **********************************************
           EVALUATE WS-2520-UNIT-OPT-CD
               WHEN WS-LITERAL-BASIC-UNIT
                  MOVE 1.000 TO WS-2520-CORRECT-UNIT-ADJ
                  MOVE WS-LITERAL-NO TO WS-2520-WFARM-REQ-FLAG

               WHEN WS-LITERAL-OPT-UNIT
                  EVALUATE WS-2520-CROP-CD
                   WHEN WS-LITERAL-CORN
                      MOVE 1.220 TO WS-2520-CORRECT-UNIT-ADJ
                      MOVE WS-LITERAL-NO TO WS-2520-WFARM-REQ-FLAG
                   WHEN WS-LITERAL-SOYBEANS
                      MOVE 1.300 TO WS-2520-CORRECT-UNIT-ADJ
                      MOVE WS-LITERAL-NO TO WS-2520-WFARM-REQ-FLAG
                  END-EVALUATE

               WHEN WS-LITERAL-ENTERPRISE-UNIT
                  IF WS-2520-NUMBER-OF-SECTIONS = ZERO
                     MOVE 11005 TO WS-8000-ERROR-CODE
                     MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                     MOVE WS-LITERAL-YES
                       TO ERROR-NBR-OF-SECTIONS
                     MOVE WS-LITERAL-NBR-OF-SECTIONS
                       TO WS-8000-FIELD-NAME1
                     MOVE WS-2520-NUMBER-OF-SECTIONS
                       TO WS-8000-BAD-DATA1
                     MOVE '> ZERO' TO WS-8000-CORR-DATA1
                     MOVE 2520 TO WS-8000-PARAGRAPH-NO
                     PERFORM 8000-RECORD-TRAN-ERROR
                        THRU 8000-RECORD-TRAN-ERROR-EXIT
                     GO TO 2520-VAL-UNIT-PREM-ADJ-EXIT
                  END-IF
                  PERFORM 2520-LOOKUP-FACTOR
                     THRU 2520-LOOKUP-FACTOR-EXIT
                  MOVE WS-LITERAL-NO TO WS-2520-WFARM-REQ-FLAG
                  IF ERROR-UNIT-PREM-ADJ-FACTOR = WS-LITERAL-YES
                     GO TO 2520-VAL-UNIT-PREM-ADJ-EXIT
                  END-IF

               WHEN WS-LITERAL-WHOLE-FARM-UNIT
                  IF WS-2520-NUMBER-OF-SECTIONS = ZERO
                     MOVE 11005 TO WS-8000-ERROR-CODE
                     MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                     MOVE WS-LITERAL-YES
                       TO ERROR-NBR-OF-SECTIONS
                     MOVE WS-LITERAL-NBR-OF-SECTIONS
                       TO WS-8000-FIELD-NAME1
                     MOVE WS-2520-NUMBER-OF-SECTIONS
                       TO WS-8000-BAD-DATA1
                     MOVE '> ZERO' TO WS-8000-CORR-DATA1
                     MOVE 2520 TO WS-8000-PARAGRAPH-NO
                     PERFORM 8000-RECORD-TRAN-ERROR
                        THRU 8000-RECORD-TRAN-ERROR-EXIT
                     GO TO 2520-VAL-UNIT-PREM-ADJ-EXIT
                  END-IF
                  PERFORM 2520-LOOKUP-FACTOR
                     THRU 2520-LOOKUP-FACTOR-EXIT
                  IF ERROR-UNIT-PREM-ADJ-FACTOR = WS-LITERAL-YES
                     GO TO 2520-VAL-UNIT-PREM-ADJ-EXIT
                  END-IF
                  MOVE WS-LITERAL-YES TO WS-2520-WFARM-REQ-FLAG

           END-EVALUATE

           MOVE WS-2520-CORRECT-UNIT-ADJ
             TO WS-2520-CORRECT-UNIT-ADJ-X

      **********************************************
      *    CHECK AGAINST INPUT ADJUSTMENT          *
      **********************************************
           IF WS-2520-UNIT-PREM-ADJ-FCTR <>
              WS-2520-CORRECT-UNIT-ADJ
              MOVE 11015 TO WS-8000-ERROR-CODE
              MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES
                TO ERROR-UNIT-PREM-ADJ-FACTOR
              MOVE WS-LITERAL-UNIT-PREM-ADJ-FCTR
                TO WS-8000-FIELD-NAME1
              MOVE WS-2520-UNIT-PREM-ADJ-FCTR-X
                TO WS-8000-BAD-DATA1
              MOVE WS-2520-CORRECT-UNIT-ADJ-X
                TO WS-8000-CORR-DATA1
              MOVE 2520 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-2520-WFARM-REQ-FLAG = WS-LITERAL-NO
              IF WS-2520-WFARM-DISCOUNT-FCTR <> 1.000
                 MOVE 11004 TO WS-8000-ERROR-CODE
                 MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                 MOVE WS-LITERAL-YES
                   TO ERROR-WHOLE-FARM-DISCOUNT-FCTR
                 MOVE WS-LITERAL-WHOLE-FARM-DISC
                   TO WS-8000-FIELD-NAME1
                 MOVE WS-2520-WFARM-DISCOUNT-FCTR-X
                   TO WS-8000-BAD-DATA1
                 MOVE '1.000' TO WS-8000-CORR-DATA1
                 MOVE 2520 TO WS-8000-PARAGRAPH-NO
                 PERFORM 8000-RECORD-TRAN-ERROR
                    THRU 8000-RECORD-TRAN-ERROR-EXIT
              END-IF
           ELSE
              IF WS-2520-WFARM-DISCOUNT-FCTR = ZERO
                 MOVE 11005 TO WS-8000-ERROR-CODE
                 MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                 MOVE WS-LITERAL-YES
                   TO ERROR-WHOLE-FARM-DISCOUNT-FCTR
                 MOVE WS-LITERAL-WHOLE-FARM-DISC
                   TO WS-8000-FIELD-NAME1
                 MOVE WS-2520-WFARM-DISCOUNT-FCTR-X
                   TO WS-8000-BAD-DATA1
                 MOVE '0.800 - 1.000' TO WS-8000-CORR-DATA1
                 MOVE 2520 TO WS-8000-PARAGRAPH-NO
                 PERFORM 8000-RECORD-TRAN-ERROR
                    THRU 8000-RECORD-TRAN-ERROR-EXIT
              END-IF
           END-IF.


       2520-VAL-UNIT-PREM-ADJ-EXIT.
           EXIT.


       2520-LOOKUP-FACTOR.

           IF ERROR-CROP-YR = WS-LITERAL-YES OR
              ERROR-RATE-STATE = WS-LITERAL-YES OR
              ERROR-CROP-CD = WS-LITERAL-YES OR
              ERROR-OPT-CD = WS-LITERAL-YES OR
              ERROR-NBR-OF-SECTIONS = WS-LITERAL-YES
              MOVE WS-LITERAL-YES TO ERROR-UNIT-PREM-ADJ-FACTOR
              GO TO 2520-LOOKUP-FACTOR-EXIT
           END-IF
           INITIALIZE WS-7595-INPUT-KEY
           MOVE WS-2520-CROP-YEAR TO WS-7595-INPUT-CROP-YR
           MOVE WS-2520-RATE-STATE TO WS-7595-INPUT-STATE-CD
           MOVE WS-2520-CROP-CD TO WS-7595-INPUT-CROP-CD
           MOVE WS-2520-INS-PLAN-CD TO WS-7595-INPUT-INS-PLAN
      *    MOVE WS-2520-OPTION-CD TO WS-7595-INPUT-OPTION-CD
           MOVE 'EU' TO WS-7595-INPUT-OPTION-CD
           MOVE WS-2520-NUMBER-OF-SECTIONS
             TO WS-7595-INPUT-NBR-SECTIONS-LOW
      *    *** SET UP ERROR IF DATA IS NOT FOUND ***
           STRING 'ADMWE KEY = '
            DELIMITED BY SIZE
            WS-7595-INPUT-KEY
            DELIMITED BY SIZE
            INTO WS-8000-CORR-DATA1
           END-STRING
           PERFORM 7595-LOOKUP-ADMWE
              THRU 7595-LOOKUP-ADMWE-EXIT

           IF MATCH-FOUND-7595
              MOVE WS-7595-PREM-DISCOUNT-FCTR
                TO WS-2520-CORRECT-UNIT-ADJ
      *       *** CLEAR ERROR DATA IF RECORD IS FOUND ***
              MOVE SPACES
                TO WS-8000-CORR-DATA1
           ELSE
              MOVE 11009 TO WS-8000-ERROR-CODE
              MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES
                TO ERROR-UNIT-PREM-ADJ-FACTOR
              MOVE WS-LITERAL-UNIT-PREM-ADJ-FCTR
                TO WS-8000-FIELD-NAME1
              MOVE WS-2520-UNIT-PREM-ADJ-FCTR-X
                TO WS-8000-BAD-DATA1
      *       *** KEY DATA IS IN WS-8000-CORR-DATA1
              MOVE 2520 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF.

       2520-LOOKUP-FACTOR-EXIT.
           EXIT.
