      ****************************************************************
      *  File   : IF2530.CBL
      *  Author : Yo-I Tsui
      *  Date   : 2/13/96
      *  Purpose: VALIDATE TRANSITIONAL YIELD
      *           IF YIELD TYPE YEAR = T, N, E, H, I, S, OR X
      *              THAN TRANSITIONAL YIELD MUST BE > 0
      *           IF YIELD FLOOR YIELDS ARE APPLICABLE TO THE CROP
      *              THAN TRANSITIONAL YIELD MUST BE > 0
      *           IF TRANSITIONAL > 0 THAN
      *              TRANSITIONAL = CFSA YIELD * YIELD FACTOR
      ****************************************************************

       2530-VAL-TRANSITIONAL-YLD.

      $IF DEBUG-SW DEFINED
          DISPLAY '2530-VALIDATING TRANSITIONAL YIELD'
          UPON CONSOLE
      $END
      **************************************************
      *          INITIALIZE LOCAL VARIABLES            *
      **************************************************
           INITIALIZE WS-2530-LOCAL
           INITIALIZE WS-2530-OUTPUT

      **********************************************
      *            CHECK PRE-CONDITIONS            *
      **********************************************
           IF ERROR-UNIT-OF-MEASURE = WS-LITERAL-YES OR
              ERROR-CROP-CD = WS-LITERAL-YES OR
              ERROR-CROP-YR = WS-LITERAL-YES OR
              ERROR-PRACTICE-CD = WS-LITERAL-YES OR
              ERROR-RATE-STATE =  WS-LITERAL-YES OR
              ERROR-RATE-COUNTY = WS-LITERAL-YES OR
              ERROR-CROP-TYPE = WS-LITERAL-YES OR
              ERROR-MAP-AREA = WS-LITERAL-YES OR
              ERROR-CFSA-YLD = WS-LITERAL-YES OR
              ERROR-YLD-TYPE-YR1  = WS-LITERAL-YES OR
              ERROR-YLD-TYPE-YR2  = WS-LITERAL-YES OR
              ERROR-YLD-TYPE-YR3  = WS-LITERAL-YES OR
              ERROR-YLD-TYPE-YR4  = WS-LITERAL-YES OR
              ERROR-YLD-TYPE-YR5  = WS-LITERAL-YES OR
              ERROR-YLD-TYPE-YR6  = WS-LITERAL-YES OR
              ERROR-YLD-TYPE-YR7  = WS-LITERAL-YES OR
              ERROR-YLD-TYPE-YR8  = WS-LITERAL-YES OR
              ERROR-YLD-TYPE-YR9  = WS-LITERAL-YES OR
              ERROR-YLD-TYPE-YR10 = WS-LITERAL-YES OR
              ERROR-YLD-LIMIT-FL  = WS-LITERAL-YES OR
              ERROR-TRANSITIONAL-YIELD = WS-LITERAL-YES

              MOVE WS-LITERAL-YES TO ERROR-TRANSITIONAL-YIELD
              GO TO 2530-VAL-TRANSITIONAL-YLD-EXIT
           END-IF

      **************************************************
      *          SET UP DISPLAY FIELDS                 *
      **************************************************
           MOVE WS-2530-CFSA-YIELD TO WS-2530-CFSA-YLD
           MOVE WS-2530-TRANS-YIELD TO WS-2530-TRANS-YLD
           MOVE WS-2530-TRANS-YLD TO WS-2530-TRANS-YLD-X
           MOVE WS-2530-CFSA-YLD TO WS-2530-CFSA-YLD-X

      **********************************************
      *    CHECK TO SEE IF ANY YIELD TYPE REQUIRES *
      *    A TRANSITIONAL YIELD                    *
      **********************************************

           PERFORM 2530-CHECK-YIELD
              THRU 2530-CHECK-YIELD-EXIT
              WITH TEST AFTER
           VARYING WS-2530-YIELD-TYPE-INT-INDEX FROM 1 BY 1
             UNTIL (WS-2530-YIELD-TYPE-INT-INDEX = 10) OR
             (WS-2530-TRANS-YIELD-REQ = WS-LITERAL-YES)

      **********************************************
      *    SEE IF THE YIELD LIMITATION FLAG        *
      *    REQUIRES A T YIELD                      *
      **********************************************

           EVALUATE WS-2530-YLD-LMT-FLG
               WHEN 5
                  MOVE WS-LITERAL-YES TO WS-2530-TRANS-YIELD-REQ
               WHEN 6
                  MOVE WS-LITERAL-YES TO WS-2530-TRANS-YIELD-REQ
               WHEN 7
                  MOVE WS-LITERAL-YES TO WS-2530-TRANS-YIELD-REQ
               WHEN 8
                  MOVE WS-LITERAL-YES TO WS-2530-TRANS-YIELD-REQ
           END-EVALUATE

      *    *** THIS IS A SOFTENED EDIT; THE EDIT SHOULD ALSO
      *    *** VALIDATE T YIELD IF THE T YIELD IS > 0.
           IF WS-2530-TRANS-YIELD-REQ NOT = WS-LITERAL-YES
              GO TO 2530-VAL-TRANSITIONAL-YLD-EXIT
           END-IF

      $IF DEBUG-SW DEFINED
           DISPLAY 'TRANSITIONAL YIELD = ',
           WS-2530-TRANS-YLD-X UPON CONSOLE
           DISPLAY 'CFSA YIELD = ', WS-2530-CFSA-YLD-X
           UPON CONSOLE
      $END

           IF WS-2530-TRANS-YLD <= 0
              MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
              MOVE 15005 TO WS-8000-ERROR-CODE
              MOVE WS-LITERAL-YES TO ERROR-TRANSITIONAL-YIELD
              MOVE WS-LITERAL-TRANSITIONAL-YLD
                TO WS-8000-FIELD-NAME1
              MOVE WS-2530-TRANS-YLD-X TO WS-8000-BAD-DATA1
              MOVE '> 0' TO WS-8000-CORR-DATA1
              MOVE 2530 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
              GO TO 2530-VAL-TRANSITIONAL-YLD-EXIT
           END-IF

      **********************************************
      *    LOOKUP THE TRANSITIONAL YIELD           *
      **********************************************

           PERFORM 2530-LOOKUP-T-YIELD
              THRU 2530-LOOKUP-T-YIELD-EXIT

           IF WS-2530-T-YIELD > 0
             IF WS-2530-TRANS-YLD <> WS-2530-T-YIELD
               EVALUATE WS-2530-PRACTICE-CD
                 WHEN '004'
                   MOVE '005' TO WS-2530-PRACTICE-CD
                   PERFORM 2530-LOOKUP-T-YIELD
                   THRU 2530-LOOKUP-T-YIELD-EXIT

                 WHEN '005'
                   MOVE '004' TO WS-2530-PRACTICE-CD
                   PERFORM 2530-LOOKUP-T-YIELD
                   THRU 2530-LOOKUP-T-YIELD-EXIT

               END-EVALUATE
             END-IF
           END-IF

      *    *** SET UP DISPLAY FIELD FOR ERRORS
           MOVE WS-2530-T-YIELD TO WS-2530-T-YIELD-X

      $IF DEBUG-SW DEFINED
           DISPLAY 'ADM T YIELD = ', WS-2530-T-YIELD-X
           UPON CONSOLE
      $END

           IF WS-2530-T-YIELD > 0
              IF WS-2530-TRANS-YLD <> WS-2530-T-YIELD
                 MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                 MOVE 15015 TO WS-8000-ERROR-CODE
                 MOVE WS-LITERAL-YES TO ERROR-TRANSITIONAL-YIELD
                 MOVE WS-LITERAL-TRANSITIONAL-YLD
                   TO WS-8000-FIELD-NAME1
                 MOVE WS-2530-TRANS-YLD-X TO WS-8000-BAD-DATA1
                 MOVE WS-2530-T-YIELD-X TO WS-8000-CORR-DATA1
                 MOVE 2530 TO WS-8000-PARAGRAPH-NO
                 PERFORM 8000-RECORD-TRAN-ERROR
                    THRU 8000-RECORD-TRAN-ERROR-EXIT
              END-IF
           END-IF.

       2530-VAL-TRANSITIONAL-YLD-EXIT.
           EXIT.


       2530-CHECK-YIELD.

           SET WS-2530-YIELD-TYPE-INDEX
            TO WS-2530-YIELD-TYPE-INT-INDEX
           IF WS-2530-TBL-YIELD-TYPE(WS-2530-YIELD-TYPE-INDEX)
              = SPACES
              GO TO 2530-CHECK-YIELD-EXIT
           END-IF

           EVALUATE WS-2530-TBL-YIELD-TYPE(WS-2530-YIELD-TYPE-INDEX)
              WHEN WS-LITERAL-S-YLD
                 MOVE WS-LITERAL-YES TO WS-2530-TRANS-YIELD-REQ
              WHEN WS-LITERAL-T-YLD
                 MOVE WS-LITERAL-YES TO WS-2530-TRANS-YIELD-REQ
              WHEN WS-LITERAL-E-YLD
                 MOVE WS-LITERAL-YES TO WS-2530-TRANS-YIELD-REQ
              WHEN WS-LITERAL-I-YLD
                 MOVE WS-LITERAL-YES TO WS-2530-TRANS-YIELD-REQ
              WHEN WS-LITERAL-N-YLD
                 MOVE WS-LITERAL-YES TO WS-2530-TRANS-YIELD-REQ
              WHEN WS-LITERAL-X-YLD
                 MOVE WS-LITERAL-YES TO WS-2530-TRANS-YIELD-REQ
              WHEN WS-LITERAL-H-YLD
                 MOVE WS-LITERAL-YES TO WS-2530-TRANS-YIELD-REQ
              WHEN WS-LITERAL-D-YLD
                 MOVE WS-LITERAL-YES TO WS-2530-TRANS-YIELD-REQ
              WHEN OTHER
                 CONTINUE
           END-EVALUATE.


       2530-CHECK-YIELD-EXIT.
           EXIT.



      $IF ISAM-SW DEFINED

       2530-LOOKUP-T-YIELD.

           INITIALIZE WS-7558-INPUT-KEY
           MOVE WS-2530-CROP-YEAR TO WS-7558-INPUT-CROP-YR
           MOVE WS-2530-STATE TO WS-7558-INPUT-STATE-CD
           MOVE WS-2530-COUNTY TO WS-7558-INPUT-COUNTY-CD
           MOVE WS-2530-CROP-CD TO WS-7558-INPUT-CROP-CD
           MOVE WS-2530-INSURANCE-PLAN-ID
             TO WS-7558-INPUT-INSURANCE-PLAN
           MOVE WS-2530-PRACTICE-CD TO WS-7558-INPUT-PRACTICE-CD
           MOVE WS-2530-TYPE TO WS-7558-INPUT-TYPE-CD
           IF WS-2530-MAP-AREA = ZEROS
              MOVE SPACES TO WS-7558-INPUT-T-YIELD-MAP-AREA
           ELSE
              MOVE WS-2530-MAP-AREA TO WS-7558-INPUT-T-YIELD-MAP-AREA
           END-IF
      *    *** SET UP ERROR IN CASE RECORD IS NOT FOUND ***
           STRING 'SEARCHED WITH '
            DELIMITED BY SIZE
            WS-7558-INPUT-KEY
            DELIMITED BY SIZE
            INTO WS-8000-CORR-DATA1
           END-STRING
           PERFORM 7558-LOOKUP-ADMY
              THRU 7558-LOOKUP-ADMY-EXIT

           IF NOT MATCH-FOUND-7558
      *       *** NOT ALL PERENNIAL CROPS ARE IN ADMY
      *       *** SO WE HAVE TO ACCEPT THE T YIELD
      *       *** WITHOUT VALIDATING IT.
              IF (NOT PERENNIAL-CROP-0009 AND
                  WS-2530-INSURANCE-PLAN-ID <> WS-LITERAL-IP)
                 IF MAP-REQUIRED-7558
                    MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                    MOVE 15083 TO WS-8000-ERROR-CODE
                    MOVE WS-LITERAL-YES TO ERROR-MAP-AREA
                    MOVE WS-LITERAL-MAP-AREA TO WS-8000-FIELD-NAME1
                    MOVE WS-2530-MAP-AREA TO WS-8000-BAD-DATA1
                    MOVE 'valid map area' TO WS-8000-CORR-DATA1
                    MOVE 2530 TO WS-8000-PARAGRAPH-NO
                    PERFORM 8000-RECORD-TRAN-ERROR
                       THRU 8000-RECORD-TRAN-ERROR-EXIT
                 ELSE
                    MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                    MOVE 15009 TO WS-8000-ERROR-CODE
                    MOVE WS-LITERAL-YES TO ERROR-TRANSITIONAL-YIELD
                    MOVE 'ADMY REC' TO WS-8000-FIELD-NAME1
                    MOVE 'NOT FOUND' TO WS-8000-BAD-DATA1
      *             *** CORR DATA 1 IS SET ABOVE ***
                    MOVE 2530 TO WS-8000-PARAGRAPH-NO
                    PERFORM 8000-RECORD-TRAN-ERROR
                       THRU 8000-RECORD-TRAN-ERROR-EXIT
                 END-IF
                 GO TO 2530-LOOKUP-T-YIELD-EXIT
              END-IF
      *       GO TO 2530-LOOKUP-T-YIELD-EXIT
           END-IF

      *    *** WIPE OUT THE ERROR THAT WAS SET UP ABOVE
           INITIALIZE WS-8000-CORR-DATA1
           IF WS-7558-AREA-YIELD > ZEROS
              MOVE WS-7558-AREA-YIELD TO WS-2530-T-YIELD
              GO TO 2530-LOOKUP-T-YIELD-EXIT
           END-IF

      *    *** IF THIS IS A T YIELD, THERE MAY BE A FACTOR
      *    *** INSTEAD OF A YIELD IN THE ADM
           IF WS-7558-YIELD-FLG = 'T' OR
              WS-7558-YIELD-FLG = 'U' OR
              WS-7558-YIELD-FLG = 'D'
              IF WS-2530-CFSA-YLD <= ZEROS
                 MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                 MOVE 15005 TO WS-8000-ERROR-CODE
                 MOVE WS-LITERAL-YES TO ERROR-CFSA-YLD
                 MOVE WS-LITERAL-CFSA-YLD TO WS-8000-FIELD-NAME1
                 MOVE WS-2530-CFSA-YLD-X TO WS-8000-BAD-DATA1
                 MOVE '> 0, when Yield is a T,U,D.'
                   TO WS-8000-CORR-DATA1
                 MOVE 2530 TO WS-8000-PARAGRAPH-NO
                 PERFORM 8000-RECORD-TRAN-ERROR
                    THRU 8000-RECORD-TRAN-ERROR-EXIT
                 GO TO 2530-LOOKUP-T-YIELD-EXIT
              END-IF

              MOVE WS-LITERAL-YES TO WS-2530-CFSA-YIELD-REQ
              IF WS-2530-CROP-UNIT-OF-MEASURE =
                 WS-LITERAL-BARRELS
                 OR WS-2530-CROP-UNIT-OF-MEASURE =
                 WS-LITERAL-TONS
      *          *** CALCULATED T-YIELD MUST BE ROUNDED TO TENTHS
                 COMPUTE WS-2530-T-YIELD-TENTHS ROUNDED =
                    WS-2530-CFSA-YLD * WS-7558-YIELD-FACTOR
                    ON SIZE ERROR
                       MOVE 2530 TO WS-8020-PARAGRAPH-NO
                       MOVE 90017 TO WS-8020-INT-ERROR-NO
                       MOVE 'T-YIELD TENTHS'
                         TO WS-8020-FIELD-NAME
                       MOVE SPACES
                         TO WS-8020-BAD-DATA
                       MOVE WS-LITERAL-YES
                         TO WS-8020-ABORT-PROGRAM
                       PERFORM 8020-RECORD-INT-ERROR
                          THRU 8020-RECORD-INT-ERROR-EXIT
                 END-COMPUTE
                 MOVE WS-2530-T-YIELD-TENTHS TO WS-2530-T-YIELD
              ELSE
      *          *** CALCULATED T-YIELD MUST BE ROUNDED TO WHOLE
                 COMPUTE WS-2530-T-YIELD-WHOLE ROUNDED =
                    WS-2530-CFSA-YLD * WS-7558-YIELD-FACTOR
                    ON SIZE ERROR
                       MOVE 2530 TO WS-8020-PARAGRAPH-NO
                       MOVE 90017 TO WS-8020-INT-ERROR-NO
                       MOVE 'T-YIELD WHOLE'
                         TO WS-8020-FIELD-NAME
                       MOVE SPACES
                         TO WS-8020-BAD-DATA
                       MOVE WS-LITERAL-YES
                         TO WS-8020-ABORT-PROGRAM
                       PERFORM 8020-RECORD-INT-ERROR
                          THRU 8020-RECORD-INT-ERROR-EXIT
                 END-COMPUTE
                 MOVE WS-2530-T-YIELD-WHOLE TO WS-2530-T-YIELD
              END-IF
      $IF DEBUG-SW DEFINED
           MOVE WS-2530-T-YIELD TO WS-2530-T-YIELD-X
           DISPLAY 'CALC T YIELD = ',
           WS-2530-T-YIELD-X UPON CONSOLE
      $END
      *       *** IF THERE IS A MAXIMUM YIELD, THE CALCULATED
      *       *** T YIELD MUST BE LESS THAN IT.
              IF WS-7558-MAX-YIELD > ZEROS
                 IF WS-2530-T-YIELD > WS-7558-MAX-YIELD
                    MOVE WS-7558-MAX-YIELD TO WS-2530-T-YIELD
                 END-IF
              END-IF
           END-IF.

       2530-LOOKUP-T-YIELD-EXIT.
           EXIT.

      $END

