      ****************************************************************
      *  File   : IF2545.CBL
      *  Author : Mike Ray
      *  Date   : 2/15/96
      *  Purpose: Validate Previous Approved Yield
      *           IF THE YEAR 10 YIELD TYPE = 'P' OR
      *              THE YIELD LIMITATION FLAG = {1,2,3,5,6,7}
      *              MUST BE > 0
      *           ELSE
      *              IF ANY YIELD TYPE = 'S'
      *                 MUST BE = 0
      *
      * 12/03/96  PUT YIELD LIMITATION FLAG CHECK BACK INTO PROGRAM
      *           PER M13 (REVISION 03).  JLH.
      ****************************************************************

       2545-VAL-PR-APPROVED-YLD.

      $IF DEBUG-SW DEFINED
          DISPLAY '2545-VALIDATING PREVIOUS APPROVED YIELD'
      $END

      **********************************************
      *            CHECK PRE-CONDITIONS            *
      **********************************************
           IF ERROR-CROP-CD = WS-LITERAL-YES OR
              ERROR-YLD-TYPE-YR1  = WS-LITERAL-YES OR
              ERROR-YLD-TYPE-YR2  = WS-LITERAL-YES OR
              ERROR-YLD-TYPE-YR3  = WS-LITERAL-YES OR
              ERROR-YLD-TYPE-YR4  = WS-LITERAL-YES OR
              ERROR-YLD-TYPE-YR5  = WS-LITERAL-YES OR
              ERROR-YLD-TYPE-YR6  = WS-LITERAL-YES OR
              ERROR-YLD-TYPE-YR7  = WS-LITERAL-YES OR
              ERROR-YLD-TYPE-YR8  = WS-LITERAL-YES OR
              ERROR-YLD-TYPE-YR9  = WS-LITERAL-YES OR
              ERROR-YLD-TYPE-YR10 = WS-LITERAL-YES OR
              ERROR-YLD-LIMIT-FL  = WS-LITERAL-YES OR
              ERROR-PREV-APPROV-YLD = WS-LITERAL-YES
              MOVE WS-LITERAL-YES TO ERROR-PREV-APPROV-YLD
              GO TO 2545-VAL-PR-APPROVED-YLD-EXIT
           END-IF

      **************************************************
      *          INITIALIZE LOCAL VARIABLES            *
      **************************************************
           INITIALIZE WS-2545-LOCAL
           MOVE WS-2545-PREV-APPROVED-YLD
             TO WS-2545-PREV-APPROVED-YIELD

      *    *** SET UP DISPLAY FIELDS FOR ERRORS
           MOVE WS-2545-PREV-APPROVED-YIELD
             TO WS-2545-PREV-APPROVED-YIELD-X

      $IF DEBUG-SW DEFINED
           DISPLAY 'PREVIOUS APPROVED YIELD = ',
           WS-2545-PREV-APPROVED-YIELD-X
      $END

      **********************************************
      *    LOOK FOR YIELD TYPES 'P' AND 'S'        *
      **********************************************

           SET WS-2545-YIELD-TYPE-INDEX TO 1
           PERFORM 2545-CHECK-YIELD
              THRU 2545-CHECK-YIELD-EXIT
              WITH TEST AFTER
           VARYING WS-2545-YIELD-TYPE-INT-INDEX FROM 1 BY 1
             UNTIL (WS-2545-YIELD-TYPE-INT-INDEX = 10).

      *******************************************************
      *  SEE IF THE YIELD LIMITATION FLAG
      *  REQUIRES A PA YIELD
      *******************************************************

           EVALUATE WS-2545-YLD-LMT-FLG
               WHEN 1
                  MOVE WS-LITERAL-YES TO WS-2545-PA-YIELD-REQ
               WHEN 2
                  MOVE WS-LITERAL-YES TO WS-2545-PA-YIELD-REQ
               WHEN 3
                  MOVE WS-LITERAL-YES TO WS-2545-PA-YIELD-REQ
               WHEN 4
                  CONTINUE
               WHEN 5
                  MOVE WS-LITERAL-YES TO WS-2545-PA-YIELD-REQ
               WHEN 6
                  MOVE WS-LITERAL-YES TO WS-2545-PA-YIELD-REQ
               WHEN 7
                  MOVE WS-LITERAL-YES TO WS-2545-PA-YIELD-REQ
               WHEN 8
                 IF WS-2545-PREV-APPROVED-YIELD > ZEROS
                    MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                    MOVE 15007 TO WS-8000-ERROR-CODE
                    MOVE WS-LITERAL-YES TO ERROR-PREV-APPROV-YLD
                    MOVE WS-LITERAL-PREV-APPROV-YLD
                      TO WS-8000-FIELD-NAME1
                    MOVE WS-2545-PREV-APPROVED-YIELD-X
                      TO WS-8000-BAD-DATA1
                    MOVE '0.0 WHEN YIELD LIMITATION FLG = 8'
                      TO WS-8000-CORR-DATA1
                    MOVE 2545 TO WS-8000-PARAGRAPH-NO
                    PERFORM 8000-RECORD-TRAN-ERROR
                       THRU 8000-RECORD-TRAN-ERROR-EXIT
                  END-IF
               WHEN OTHER
                  MOVE WS-LITERAL-YES TO ERROR-PREV-APPROV-YLD
                  MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
                  MOVE 044 TO WS-8000-SHORT-ERROR
                  MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
                  MOVE WS-LITERAL-YLD-LIMIT-FL TO WS-8000-FIELD-NAME1
                  MOVE WS-2545-YLD-LMT-FLG TO WS-8000-BAD-DATA1
                  MOVE 'NO LOGIC FOR THIS YIELD LIMITATION FLAG'
                    TO WS-8000-CORR-DATA1
                  MOVE 2545 TO WS-8000-PARAGRAPH-NO
                  PERFORM 8000-RECORD-TRAN-ERROR
                     THRU 8000-RECORD-TRAN-ERROR-EXIT
                  GO TO 2545-VAL-PR-APPROVED-YLD-EXIT
           END-EVALUATE


           IF (WS-2545-PA-YIELD-REQ = WS-LITERAL-YES) OR
              (WS-2545-TYPE-P-FOUND = WS-LITERAL-YES)
              MOVE WS-LITERAL-YES TO WS-2545-PA-YIELD-REQ
           ELSE
              IF WS-2545-TYPE-S-FOUND <> WS-LITERAL-YES
                 GO TO 2545-VAL-PR-APPROVED-YLD-EXIT
              END-IF
           END-IF.

      **********************************************
      *    CHECK TO SEE IF THE PA YIELD IS > 0     *
      **********************************************
           IF (WS-2545-PA-YIELD-REQ = WS-LITERAL-YES)
              IF (WS-2545-PREV-APPROVED-YIELD <= ZEROS)
                 MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                 MOVE 15005 TO WS-8000-ERROR-CODE
                 MOVE WS-LITERAL-YES TO ERROR-PREV-APPROV-YLD
                 MOVE WS-LITERAL-PREV-APPROV-YLD
                   TO WS-8000-FIELD-NAME1
                 MOVE WS-2545-PREV-APPROVED-YIELD-X
                   TO WS-8000-BAD-DATA1
                 MOVE '> 0.0' TO WS-8000-CORR-DATA1
                 MOVE 2545 TO WS-8000-PARAGRAPH-NO
                 PERFORM 8000-RECORD-TRAN-ERROR
                    THRU 8000-RECORD-TRAN-ERROR-EXIT
              ELSE
                 GO TO 2545-VAL-PR-APPROVED-YLD-EXIT
              END-IF
           ELSE
              IF (WS-2545-TYPE-S-FOUND = WS-LITERAL-YES) AND
                 (WS-2545-PREV-APPROVED-YIELD > ZEROS)
                 MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                 MOVE 15007 TO WS-8000-ERROR-CODE
                 MOVE WS-LITERAL-YES TO ERROR-PREV-APPROV-YLD
                 MOVE WS-LITERAL-PREV-APPROV-YLD
                   TO WS-8000-FIELD-NAME1
                 MOVE WS-2545-PREV-APPROVED-YIELD-X
                   TO WS-8000-BAD-DATA1
                 MOVE '0.0 WHEN YLD TYPE S REPORTED'
                   TO WS-8000-CORR-DATA1
                 MOVE 2545 TO WS-8000-PARAGRAPH-NO
                 PERFORM 8000-RECORD-TRAN-ERROR
                    THRU 8000-RECORD-TRAN-ERROR-EXIT
              END-IF
           END-IF.

       2545-VAL-PR-APPROVED-YLD-EXIT.
           EXIT.


       2545-CHECK-YIELD.

           SET WS-2545-YIELD-TYPE-INDEX
            TO WS-2545-YIELD-TYPE-INT-INDEX
           IF WS-2545-TBL-YIELD-TYPE(WS-2545-YIELD-TYPE-INDEX)
              = SPACES
              GO TO 2545-CHECK-YIELD-EXIT
           END-IF

           EVALUATE WS-2545-TBL-YIELD-TYPE(WS-2545-YIELD-TYPE-INDEX)
              WHEN WS-LITERAL-P-YLD
                 IF WS-2545-YIELD-TYPE-INT-INDEX = 10
                    MOVE WS-LITERAL-YES TO WS-2545-TYPE-P-FOUND
                 END-IF
              WHEN WS-LITERAL-S-YLD
                 MOVE WS-LITERAL-YES TO WS-2545-TYPE-S-FOUND
              WHEN OTHER
                 CONTINUE
           END-EVALUATE.


       2545-CHECK-YIELD-EXIT.
           EXIT.

