      ****************************************************************
      *  File   : IF2550.CBL
      *  Author : Mike Ray
      *  Date   : 2/14/96
      *  Purpose: VALIDATE APPROVED YIELD
      *
      *  Modifications, Enhancements, etc:
      *
      *  09/96   RECREATE WS-YIELD-LIMITATION-FLAG; CHECK TO SEE
      *  IF AVG YIELD CALCULATED FALLS INTO VALID YIELD CUP, CAP
      *  OR FLOOR RANGE (SEE "CALCULATE CORRECT YIELD").    JLH.
      *
      *  12/96   PUT YIELD-LIMITATION-FLAG BACK INTO PROGRAM, PER
      *  M13 (REVISION 3). PARAGRAPH 2550-RECREATE-YIELD-FLAG
      *  IS TEMPORARY UNTIL ALL COMPANIES SEND YIELD-LIMIT-FLAG. JLH.
      *
      ****************************************************************

       2550-VAL-APPROVED-YIELD.

      $IF DEBUG-SW DEFINED
          DISPLAY '2550-VALIDATING APPROVED YIELD'
      $END

      **********************************************
      *        INITIALIZE LOCAL WORKING STORAGE    *
      **********************************************
           INITIALIZE WS-2550-LOCAL
           INITIALIZE WS-2550-OUTPUT

      **********************************************
      *            CHECK PRE-CONDITIONS            *
      **********************************************
           IF ERROR-CROP-CD = WS-LITERAL-YES OR
              ERROR-UNIT-OF-MEASURE = WS-LITERAL-YES OR
              ERROR-PREV-APPROV-YLD = WS-LITERAL-YES OR
              ERROR-TRANSITIONAL-YIELD = WS-LITERAL-YES OR
              ERROR-YLD-IND = WS-LITERAL-YES OR
              ERROR-YLD-LIMIT-FL = WS-LITERAL-YES OR
              ERROR-AVG-YIELD = WS-LITERAL-YES OR
              ERROR-APPROVED-YLD = WS-LITERAL-YES OR
              ERROR-INSUR-PLAN-CD = WS-LITERAL-YES

              MOVE WS-LITERAL-YES TO ERROR-APPROVED-YLD
              GO TO 2550-VAL-APPROVED-YIELD-EXIT
           END-IF


      $IF DEBUG-SW DEFINED
            MOVE WS-2550-PREV-APPROVED-YIELD
              TO WS-2550-DISPLAY-YIELD-X
            DISPLAY 'PREV APPROVED YLD  = ',
            WS-2550-DISPLAY-YIELD-X UPON CONSOLE
            MOVE WS-2550-APPROVED-YIELD TO WS-2550-DISPLAY-YIELD-X
            DISPLAY 'INPUT APPROVED YLD = ',
            WS-2550-DISPLAY-YIELD-X UPON CONSOLE
      $END

      *************************************************
      * IF YIELD INDICATOR = F OR M - SKIP VALIDATION *
      *************************************************
           IF WS-2550-YIELD-INDICATOR = WS-LITERAL-RSO-ASSIGNED-YLD OR
              WS-2550-YIELD-INDICATOR = WS-LITERAL-MASTER-YIELD
              GO TO 2550-VAL-APPROVED-YIELD-EXIT
           END-IF


      **************************************************
      * IF INSURANCE PLAN = AVOCADOS - SKIP VALIDATION *
      **************************************************
           IF WS-2550-INS-PLAN-CD = WS-LITERAL-ARC
              GO TO 2550-VAL-APPROVED-YIELD-EXIT
           END-IF

      **********************************************
      *          CALCULATE YIELD FLOORS            *
      **********************************************

           IF WS-2550-UNIT-OF-MEASURE = WS-LITERAL-BARRELS OR
              WS-2550-UNIT-OF-MEASURE = WS-LITERAL-TONS
              COMPUTE WS-2550-YIELD-FLOOR ROUNDED
                = (WS-2550-TRANSITIONAL-YIELD
                  * 0.70)
                ON SIZE ERROR
                   MOVE 2550 TO WS-8020-PARAGRAPH-NO
                   MOVE 90017 TO WS-8020-INT-ERROR-NO
                   MOVE 'T YIELD * FLOOR PCT'
                     TO WS-8020-FIELD-NAME
                   MOVE SPACES TO WS-8020-BAD-DATA
                   MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                   PERFORM 8020-RECORD-INT-ERROR
                      THRU 8020-RECORD-INT-ERROR-EXIT
              END-COMPUTE
           ELSE
              COMPUTE WS-2550-YIELD-FLOOR-INT ROUNDED
                = (WS-2550-TRANSITIONAL-YIELD
                  * 0.70)
                ON SIZE ERROR
                   MOVE 2550 TO WS-8020-PARAGRAPH-NO
                   MOVE 90017 TO WS-8020-INT-ERROR-NO
                   MOVE 'T YIELD * FLOOR PCT'
                     TO WS-8020-FIELD-NAME
                   MOVE SPACES TO WS-8020-BAD-DATA
                   MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                   PERFORM 8020-RECORD-INT-ERROR
                      THRU 8020-RECORD-INT-ERROR-EXIT
              END-COMPUTE
              MOVE WS-2550-YIELD-FLOOR-INT TO WS-2550-YIELD-FLOOR
           END-IF
           MOVE WS-2550-YIELD-FLOOR TO WS-2550-YIELD-FLOOR-70

      $IF DEBUG-SW DEFINED
            MOVE WS-2550-YIELD-FLOOR-70
              TO WS-2550-DISPLAY-YIELD-X
            DISPLAY '70% YIELD FLOOR = ', WS-2550-DISPLAY-YIELD-X
      $END

           IF WS-2550-UNIT-OF-MEASURE = WS-LITERAL-BARRELS OR
              WS-2550-UNIT-OF-MEASURE = WS-LITERAL-TONS
              COMPUTE WS-2550-YIELD-FLOOR ROUNDED
                = (WS-2550-TRANSITIONAL-YIELD
                  * 0.75)
                ON SIZE ERROR
                   MOVE 2550 TO WS-8020-PARAGRAPH-NO
                   MOVE 90017 TO WS-8020-INT-ERROR-NO
                   MOVE 'T YIELD * FLOOR PCT'
                     TO WS-8020-FIELD-NAME
                   MOVE SPACES TO WS-8020-BAD-DATA
                   MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                   PERFORM 8020-RECORD-INT-ERROR
                      THRU 8020-RECORD-INT-ERROR-EXIT
              END-COMPUTE
           ELSE
              COMPUTE WS-2550-YIELD-FLOOR-INT ROUNDED
                = (WS-2550-TRANSITIONAL-YIELD
                  * 0.75)
                ON SIZE ERROR
                   MOVE 2550 TO WS-8020-PARAGRAPH-NO
                   MOVE 90017 TO WS-8020-INT-ERROR-NO
                   MOVE 'T YIELD * FLOOR PCT'
                     TO WS-8020-FIELD-NAME
                   MOVE SPACES TO WS-8020-BAD-DATA
                   MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                   PERFORM 8020-RECORD-INT-ERROR
                      THRU 8020-RECORD-INT-ERROR-EXIT
              END-COMPUTE
              MOVE WS-2550-YIELD-FLOOR-INT TO WS-2550-YIELD-FLOOR
           END-IF
           MOVE WS-2550-YIELD-FLOOR TO WS-2550-YIELD-FLOOR-75

      $IF DEBUG-SW DEFINED
            MOVE WS-2550-YIELD-FLOOR-75
              TO WS-2550-DISPLAY-YIELD-X
            DISPLAY '75% YIELD FLOOR = ', WS-2550-DISPLAY-YIELD-X
      $END

           IF WS-2550-UNIT-OF-MEASURE = WS-LITERAL-BARRELS OR
              WS-2550-UNIT-OF-MEASURE = WS-LITERAL-TONS
              COMPUTE WS-2550-YIELD-FLOOR ROUNDED
                = (WS-2550-TRANSITIONAL-YIELD
                  * 0.80)
                ON SIZE ERROR
                   MOVE 2550 TO WS-8020-PARAGRAPH-NO
                   MOVE 90017 TO WS-8020-INT-ERROR-NO
                   MOVE 'T YIELD * FLOOR PCT'
                     TO WS-8020-FIELD-NAME
                   MOVE SPACES TO WS-8020-BAD-DATA
                   MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                   PERFORM 8020-RECORD-INT-ERROR
                      THRU 8020-RECORD-INT-ERROR-EXIT
              END-COMPUTE
           ELSE
              COMPUTE WS-2550-YIELD-FLOOR-INT ROUNDED
                = (WS-2550-TRANSITIONAL-YIELD
                  * 0.80)
                ON SIZE ERROR
                   MOVE 2550 TO WS-8020-PARAGRAPH-NO
                   MOVE 90017 TO WS-8020-INT-ERROR-NO
                   MOVE 'T YIELD * FLOOR PCT'
                     TO WS-8020-FIELD-NAME
                   MOVE SPACES TO WS-8020-BAD-DATA
                   MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                   PERFORM 8020-RECORD-INT-ERROR
                      THRU 8020-RECORD-INT-ERROR-EXIT
              END-COMPUTE
              MOVE WS-2550-YIELD-FLOOR-INT TO WS-2550-YIELD-FLOOR
           END-IF
           MOVE WS-2550-YIELD-FLOOR TO WS-2550-YIELD-FLOOR-80

      $IF DEBUG-SW DEFINED
            MOVE WS-2550-YIELD-FLOOR-80
              TO WS-2550-DISPLAY-YIELD-X
            DISPLAY '80% YIELD FLOOR = ', WS-2550-DISPLAY-YIELD-X
      $END

           EVALUATE WS-2550-ACTUAL-YEARS
               WHEN 0 THRU 1
                  MOVE 0.70 TO WS-2550-CORR-YIELD-FLOOR-PCT
                  MOVE WS-2550-YIELD-FLOOR-70 TO WS-2550-YIELD-FLOOR
               WHEN 2 THRU 4
                  MOVE 0.75 TO WS-2550-CORR-YIELD-FLOOR-PCT
                  MOVE WS-2550-YIELD-FLOOR-75 TO WS-2550-YIELD-FLOOR
               WHEN 5 THRU 10
                  MOVE 0.80 TO WS-2550-CORR-YIELD-FLOOR-PCT
                  MOVE WS-2550-YIELD-FLOOR-80 TO WS-2550-YIELD-FLOOR
           END-EVALUATE
           MOVE WS-2550-CORR-YIELD-FLOOR-PCT
             TO WS-2550-DISPLAY-PCT-X
           MOVE WS-2550-YIELD-FLOOR
             TO WS-2550-DISPLAY-YIELD-X

      $IF DEBUG-SW DEFINED
           DISPLAY 'CORRECT YIELD FLOOR % = ',
           WS-2550-DISPLAY-PCT-X, ' ', WS-2550-DISPLAY-YIELD-X
           UPON CONSOLE
      $END


      **********************************************
      *          CALCULATE YIELD CAP               *
      **********************************************
           IF WS-2550-UNIT-OF-MEASURE = WS-LITERAL-BARRELS OR
              WS-2550-UNIT-OF-MEASURE = WS-LITERAL-TONS
              COMPUTE WS-2550-YIELD-CAP ROUNDED
                = (WS-2550-PREV-APPROVED-YIELD * 1.20)
                ON SIZE ERROR
                   MOVE 2550 TO WS-8020-PARAGRAPH-NO
                   MOVE 90017 TO WS-8020-INT-ERROR-NO
                   MOVE 'PA YIELD * 1+CAP'
                     TO WS-8020-FIELD-NAME
                   MOVE SPACES TO WS-8020-BAD-DATA
                   MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                   PERFORM 8020-RECORD-INT-ERROR
                      THRU 8020-RECORD-INT-ERROR-EXIT
              END-COMPUTE
           ELSE
              COMPUTE WS-2550-YIELD-CAP-INT ROUNDED
                = (WS-2550-PREV-APPROVED-YIELD * 1.20)
                ON SIZE ERROR
                   MOVE 2550 TO WS-8020-PARAGRAPH-NO
                   MOVE 90017 TO WS-8020-INT-ERROR-NO
                   MOVE 'PA YIELD * 1+CAP'
                     TO WS-8020-FIELD-NAME
                   MOVE SPACES TO WS-8020-BAD-DATA
                   MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                   PERFORM 8020-RECORD-INT-ERROR
                      THRU 8020-RECORD-INT-ERROR-EXIT
              END-COMPUTE
              MOVE WS-2550-YIELD-CAP-INT TO WS-2550-YIELD-CAP
           END-IF

      $IF DEBUG-SW DEFINED
           MOVE WS-2550-YIELD-CAP
             TO WS-2550-DISPLAY-YIELD-X
           DISPLAY 'YIELD CAP = ', WS-2550-DISPLAY-YIELD-X
      $END

      **********************************************
      *          CALCULATE YIELD CUP               *
      **********************************************
           IF WS-2550-UNIT-OF-MEASURE = WS-LITERAL-BARRELS OR
              WS-2550-UNIT-OF-MEASURE = WS-LITERAL-TONS
              COMPUTE WS-2550-YIELD-CUP ROUNDED
                = (WS-2550-PREV-APPROVED-YIELD * 0.90)
                ON SIZE ERROR
                   MOVE 2550 TO WS-8020-PARAGRAPH-NO
                   MOVE 90017 TO WS-8020-INT-ERROR-NO
                   MOVE 'PA YIELD * 1-CUP'
                     TO WS-8020-FIELD-NAME
                   MOVE SPACES TO WS-8020-BAD-DATA
                   MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                   PERFORM 8020-RECORD-INT-ERROR
                      THRU 8020-RECORD-INT-ERROR-EXIT
              END-COMPUTE
           ELSE
              COMPUTE WS-2550-YIELD-CUP-INT ROUNDED
                = (WS-2550-PREV-APPROVED-YIELD * 0.90)
                ON SIZE ERROR
                   MOVE 2550 TO WS-8020-PARAGRAPH-NO
                   MOVE 90017 TO WS-8020-INT-ERROR-NO
                   MOVE 'PA YIELD * 1-CUP'
                     TO WS-8020-FIELD-NAME
                   MOVE SPACES TO WS-8020-BAD-DATA
                   MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                   PERFORM 8020-RECORD-INT-ERROR
                      THRU 8020-RECORD-INT-ERROR-EXIT
              END-COMPUTE
              MOVE WS-2550-YIELD-CUP-INT TO WS-2550-YIELD-CUP
           END-IF


      $IF DEBUG-SW DEFINED
           MOVE WS-2550-YIELD-CUP
             TO WS-2550-DISPLAY-YIELD-X
           DISPLAY 'YIELD CUP = ', WS-2550-DISPLAY-YIELD-X
      $END

      $IF DEBUG-SW DEFINED
           MOVE WS-2550-AVERAGE-YIELD
             TO WS-2550-DISPLAY-YIELD-X
           DISPLAY 'AVERAGE YIELD = ', WS-2550-DISPLAY-YIELD-X
           DISPLAY 'ACTUAL YRS EXP= ', WS-2550-ACTUAL-YEARS
           DISPLAY 'YIELD LIMITATION FLAG = ',
           WS-2550-YIELD-LIMITATION-FLG
           UPON CONSOLE
      $END

      **********************************************************
      *          CHECK YIELD LIMITATION FLAG
      **********************************************************

           EVALUATE WS-2550-YIELD-LIMITATION-FLG
           WHEN 1
              IF (WS-2550-AVERAGE-YIELD < WS-2550-YIELD-CUP) OR
                 (WS-2550-AVERAGE-YIELD > WS-2550-YIELD-CAP)
                 MOVE 15069 TO WS-8000-ERROR-CODE
                 MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                 MOVE WS-LITERAL-YES TO ERROR-APPROVED-YLD
                 MOVE WS-LITERAL-YES TO ERROR-YLD-LIMIT-FL
                 MOVE WS-LITERAL-YLD-LIMIT-FL
                   TO WS-8000-FIELD-NAME1
                 MOVE WS-2550-YIELD-LIMITATION-FLG
                   TO WS-8000-BAD-DATA1
                 MOVE WS-2550-YIELD-CAP TO WS-2550-DISPLAY-YIELD-X
                 MOVE WS-2550-YIELD-CUP TO WS-2550-DISPLAY-YIELD2-X
                 MOVE WS-2550-AVERAGE-YIELD
                   TO WS-2550-DISPLAY-YIELD3-X
                 STRING 'AYLD '
                       DELIMITED BY SIZE
                       WS-2550-DISPLAY-YIELD3-X
                       DELIMITED BY SIZE
                       ' NOT <= '
                       DELIMITED BY SIZE
                       WS-2550-DISPLAY-YIELD-X
                       DELIMITED BY SIZE
                       ' ,>= '
                       DELIMITED BY SIZE
                       WS-2550-DISPLAY-YIELD2-X
                       DELIMITED BY SIZE
                   INTO WS-8000-CORR-DATA1
                 END-STRING
                 MOVE 2550 TO WS-8000-PARAGRAPH-NO
                 PERFORM 8000-RECORD-TRAN-ERROR
                    THRU 8000-RECORD-TRAN-ERROR-EXIT
                 GO TO 2550-VAL-APPROVED-YIELD-EXIT
              ELSE
                 MOVE WS-2550-AVERAGE-YIELD
                   TO WS-2550-CORRECT-YIELD
              END-IF

           WHEN 2
              IF (WS-2550-AVERAGE-YIELD < WS-2550-YIELD-CAP)
                 MOVE 15069 TO WS-8000-ERROR-CODE
                 MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                 MOVE WS-LITERAL-YES TO ERROR-APPROVED-YLD
                 MOVE WS-LITERAL-YES TO ERROR-YLD-LIMIT-FL
                 MOVE WS-LITERAL-YLD-LIMIT-FL
                   TO WS-8000-FIELD-NAME1
                 MOVE WS-2550-YIELD-LIMITATION-FLG
                   TO WS-8000-BAD-DATA1
                 MOVE WS-2550-YIELD-CAP TO WS-2550-DISPLAY-YIELD-X
                 MOVE WS-2550-AVERAGE-YIELD
                   TO WS-2550-DISPLAY-YIELD3-X
                 STRING 'AYLD '
                       DELIMITED BY SIZE
                       WS-2550-DISPLAY-YIELD3-X
                       DELIMITED BY SIZE
                       ' NOT <= '
                       DELIMITED BY SIZE
                       WS-2550-DISPLAY-YIELD-X
                       DELIMITED BY SIZE
                   INTO WS-8000-CORR-DATA1
                 END-STRING
                 MOVE 2550 TO WS-8000-PARAGRAPH-NO
                 PERFORM 8000-RECORD-TRAN-ERROR
                    THRU 8000-RECORD-TRAN-ERROR-EXIT
                 GO TO 2550-VAL-APPROVED-YIELD-EXIT
              ELSE
                 MOVE WS-2550-YIELD-CAP TO WS-2550-CORRECT-YIELD
              END-IF

           WHEN 3
              IF (WS-2550-AVERAGE-YIELD > WS-2550-YIELD-CUP)
                 MOVE 15069 TO WS-8000-ERROR-CODE
                 MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                 MOVE WS-LITERAL-YES TO ERROR-APPROVED-YLD
                 MOVE WS-LITERAL-YES TO ERROR-YLD-LIMIT-FL
                 MOVE WS-LITERAL-YLD-LIMIT-FL
                   TO WS-8000-FIELD-NAME1
                 MOVE WS-2550-YIELD-LIMITATION-FLG
                   TO WS-8000-BAD-DATA1
                 MOVE WS-2550-YIELD-CUP TO WS-2550-DISPLAY-YIELD-X
                 MOVE WS-2550-AVERAGE-YIELD
                   TO WS-2550-DISPLAY-YIELD3-X
                 STRING 'AYLD '
                       DELIMITED BY SIZE
                       WS-2550-DISPLAY-YIELD3-X
                       DELIMITED BY SIZE
                       ' NOT <= '
                       DELIMITED BY SIZE
                       WS-2550-DISPLAY-YIELD-X
                       DELIMITED BY SIZE
                   INTO WS-8000-CORR-DATA1
                 END-STRING
                 MOVE 2550 TO WS-8000-PARAGRAPH-NO
                 PERFORM 8000-RECORD-TRAN-ERROR
                    THRU 8000-RECORD-TRAN-ERROR-EXIT
                 GO TO 2550-VAL-APPROVED-YIELD-EXIT
              ELSE
                 MOVE WS-2550-YIELD-CUP TO WS-2550-CORRECT-YIELD
              END-IF

           WHEN 4
              IF (WS-2550-AVERAGE-YIELD > WS-2550-YIELD-CUP) AND
                 (WS-2550-AVERAGE-YIELD < WS-2550-YIELD-CAP)
                 MOVE 15069 TO WS-8000-ERROR-CODE
                 MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                 MOVE WS-LITERAL-YES TO ERROR-APPROVED-YLD
                 MOVE WS-LITERAL-YES TO ERROR-YLD-LIMIT-FL
                 MOVE WS-LITERAL-YLD-LIMIT-FL
                   TO WS-8000-FIELD-NAME1
                 MOVE WS-2550-YIELD-LIMITATION-FLG
                   TO WS-8000-BAD-DATA1
                 MOVE WS-2550-YIELD-CAP
                   TO WS-2550-DISPLAY-YIELD-X
                 MOVE WS-2550-YIELD-CUP
                   TO WS-2550-DISPLAY-YIELD2-X
                 MOVE WS-2550-AVERAGE-YIELD
                   TO WS-2550-DISPLAY-YIELD3-X
                 STRING 'AYLD '
                       DELIMITED BY SIZE
                       WS-2550-DISPLAY-YIELD3-X
                       DELIMITED BY SIZE
                       ' NOT <= '
                       DELIMITED BY SIZE
                       WS-2550-DISPLAY-YIELD-X
                       DELIMITED BY SIZE
                       ' ,>= '
                       DELIMITED BY SIZE
                       WS-2550-DISPLAY-YIELD2-X
                       DELIMITED BY SIZE
                   INTO WS-8000-CORR-DATA1
                 END-STRING
                 MOVE 2550 TO WS-8000-PARAGRAPH-NO
                 PERFORM 8000-RECORD-TRAN-ERROR
                    THRU 8000-RECORD-TRAN-ERROR-EXIT
                 GO TO 2550-VAL-APPROVED-YIELD-EXIT
              ELSE
                 MOVE WS-2550-AVERAGE-YIELD
                   TO WS-2550-CORRECT-YIELD
              END-IF

           WHEN 5
              IF (WS-2550-YIELD-FLOOR < WS-2550-AVERAGE-YIELD)
                 IF WS-2550-IN-REFERENCE-UNIT-REQ
                    = WS-LITERAL-YES AND
                    WS-2550-YIELD-FLOOR-80 > WS-2550-AVERAGE-YIELD
      *             *** AN ADDED LAND/CROP SITUATION MAY EXIST
                    MOVE WS-LITERAL-YES
                      TO WS-2550-REFERENCE-UNIT-REQ
                    MOVE WS-2550-YIELD-FLOOR
                      TO WS-2550-CORRECT-YIELD
                 ELSE
                    MOVE 15069 TO WS-8000-ERROR-CODE
                    MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                    MOVE WS-LITERAL-YES TO ERROR-APPROVED-YLD
                    MOVE WS-LITERAL-YES TO ERROR-YLD-LIMIT-FL
                    MOVE WS-LITERAL-YLD-LIMIT-FL
                      TO WS-8000-FIELD-NAME1
                    MOVE WS-2550-YIELD-LIMITATION-FLG
                      TO WS-8000-BAD-DATA1
                    MOVE WS-2550-AVERAGE-YIELD
                      TO WS-2550-DISPLAY-YIELD-X
                    MOVE WS-2550-YIELD-FLOOR
                      TO WS-2550-DISPLAY-YIELD3-X
                    STRING 'YLD FL'
                          DELIMITED BY SIZE
                          WS-2550-DISPLAY-YIELD3-X
                          DELIMITED BY SIZE
                          ' NOT >= '
                          DELIMITED BY SIZE
                          WS-2550-DISPLAY-YIELD-X
                          DELIMITED BY SIZE
                      INTO WS-8000-CORR-DATA1
                    END-STRING
                    MOVE 2550 TO WS-8000-PARAGRAPH-NO
                    PERFORM 8000-RECORD-TRAN-ERROR
                       THRU 8000-RECORD-TRAN-ERROR-EXIT
                    GO TO 2550-VAL-APPROVED-YIELD-EXIT
                 END-IF
              ELSE
                 MOVE WS-2550-YIELD-FLOOR
                   TO WS-2550-CORRECT-YIELD
              END-IF

           WHEN 6
              IF (WS-2550-YIELD-FLOOR < WS-2550-YIELD-CAP)
                 IF WS-2550-IN-REFERENCE-UNIT-REQ
                    = WS-LITERAL-YES AND
                    WS-2550-YIELD-FLOOR-80 > WS-2550-YIELD-CAP
      *             *** AN ADDED LAND/CROP SITUATION MAY EXIST
                    MOVE WS-LITERAL-YES
                      TO WS-2550-REFERENCE-UNIT-REQ
                    MOVE WS-2550-YIELD-FLOOR
                      TO WS-2550-CORRECT-YIELD
                 ELSE
                    MOVE 15069 TO WS-8000-ERROR-CODE
                    MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                    MOVE WS-LITERAL-YES TO ERROR-APPROVED-YLD
                    MOVE WS-LITERAL-YES TO ERROR-YLD-LIMIT-FL
                    MOVE WS-LITERAL-YLD-LIMIT-FL
                      TO WS-8000-FIELD-NAME1
                    MOVE WS-2550-YIELD-LIMITATION-FLG
                      TO WS-8000-BAD-DATA1
                    MOVE WS-2550-YIELD-CAP
                      TO WS-2550-DISPLAY-YIELD-X
                    MOVE WS-2550-YIELD-FLOOR
                      TO WS-2550-DISPLAY-YIELD3-X
                    STRING 'YLD FL '
                          DELIMITED BY SIZE
                          WS-2550-DISPLAY-YIELD3-X
                          DELIMITED BY SIZE
                          ' NOT >= '
                          WS-2550-DISPLAY-YIELD-X
                          DELIMITED BY SIZE
                      INTO WS-8000-CORR-DATA1
                    END-STRING
                    MOVE 2550 TO WS-8000-PARAGRAPH-NO
                    PERFORM 8000-RECORD-TRAN-ERROR
                       THRU 8000-RECORD-TRAN-ERROR-EXIT
                    GO TO 2550-VAL-APPROVED-YIELD-EXIT
                 END-IF
              ELSE
                 MOVE WS-2550-YIELD-FLOOR
                   TO WS-2550-CORRECT-YIELD
              END-IF

           WHEN 7
              IF (WS-2550-YIELD-FLOOR < WS-2550-YIELD-CUP)
                 IF WS-2550-IN-REFERENCE-UNIT-REQ
                    = WS-LITERAL-YES AND
                    WS-2550-YIELD-FLOOR-80 > WS-2550-YIELD-CUP
      *             *** AN ADDED LAND/CROP SITUATION MAY EXIST
                    MOVE WS-LITERAL-YES
                      TO WS-2550-REFERENCE-UNIT-REQ
                    MOVE WS-2550-YIELD-FLOOR
                      TO WS-2550-CORRECT-YIELD
                 ELSE
                 MOVE 15069 TO WS-8000-ERROR-CODE
                 MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                 MOVE WS-LITERAL-YES TO ERROR-APPROVED-YLD
                 MOVE WS-LITERAL-YES TO ERROR-YLD-LIMIT-FL
                 MOVE WS-LITERAL-YLD-LIMIT-FL
                   TO WS-8000-FIELD-NAME1
                 MOVE WS-2550-YIELD-LIMITATION-FLG
                   TO WS-8000-BAD-DATA1
                 MOVE WS-2550-YIELD-CUP
                   TO WS-2550-DISPLAY-YIELD-X
                 MOVE WS-2550-YIELD-FLOOR
                   TO WS-2550-DISPLAY-YIELD3-X
                 STRING 'YLD FL '
                       DELIMITED BY SIZE
                       WS-2550-DISPLAY-YIELD3-X
                       DELIMITED BY SIZE
                       ' NOT >= '
                       WS-2550-DISPLAY-YIELD-X
                       DELIMITED BY SIZE
                   INTO WS-8000-CORR-DATA1
                 END-STRING
                 MOVE 2550 TO WS-8000-PARAGRAPH-NO
                 PERFORM 8000-RECORD-TRAN-ERROR
                    THRU 8000-RECORD-TRAN-ERROR-EXIT
                 GO TO 2550-VAL-APPROVED-YIELD-EXIT
              END-IF
              ELSE
                 MOVE WS-2550-YIELD-FLOOR
                   TO WS-2550-CORRECT-YIELD
              END-IF

           WHEN 8
              IF (WS-2550-YIELD-FLOOR < WS-2550-AVERAGE-YIELD)
                 IF WS-2550-IN-REFERENCE-UNIT-REQ
                    = WS-LITERAL-YES AND
                    WS-2550-YIELD-FLOOR-80 > WS-2550-AVERAGE-YIELD
      *             *** AN ADDED LAND/CROP SITUATION MAY EXIST
                    MOVE WS-LITERAL-YES
                      TO WS-2550-REFERENCE-UNIT-REQ
                    MOVE WS-2550-YIELD-FLOOR
                      TO WS-2550-CORRECT-YIELD
                 ELSE
                 MOVE 15069 TO WS-8000-ERROR-CODE
                 MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                 MOVE WS-LITERAL-YES TO ERROR-APPROVED-YLD
                 MOVE WS-LITERAL-YES TO ERROR-YLD-LIMIT-FL
                 MOVE WS-LITERAL-YLD-LIMIT-FL
                   TO WS-8000-FIELD-NAME1
                 MOVE WS-2550-YIELD-LIMITATION-FLG
                   TO WS-8000-BAD-DATA1
                 MOVE WS-2550-AVERAGE-YIELD
                   TO WS-2550-DISPLAY-YIELD-X
                 MOVE WS-2550-YIELD-FLOOR
                   TO WS-2550-DISPLAY-YIELD3-X
                 STRING 'YLD FL '
                       DELIMITED BY SIZE
                       WS-2550-DISPLAY-YIELD3-X
                       DELIMITED BY SIZE
                       ' NOT >= '
                       WS-2550-DISPLAY-YIELD-X
                       DELIMITED BY SIZE
                   INTO WS-8000-CORR-DATA1
                 END-STRING
                 MOVE 2550 TO WS-8000-PARAGRAPH-NO
                 PERFORM 8000-RECORD-TRAN-ERROR
                    THRU 8000-RECORD-TRAN-ERROR-EXIT
                 GO TO 2550-VAL-APPROVED-YIELD-EXIT
              END-IF
              ELSE
                 MOVE WS-2550-YIELD-FLOOR
                   TO WS-2550-CORRECT-YIELD
              END-IF
           END-EVALUATE

      **      **  WHEN THE UNIT OF MEASURE FOR THE CROP IS BARRELS OR
      **      **  TONS, THE CORRECT YIELD SHOULD BE ROUNDED TO TENTHS.
      **      **  SINCE CORRECT YIELD FIELD AND THE PICTURE CLAUSE OF EACH
      **      **  FIELD THAT WE MOVED INTO CORRECT YIELD ABOVE WAS
      **      **  9(05)V9(01), WE DO NOT NEED TO ROUND THE CORRECT YIELD.
           IF WS-2550-CROP-UNIT-OF-MEASURE = WS-LITERAL-BARRELS OR
              WS-2550-CROP-UNIT-OF-MEASURE = WS-LITERAL-TONS
              CONTINUE
           ELSE
      **      ** WHEN THE UNIT OF MEASURE FOR THE CROP IS
      **      ** ANYTHING OTHER THAN BARRELS OR TONS,
      **      ** THE CORRECT YIELD SHOULD BE ROUNDED TO A WHOLE NUMBER.
              COMPUTE WS-2550-CORRECT-YIELD-WHOLE ROUNDED =
                      WS-2550-CORRECT-YIELD * 1
                 ON SIZE ERROR
                    MOVE 2550 TO WS-8020-PARAGRAPH-NO
                    MOVE 90017 TO WS-8020-INT-ERROR-NO
                    MOVE 'CORRECT YLD - WHOLE'
                      TO WS-8020-FIELD-NAME
                    MOVE SPACES TO WS-8020-BAD-DATA
                    MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                    PERFORM 8020-RECORD-INT-ERROR
                       THRU 8020-RECORD-INT-ERROR-EXIT
              END-COMPUTE
              MOVE WS-2550-CORRECT-YIELD-WHOLE
                TO WS-2550-CORRECT-YIELD
           END-IF

      $IF DEBUG-SW DEFINED
           MOVE WS-2550-CORRECT-YIELD
             TO WS-2550-DISPLAY-YIELD-X
           DISPLAY 'CORRECT YIELD = ', WS-2550-DISPLAY-YIELD-X
           MOVE WS-2550-APPROVED-YIELD
             TO WS-2550-DISPLAY-YIELD-X
           DISPLAY 'APPROVED YIELD = ', WS-2550-DISPLAY-YIELD-X
      $END


           IF WS-2550-APPROVED-YIELD NOT = WS-2550-CORRECT-YIELD
              IF WS-2550-IN-REFERENCE-UNIT-REQ = WS-LITERAL-YES
                 EVALUATE WS-2550-APPROVED-YIELD
                   WHEN WS-2550-YIELD-FLOOR-70
                      MOVE WS-LITERAL-YES
                        TO WS-2550-REFERENCE-UNIT-REQ
                      MOVE 0 TO WS-2550-REFERENCE-YEARS-REQ
                   WHEN WS-2550-YIELD-FLOOR-75
                      MOVE WS-LITERAL-YES
                        TO WS-2550-REFERENCE-UNIT-REQ
                      MOVE 2 TO WS-2550-REFERENCE-YEARS-REQ
                   WHEN WS-2550-YIELD-FLOOR-80
                      MOVE WS-LITERAL-YES
                        TO WS-2550-REFERENCE-UNIT-REQ
                      MOVE 5 TO WS-2550-REFERENCE-YEARS-REQ
                   WHEN OTHER
                      MOVE 15067 TO WS-8000-ERROR-CODE
                      MOVE WS-LITERAL-NO
                        TO WS-2550-REFERENCE-UNIT-REQ
                 END-EVALUATE
      $IF DEBUG-SW DEFINED
           DISPLAY 'REF YEARS REQUIRED = ',
           WS-2550-REFERENCE-YEARS-REQ
           UPON CONSOLE
      $END
                 IF WS-2550-REFERENCE-UNIT-REQ = WS-LITERAL-YES
                    GO TO 2550-VAL-APPROVED-YIELD-EXIT
                 END-IF
              ELSE
                 IF WS-2550-APPROVED-YIELD =
                    (WS-2550-CORRECT-YIELD + 1) OR
                    WS-2550-APPROVED-YIELD =
                    (WS-2550-CORRECT-YIELD - 1)
                    MOVE 15086 TO WS-8000-ERROR-CODE
                 ELSE
                    MOVE 15067 TO WS-8000-ERROR-CODE
                 END-IF
              END-IF
              MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO ERROR-APPROVED-YLD
              MOVE WS-LITERAL-APPROVED-YLD TO WS-8000-FIELD-NAME1
              MOVE WS-2550-APPROVED-YIELD
                TO WS-2550-DISPLAY-YIELD-X
              MOVE WS-2550-DISPLAY-YIELD-X
                TO WS-8000-BAD-DATA1
              MOVE WS-2550-CORRECT-YIELD
                TO WS-2550-DISPLAY-YIELD-X
              MOVE WS-2550-DISPLAY-YIELD-X
                TO WS-8000-CORR-DATA1
              MOVE 2550 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF.

       2550-VAL-APPROVED-YIELD-EXIT.
           EXIT.

