      ***************************************************************
      * File:      IF2560.CBL
      * Author:    Laura Dittamo
      * Date:      02/08/96
      * Purpose:
      *    This routine validates the NCS Yield Factor.
      *    If the producer is classified under NCS, the NCS Yield
      *    Factor must match the ADM's NCS Yield Factor.
      ***************************************************************

       2560-VAL-NCS-YLD-FACTOR.

      $IF DEBUG-SW DEFINED
           DISPLAY '2560-VALIDATING NCS YIELD FACTOR'
           UPON CONSOLE
      $END

      **********************************************
      *  INITIALIZE LOCAL AND OUTPUT VARIABLES     *
      **********************************************
           INITIALIZE WS-2560-WORK
           INITIALIZE WS-2560-OUTPUT

      *    *** SET UP DISPLAY FIELDS FOR ERRORS
           MOVE WS-2560-NCS-YIELD-FACTOR
             TO WS-2560-NCS-YIELD-FACTOR-X

      **********************************************
      *            CHECK PRE-CONDITIONS            *
      **********************************************
           IF ERROR-RATE-STATE = WS-LITERAL-YES
              OR ERROR-CROP-YR = WS-LITERAL-YES
              OR ERROR-RATE-COUNTY = WS-LITERAL-YES
              OR ERROR-CROP-CD = WS-LITERAL-YES
              OR ERROR-CROP-TYPE = WS-LITERAL-YES
              OR ERROR-PRACTICE-CD = WS-LITERAL-YES
              OR ERROR-NCS-EXCEPTION-FLAG = WS-LITERAL-YES
              OR ERROR-NCS-YLD-FCTR = WS-LITERAL-YES
              OR ERROR-ID-NO = WS-LITERAL-YES
              OR ERROR-OPT-CD = WS-LITERAL-YES
              OR ERROR-INSUR-PLAN-CD = WS-LITERAL-YES
              MOVE WS-LITERAL-YES TO ERROR-NCS-YLD-FCTR
              GO TO 2560-VAL-NCS-YLD-FACTOR-EXIT
           END-IF


      **********************************************
      *            NORMAL PROCESSING               *
      **********************************************

           IF WS-2560-NCS-YIELD-FACTOR > 1.00
              MOVE 15008 TO WS-8000-ERROR-CODE
              MOVE WS-LITERAL-YES TO ERROR-NCS-YLD-FCTR
              MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-NCS-YLD-FCTR TO WS-8000-FIELD-NAME1
              MOVE WS-2560-NCS-YIELD-FACTOR-X TO WS-8000-BAD-DATA1
              MOVE '< OR = 1.00' TO WS-8000-CORR-DATA1
              MOVE 2560 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
              GO TO 2560-VAL-NCS-YLD-FACTOR-EXIT
           END-IF

      **************************************************
      *   DETERMINE WHETHER THIS PRODUCER IS CLASSIFIED
      *   UNDER NCS.  IF PRODUCER IS FOUND ON NCS, THE
      *   NCS YIELD FACTOR MUST MATCH THE ADM NCS YIELD
      *   FACTOR.
      **************************************************

      $IF DEBUG-SW DEFINED
          DISPLAY '2560-LOCATING NCS LISTING'
          UPON CONSOLE
      $END

      $IF DATABASE-SW DEFINED
           DISPLAY 'NO DATABASE LOOKUP FOR NCS PRODUCERS IMPLEMENTED!'
           UPON CONSOLE.
      $END

      $IF ISAM-SW DEFINED

      *    IF WS-2560-ID-TYPE <> WS-LITERAL-SSN
           IF WS-2560-ID-NUM = ZEROS
              IF WS-2560-NCS-YIELD-FACTOR < 1.00
                 MOVE WS-LITERAL-YES TO WS-2560-NCS-PRODUCER
              END-IF
              GO TO 2560-VAL-NCS-YLD-FACTOR-EXIT
           END-IF
           INITIALIZE WS-7555-INPUT-KEY
           MOVE WS-2560-ID-NUM TO WS-7555-INPUT-ID-NUM
           MOVE WS-2560-CROP-YEAR TO WS-7555-INPUT-CROP-YR
           MOVE WS-2560-RATE-STATE TO WS-7555-INPUT-STATE-CD
           MOVE WS-2560-RATE-COUNTY TO WS-7555-INPUT-COUNTY-CD
           MOVE WS-2560-CROP-CD TO WS-7555-INPUT-CROP-CD
           MOVE WS-2560-INS-PLAN-CD TO WS-7555-INPUT-INSURANCE-PLAN
           MOVE WS-2560-TYPE-CD TO WS-7555-INPUT-TYPE-CD
           MOVE WS-2560-PRACTICE-CD TO WS-7555-INPUT-PRACTICE-CD
      *    *** NO OPTION CODE EXIST FOR TYPE 15 RECORDS ***
           MOVE SPACES TO WS-7555-INPUT-OPTION-CD
           PERFORM 7555-LOOKUP-ADMSSN
              THRU 7555-LOOKUP-ADMSSN-EXIT

           IF MATCH-FOUND-7555
      *       *** THIS IS AN FCI-35 RECORD AND SHOULD HAVE YIELD FACTOR ***
              IF WS-7555-RECORD-TYPE-SFX = 5
                 MOVE WS-LITERAL-YES TO WS-2560-NCS-PRODUCER
                 MOVE WS-7555-YIELD-FACTOR
                   TO WS-2560-ADM-YIELD-FACTOR
      *          *** SET UP DISPLAY FIELD FOR ERROR
                 MOVE WS-2560-ADM-YIELD-FACTOR
                   TO WS-2560-ADM-YIELD-FACTOR-X
                 IF WS-2560-NCS-YIELD-FACTOR <>
                    WS-2560-ADM-YIELD-FACTOR and
                    WS-2560-NCS-YIELD-FACTOR <> 1 and
                    WS-2560-ADM-YIELD-FACTOR <> 0
                    MOVE 15015 TO WS-8000-ERROR-CODE
                    MOVE WS-LITERAL-YES TO ERROR-NCS-YLD-FCTR
                    MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                    MOVE WS-LITERAL-NCS-YLD-FCTR
                      TO WS-8000-FIELD-NAME1
                    MOVE WS-2560-NCS-YIELD-FACTOR-X
                      TO WS-8000-BAD-DATA1
                    MOVE WS-2560-ADM-YIELD-FACTOR-X
                      TO WS-8000-CORR-DATA1
                    MOVE 2560 TO WS-8000-PARAGRAPH-NO
                    PERFORM 8000-RECORD-TRAN-ERROR
                       THRU 8000-RECORD-TRAN-ERROR-EXIT
                 END-IF
      *       *** THIS IS AN FCI-32 RECORD - NO YIELD DATA ***
              ELSE
                 IF WS-2560-NCS-YIELD-FACTOR < 1.00
                    MOVE WS-LITERAL-YES TO WS-2560-NCS-PRODUCER
                 END-IF
              END-IF
           ELSE
      **************************************************
      *   NOT ALL NCS PRODUCERS ARE LISTED IN THE
      *   ADM NCS FILE.  IF THE NCS YIELD FACTOR IS LESS
      *   THAN 1.00, WE WILL ASSUME THE PRODUCER IS
      *   UNDER NCS.
      **************************************************
             IF WS-2560-NCS-YIELD-FACTOR < 1.00
                MOVE WS-LITERAL-YES TO WS-2560-NCS-PRODUCER
             END-IF
           END-IF.
      $END


       2560-VAL-NCS-YLD-FACTOR-EXIT.
           EXIT.


