      *****************************************************************
      * File:      IF2580.CBL
      * Author:    LAURA DITTAMO
      * Date:      6/11/96
      * Purpose:   Validate Group Payment Calculation Factor
      *         If the Stage Code is PL, this edit calculates the
      *         Preliminary Payment Calculation Factor.
      *         If the Stage Code is FL, both the Preliminary and
      *         Final Payment Calculation Factors are calculated.
      *
      *         The Preliminary Payment Calculation Factor is
      *         determined for later use by the Indemnity calculation.
      *         The Final Payment Calculation Factor is calculated
      *         and used to validate the input Group Payment Calc Factor.
      *
      *   NOTE: Preliminary Loss Payment was eliminated for DAS97.
      *         Stage Code PL is no longer valid.
      *************************************************************

       2580-VAL-GRP-PMT-CALC.

      $IF DEBUG-SW DEFINED
           DISPLAY '2580 VALIDATE GROUP PAYMENT CALCULATION FACTOR'
           UPON CONSOLE
      $END

      ****************************************************************
      *              INITIALIZE OUTPUTS & LOCAL WS                   *
      ****************************************************************
           INITIALIZE WS-2580-WORK
           INITIALIZE WS-2580-OUTPUT

      ****************************************************************
      *            CHECK THE PRE-CONDITIONS BEFORE THE EDIT          *
      ****************************************************************

           IF ERROR-CVG-LVL-PCT = WS-LITERAL-YES OR
              ERROR-LOC-CNTY = WS-LITERAL-YES OR
              ERROR-LOC-STATE = WS-LITERAL-YES OR
              ERROR-CROP-YR = WS-LITERAL-YES OR
              ERROR-CROP-TYPE = WS-LITERAL-YES OR
              ERROR-PRACTICE-CD = WS-LITERAL-YES OR
              ERROR-CVG-FL = WS-LITERAL-YES OR
              ERROR-CROP-CD = WS-LITERAL-YES OR
              ERROR-INSUR-PLAN-CD = WS-LITERAL-YES OR
              ERROR-STAGE-CD = WS-LITERAL-YES OR
              ERROR-GRP-PMT-CALC-FCTR = WS-LITERAL-YES OR
              ERROR-UNIT-OF-MEASURE = WS-LITERAL-YES
              MOVE WS-LITERAL-YES TO ERROR-GRP-PMT-CALC-FCTR
              GO TO 2580-VAL-GRP-PMT-CALC-EXIT
           END-IF

      *  ** THIS FIELD IS ONLY EDITED FOR GROUP INSURANCE PLANS
           IF WS-2580-INS-PLAN-CD = WS-LITERAL-GRP
              CONTINUE
           ELSE
              GO TO 2580-VAL-GRP-PMT-CALC-EXIT
           END-IF


      *  **IF THE COVERAGE IS CAT -
      *  **GROUP PAYMENT CALCULATION FACTOR IS GIVEN A DEFAULT VALUE 1
           IF WS-2580-COVERAGE-FL = WS-LITERAL-CAT
              MOVE 1 TO WS-2580-OUT-GRP-PMT-CALC-FCTR
              MOVE WS-LITERAL-YES TO WS-2580-UPDATE-MADE
              GO TO 2580-VAL-GRP-PMT-CALC-EXIT
           END-IF


           EVALUATE WS-2580-STAGE-CD
               WHEN WS-LITERAL-FINAL-LOSS
                 INITIALIZE WS-4510-INPUT
                 MOVE WS-2580-CROP-UNIT-OF-MEASURE
                   TO WS-4510-CROP-UNIT-OF-MEASURE
                 MOVE WS-2580-CROP-CD TO WS-4510-CROP-CD
                 MOVE WS-2580-INS-PLAN-CD
                   TO WS-4510-INSURANCE-PLAN-ID
                 MOVE WS-2580-CROP-YEAR TO WS-4510-CROP-YEAR
                 MOVE WS-2580-LOCATION-STATE
                   TO WS-4510-LOCATION-STATE
                 MOVE WS-2580-LOCATION-COUNTY
                   TO WS-4510-LOCATION-COUNTY
                 MOVE WS-2580-TYPE-CD TO WS-4510-TYPE-CD
                 MOVE WS-2580-PRACTICE-CD TO WS-4510-PRACTICE-CD
                 MOVE WS-2580-COVERAGE-LVL-PCT
                   TO WS-4510-COVERAGE-LVL-PCT
                 PERFORM 4510-CALC-FINAL-GRP-PMT
                    THRU 4510-CALC-FINAL-GRP-PMT-EXIT
                 IF CALC-ERROR-4510
                    MOVE WS-LITERAL-YES TO ERROR-GRP-PMT-CALC-FCTR
                    GO TO 2580-VAL-GRP-PMT-CALC-EXIT
                 END-IF
      *        ** CHECK POST CONDITIONS
                 IF WS-4510-FINAL-PMT-CALC-FACTOR = ZEROS
                    MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                    MOVE 21009 TO WS-8000-ERROR-CODE
                    MOVE WS-LITERAL-YES TO ERROR-GRP-PMT-CALC-FCTR
                    MOVE 'ADM1G REC NOT FOUND' TO WS-8000-FIELD-NAME1
                    MOVE 'FINAL PMT CALC FCTR' TO WS-8000-BAD-DATA1
                    MOVE 2580 TO WS-8000-PARAGRAPH-NO
                    MOVE 'ADM1G' TO WS-8000-TABLE-NAME
                    PERFORM 8000-RECORD-TRAN-ERROR
                       THRU 8000-RECORD-TRAN-ERROR-EXIT
                    GO TO 2580-VAL-GRP-PMT-CALC-EXIT
                 END-IF

                 MOVE WS-4510-FINAL-PMT-CALC-FACTOR
                   TO WS-2580-CALC-GRP-PMT-CALC-FCTR

               WHEN OTHER
      *        ** THE ONLY ALLOWABLE STAGE CODE FOR GROUP INSURED
      *        ** CROPS IS FL
                  MOVE WS-LITERAL-YES TO ERROR-GRP-PMT-CALC-FCTR
                  MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
                  MOVE 044 TO WS-8000-SHORT-ERROR
                  MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
                  MOVE 'STAGE CODE' TO WS-8000-FIELD-NAME1
                  MOVE WS-2580-STAGE-CD TO WS-8000-BAD-DATA1
                  MOVE 'INVALID FOR GRP, SHOULD HAVE BEEN TRAPPED'
                    TO WS-8000-CORR-DATA1
                  MOVE 2580 TO WS-8000-PARAGRAPH-NO
                  PERFORM 8000-RECORD-TRAN-ERROR
                     THRU 8000-RECORD-TRAN-ERROR-EXIT
                  GO TO 2580-VAL-GRP-PMT-CALC-EXIT
           END-EVALUATE

           IF WS-2580-GROUP-PMT-CALC-FCTR <>
              WS-2580-CALC-GRP-PMT-CALC-FCTR
              MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
              MOVE 21055 TO WS-8000-ERROR-CODE
              MOVE WS-LITERAL-YES TO ERROR-GRP-PMT-CALC-FCTR
              MOVE WS-LITERAL-GRP-PMT-CALC-FCTR TO WS-8000-FIELD-NAME1
      *       ** POPULATE DISPLAY FIELDS
              MOVE WS-2580-GROUP-PMT-CALC-FCTR
                TO WS-2580-GROUP-PMT-CALC-FCTR-X
              MOVE WS-2580-CALC-GRP-PMT-CALC-FCTR
                TO WS-2580-CALC-GRP-PMT-CALC-X
              MOVE WS-2580-GROUP-PMT-CALC-FCTR-X TO WS-8000-BAD-DATA1
              MOVE WS-2580-CALC-GRP-PMT-CALC-X TO WS-8000-CORR-DATA1
              MOVE 2580 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF.

       2580-VAL-GRP-PMT-CALC-EXIT.
           EXIT.

