      ****************************************************************
      *  File   : IF2595.CBL
      *  Author : Yo-I Tsui
      *  Date   : 06/10/96
      *  Purpose: VALIDATE PRIMARY CAUSE, SECONDARY CAUSE, CAUSE OF
      *           LOSS AND PREVIOUS CAUSE
      *           DETERMINE WHETHER CAUSE IS A VALID CAUSE OF
      *           LOSS FOR A PARTICULAR CROP/CROP PRACTICE GROWN IN A
      *           PARTICULAR STATE (UNDER A SPECIFIC INSURANCE PLAN).
      ****************************************************************

       2595-VAL-LOSS-CAUSE-CD.

      $IF DEBUG-SW DEFINED
           DISPLAY '2595-VALIDATING LOSS CAUSE CD'
           UPON CONSOLE
      $END


      **********************************************
      *            CHECK PRE-CONDITIONS            *
      **********************************************
           EVALUATE TRUE
      ******** PRIMARY CAUSE ********
              WHEN PRIMARY-CAUSE-2595
                IF ERROR-PRIMARY-CAUSE = WS-LITERAL-YES
                   GO TO 2595-VAL-LOSS-CAUSE-CD-EXIT
                END-IF
      ******** SECONDARY CAUSE ********
              WHEN SECONDARY-CAUSE-2595
                IF ERROR-SECONDARY-CAUSE = WS-LITERAL-YES
                   GO TO 2595-VAL-LOSS-CAUSE-CD-EXIT
                END-IF
                IF WS-2595-LOSS-CAUSE-CD = ZEROS
                   GO TO 2595-VAL-LOSS-CAUSE-CD-EXIT
                END-IF
      ******** CAUSE OF LOSS ********
              WHEN CAUSE-OF-LOSS-2595
                IF ERROR-CAUSE-OF-LOSS-CD = WS-LITERAL-YES
                   GO TO 2595-VAL-LOSS-CAUSE-CD-EXIT
                END-IF
      ******** PREVIOUS CAUSE ********
              WHEN PREVIOUS-CAUSE-2595
                IF ERROR-PREV-CAUSE-CD = WS-LITERAL-YES
                   GO TO 2595-VAL-LOSS-CAUSE-CD-EXIT
                END-IF
      ******** OTHERS ********
              WHEN OTHER
                MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
                MOVE 044 TO WS-8000-SHORT-ERROR
                MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
                MOVE 'WS-2595-SOURCE-FIELD' TO WS-8000-FIELD-NAME1
                MOVE WS-2595-SOURCE-FIELD TO WS-8000-BAD-DATA1
                MOVE 'WHICH LOSS CAUSE IS BEING VALIDATED?'
                  TO WS-8000-CORR-DATA1
                MOVE 2595 TO WS-8000-PARAGRAPH-NO
                PERFORM 8000-RECORD-TRAN-ERROR
                   THRU 8000-RECORD-TRAN-ERROR-EXIT
                GO TO 2595-VAL-LOSS-CAUSE-CD-EXIT
           END-EVALUATE.

           IF ERROR-CROP-CD = WS-LITERAL-YES OR
              ERROR-INSUR-PLAN-CD = WS-LITERAL-YES OR
              ERROR-LOC-STATE = WS-LITERAL-YES
              EVALUATE TRUE
      ******** PRIMARY CAUSE ********
                 WHEN PRIMARY-CAUSE-2595
                   MOVE WS-LITERAL-YES TO ERROR-PRIMARY-CAUSE
      ******** SECONDARY CAUSE ********
                 WHEN SECONDARY-CAUSE-2595
                   MOVE WS-LITERAL-YES TO ERROR-SECONDARY-CAUSE
      ******** CAUSE OF LOSS ********
                 WHEN CAUSE-OF-LOSS-2595
                   MOVE WS-LITERAL-YES TO ERROR-CAUSE-OF-LOSS-CD
      ******** PREVIOUS CAUSE ********
                 WHEN PREVIOUS-CAUSE-2595
                   MOVE WS-LITERAL-YES TO ERROR-PREV-CAUSE-CD
      ******** OTHERS ********
                 WHEN OTHER
                    MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
                    MOVE 044 TO WS-8000-SHORT-ERROR
                    MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
                    MOVE 'WS-2595-SOURCE-FIELD'
                      TO WS-8000-FIELD-NAME1
                    MOVE WS-2595-SOURCE-FIELD TO WS-8000-BAD-DATA1
                    MOVE 'WHICH LOSS CAUSE IS BEING VALIDATED?'
                      TO WS-8000-CORR-DATA1
                    MOVE 2595 TO WS-8000-PARAGRAPH-NO
                    PERFORM 8000-RECORD-TRAN-ERROR
                       THRU 8000-RECORD-TRAN-ERROR-EXIT
              END-EVALUATE
              GO TO 2595-VAL-LOSS-CAUSE-CD-EXIT
           END-IF

      $IF DEBUG-SW DEFINED
           DISPLAY 'INSURANCE PLAN   = ', WS-2595-INS-PLAN-CD
           UPON CONSOLE
           DISPLAY 'CROP CODE        = ', WS-2595-CROP-CD
           UPON CONSOLE
           DISPLAY 'LOSS CAUSE       = ', WS-2595-LOSS-CAUSE-CD
           UPON CONSOLE
      $END

      **********************************************
      *            NORMAL PROCESSING               *
      **********************************************

           PERFORM 2595-LOOKUP-LOSS-CAUSE
              THRU 2595-LOOKUP-LOSS-CAUSE-EXIT.


       2595-VAL-LOSS-CAUSE-CD-EXIT.
           EXIT.



      $IF ISAM-SW DEFINED

       2595-LOOKUP-LOSS-CAUSE.

           INITIALIZE WS-7355-FOUND-FLG
           INITIALIZE WS-7355-INPUT

           MOVE WS-2595-CROP-CD TO WS-7355-CROP-CD
           MOVE WS-2595-LOSS-CAUSE-CD TO WS-7355-LOSS-CAUSE-CD

      *    *** INS PLAN EXCEPTIONS FOR IP, CRC, GRP, & FRESH MARKET TOMATOES
           IF WS-2595-INS-PLAN-CD = WS-LITERAL-GRP OR
              WS-2595-INS-PLAN-CD = WS-LITERAL-IP OR
              WS-2595-INS-PLAN-CD = WS-LITERAL-CRC OR
              (WS-2595-CROP-CD = WS-LITERAL-FRESH-TOMATOES AND
              (WS-2595-INS-PLAN-CD = WS-LITERAL-DOLLAR-AMT OR
               WS-2595-INS-PLAN-CD = WS-LITERAL-APH-AREA-PLAN))
              MOVE WS-2595-INS-PLAN-CD TO WS-7355-INS-PLAN-CD
           ELSE
              MOVE 98 TO WS-7355-INS-PLAN-CD
           END-IF

      *    *** STATE EXCEPTIONS FOR FLORIDA, TEXAS,
           EVALUATE WS-2595-LOC-STATE
               WHEN WS-LITERAL-FLORIDA
                  IF WS-2595-CROP-CD = WS-LITERAL-CITRUS OR
                     WS-LITERAL-ORANGE-TREES OR
                     WS-LITERAL-GRAPEFRUIT-TREES OR
                     WS-LITERAL-LEMON-TREES OR
                     WS-LITERAL-LIME-TREES OR
                     WS-LITERAL-OTHER-CITRUS-TREES OR
                     WS-LITERAL-AVOCADO-TREES OR
                     WS-LITERAL-CARAMBOLA-TREES OR
                     WS-LITERAL-MANGO-TREES
                     MOVE WS-2595-LOC-STATE TO WS-7355-STATE-CD
                  ELSE
                     MOVE 98 TO WS-7355-STATE-CD
                  END-IF

               WHEN WS-LITERAL-TEXAS
                  IF WS-2595-CROP-CD = WS-LITERAL-CITRUS-TREES OR
                     WS-LITERAL-EARLY-MID-ORANGES OR
                     WS-LITERAL-LATE-ORANGES OR
                     WS-LITERAL-ALL-OTH-GRAPEFRUIT OR
                     WS-LITERAL-RUBY-RED-GRAPEFRUIT OR
                     WS-LITERAL-RIO-RED-STAR-RUBY
                     MOVE WS-2595-LOC-STATE TO WS-7355-STATE-CD
                  ELSE
                     MOVE 98 TO WS-7355-STATE-CD
                  END-IF

               WHEN WS-LITERAL-ARIZONA
               WHEN WS-LITERAL-CALIFORNIA
                  IF WS-2595-CROP-CD = WS-LITERAL-GRAPEFRUIT OR
                     WS-LITERAL-LEMONS OR
                     WS-LITERAL-NAVEL-ORANGES OR
                     WS-LITERAL-SWEET-ORANGES OR
                     WS-LITERAL-VALENCIA-ORANGES OR
                     WS-LITERAL-MINEOLA-TANGELOS OR
                     WS-LITERAL-ORLANDO-TANGELOS OR
                     WS-LITERAL-KINNOW-MANDARINS
                     MOVE WS-2595-LOC-STATE TO WS-7355-STATE-CD
                  ELSE
                     MOVE 98 TO WS-7355-STATE-CD
                  END-IF

               WHEN OTHER
                  MOVE 98 TO WS-7355-STATE-CD
           END-EVALUATE


      *    *** SET UP ERROR STRING IN CASE LOSS CAUSE CD NOT FOUND
           STRING 'SEARCHED WITH = '
               DELIMITED BY SIZE
               WS-7355-INPUT
               DELIMITED BY SIZE
               INTO WS-8000-CORR-DATA1
           END-STRING


           PERFORM 7355-LOOKUP-LOSS-CSE-CROP
              THRU 7355-LOOKUP-LOSS-CSE-CROP-EXIT


           IF NOT MATCH-FOUND-7355
              IF WS-2595-INS-PLAN-CD = WS-LITERAL-IP OR
                 WS-2595-INS-PLAN-CD = WS-LITERAL-CRC

              MOVE 98 TO WS-7355-INS-PLAN-CD
              PERFORM 7355-LOOKUP-LOSS-CSE-CROP
                 THRU 7355-LOOKUP-LOSS-CSE-CROP-EXIT
           END-IF
           END-IF


           IF MATCH-FOUND-7355
      *       *** CLEAR THE ERROR SET ABOVE
              MOVE SPACES TO WS-8000-CORR-DATA1
           ELSE
              MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 009 TO WS-8000-SHORT-ERROR

              EVALUATE TRUE
      ******** PRIMARY CAUSE ********
                WHEN PRIMARY-CAUSE-2595
                  MOVE WS-LITERAL-YES TO ERROR-PRIMARY-CAUSE
                  MOVE WS-LITERAL-PRIMARY-CAUSE
                    TO WS-8000-FIELD-NAME1
      ******** SECONDARY CAUSE ********
                WHEN SECONDARY-CAUSE-2595
                  MOVE WS-LITERAL-YES TO ERROR-SECONDARY-CAUSE
                  MOVE WS-LITERAL-SECONDRY-CAUSE
                    TO WS-8000-FIELD-NAME1
      ******** CAUSE OF LOSS ********
                WHEN CAUSE-OF-LOSS-2595
                  MOVE WS-LITERAL-YES TO ERROR-CAUSE-OF-LOSS-CD
                  MOVE WS-LITERAL-CAUSE-OF-LOSS-CD
                    TO WS-8000-FIELD-NAME1
      ******** PREVIOUS CAUSE ********
                WHEN PREVIOUS-CAUSE-2595
                  MOVE WS-LITERAL-YES TO ERROR-PREV-CAUSE-CD
                  MOVE WS-LITERAL-PREV-CAUSE-CD
                    TO WS-8000-FIELD-NAME1
      ******** OTHERS ********
                WHEN OTHER
                MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
                MOVE 044 TO WS-8000-SHORT-ERROR
                MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
                MOVE 'WS-2595-SOURCE-FIELD' TO WS-8000-FIELD-NAME1
                MOVE WS-2595-SOURCE-FIELD TO WS-8000-BAD-DATA1
                MOVE 'WHICH LOSS CAUSE IS BEING VALIDATED?'
                  TO WS-8000-CORR-DATA1
                MOVE 2595 TO WS-8000-PARAGRAPH-NO
                PERFORM 8000-RECORD-TRAN-ERROR
                   THRU 8000-RECORD-TRAN-ERROR-EXIT
                GO TO 2595-LOOKUP-LOSS-CAUSE-EXIT
              END-EVALUATE
              MOVE WS-2595-LOSS-CAUSE-CD TO WS-8000-BAD-DATA1
      *       *** SEARCH KEY USED IS IN CORR-DATA1
              MOVE 'LOSS CAUSE CROP TBL' TO WS-8000-TABLE-NAME
              MOVE 2595 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF.


       2595-LOOKUP-LOSS-CAUSE-EXIT.
           EXIT.

      $END

