      ****************************************************************
      *  File   : IR2615.CBL
      *  Author : Mike Ray
      *  Date   : 05/22/97
      *  Purpose:
      *    This module calculates the Stage Guarantee Per Acre and the
      *    Loss Guarantee and validates them against the input data.
      ****************************************************************

       2615-VAL-LOSS-GUARANTEE.

      $IF DEBUG-SW DEFINED
           DISPLAY '2615-VALIDATING LOSS GUARANTEE'
           UPON CONSOLE
      $END

      *****************************************************
      *    INITIALIZE LOCAL AND OUTPUT VARIABLES          *
      *****************************************************
           INITIALIZE WS-2615-WORK

           MOVE WS-2615-INPUT-LOSS-GUARANTEE
             TO WS-2615-INPUT-LOSS-GUARANTEE-X
           MOVE WS-2615-INPUT-STAGE-GPA
             TO WS-2615-INPUT-STAGE-GPA-X

      *****************************************************
      *    CHECK PRE-CONDITIONS                           *
      *****************************************************


           IF ERROR-STAGE-CD = WS-LITERAL-YES OR
              ERROR-LOSS-GUAR = WS-LITERAL-YES OR
              ERROR-STAGE-GPA = WS-LITERAL-YES OR
              ERROR-CROP-CD = WS-LITERAL-YES OR
              ERROR-UNIT-OF-MEASURE = WS-LITERAL-YES OR
              ERROR-INSUR-PLAN-CD = WS-LITERAL-YES
              MOVE WS-LITERAL-YES TO ERROR-LOSS-GUAR
              MOVE WS-LITERAL-YES TO ERROR-STAGE-GPA
              GO TO 2615-VAL-LOSS-GUARANTEE-EXIT
           END-IF

      $IF DEBUG-SW DEFINED
           DISPLAY 'INPUT STAGE GPA      = ',
           WS-2615-INPUT-STAGE-GPA-X UPON CONSOLE
           DISPLAY 'INPUT LOSS GUARANTEE = ',
           WS-2615-INPUT-LOSS-GUARANTEE-X UPON CONSOLE
      $END

      *****************************************************
      *    check for input stage gpa > 0 if not nursey    *
      *****************************************************

           IF WS-2615-INPUT-STAGE-GPA = zeroes
              and ws-2615-crop-cd <> ws-literal-nursery
              MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
              MOVE 21005 TO WS-8000-ERROR-CODE
              MOVE WS-LITERAL-YES TO ERROR-STAGE-GPA
              MOVE WS-LITERAL-YES TO ERROR-LOSS-GUAR
              MOVE WS-LITERAL-STAGE-GPA TO WS-8000-FIELD-NAME1
              MOVE WS-2615-INPUT-STAGE-GPA-X
                TO WS-8000-BAD-DATA1
              MOVE '> 0'
                TO WS-8000-CORR-DATA1
              MOVE 2615 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
              GO TO 2615-VAL-LOSS-GUARANTEE-EXIT
           END-IF

      *****************************************************
      *    LOOK UP REPLANT LIMITATIONS - IF NECESSARY     *
      *****************************************************

           IF WS-2615-STAGE-CD = WS-LITERAL-REPLANTED

              INITIALIZE WS-7330-I-CROP-LIMIT-AREA
              MOVE WS-2615-CROP-CD TO WS-7330-I-CROP
              MOVE WS-2615-TYPE-CD TO WS-7330-I-CROP-TYPE
              MOVE WS-2615-INS-PLAN-CD TO WS-7330-I-INSURANCE-PLAN

              INITIALIZE WS-7330-I-CROP-LIMIT-AREA
              MOVE WS-2615-CROP-CD TO WS-7330-I-CROP

      *  ** SET DEFAULT VALUES FOR CROP TYPE AND INSURANCE PLAN
              MOVE 998 TO WS-7330-I-CROP-TYPE
              MOVE 98 TO WS-7330-I-INSURANCE-PLAN

              EVALUATE WS-2615-CROP-CD
                  WHEN WS-LITERAL-CORN

      *  ** TYPE CODES FOR GRAIN ONLY AND SILAGE ONLY WILL BE
      *  ** PROCESSED THE SAME WAY AS GRAIN AND SILAGE RESPECTIVELY
                     IF WS-2615-TYPE-CD = WS-LITERAL-GRAIN-ONLY
                        MOVE WS-LITERAL-GRAIN TO WS-2615-TYPE-CD
                     END-IF

                     IF WS-2615-TYPE-CD = WS-LITERAL-SILAGE-ONLY
                        MOVE WS-LITERAL-SILAGE TO WS-2615-TYPE-CD
                     END-IF

                     IF WS-2615-TYPE-CD = WS-LITERAL-GRAIN
                        OR WS-2615-TYPE-CD = WS-LITERAL-SILAGE
                        MOVE WS-2615-TYPE-CD TO WS-7330-I-CROP-TYPE
                     END-IF

                  WHEN WS-LITERAL-FRESH-TOMATOES
                     IF WS-2615-INS-PLAN-CD = WS-LITERAL-DOLLAR-AMT
                        OR WS-2615-INS-PLAN-CD =
                        WS-LITERAL-APH-AREA-PLAN
                        MOVE WS-2615-INS-PLAN-CD
                          TO WS-7330-I-INSURANCE-PLAN
                     END-IF

                  WHEN OTHER
                     CONTINUE
              END-EVALUATE

              STRING 'SEARCHED WITH '
                  DELIMITED BY SIZE
                  WS-7330-I-CROP-LIMIT-AREA
                  DELIMITED BY SIZE
                  INTO WS-8020-BAD-DATA
              END-STRING


              PERFORM 7330-LOOKUP-CROP-LIMIT
                 THRU 7330-LOOKUP-CROP-LIMIT-EXIT

              IF MATCH-FOUND-7330
                 MOVE WS-7330-O-CROP-MAX-LIMIT
                   TO WS-2615-CROP-MAX-REPLANT-GPA

      $IF DEBUG-SW DEFINED
           DISPLAY  WS-2615-INPUT-STAGE-GPA
               UPON CONSOLE
           DISPLAY  WS-2615-CROP-MAX-REPLANT-GPA
               UPON CONSOLE
           DISPLAY  WS-7330-O-CROP-LIMIT-AREA
               UPON CONSOLE
           DISPLAY  WS-7330-O-CROP-MAX-LIMIT
               UPON CONSOLE
           DISPLAY  WS-2615-CROP-MAX-REPLANT-GPA
               UPON CONSOLE
      $END

                 IF WS-2615-INPUT-STAGE-GPA >
                    WS-2615-CROP-MAX-REPLANT-GPA
                    MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                    MOVE 21088 TO WS-8000-ERROR-CODE
                    MOVE WS-LITERAL-YES TO ERROR-STAGE-GPA
                    MOVE WS-LITERAL-YES TO ERROR-CROP-MAX-REPLANT-QTY
                    MOVE WS-LITERAL-STAGE-GPA TO WS-8000-FIELD-NAME1
                    MOVE WS-2615-INPUT-STAGE-GPA-X
                      TO WS-8000-BAD-DATA1
                    MOVE WS-2615-CROP-MAX-REPLANT-GPA
                      TO WS-2615-CALC-STAGE-GPA-X
                    MOVE WS-2615-CALC-STAGE-GPA-X
                      TO WS-8000-CORR-DATA1
                    MOVE 2615 TO WS-8000-PARAGRAPH-NO
                    PERFORM 8000-RECORD-TRAN-ERROR
                       THRU 8000-RECORD-TRAN-ERROR-EXIT
                 END-IF
              END-IF
           END-IF

      *****************************************************
      *    CALCULATE CORRECT STAGE/LOSS GUARANTEES        *
      *****************************************************
           PERFORM 2615-DETERMINE-LOSSG
              THRU 2615-DETERMINE-LOSSG-EXIT

           IF ERROR-LOSS-GUAR = WS-LITERAL-YES
              GO TO 2615-VAL-LOSS-GUARANTEE-EXIT
           END-IF

      *****************************************************
      *    CHECK INPUT DATA - REPLANTS                    *
      *****************************************************

           IF WS-2615-STAGE-CD = WS-LITERAL-REPLANTED

              IF WS-2615-INPUT-STAGE-GPA >
                 (WS-2615-CALC-STAGE-GPA)
                 MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                 MOVE 21084 TO WS-8000-ERROR-CODE
                 MOVE WS-LITERAL-YES TO ERROR-STAGE-GPA
                 MOVE WS-LITERAL-STAGE-GPA TO WS-8000-FIELD-NAME1
                 MOVE WS-2615-INPUT-STAGE-GPA-X
                   TO WS-8000-BAD-DATA1
      ***********************************************************
                 MOVE WS-2615-CALC-STAGE-GPA
                   TO WS-2615-CALC-STAGE-GPA-X
      ***********************************************************
                 MOVE WS-2615-CALC-STAGE-GPA-X
                   TO WS-8000-CORR-DATA1
                 MOVE 2615 TO WS-8000-PARAGRAPH-NO
                 PERFORM 8000-RECORD-TRAN-ERROR
                    THRU 8000-RECORD-TRAN-ERROR-EXIT
              END-IF

      ***********************************************************
              IF WS-2615-INPUT-LOSS-GUARANTEE >
                 (WS-2615-CALC-LOSS-GUARANTEE + 1)
      ***        WS-2615-INPUT-LOSS-GUARANTEE <
      ***        (WS-2615-CALC-LOSS-GUARANTEE - 1)
      ***********************************************************

                 MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                 MOVE 21085 TO WS-8000-ERROR-CODE
                 MOVE WS-LITERAL-YES TO ERROR-LOSS-GUAR
                 MOVE WS-LITERAL-LOSS-GUAR TO WS-8000-FIELD-NAME1
                 MOVE WS-2615-INPUT-LOSS-GUARANTEE-X
                   TO WS-8000-BAD-DATA1
      ***********************************************************
                 MOVE WS-2615-CALC-LOSS-GUARANTEE
                   TO WS-2615-CALC-LOSS-GUARANTEE-X
      ***********************************************************
                 MOVE WS-2615-CALC-LOSS-GUARANTEE-X
                   TO WS-8000-CORR-DATA1
                 MOVE 2615 TO WS-8000-PARAGRAPH-NO
                 PERFORM 8000-RECORD-TRAN-ERROR
                    THRU 8000-RECORD-TRAN-ERROR-EXIT
              END-IF
           END-IF

      *****************************************************
      *    CHECK INPUT DATA - NON-REPLANT                 *
      *****************************************************


      $IF DEBUG-SW DEFINED
           DISPLAY '%%%%%%%%%%%%%%' UPON CONSOLE
           DISPLAY WS-2615-STAGE-CD
           UPON CONSOLE
           DISPLAY WS-2615-INPUT-STAGE-GPA
           UPON CONSOLE
           DISPLAY WS-2615-CALC-STAGE-GPA
           UPON CONSOLE
           DISPLAY   WS-2615-MULTIPLE-GUAR-RED-PCT
           UPON CONSOLE
      $END

      ***********************************************************
           IF WS-2615-CROP-CD <> WS-LITERAL-NURSERY
      ***********************************************************

           IF WS-2615-STAGE-CD <> WS-LITERAL-REPLANTED

              IF WS-2615-INPUT-STAGE-GPA >
                 (WS-2615-CALC-STAGE-GPA + 1)
      ***        (WS-2615-CALC-STAGE-GPA + 1) OR
      ***        WS-2615-INPUT-STAGE-GPA <
      ***        (WS-2615-CALC-STAGE-GPA - 1)
                 IF (WS-2615-MULTIPLE-GUAR-RED-PCT
                    = WS-LITERAL-YES) AND
                    (WS-2615-INPUT-STAGE-GPA <
                    (WS-2615-CALC-STAGE-GPA + 1))
      *             *** INPUT IS LESS THAN THE UPPER BOUND
      *             *** AND IS THEREFORE OK
                    CONTINUE
                 ELSE
                    MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                    MOVE 21060 TO WS-8000-ERROR-CODE
                    MOVE WS-LITERAL-YES TO ERROR-STAGE-GPA
                    MOVE WS-LITERAL-STAGE-GPA TO WS-8000-FIELD-NAME1
                    MOVE WS-2615-INPUT-STAGE-GPA-X
                      TO WS-8000-BAD-DATA1
                    MOVE WS-2615-CALC-STAGE-GPA
                      TO WS-2615-CALC-STAGE-GPA-X
                    MOVE WS-2615-CALC-STAGE-GPA-X
                      TO WS-8000-CORR-DATA1
                    MOVE 2615 TO WS-8000-PARAGRAPH-NO
                    PERFORM 8000-RECORD-TRAN-ERROR
                       THRU 8000-RECORD-TRAN-ERROR-EXIT
                 END-IF
              END-IF

      ***     IF WS-2615-INPUT-LOSS-GUARANTEE >
      ***        (WS-2615-CALC-LOSS-GUARANTEE + 1) OR
      ***        WS-2615-INPUT-LOSS-GUARANTEE <
      ***        (WS-2615-CALC-LOSS-GUARANTEE - 1)

              IF (WS-2615-INPUT-LOSS-GUARANTEE >
                 (WS-2615-CALC-LOSS-GUARANTEE + 1) and
                  WS-T21-LIABILITY-FACTOR not < 1) or

                 (WS-2615-INPUT-LOSS-GUARANTEE >
                 (WS-2615-CALC-LOSS-GUARANTEE + 12) and
                  WS-T21-LIABILITY-FACTOR < 1)
      **********************************************************
                 MOVE 21061 TO WS-8000-ERROR-CODE

              IF WS-8000-ERROR-CODE = 21061

              IF (WS-2615-INPUT-LOSS-GUARANTEE >
                 (WS-2615-OLD-WAY             + 1) and
                  WS-T21-LIABILITY-FACTOR not < 1) or

                 (WS-2615-INPUT-LOSS-GUARANTEE >
                 (WS-2615-OLD-WAY             + 12) and
                  WS-T21-LIABILITY-FACTOR < 1)

                  CONTINUE
              ELSE
                 MOVE 00000 TO WS-8000-ERROR-CODE
                    GO TO 2615-NEXT

              END-IF
              END-IF


      **********************************************************

                 MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                 MOVE WS-LITERAL-YES TO ERROR-LOSS-GUAR
                 MOVE WS-LITERAL-LOSS-GUAR TO WS-8000-FIELD-NAME1
                 MOVE WS-2615-INPUT-LOSS-GUARANTEE-X
                   TO WS-8000-BAD-DATA1
                 MOVE WS-2615-CALC-LOSS-GUARANTEE
                   TO WS-2615-CALC-LOSS-GUARANTEE-X
                 MOVE WS-2615-CALC-LOSS-GUARANTEE-X
                   TO WS-8000-CORR-DATA1
                 MOVE 2615 TO WS-8000-PARAGRAPH-NO
                 PERFORM 8000-RECORD-TRAN-ERROR
                    THRU 8000-RECORD-TRAN-ERROR-EXIT
              END-IF
              END-IF
           END-IF.

      *******************************************************
       2615-NEXT.

           IF WS-2615-CROP-CD =  WS-LITERAL-NURSERY

      ***     IF WS-2615-INPUT-LOSS-GUARANTEE >
      ***        (WS-2615-CALC-LOSS-GUARANTEE + 1) OR
      ***        WS-2615-INPUT-LOSS-GUARANTEE <
      ***        (WS-2615-CALC-LOSS-GUARANTEE - 1)

              IF WS-2615-INPUT-LOSS-GUARANTEE >
                 (WS-2615-CALC-LOSS-GUARANTEE + 1)


                 MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                 MOVE 21061 TO WS-8000-ERROR-CODE
                 MOVE WS-LITERAL-YES TO ERROR-LOSS-GUAR
                 MOVE WS-LITERAL-LOSS-GUAR TO WS-8000-FIELD-NAME1
                 MOVE WS-2615-INPUT-LOSS-GUARANTEE-X
                   TO WS-8000-BAD-DATA1
                 MOVE WS-2615-CALC-LOSS-GUARANTEE
                   TO WS-2615-CALC-LOSS-GUARANTEE-X
                 MOVE WS-2615-CALC-LOSS-GUARANTEE-X
                   TO WS-8000-CORR-DATA1
                 MOVE 2615 TO WS-8000-PARAGRAPH-NO
                 PERFORM 8000-RECORD-TRAN-ERROR
                    THRU 8000-RECORD-TRAN-ERROR-EXIT
              END-IF
           END-IF.


      *******************************************************


       2615-VAL-LOSS-GUARANTEE-EXIT.
           EXIT.


       2615-DETERMINE-LOSSG.

      $IF DEBUG-SW DEFINED
           DISPLAY '2615-DETERMINING CORRECT LOSS GUARANTEE'
           UPON CONSOLE
      $END

           EVALUATE WS-2615-INS-PLAN-CD
      *        ********************************************
      *        *    APH LOSS GUARANTEE                    *
      *        ********************************************
               WHEN WS-LITERAL-APH
               WHEN WS-LITERAL-APH-AREA-SPAN
               WHEN WS-LITERAL-APH-AREA-PLAN
      *           *** CHECK PRECONDITIONS ***
                  IF ERROR-YLD-QUOTA = WS-LITERAL-YES OR
                     ERROR-CVG-LVL-PCT = WS-LITERAL-YES OR
                     ERROR-GUAR-RED-PCT = WS-LITERAL-YES OR
                     ERROR-CROP-MAX-REPLANT-QTY = WS-LITERAL-YES OR
                     ERROR-DETERM-ACRES = WS-LITERAL-YES OR
                     ERROR-LIAB-FCTR = WS-LITERAL-YES
                     MOVE WS-LITERAL-YES TO ERROR-LOSS-GUAR
                     MOVE WS-LITERAL-YES TO ERROR-STAGE-GUARANTEE
                     GO TO 2615-DETERMINE-LOSSG-EXIT
                  END-IF
      *           *** PERFORM CALCULATION ***
                  INITIALIZE WS-4705-INPUT
                  MOVE WS-2615-STAGE-CD TO WS-4705-STAGE-CD
                  MOVE WS-2615-YIELD TO WS-4705-YIELD
                  MOVE WS-2615-COVERAGE-LEVEL-PCT
                    TO WS-4705-CVG-LVL-PERCENT

      *********************************************************


                  IF WS-T21-STAGE-CD = 'P1'
                     MOVE .250 TO WS-4705-GUAR-REDUCTION-FCTR
                  ELSE
                  IF WS-T21-STAGE-CD = 'P2'
                     MOVE .500 TO WS-4705-GUAR-REDUCTION-FCTR
                  ELSE

      *********************************************************

                  MOVE WS-2615-GUAR-REDUCTION-FCTR
                    TO WS-4705-GUAR-REDUCTION-FCTR
                  END-IF
                  END-IF


                  MOVE WS-2615-STAGE-PERCENT-FCTR
                    TO WS-4705-STAGE-PCT-FCTR
                  MOVE WS-2615-CROP-UNIT-OF-MEASURE
                    TO WS-4705-CROP-UNIT-OF-MEASURE
                  MOVE WS-2615-INPUT-STAGE-GPA
                    TO WS-4705-INPUT-STAGE-GPA
                  MOVE WS-2615-CROP-MAX-REPLANT-GPA
                    TO WS-4705-CROP-MAX-REPLANT-GPA
                  MOVE WS-2615-DETERMINED-ACRES
                    TO WS-4705-ACRES
                  MOVE WS-2615-LIABILITY-ADJ-FACTOR
                    TO WS-4705-LIABILITY-ADJ-FCTR
                  PERFORM 4705-CALC-APH-LOSSG
                     THRU 4705-CALC-APH-LOSSG-EXIT
      *           *** CHECK FOR FAILURE ***
                  IF CALC-ERROR-4705
                     MOVE WS-LITERAL-YES TO ERROR-LOSS-GUAR
                     MOVE WS-LITERAL-YES TO ERROR-STAGE-GUARANTEE
                     GO TO 2615-DETERMINE-LOSSG-EXIT
                  END-IF
      *           *** MOVE RESULTS ***
                  MOVE WS-4705-STAGE-GPA
                    TO WS-2615-CALC-STAGE-GPA
                  MOVE WS-4705-LOSS-GUARANTEE
                    TO WS-2615-CALC-LOSS-GUARANTEE


      *        ********************************************
      *        *    CRC LOSS GUARANTEE                    *
      *        ********************************************
               WHEN WS-LITERAL-CRC
      *           *** CHECK PRECONDITIONS ***
                  IF ERROR-YLD-QUOTA = WS-LITERAL-YES OR
                     ERROR-CVG-LVL-PCT = WS-LITERAL-YES OR
                     ERROR-GUAR-RED-PCT = WS-LITERAL-YES OR
                     ERROR-PRICE-ELECTION = WS-LITERAL-YES OR
                     ERROR-CROP-MAX-REPLANT-QTY = WS-LITERAL-YES OR
                     ERROR-DETERM-ACRES = WS-LITERAL-YES OR
                     ERROR-LIAB-FCTR = WS-LITERAL-YES
                     MOVE WS-LITERAL-YES TO ERROR-LOSS-GUAR
                     MOVE WS-LITERAL-YES TO ERROR-STAGE-GUARANTEE
                     GO TO 2615-DETERMINE-LOSSG-EXIT
                  END-IF
      *           *** PERFORM CALCULATION ***
                  INITIALIZE WS-4745-INPUT
                  MOVE WS-2615-STAGE-CD TO WS-4745-STAGE-CD
                  MOVE WS-2615-YIELD TO WS-4745-YIELD
                  MOVE WS-2615-COVERAGE-LEVEL-PCT
                    TO WS-4745-CVG-LVL-PERCENT

      *********************************************************


                  IF WS-T21-STAGE-CD = 'P1'
                     MOVE .250 TO WS-4745-GUAR-REDUCTION-FCTR
                  ELSE
                  IF WS-T21-STAGE-CD = 'P2'
                     MOVE .500 TO WS-4745-GUAR-REDUCTION-FCTR
                  ELSE

      *********************************************************

                  MOVE WS-2615-GUAR-REDUCTION-FCTR
                    TO WS-4745-GUAR-REDUCTION-FCTR
                  END-IF
                  END-IF

                  MOVE WS-2615-CROP-UNIT-OF-MEASURE
                    TO WS-4745-CROP-UNIT-OF-MEASURE
                  MOVE WS-2615-PRICE-ELECTION
                    TO WS-4745-PRICE-ELECTION
                  MOVE WS-2615-INPUT-STAGE-GPA
                    TO WS-4745-INPUT-STAGE-GPA
                  MOVE WS-2615-CROP-MAX-REPLANT-GPA
                    TO WS-4745-CROP-MAX-REPLANT-GPA
                  MOVE WS-2615-DETERMINED-ACRES
                    TO WS-4745-ACRES
                  MOVE WS-2615-LIABILITY-ADJ-FACTOR
                    TO WS-4745-LIABILITY-ADJ-FCTR
                  PERFORM 4745-CALC-CRC-LOSSG
                     THRU 4745-CALC-CRC-LOSSG-EXIT
      *           *** CHECK FOR FAILURE ***
                  IF CALC-ERROR-4745
                     MOVE WS-LITERAL-YES TO ERROR-LOSS-GUAR
                     MOVE WS-LITERAL-YES TO ERROR-STAGE-GUARANTEE
                     GO TO 2615-DETERMINE-LOSSG-EXIT
                  END-IF
      *           *** MOVE RESULTS ***
                  MOVE WS-4745-STAGE-GPA
                    TO WS-2615-CALC-STAGE-GPA
                  MOVE WS-4745-LOSS-GUARANTEE
                    TO WS-2615-CALC-LOSS-GUARANTEE

      ********************************************************

                  MOVE WS-4745-OLD-WAY
                    TO WS-2615-OLD-WAY

      ********************************************************

      *        ********************************************
      *        *    DOLLAR CROPS LOSS GUARANTEE           *
      *        ********************************************
               WHEN WS-LITERAL-DOLLAR-AMT
      *           *** CHECK PRECONDITIONS ***
                  IF ERROR-DOLLAR-AMT-INSUR = WS-LITERAL-YES OR
                     ERROR-CROP-MAX-REPLANT-QTY = WS-LITERAL-YES OR
                     ERROR-DETERM-ACRES = WS-LITERAL-YES OR
                     ERROR-LIAB-FCTR = WS-LITERAL-YES
                     MOVE WS-LITERAL-YES TO ERROR-LOSS-GUAR
                     MOVE WS-LITERAL-YES TO ERROR-STAGE-GUARANTEE
                     GO TO 2615-DETERMINE-LOSSG-EXIT
                  END-IF
      *           *** PERFORM CALCULATION ***
                  INITIALIZE WS-4715-INPUT
                  MOVE WS-2615-STAGE-CD TO WS-4715-STAGE-CD
                  MOVE WS-2615-DOLLAR-AMT-INS
                    TO WS-4715-DOLLAR-AMT-INS

      *******************************************************
                  IF WS-2615-CROP-CD = WS-LITERAL-NURSERY
      ***            MOVE WS-0011-TBL-LIABILITY(WS-0011-T11-INDEX)
                     MOVE WS-0011-UNIT-TBL-TOT-LIABILITY
                     (WS-0011-UNIT-INDEX)
                     TO WS-4715-DOLLAR-AMT-INS
                  END-IF
      *******************************************************

                  MOVE WS-2615-STAGE-PERCENT-FCTR
                    TO WS-4715-STAGE-PCT-FCTR
                  MOVE WS-2615-CROP-UNIT-OF-MEASURE
                    TO WS-4715-CROP-UNIT-OF-MEASURE
                  MOVE WS-2615-INPUT-STAGE-GPA
                    TO WS-4715-INPUT-STAGE-GPA
                  MOVE WS-2615-CROP-MAX-REPLANT-GPA
                    TO WS-4715-CROP-MAX-REPLANT-GPA
                  MOVE WS-2615-DETERMINED-ACRES
                    TO WS-4715-ACRES
                  MOVE WS-2615-LIABILITY-ADJ-FACTOR
                    TO WS-4715-LIABILITY-ADJ-FCTR
                  PERFORM 4715-CALC-DOLLAR-LOSSG
                     THRU 4715-CALC-DOLLAR-LOSSG-EXIT
      *           *** CHECK FOR FAILURE ***
                  IF CALC-ERROR-4715
                     MOVE WS-LITERAL-YES TO ERROR-LOSS-GUAR
                     MOVE WS-LITERAL-YES TO ERROR-STAGE-GUARANTEE
                     GO TO 2615-DETERMINE-LOSSG-EXIT
                  END-IF
      *           *** MOVE RESULTS ***
                  MOVE WS-4715-STAGE-GPA
                    TO WS-2615-CALC-STAGE-GPA
                  MOVE WS-4715-LOSS-GUARANTEE
                    TO WS-2615-CALC-LOSS-GUARANTEE


      *        ********************************************
      *        *    FLORIDA FRUIT LOSS GUARANTEE          *
      *        ********************************************
               WHEN WS-LITERAL-FLORIDA-FRUIT
      *           *** CHECK PRECONDITIONS ***
                  IF ERROR-YLD-QUOTA = WS-LITERAL-YES OR
                     ERROR-CVG-LVL-PCT = WS-LITERAL-YES OR
                     ERROR-GUAR-RED-PCT = WS-LITERAL-YES OR
                     ERROR-PRICE-ELECTION = WS-LITERAL-YES OR
                     ERROR-LIAB-FCTR = WS-LITERAL-YES
                     MOVE WS-LITERAL-YES TO ERROR-LOSS-GUAR
                     MOVE WS-LITERAL-YES TO ERROR-STAGE-GUARANTEE
                     GO TO 2615-DETERMINE-LOSSG-EXIT
                  END-IF
      *           *** PERFORM CALCULATION ***
                  INITIALIZE WS-4750-INPUT
                  MOVE WS-2615-STAGE-CD TO WS-4750-STAGE-CD
                  MOVE WS-2615-QUOTA TO WS-4750-QUOTA
                  MOVE WS-2615-COVERAGE-LEVEL-PCT
                    TO WS-4750-CVG-LVL-PERCENT
                  MOVE WS-2615-GUAR-REDUCTION-FCTR
                    TO WS-4750-GUAR-REDUCTION-FCTR
                  MOVE WS-2615-PRICE-ELECTION
                    TO WS-4750-PRICE-ELECTION
                  MOVE WS-2615-CROP-UNIT-OF-MEASURE
                    TO WS-4750-CROP-UNIT-OF-MEASURE
                  MOVE WS-2615-LIABILITY-ADJ-FACTOR
                    TO WS-4750-LIABILITY-ADJ-FCTR
                  PERFORM 4750-CALC-FL-FRUIT-LOSSG
                     THRU 4750-CALC-FL-FRUIT-LOSSG-EXIT
      *           *** CHECK FOR FAILURE ***
                  IF CALC-ERROR-4750
                     MOVE WS-LITERAL-YES TO ERROR-LOSS-GUAR
                     MOVE WS-LITERAL-YES TO ERROR-STAGE-GUARANTEE
                     GO TO 2615-DETERMINE-LOSSG-EXIT
                  END-IF
      *           *** MOVE RESULTS ***
                  MOVE WS-4750-STAGE-GPA
                    TO WS-2615-CALC-STAGE-GPA
                  MOVE WS-4750-LOSS-GUARANTEE
                    TO WS-2615-CALC-LOSS-GUARANTEE


      *        ********************************************
      *        *    GRP LOSS GUARANTEE                    *
      *        ********************************************
               WHEN WS-LITERAL-GRP
      *           *** CHECK PRECONDITIONS ***
                  IF ERROR-DOLLAR-AMT-INSUR = WS-LITERAL-YES OR
                     ERROR-CROP-MAX-REPLANT-QTY = WS-LITERAL-YES OR
                     ERROR-PRICE-ELECTION = WS-LITERAL-YES OR
                     ERROR-DETERM-ACRES = WS-LITERAL-YES OR
                     ERROR-LIAB-FCTR = WS-LITERAL-YES
                     MOVE WS-LITERAL-YES TO ERROR-LOSS-GUAR
                     MOVE WS-LITERAL-YES TO ERROR-STAGE-GUARANTEE
                     GO TO 2615-DETERMINE-LOSSG-EXIT
                  END-IF
      *           *** PERFORM CALCULATION ***
                  INITIALIZE WS-4730-INPUT
                  MOVE WS-2615-STAGE-CD TO WS-4730-STAGE-CD
                  MOVE WS-2615-DOLLAR-AMT-INS
                    TO WS-4730-DOLLAR-AMT-INS
                  MOVE WS-2615-CROP-UNIT-OF-MEASURE
                    TO WS-4730-CROP-UNIT-OF-MEASURE
                  MOVE WS-2615-INPUT-STAGE-GPA
                    TO WS-4730-INPUT-STAGE-GPA
                  MOVE WS-2615-CROP-MAX-REPLANT-GPA
                    TO WS-4730-CROP-MAX-REPLANT-GPA
                  MOVE WS-2615-PRICE-ELECTION
                    TO WS-4730-PRICE-ELECTION
                  MOVE WS-2615-DETERMINED-ACRES
                    TO WS-4730-ACRES
                  MOVE WS-2615-LIABILITY-ADJ-FACTOR
                    TO WS-4730-LIABILITY-ADJ-FCTR
                  PERFORM 4730-CALC-GRP-LOSSG
                     THRU 4730-CALC-GRP-LOSSG-EXIT
      *           *** CHECK FOR FAILURE ***
                  IF CALC-ERROR-4730
                     MOVE WS-LITERAL-YES TO ERROR-LOSS-GUAR
                     MOVE WS-LITERAL-YES TO ERROR-STAGE-GUARANTEE
                     GO TO 2615-DETERMINE-LOSSG-EXIT
                  END-IF
      *           *** MOVE RESULTS ***
                  MOVE WS-4730-STAGE-GPA
                    TO WS-2615-CALC-STAGE-GPA
                  MOVE WS-4730-LOSS-GUARANTEE
                    TO WS-2615-CALC-LOSS-GUARANTEE


      *        ********************************************
      *        *    GUARANTEE TOBACCO LOSS GUARANTEE      *
      *        ********************************************
               WHEN WS-LITERAL-GUARANTEE-TOBACCO
      *           *** CHECK PRECONDITIONS ***
                  IF ERROR-YLD-QUOTA = WS-LITERAL-YES OR
                     ERROR-CVG-LVL-PCT = WS-LITERAL-YES OR
                     ERROR-GUAR-RED-PCT = WS-LITERAL-YES OR
                     ERROR-DETERM-ACRES = WS-LITERAL-YES OR
                     ERROR-LIAB-FCTR = WS-LITERAL-YES
                     MOVE WS-LITERAL-YES TO ERROR-LOSS-GUAR
                     MOVE WS-LITERAL-YES TO ERROR-STAGE-GUARANTEE
                     GO TO 2615-DETERMINE-LOSSG-EXIT
                  END-IF
      *           *** PERFORM CALCULATION ***
                  INITIALIZE WS-4735-INPUT
                  MOVE WS-2615-STAGE-CD TO WS-4735-STAGE-CD
                  MOVE WS-2615-YIELD TO WS-4735-YIELD
                  MOVE WS-2615-COVERAGE-LEVEL-PCT
                    TO WS-4735-CVG-LVL-PERCENT
                  MOVE WS-2615-GUAR-REDUCTION-FCTR
                    TO WS-4735-GUAR-REDUCTION-FCTR
                  MOVE WS-2615-CROP-UNIT-OF-MEASURE
                    TO WS-4735-CROP-UNIT-OF-MEASURE
                  MOVE WS-2615-DETERMINED-ACRES


      *****************************************************
      ***           TO WS-4730-ACRES
                    TO WS-4735-ACRES

      *****************************************************


                  MOVE WS-2615-LIABILITY-ADJ-FACTOR
                    TO WS-4735-LIABILITY-ADJ-FCTR
                  PERFORM 4735-CALC-GTOBACCO-LOSSG
                     THRU 4735-CALC-GTOBACCO-LOSSG-EXIT
      *           *** CHECK FOR FAILURE ***
                  IF CALC-ERROR-4735
                     MOVE WS-LITERAL-YES TO ERROR-LOSS-GUAR
                     MOVE WS-LITERAL-YES TO ERROR-STAGE-GUARANTEE
                     GO TO 2615-DETERMINE-LOSSG-EXIT
                  END-IF
      *           *** MOVE RESULTS ***
                  MOVE WS-4735-STAGE-GPA
                    TO WS-2615-CALC-STAGE-GPA
                  MOVE WS-4735-LOSS-GUARANTEE
                    TO WS-2615-CALC-LOSS-GUARANTEE


      *        ********************************************
      *        *    IP LOSS GUARANTEE                     *
      *        ********************************************
               WHEN WS-LITERAL-IP
      *           *** CHECK PRECONDITIONS ***
                  IF ERROR-DOLLAR-AMT-INSUR = WS-LITERAL-YES OR
                     ERROR-GUAR-RED-PCT = WS-LITERAL-YES OR
                     ERROR-CROP-MAX-REPLANT-QTY = WS-LITERAL-YES OR
                     ERROR-PRICE-ELECTION = WS-LITERAL-YES OR
                     ERROR-INSURED-SHARE = WS-LITERAL-YES OR
                     ERROR-DETERM-ACRES = WS-LITERAL-YES OR
                     ERROR-LIAB-FCTR = WS-LITERAL-YES
                     MOVE WS-LITERAL-YES TO ERROR-LOSS-GUAR
                     MOVE WS-LITERAL-YES TO ERROR-STAGE-GUARANTEE
                     GO TO 2615-DETERMINE-LOSSG-EXIT
                  END-IF
      *           *** PERFORM CALCULATION ***
                  INITIALIZE WS-4760-INPUT
                  MOVE WS-2615-STAGE-CD TO WS-4760-STAGE-CD
                  MOVE WS-2615-DOLLAR-AMT-INS
                    TO WS-4760-DOLLAR-AMT-INS

                  MOVE WS-2615-GUAR-REDUCTION-FCTR
                    TO WS-4760-GUAR-REDUCTION-FCTR


                  MOVE WS-2615-PRICE-ELECTION
                    TO WS-4760-PRICE-ELECTION
                  MOVE WS-2615-INSURED-SHARE
                    TO WS-4760-INS-SHARE
                  MOVE WS-2615-CROP-UNIT-OF-MEASURE
                    TO WS-4760-CROP-UNIT-OF-MEASURE
                  MOVE WS-2615-INPUT-STAGE-GPA
                    TO WS-4760-INPUT-STAGE-GPA
                  MOVE WS-2615-CROP-MAX-REPLANT-GPA
                    TO WS-4760-CROP-MAX-REPLANT-GPA
                  MOVE WS-2615-DETERMINED-ACRES
                    TO WS-4760-ACRES
                  MOVE WS-2615-LIABILITY-ADJ-FACTOR
                    TO WS-4760-LIABILITY-ADJ-FCTR
                  PERFORM 4760-CALC-IP-LOSSG
                     THRU 4760-CALC-IP-LOSSG-EXIT
      *           *** CHECK FOR FAILURE ***
                  IF CALC-ERROR-4760
                     MOVE WS-LITERAL-YES TO ERROR-LOSS-GUAR
                     MOVE WS-LITERAL-YES TO ERROR-STAGE-GUARANTEE
                     GO TO 2615-DETERMINE-LOSSG-EXIT
                  END-IF
      *           *** MOVE RESULTS ***
                  MOVE WS-4760-STAGE-GPA
                    TO WS-2615-CALC-STAGE-GPA
                  MOVE WS-4760-LOSS-GUARANTEE
                    TO WS-2615-CALC-LOSS-GUARANTEE


      *        ********************************************
      *        *    QUOTA PEANUTS LOSS GUARANTEE          *
      *        ********************************************
               WHEN WS-LITERAL-PEANUTS-PLAN
      *           *** CHECK PRECONDITIONS ***
                  IF ERROR-YLD-QUOTA = WS-LITERAL-YES OR
                     ERROR-CVG-LVL-PCT = WS-LITERAL-YES OR
                     ERROR-GUAR-RED-PCT = WS-LITERAL-YES OR
                     ERROR-PRICE-ELECTION = WS-LITERAL-YES OR
                     ERROR-DETERM-ACRES = WS-LITERAL-YES OR
                     ERROR-LIAB-FCTR = WS-LITERAL-YES
                     MOVE WS-LITERAL-YES TO ERROR-LOSS-GUAR
                     MOVE WS-LITERAL-YES TO ERROR-STAGE-GUARANTEE
                     GO TO 2615-DETERMINE-LOSSG-EXIT
                  END-IF
      *           *** PERFORM CALCULATION ***
                  INITIALIZE WS-4710-INPUT
                  MOVE WS-2615-STAGE-CD TO WS-4710-STAGE-CD
                  IF QUOTA-PEANUTS-0009
                     MOVE WS-2615-QUOTA TO WS-4710-QUOTA
                  ELSE
                     MOVE WS-2615-YIELD TO WS-4710-QUOTA
                  END-IF
                  MOVE WS-2615-COVERAGE-LEVEL-PCT
                    TO WS-4710-CVG-LVL-PERCENT

                  MOVE WS-2615-GUAR-REDUCTION-FCTR
                    TO WS-4710-GUAR-REDUCTION-FCTR

                  MOVE WS-2615-PRICE-ELECTION
                    TO WS-4710-PRICE-ELECTION
                  MOVE WS-2615-CROP-UNIT-OF-MEASURE
                    TO WS-4710-CROP-UNIT-OF-MEASURE
                  MOVE WS-2615-INPUT-STAGE-GPA
                    TO WS-4710-INPUT-STAGE-GPA
                  MOVE WS-2615-CROP-MAX-REPLANT-GPA
                    TO WS-4710-CROP-MAX-REPLANT-GPA
                  MOVE WS-2615-DETERMINED-ACRES
                    TO WS-4710-ACRES
                  MOVE WS-2615-LIABILITY-ADJ-FACTOR
                    TO WS-4710-LIABILITY-ADJ-FCTR
                  PERFORM 4710-CALC-QPEANUT-LOSSG
                     THRU 4710-CALC-QPEANUT-LOSSG-EXIT
      *           *** CHECK FOR FAILURE ***
                  IF CALC-ERROR-4710
                     MOVE WS-LITERAL-YES TO ERROR-LOSS-GUAR
                     MOVE WS-LITERAL-YES TO ERROR-STAGE-GUARANTEE
                     GO TO 2615-DETERMINE-LOSSG-EXIT
                  END-IF
      *           *** MOVE RESULTS ***
                  MOVE WS-4710-STAGE-GPA
                    TO WS-2615-CALC-STAGE-GPA
                  MOVE WS-4710-LOSS-GUARANTEE
                    TO WS-2615-CALC-LOSS-GUARANTEE


      *        ********************************************
      *        *    QUOTA TOBACCO LOSS GUARANTEE          *
      *        ********************************************
               WHEN WS-LITERAL-QUOTA-TOBACCO
      *           *** CHECK PRECONDITIONS ***
                  IF ERROR-YLD-QUOTA = WS-LITERAL-YES OR
                     ERROR-CVG-LVL-PCT = WS-LITERAL-YES OR
                     ERROR-GUAR-RED-PCT = WS-LITERAL-YES OR
                     ERROR-PRICE-ELECTION = WS-LITERAL-YES OR
                     ERROR-LIAB-FCTR = WS-LITERAL-YES
                     MOVE WS-LITERAL-YES TO ERROR-LOSS-GUAR
                     MOVE WS-LITERAL-YES TO ERROR-STAGE-GUARANTEE
                     GO TO 2615-DETERMINE-LOSSG-EXIT
                  END-IF
      *           *** PERFORM CALCULATION ***
                  INITIALIZE WS-4740-INPUT
                  MOVE WS-2615-STAGE-CD TO WS-4740-STAGE-CD
                  MOVE WS-2615-QUOTA TO WS-4740-QUOTA
                  MOVE WS-2615-COVERAGE-LEVEL-PCT
                    TO WS-4740-CVG-LVL-PERCENT
                  MOVE WS-2615-GUAR-REDUCTION-FCTR
                    TO WS-4740-GUAR-REDUCTION-FCTR
                  MOVE WS-2615-PRICE-ELECTION
                    TO WS-4740-PRICE-ELECTION
                  MOVE WS-2615-CROP-UNIT-OF-MEASURE
                    TO WS-4740-CROP-UNIT-OF-MEASURE
                  MOVE WS-2615-LIABILITY-ADJ-FACTOR
                    TO WS-4740-LIABILITY-ADJ-FCTR
                  PERFORM 4740-CALC-QTOBACCO-LOSSG
                     THRU 4740-CALC-QTOBACCO-LOSSG-EXIT
      *           *** CHECK FOR FAILURE ***
                  IF CALC-ERROR-4740
                     MOVE WS-LITERAL-YES TO ERROR-LOSS-GUAR
                     MOVE WS-LITERAL-YES TO ERROR-STAGE-GUARANTEE
                     GO TO 2615-DETERMINE-LOSSG-EXIT
                  END-IF
      *           *** MOVE RESULTS ***
                  MOVE WS-4740-STAGE-GPA
                    TO WS-2615-CALC-STAGE-GPA
                  MOVE WS-4740-LOSS-GUARANTEE
                    TO WS-2615-CALC-LOSS-GUARANTEE


      *        ********************************************
      *        *    YIELD-BASED $CROP LOSS GUARANTEE      *
      *        ********************************************
               WHEN WS-LITERAL-YLD-BASED-DOL-AMT
      *           *** CHECK PRECONDITIONS ***
                  IF ERROR-YLD-QUOTA = WS-LITERAL-YES OR
                     ERROR-PRICE-ELECTION = WS-LITERAL-YES OR
                     ERROR-DETERM-ACRES = WS-LITERAL-YES OR
                     ERROR-LIAB-FCTR = WS-LITERAL-YES
                     MOVE WS-LITERAL-YES TO ERROR-LOSS-GUAR
                     MOVE WS-LITERAL-YES TO ERROR-STAGE-GUARANTEE
                     GO TO 2615-DETERMINE-LOSSG-EXIT
                  END-IF
      *           *** PERFORM CALCULATION ***
                  INITIALIZE WS-4725-INPUT
                  MOVE WS-2615-STAGE-CD TO WS-4725-STAGE-CD
                  MOVE WS-2615-YIELD TO WS-4725-YIELD
                  MOVE WS-2615-PRICE-ELECTION
                    TO WS-4725-PRICE-ELECTION
                  MOVE WS-2615-CROP-UNIT-OF-MEASURE
                    TO WS-4725-CROP-UNIT-OF-MEASURE
                  MOVE WS-2615-DETERMINED-ACRES
                    TO WS-4725-ACRES
                  MOVE WS-2615-LIABILITY-ADJ-FACTOR
                    TO WS-4725-LIABILITY-ADJ-FCTR
                  PERFORM 4725-CALC-YLDDLR-LOSSG
                     THRU 4725-CALC-YLDDLR-LOSSG-EXIT
      *           *** CHECK FOR FAILURE ***
                  IF CALC-ERROR-4725
                     MOVE WS-LITERAL-YES TO ERROR-LOSS-GUAR
                     MOVE WS-LITERAL-YES TO ERROR-STAGE-GUARANTEE
                     GO TO 2615-DETERMINE-LOSSG-EXIT
                  END-IF
      *           *** MOVE RESULTS ***
                  MOVE WS-4725-STAGE-GPA
                    TO WS-2615-CALC-STAGE-GPA
                  MOVE WS-4725-LOSS-GUARANTEE
                    TO WS-2615-CALC-LOSS-GUARANTEE

      *        ********************************************
      *        *    RA LOSS GUARANTEE                     *
      *        ********************************************
               WHEN WS-LITERAL-RA
      *           *** CHECK PRECONDITIONS ***
                  IF ERROR-DOLLAR-AMT-INSUR = WS-LITERAL-YES OR
                     ERROR-GUAR-RED-PCT = WS-LITERAL-YES OR
                     ERROR-CROP-MAX-REPLANT-QTY = WS-LITERAL-YES OR
                     ERROR-YLD-QUOTA = WS-LITERAL-YES OR
                     ERROR-REVENUE-CVG-LVL = WS-LITERAL-YES OR
                     ERROR-INSURED-SHARE = WS-LITERAL-YES OR
                     ERROR-DETERM-ACRES = WS-LITERAL-YES OR
                     ERROR-LIAB-FCTR = WS-LITERAL-YES
                     MOVE WS-LITERAL-YES TO ERROR-LOSS-GUAR
                     MOVE WS-LITERAL-YES TO ERROR-STAGE-GUARANTEE
                     GO TO 2615-DETERMINE-LOSSG-EXIT
                  END-IF
      *           *** PERFORM CALCULATION ***
                  INITIALIZE WS-4755-INPUT
                  MOVE WS-2615-STAGE-CD TO WS-4755-STAGE-CD
                  MOVE WS-2615-DOLLAR-AMT-INS
                    TO WS-4755-DOLLAR-AMT-INS
                  MOVE WS-2615-GUAR-REDUCTION-FCTR
                    TO WS-4755-GUAR-REDUCTION-FCTR
                  MOVE WS-2615-INSURED-SHARE
                    TO WS-4755-INS-SHARE
                  MOVE WS-2615-CROP-UNIT-OF-MEASURE
                    TO WS-4755-CROP-UNIT-OF-MEASURE
                  MOVE WS-2615-YIELD TO WS-4755-YIELD
                  MOVE WS-2615-RA-COVERAGE-LEVEL
                    TO WS-4755-RA-COVERAGE-LEVEL
                  MOVE WS-2615-INPUT-STAGE-GPA
                    TO WS-4755-INPUT-STAGE-GPA
                  MOVE WS-2615-CROP-MAX-REPLANT-GPA
                    TO WS-4755-CROP-MAX-REPLANT-GPA
                  MOVE WS-2615-DETERMINED-ACRES
                    TO WS-4755-ACRES
                  MOVE WS-2615-LIABILITY-ADJ-FACTOR
                    TO WS-4755-LIABILITY-ADJ-FCTR
                  PERFORM 4755-CALC-RA-LOSSG
                     THRU 4755-CALC-RA-LOSSG-EXIT
      *           *** CHECK FOR FAILURE ***
                  IF CALC-ERROR-4755
                     MOVE WS-LITERAL-YES TO ERROR-LOSS-GUAR
                     MOVE WS-LITERAL-YES TO ERROR-STAGE-GUARANTEE
                     GO TO 2615-DETERMINE-LOSSG-EXIT
                  END-IF
      *           *** MOVE RESULTS ***
                  MOVE WS-4755-STAGE-GPA
                    TO WS-2615-CALC-STAGE-GPA
                  MOVE WS-4755-LOSS-GUARANTEE
                    TO WS-2615-CALC-LOSS-GUARANTEE

               WHEN OTHER
                  MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
                  MOVE 042 TO WS-8000-SHORT-ERROR
                  MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                  MOVE WS-LITERAL-YES TO ERROR-LOSS-GUAR
                  MOVE WS-LITERAL-YES TO ERROR-STAGE-GUARANTEE
                  MOVE WS-LITERAL-YES TO ERROR-INSUR-PLAN-CD
                  MOVE WS-LITERAL-INSURE-PLAN-CD
                    TO WS-8000-FIELD-NAME1
                  MOVE WS-2615-INS-PLAN-CD TO WS-8000-BAD-DATA1
                  MOVE 2615 TO WS-8000-PARAGRAPH-NO
                  PERFORM 8000-RECORD-TRAN-ERROR
                     THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-EVALUATE.


       2615-DETERMINE-LOSSG-EXIT.
           EXIT.
