      ****************************************************************
      *  File   : IR2630.CBL
      *  Author : Mike Ray
      *  Date   : 05/23/97
      *  Purpose: This module calculates and validates Farm Unit
      *           Deficiency and Indemnity.
      ****************************************************************

       2630-VAL-INDEMNITY.

      $IF DEBUG-SW DEFINED
           DISPLAY '2630-VALIDATING INDEMNITY'
           UPON CONSOLE
      $END

      *******************************************
      *    INITIALIZE LOCAL & OUTPUT VARIABLES  *
      *******************************************
           INITIALIZE WS-2630-WORK
           INITIALIZE WS-2630-OUTPUT

      *******************************************
      *    SET UP DISPLAY FIELDS                *
      *******************************************
           MOVE WS-2630-INPUT-FARM-UNIT-DEF
             TO WS-2630-INPUT-FARM-UNIT-DEF-X
           MOVE WS-2630-INPUT-INDEMNITY
             TO WS-2630-INPUT-INDEMNITY-X

      $IF DEBUG-SW DEFINED
           DISPLAY 'INPUT FARM UNIT DEF  = ',
           WS-2630-INPUT-FARM-UNIT-DEF-X UPON CONSOLE
           DISPLAY 'INPUT INDEMNITY      = ',
           WS-2630-INPUT-INDEMNITY-X UPON CONSOLE
      $END

      *******************************************
      *    CHECK PRECONDITIONS                  *
      *******************************************
           IF ERROR-INSUR-PLAN-CD = WS-LITERAL-YES OR
              ERROR-UNIT-OF-MEASURE = WS-LITERAL-YES OR
              ERROR-CROP-CD = WS-LITERAL-YES OR
              ERROR-FARM-UNIT-DEFICIENCY = WS-LITERAL-YES OR
              ERROR-INSURED-SHARE = WS-LITERAL-YES OR
              ERROR-LOSS-GUAR = WS-LITERAL-YES OR
              ERROR-PRODUCTION-TO-COUNT = WS-LITERAL-YES OR
              ERROR-INDEM = WS-LITERAL-YES
              MOVE WS-LITERAL-YES TO ERROR-FARM-UNIT-DEFICIENCY
              MOVE WS-LITERAL-YES TO ERROR-INDEM
              GO TO 2630-VAL-INDEMNITY-EXIT
           END-IF

      *****************************************************
      *    CALCULATE FARM UNIT DEFICENCY AND INDEMNITY    *
      *****************************************************
           PERFORM 2630-CALC-INDEMNITY
              THRU 2630-CALC-INDEMNITY-EXIT

           IF ERROR-INDEM = WS-LITERAL-YES
              GO TO 2630-VAL-INDEMNITY-EXIT
           END-IF

      *******************************************
      *    SET UP DISPLAY FIELDS                *
      *******************************************
           MOVE WS-2630-CALC-FARM-UNIT-DEF
             TO WS-2630-CALC-FARM-UNIT-DEF-X
           MOVE WS-2630-CALC-INDEMNITY
             TO WS-2630-CALC-INDEMNITY-X

      $IF DEBUG-SW DEFINED
           DISPLAY 'CALC FARM UNIT DEF   = ',
           WS-2630-CALC-FARM-UNIT-DEF-X
           UPON CONSOLE
           DISPLAY 'CALC INDEMNITY       = ',
           WS-2630-CALC-INDEMNITY-X
           UPON CONSOLE
      $END

      *****************************************************
      *    CHECK INPUT FIELDS AGAINST CALCULATIONS        *
      *****************************************************
           IF WS-2630-INPUT-FARM-UNIT-DEF >
              (WS-2630-CALC-FARM-UNIT-DEF + 1) OR
              WS-2630-INPUT-FARM-UNIT-DEF <
              (WS-2630-CALC-FARM-UNIT-DEF - 1)
              MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO ERROR-FARM-UNIT-DEFICIENCY
              MOVE 21065 TO WS-8000-ERROR-CODE
              MOVE WS-LITERAL-FARM-UNIT-DEFC
                TO WS-8000-FIELD-NAME1
              MOVE WS-2630-INPUT-FARM-UNIT-DEF-X
                TO WS-8000-BAD-DATA1
              MOVE WS-2630-CALC-FARM-UNIT-DEF-X
                TO WS-8000-CORR-DATA1
              MOVE 2630 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

      ***  IF WS-2630-INPUT-INDEMNITY >
      ***     (WS-2630-CALC-INDEMNITY + 1) OR
      ***     WS-2630-INPUT-INDEMNITY <
      ***     (WS-2630-CALC-INDEMNITY - 1)


           IF WS-2630-INPUT-INDEMNITY >
              (WS-2630-CALC-INDEMNITY + 1)


              MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO ERROR-INDEM
              IF WS-2630-STAGE-CD = WS-LITERAL-REPLANTED
                 MOVE 21086 TO WS-8000-ERROR-CODE
                 MOVE WS-LITERAL-REPLANT-PAYMENT
                   TO WS-8000-FIELD-NAME1
              ELSE
                 MOVE 21066 TO WS-8000-ERROR-CODE
                 MOVE WS-LITERAL-INDEM TO WS-8000-FIELD-NAME1
              END-IF
              MOVE WS-2630-INPUT-INDEMNITY-X
                TO WS-8000-BAD-DATA1
              MOVE WS-2630-CALC-INDEMNITY-X
                TO WS-8000-CORR-DATA1
              MOVE 2630 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF.


       2630-VAL-INDEMNITY-EXIT.
           EXIT.


      ****************************************************************
      *    CALCULATE FARM UNIT DEFICIENCY / INDEMNITY                *
      ****************************************************************

       2630-CALC-INDEMNITY.

      $IF DEBUG-SW DEFINED
           DISPLAY '2615-CALCULATING FARM UNIT DEF/INDEMNITY'
           UPON CONSOLE
      $END

           EVALUATE WS-2630-INS-PLAN-CD

      *        ********************************************
      *        *    APH INDEMNITY                         *
      *        ********************************************
               WHEN WS-LITERAL-APH
               WHEN WS-LITERAL-APH-AREA-SPAN
               WHEN WS-LITERAL-APH-AREA-PLAN
      *           *** CHECK PRECONDITIONS ***
                  IF ERROR-INSURED-SHARE = WS-LITERAL-YES OR
                     ERROR-PRICE-ELECTION = WS-LITERAL-YES OR
                     ERROR-YLD-CONVER-FCTR = WS-LITERAL-YES
                     MOVE WS-LITERAL-YES
                       TO ERROR-FARM-UNIT-DEFICIENCY
                     MOVE WS-LITERAL-YES TO ERROR-INDEM
                     GO TO 2630-CALC-INDEMNITY-EXIT
                  END-IF
      *           *** PERFORM CALCULATION ***
                  INITIALIZE WS-4805-INPUT
                  MOVE WS-2630-STAGE-CD TO WS-4805-STAGE-CD
                  MOVE WS-2630-CROP-UNIT-OF-MEASURE
                    TO WS-4805-CROP-UNIT-OF-MEASURE
                  MOVE WS-2630-LOSS-GUARANTEE
                    TO WS-4805-LOSS-GUARANTEE
                  MOVE WS-2630-PROD-TO-COUNT
                    TO WS-4805-PROD-TO-COUNT
                  MOVE WS-2630-INPUT-FARM-UNIT-DEF
                    TO WS-4805-INPUT-FARM-UNIT-DEF
                  MOVE WS-2630-PRICE-ELECTION
                    TO WS-4805-PRICE-ELECTION
                  MOVE WS-2630-PERCENT-ELECTION
                    TO WS-4805-PERCENT-ELECTION
                  MOVE WS-2630-INSURED-SHARE
                    TO WS-4805-INSURED-SHARE
                  PERFORM 4805-CALC-APH-INDEM
                     THRU 4805-CALC-APH-INDEM-EXIT
      *           *** CHECK FOR FAILURE ***
                  IF CALC-ERROR-4805
                     MOVE WS-LITERAL-YES
                       TO ERROR-FARM-UNIT-DEFICIENCY
                     MOVE WS-LITERAL-YES TO ERROR-INDEM
                     GO TO 2630-CALC-INDEMNITY-EXIT
                  END-IF
      *           *** MOVE RESULTS ***
                  MOVE WS-4805-FARM-UNIT-DEF
                    TO WS-2630-CALC-FARM-UNIT-DEF
                  MOVE WS-4805-INDEMNITY TO WS-2630-CALC-INDEMNITY


      *        ********************************************
      *        *    CRC INDEMNITY                         *
      *        ********************************************
               WHEN WS-LITERAL-CRC
      *           *** CHECK PRECONDITIONS ***
                  IF ERROR-INSURED-SHARE = WS-LITERAL-YES OR
                     ERROR-PRICE-ELECTION = WS-LITERAL-YES
                     MOVE WS-LITERAL-YES
                       TO ERROR-FARM-UNIT-DEFICIENCY
                     MOVE WS-LITERAL-YES TO ERROR-INDEM
                     GO TO 2630-CALC-INDEMNITY-EXIT
                  END-IF
      *           *** PERFORM CALCULATION ***
                  INITIALIZE WS-4845-INPUT
                  MOVE WS-2630-STAGE-CD TO WS-4845-STAGE-CD
                  MOVE WS-2630-CROP-UNIT-OF-MEASURE
                    TO WS-4845-CROP-UNIT-OF-MEASURE
                  MOVE WS-2630-LOSS-GUARANTEE
                    TO WS-4845-LOSS-GUARANTEE
                  MOVE WS-2630-PROD-TO-COUNT
                    TO WS-4845-PROD-TO-COUNT
                  MOVE WS-2630-INPUT-FARM-UNIT-DEF
                    TO WS-4845-INPUT-FARM-UNIT-DEF
                  MOVE WS-2630-PRICE-ELECTION
                    TO WS-4845-PRICE-ELECTION
                  MOVE WS-2630-INSURED-SHARE
                    TO WS-4845-INSURED-SHARE
                  PERFORM 4845-CALC-CRC-INDEM
                     THRU 4845-CALC-CRC-INDEM-EXIT
      *           *** CHECK FOR FAILURE ***
                  IF CALC-ERROR-4845
                     MOVE WS-LITERAL-YES
                       TO ERROR-FARM-UNIT-DEFICIENCY
                     MOVE WS-LITERAL-YES TO ERROR-INDEM
                     GO TO 2630-CALC-INDEMNITY-EXIT
                  END-IF
      *           *** MOVE RESULTS ***
                  MOVE WS-4845-FARM-UNIT-DEF
                    TO WS-2630-CALC-FARM-UNIT-DEF
                  MOVE WS-4845-INDEMNITY TO WS-2630-CALC-INDEMNITY


      *        ********************************************
      *        *    DOLLAR AMOUNT OF INSURANCE INDEMNITY  *
      *        ********************************************
               WHEN WS-LITERAL-DOLLAR-AMT
      *           *** CHECK PRECONDITIONS ***
                  IF ERROR-INSURED-SHARE = WS-LITERAL-YES
                     MOVE WS-LITERAL-YES
                       TO ERROR-FARM-UNIT-DEFICIENCY
                     MOVE WS-LITERAL-YES TO ERROR-INDEM
                     GO TO 2630-CALC-INDEMNITY-EXIT
                  END-IF
      *           *** PERFORM CALCULATION ***
                  INITIALIZE WS-4815-INPUT
                  MOVE WS-2630-STAGE-CD TO WS-4815-STAGE-CD
                  MOVE WS-2630-CROP-UNIT-OF-MEASURE
                    TO WS-4815-CROP-UNIT-OF-MEASURE
                  MOVE WS-2630-LOSS-GUARANTEE
                    TO WS-4815-LOSS-GUARANTEE
                  MOVE WS-2630-PROD-TO-COUNT
                    TO WS-4815-PROD-TO-COUNT
                  MOVE WS-2630-INPUT-FARM-UNIT-DEF
                    TO WS-4815-INPUT-FARM-UNIT-DEF
                  MOVE WS-2630-INSURED-SHARE
                    TO WS-4815-INSURED-SHARE
                  PERFORM 4815-CALC-DOLLAR-INDEM
                     THRU 4815-CALC-DOLLAR-INDEM-EXIT
      *           *** CHECK FOR FAILURE ***
                  IF CALC-ERROR-4815
                     MOVE WS-LITERAL-YES
                       TO ERROR-FARM-UNIT-DEFICIENCY
                     MOVE WS-LITERAL-YES TO ERROR-INDEM
                     GO TO 2630-CALC-INDEMNITY-EXIT
                  END-IF
      *           *** MOVE RESULTS ***
                  MOVE WS-4815-FARM-UNIT-DEF
                    TO WS-2630-CALC-FARM-UNIT-DEF
                  MOVE WS-4815-INDEMNITY TO WS-2630-CALC-INDEMNITY


      *        ********************************************
      *        *    FLORIDA FRUIT TREES INDEMNITY         *
      *        ********************************************
               WHEN WS-LITERAL-FLORIDA-FRUIT
      *           *** CHECK PRECONDITIONS ***
                  IF ERROR-INSURED-SHARE = WS-LITERAL-YES
                     MOVE WS-LITERAL-YES
                       TO ERROR-FARM-UNIT-DEFICIENCY
                     MOVE WS-LITERAL-YES TO ERROR-INDEM
                     GO TO 2630-CALC-INDEMNITY-EXIT
                  END-IF
      *           *** PERFORM CALCULATION ***
                  INITIALIZE WS-4850-INPUT
                  MOVE WS-2630-STAGE-CD TO WS-4850-STAGE-CD
                  MOVE WS-2630-CROP-UNIT-OF-MEASURE
                    TO WS-4850-CROP-UNIT-OF-MEASURE
                  MOVE WS-2630-LOSS-GUARANTEE
                    TO WS-4850-LOSS-GUARANTEE
                  MOVE WS-2630-PROD-TO-COUNT
                    TO WS-4850-PROD-TO-COUNT
                  MOVE WS-2630-INPUT-FARM-UNIT-DEF
                    TO WS-4850-INPUT-FARM-UNIT-DEF
                  MOVE WS-2630-INSURED-SHARE
                    TO WS-4850-INSURED-SHARE
                  PERFORM 4850-CALC-FL-FRUIT-INDEM
                     THRU 4850-CALC-FL-FRUIT-INDEM-EXIT
      *           *** CHECK FOR FAILURE ***
                  IF CALC-ERROR-4850
                     MOVE WS-LITERAL-YES
                       TO ERROR-FARM-UNIT-DEFICIENCY
                     MOVE WS-LITERAL-YES TO ERROR-INDEM
                     GO TO 2630-CALC-INDEMNITY-EXIT
                  END-IF
      *           *** MOVE RESULTS ***
                  MOVE WS-4850-FARM-UNIT-DEF
                    TO WS-2630-CALC-FARM-UNIT-DEF
                  MOVE WS-4850-INDEMNITY TO WS-2630-CALC-INDEMNITY


      *        ********************************************
      *        *    GRP INDEMNITY                         *
      *        ********************************************
               WHEN WS-LITERAL-GRP
      *           *** CHECK PRECONDITIONS ***
                  IF ERROR-INSURED-SHARE = WS-LITERAL-YES
                     MOVE WS-LITERAL-YES
                       TO ERROR-FARM-UNIT-DEFICIENCY
                     MOVE WS-LITERAL-YES TO ERROR-INDEM
                     GO TO 2630-CALC-INDEMNITY-EXIT
                  END-IF
      *           *** PERFORM CALCULATION ***
                  INITIALIZE WS-4830-INPUT
                  MOVE WS-2630-STAGE-CD TO WS-4830-STAGE-CD
                  MOVE WS-2630-CROP-UNIT-OF-MEASURE
                    TO WS-4830-CROP-UNIT-OF-MEASURE
                  MOVE WS-2630-LOSS-GUARANTEE
                    TO WS-4830-LOSS-GUARANTEE
                  MOVE WS-2630-PROD-TO-COUNT
                    TO WS-4830-PROD-TO-COUNT
                  MOVE WS-2630-INPUT-FARM-UNIT-DEF
                    TO WS-4830-INPUT-FARM-UNIT-DEF
                  MOVE WS-2630-INSURED-SHARE
                    TO WS-4830-INSURED-SHARE
                  MOVE WS-2630-GRP-PAYMENT-FACTOR
                    TO WS-4830-GRP-PAYMENT-FACTOR
                  PERFORM 4830-CALC-GRP-INDEM
                     THRU 4830-CALC-GRP-INDEM-EXIT
      *           *** CHECK FOR FAILURE ***
                  IF CALC-ERROR-4830
                     MOVE WS-LITERAL-YES
                       TO ERROR-FARM-UNIT-DEFICIENCY
                     MOVE WS-LITERAL-YES TO ERROR-INDEM
                     GO TO 2630-CALC-INDEMNITY-EXIT
                  END-IF
      *           *** MOVE RESULTS ***
                  MOVE WS-4830-FARM-UNIT-DEF
                    TO WS-2630-CALC-FARM-UNIT-DEF
                  MOVE WS-4830-INDEMNITY TO WS-2630-CALC-INDEMNITY


      *        ********************************************
      *        *    GUARANTEE TOBACCO                     *
      *        ********************************************
               WHEN WS-LITERAL-GUARANTEE-TOBACCO
      *           *** CHECK PRECONDITIONS ***
                  IF ERROR-INSURED-SHARE = WS-LITERAL-YES OR
                     ERROR-PRICE-ELECTION = WS-LITERAL-YES
                     MOVE WS-LITERAL-YES
                       TO ERROR-FARM-UNIT-DEFICIENCY
                     MOVE WS-LITERAL-YES TO ERROR-INDEM
                     GO TO 2630-CALC-INDEMNITY-EXIT
                  END-IF
      *           *** PERFORM CALCULATION ***
                  INITIALIZE WS-4835-INPUT
                  MOVE WS-2630-STAGE-CD TO WS-4835-STAGE-CD
                  MOVE WS-2630-CROP-UNIT-OF-MEASURE
                    TO WS-4835-CROP-UNIT-OF-MEASURE
                  MOVE WS-2630-LOSS-GUARANTEE
                    TO WS-4835-LOSS-GUARANTEE
                  MOVE WS-2630-PROD-TO-COUNT
                    TO WS-4835-PROD-TO-COUNT
                  MOVE WS-2630-INPUT-FARM-UNIT-DEF
                    TO WS-4835-INPUT-FARM-UNIT-DEF
                  MOVE WS-2630-PRICE-ELECTION
                    TO WS-4835-PRICE-ELECTION
                  MOVE WS-2630-INSURED-SHARE
                    TO WS-4835-INSURED-SHARE
                  PERFORM 4835-CALC-GTOBACCO-INDEM
                     THRU 4835-CALC-GTOBACCO-INDEM-EXIT
      *           *** CHECK FOR FAILURE ***
                  IF CALC-ERROR-4835
                     MOVE WS-LITERAL-YES
                       TO ERROR-FARM-UNIT-DEFICIENCY
                     MOVE WS-LITERAL-YES TO ERROR-INDEM
                     GO TO 2630-CALC-INDEMNITY-EXIT
                  END-IF
      *           *** MOVE RESULTS ***
                  MOVE WS-4835-FARM-UNIT-DEF
                    TO WS-2630-CALC-FARM-UNIT-DEF
                  MOVE WS-4835-INDEMNITY TO WS-2630-CALC-INDEMNITY


      *        ********************************************
      *        *    INCOME PROTECTION                     *
      *        ********************************************
               WHEN WS-LITERAL-IP
      *           *** CHECK PRECONDITIONS ***
                  IF ERROR-INSURED-SHARE = WS-LITERAL-YES
                     MOVE WS-LITERAL-YES
                       TO ERROR-FARM-UNIT-DEFICIENCY
                     MOVE WS-LITERAL-YES TO ERROR-INDEM
                     GO TO 2630-CALC-INDEMNITY-EXIT
                  END-IF
      *           *** PERFORM CALCULATION ***
                  INITIALIZE WS-4860-INPUT
                  MOVE WS-2630-STAGE-CD TO WS-4860-STAGE-CD
                  MOVE WS-2630-CROP-UNIT-OF-MEASURE
                    TO WS-4860-CROP-UNIT-OF-MEASURE
                  MOVE WS-2630-LOSS-GUARANTEE
                    TO WS-4860-LOSS-GUARANTEE
                  MOVE WS-2630-PROD-TO-COUNT
                    TO WS-4860-PROD-TO-COUNT
                  MOVE WS-2630-INPUT-FARM-UNIT-DEF
                    TO WS-4860-INPUT-FARM-UNIT-DEF
                  MOVE WS-2630-INSURED-SHARE
                    TO WS-4860-INSURED-SHARE
                  PERFORM 4860-CALC-IP-INDEM
                     THRU 4860-CALC-IP-INDEM-EXIT
      *           *** CHECK FOR FAILURE ***
                  IF CALC-ERROR-4860
                     MOVE WS-LITERAL-YES
                       TO ERROR-FARM-UNIT-DEFICIENCY
                     MOVE WS-LITERAL-YES TO ERROR-INDEM
                     GO TO 2630-CALC-INDEMNITY-EXIT
                  END-IF
      *           *** MOVE RESULTS ***
                  MOVE WS-4860-FARM-UNIT-DEF
                    TO WS-2630-CALC-FARM-UNIT-DEF
                  MOVE WS-4860-INDEMNITY TO WS-2630-CALC-INDEMNITY


      *        ********************************************
      *        *    QUOTA PEANUTS                         *
      *        ********************************************
               WHEN WS-LITERAL-PEANUTS-PLAN
      *           *** CHECK PRECONDITIONS ***
                  IF ERROR-INSURED-SHARE = WS-LITERAL-YES OR
                     ERROR-PRICE-ELECTION = WS-LITERAL-YES
                     MOVE WS-LITERAL-YES
                       TO ERROR-FARM-UNIT-DEFICIENCY
                     MOVE WS-LITERAL-YES TO ERROR-INDEM
                     GO TO 2630-CALC-INDEMNITY-EXIT
                  END-IF
      *           *** PERFORM CALCULATION ***
                  INITIALIZE WS-4810-INPUT
                  MOVE WS-2630-STAGE-CD TO WS-4810-STAGE-CD
                  MOVE WS-2630-CROP-UNIT-OF-MEASURE
                    TO WS-4810-CROP-UNIT-OF-MEASURE
                  MOVE WS-2630-LOSS-GUARANTEE
                    TO WS-4810-LOSS-GUARANTEE
                  MOVE WS-2630-PROD-TO-COUNT
                    TO WS-4810-PROD-TO-COUNT
                  MOVE WS-2630-INPUT-FARM-UNIT-DEF
                    TO WS-4810-INPUT-FARM-UNIT-DEF
                  MOVE WS-2630-PRICE-ELECTION
                    TO WS-4810-PRICE-ELECTION
                  MOVE WS-2630-INSURED-SHARE
                    TO WS-4810-INSURED-SHARE
                  PERFORM 4810-CALC-QPEANUT-INDEM
                     THRU 4810-CALC-QPEANUT-INDEM-EXIT
      *           *** CHECK FOR FAILURE ***
                  IF CALC-ERROR-4810
                     MOVE WS-LITERAL-YES
                       TO ERROR-FARM-UNIT-DEFICIENCY
                     MOVE WS-LITERAL-YES TO ERROR-INDEM
                     GO TO 2630-CALC-INDEMNITY-EXIT
                  END-IF
      *           *** MOVE RESULTS ***
                  MOVE WS-4810-FARM-UNIT-DEF
                    TO WS-2630-CALC-FARM-UNIT-DEF
                  MOVE WS-4810-INDEMNITY TO WS-2630-CALC-INDEMNITY


      *        ********************************************
      *        *    QUOTA TOBACCO                         *
      *        ********************************************
               WHEN WS-LITERAL-QUOTA-TOBACCO
      *           *** CHECK PRECONDITIONS ***
                  IF ERROR-INSURED-SHARE = WS-LITERAL-YES
                     MOVE WS-LITERAL-YES
                       TO ERROR-FARM-UNIT-DEFICIENCY
                     MOVE WS-LITERAL-YES TO ERROR-INDEM
                     GO TO 2630-CALC-INDEMNITY-EXIT
                  END-IF
      *           *** PERFORM CALCULATION ***
                  INITIALIZE WS-4840-INPUT
                  MOVE WS-2630-STAGE-CD TO WS-4840-STAGE-CD
                  MOVE WS-2630-CROP-UNIT-OF-MEASURE
                    TO WS-4840-CROP-UNIT-OF-MEASURE
                  MOVE WS-2630-LOSS-GUARANTEE
                    TO WS-4840-LOSS-GUARANTEE
                  MOVE WS-2630-PROD-TO-COUNT
                    TO WS-4840-PROD-TO-COUNT
                  MOVE WS-2630-INPUT-FARM-UNIT-DEF
                    TO WS-4840-INPUT-FARM-UNIT-DEF
                  MOVE WS-2630-INSURED-SHARE
                    TO WS-4840-INSURED-SHARE
                  PERFORM 4840-CALC-QTOBACCO-INDEM
                     THRU 4840-CALC-QTOBACCO-INDEM-EXIT
      *           *** CHECK FOR FAILURE ***
                  IF CALC-ERROR-4840
                     MOVE WS-LITERAL-YES
                       TO ERROR-FARM-UNIT-DEFICIENCY
                     MOVE WS-LITERAL-YES TO ERROR-INDEM
                     GO TO 2630-CALC-INDEMNITY-EXIT
                  END-IF
      *           *** MOVE RESULTS ***
                  MOVE WS-4840-FARM-UNIT-DEF
                    TO WS-2630-CALC-FARM-UNIT-DEF
                  MOVE WS-4840-INDEMNITY TO WS-2630-CALC-INDEMNITY


      *        ********************************************
      *        *    YIELD-BASED DOLLAR CROPS              *
      *        ********************************************
               WHEN WS-LITERAL-YLD-BASED-DOL-AMT
      *           *** CHECK PRECONDITIONS ***
                  IF ERROR-INSURED-SHARE = WS-LITERAL-YES
                     MOVE WS-LITERAL-YES
                       TO ERROR-FARM-UNIT-DEFICIENCY
                     MOVE WS-LITERAL-YES TO ERROR-INDEM
                     GO TO 2630-CALC-INDEMNITY-EXIT
                  END-IF
      *           *** PERFORM CALCULATION ***
                  INITIALIZE WS-4825-INPUT
                  MOVE WS-2630-STAGE-CD TO WS-4825-STAGE-CD
                  MOVE WS-2630-CROP-UNIT-OF-MEASURE
                    TO WS-4825-CROP-UNIT-OF-MEASURE
                  MOVE WS-2630-LOSS-GUARANTEE
                    TO WS-4825-LOSS-GUARANTEE
                  MOVE WS-2630-PROD-TO-COUNT
                    TO WS-4825-PROD-TO-COUNT
                  MOVE WS-2630-INPUT-FARM-UNIT-DEF
                    TO WS-4825-INPUT-FARM-UNIT-DEF
                  MOVE WS-2630-INSURED-SHARE
                    TO WS-4825-INSURED-SHARE
                  PERFORM 4825-CALC-YLDDLR-INDEM
                     THRU 4825-CALC-YLDDLR-INDEM-EXIT
      *           *** CHECK FOR FAILURE ***
                  IF CALC-ERROR-4825
                     MOVE WS-LITERAL-YES
                       TO ERROR-FARM-UNIT-DEFICIENCY
                     MOVE WS-LITERAL-YES TO ERROR-INDEM
                     GO TO 2630-CALC-INDEMNITY-EXIT
                  END-IF
      *           *** MOVE RESULTS ***
                  MOVE WS-4825-FARM-UNIT-DEF
                    TO WS-2630-CALC-FARM-UNIT-DEF
                  MOVE WS-4825-INDEMNITY TO WS-2630-CALC-INDEMNITY


      *        ********************************************
      *        *    REVENUE ASSURANCE                     *
      *        ********************************************
               WHEN WS-LITERAL-RA
      *           *** CHECK PRECONDITIONS ***
                  IF ERROR-INSURED-SHARE = WS-LITERAL-YES OR
                     ERROR-PRICE-ELECTION = WS-LITERAL-YES
                     MOVE WS-LITERAL-YES
                       TO ERROR-FARM-UNIT-DEFICIENCY
                     MOVE WS-LITERAL-YES TO ERROR-INDEM
                     GO TO 2630-CALC-INDEMNITY-EXIT
                  END-IF
      *           *** PERFORM CALCULATION ***
                  INITIALIZE WS-4855-INPUT
                  MOVE WS-2630-STAGE-CD TO WS-4855-STAGE-CD
                  MOVE WS-2630-CROP-UNIT-OF-MEASURE
                    TO WS-4855-CROP-UNIT-OF-MEASURE
                  MOVE WS-2630-LOSS-GUARANTEE
                    TO WS-4855-LOSS-GUARANTEE
                  MOVE WS-2630-PROD-TO-COUNT
                    TO WS-4855-PROD-TO-COUNT
                  MOVE WS-2630-INPUT-FARM-UNIT-DEF
                    TO WS-4855-INPUT-FARM-UNIT-DEF
                  MOVE WS-2630-PRICE-ELECTION
                    TO WS-4855-PRICE-ELECTION
                  MOVE WS-2630-INSURED-SHARE
                    TO WS-4855-INSURED-SHARE
                  PERFORM 4855-CALC-RA-INDEM
                     THRU 4855-CALC-RA-INDEM-EXIT
      *           *** CHECK FOR FAILURE ***
                  IF CALC-ERROR-4855
                     MOVE WS-LITERAL-YES
                       TO ERROR-FARM-UNIT-DEFICIENCY
                     MOVE WS-LITERAL-YES TO ERROR-INDEM
                     GO TO 2630-CALC-INDEMNITY-EXIT
                  END-IF
      *           *** MOVE RESULTS ***
                  MOVE WS-4855-FARM-UNIT-DEF
                    TO WS-2630-CALC-FARM-UNIT-DEF
                  MOVE WS-4855-INDEMNITY TO WS-2630-CALC-INDEMNITY


               WHEN OTHER
                  MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
                  MOVE 042 TO WS-8000-SHORT-ERROR
                  MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                  MOVE WS-LITERAL-YES TO ERROR-LOSS-GUAR
                  MOVE WS-LITERAL-YES TO ERROR-STAGE-GUARANTEE
                  MOVE WS-LITERAL-YES TO ERROR-INSUR-PLAN-CD
                  MOVE WS-LITERAL-INSURE-PLAN-CD
                    TO WS-8000-FIELD-NAME1
                  MOVE WS-2630-INS-PLAN-CD TO WS-8000-BAD-DATA1
                  MOVE 2630 TO WS-8000-PARAGRAPH-NO
                  PERFORM 8000-RECORD-TRAN-ERROR
                     THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-EVALUATE.


       2630-CALC-INDEMNITY-EXIT.
           EXIT.



