      ******************************************************************
      * FILE:     IR3300.CBL                                           *
      * AUTHOR:   LAURA DITTAMO                                        *
      * DATE:     8/28/95                                              *
      * PURPOSE:  THIS ROUTINE PERFORMS INTER-RECORD VALIDATION ON     *
      *           TYPE 10 RECORDS.                                     *
      *                                                                *
      *           EACH TYPE 10, RECORD NUMBER 1,                       *
      *           THAT HAS AN ENTITY TYPE = CORPORATION (C), UNDIVIDED *
      *           INTEREST (U), TOBACCO MARKETING CARD (T), REVOCABLE  *
      *           TRUST (R), PARTNERSHIP (P), JOINT OPERATORS (J), OR  *
      *           INDIVIDUAL (I) -AND- AN ID TYPE OF EIN (2) OR EIN    *
      *           APPLIED FOR (4) MUST HAVE AT LEAST ONE SBI RECORD    *
      *           WITH AN SSN.                                         *
      *                                                                *
      * rgh - modified 11/25/96 per Bob McGraw:                        *
      *    only type 10 individuals w/ein require sbi with ssn         *
      ******************************************************************

       3300-CHECK-SBIS.

      $IF DEBUG-SW DEFINED
           DISPLAY '3300-CHECK SBIS FOR TYPE 10 RECORD 001'
           UPON CONSOLE
      $END

      ****************************
      *    INITIALIZE WORK FIELDS
      ****************************

           INITIALIZE WS-3300-SWITCHES

      ****************************
      *    NORMAL PROCESSING
      ****************************
           IF WS-0005-REJECT-POLICY-FLAG = WS-LITERAL-YES
      ******* ERRORS WERE ENCOUNTERED WITH THIS TYPE 10.
      ******* CHECK THE SPECIFIC NUMERIC FIELDS WHICH ARE USED IN
      ******* THIS EDIT.
              IF WS-0005-ID-TYPE IS NOT NUMERIC
                 GO TO 3300-CHECK-SBIS-EXIT
              END-IF
           END-IF


           IF WS-0005-ENTITY-TYPE = WS-LITERAL-individual
              IF (WS-0005-ID-TYPE = WS-LITERAL-ein or
                 ws-0005-id-type = ws-literal-ein-applied-for)
                   continue
                 else
                   GO TO 3300-CHECK-SBIS-EXIT
              END-IF

              MOVE WS-LITERAL-NO TO WS-3300-SBI-W-SSN-FOUND-SW

              IF WS-0010-SBI-REC-COUNT > 0
                 PERFORM 3300-FIND-SBI-W-SSN
                    THRU 3300-FIND-SBI-W-SSN-EXIT
                    WITH TEST AFTER
                 VARYING WS-0010-SBI-INT-INDEX FROM 1 BY 1
                   UNTIL WS-0010-SBI-INT-INDEX = WS-0010-SBI-REC-COUNT
                      OR WS-3300-SBI-W-SSN-FOUND-SW = WS-LITERAL-YES
              END-IF

              IF WS-3300-SBI-W-SSN-FOUND-SW = WS-LITERAL-NO
                 MOVE WS-LITERAL-YES TO WS-0005-REJECT-POLICY-FLAG
                 MOVE WS-LITERAL-YES TO WS-0005-ERROR-RECORDED
                 MOVE WS-LITERAL-IR TO WS-8000-ERROR-TYPE
                 MOVE 10060 TO WS-8000-ERROR-CODE
                 MOVE 3300 TO WS-8000-PARAGRAPH-NO
                 MOVE 'NO SBI WITH SSN' TO WS-8000-BAD-DATA1
                 MOVE WS-0005-TRAN-SEQ-NO TO WS-8000-TRAN-SEQ-NO
                 MOVE WS-0005-CURRENT-POLICY-NO TO WS-8000-POLICY-NO
                 MOVE WS-0005-RECORD-NUM TO WS-8000-RECORD-NUM
                 PERFORM 8000-RECORD-TRAN-ERROR
                    THRU 8000-RECORD-TRAN-ERROR-EXIT
              END-IF
           END-IF.


       3300-CHECK-SBIS-EXIT.
           EXIT.


       3300-FIND-SBI-W-SSN.

           SET WS-0010-SBI-INDEX TO WS-0010-SBI-INT-INDEX

           IF WS-0010-TBL-ID-TYPE(WS-0010-SBI-INDEX) NUMERIC
              IF WS-0010-TBL-ID-TYPE(WS-0010-SBI-INDEX)
                 = WS-LITERAL-SSN
                 MOVE WS-LITERAL-YES TO WS-3300-SBI-W-SSN-FOUND-SW
              END-IF
           END-IF.


       3300-FIND-SBI-W-SSN-EXIT.
           EXIT.




