      ****************************************************************
      *  File   : IR3335.CBL
      *  Author : MIKE RAY
      *  Date   : 03/13/97
      *  Purpose: Validates the Revenue Assurance Whole Farm Discount
      *           Factor based upon the ratio of Corn Acres to Total
      *           Acres for the Whole Farm.
      ****************************************************************

       3335-VAL-RA-WFARM-DISCNT.

      $IF DEBUG-SW DEFINED
           DISPLAY '3335-VALIDATING RA WHOLE FARM DISCOUNT FACTOR'
           UPON CONSOLE
      $END

      *    ***************************************************
      *    *  INITIALIZE LOCAL WORKING STORAGE               *
      *    ***************************************************
           INITIALIZE WS-3335-LOCAL

      *    ***************************************************
      *    *  SET UP DISPLAY FIELDS                          *
      *    ***************************************************
           MOVE WS-0011-RA-CORN-ACRES
             TO WS-3335-CORN-ACRES-X
           MOVE WS-0011-RA-SOY-ACRES
             TO WS-3335-SOY-ACRES-X

      *    ***************************************************
      *    *  ONLY PERFORM EDIT IF THE UNIT ORGANIZATION IS  *
      *    *  WHOLE FARM.  IF CORN & SOYBEANS DO NOT HAVE    *
      *    *  THE SAME UNIT ORGANIZATION AND ONE IS WHOLE    *
      *    *  FARM, IR3365 WILL REJECT ALL OF THE RECORDS.   *
      *    ***************************************************
           IF WS-0011-RA-CORN-UNIT-ORG
              <> WS-LITERAL-WHOLE-FARM-UNIT OR
              WS-0011-RA-SOY-UNIT-ORG
              <> WS-LITERAL-WHOLE-FARM-UNIT
              GO TO 3335-VAL-RA-WFARM-DISCNT-EXIT
           END-IF

      *    ***************************************************
      *    *  COMPUTE TOTAL ACRES                            *
      *    ***************************************************
           COMPUTE WS-3335-TOTAL-ACRES ROUNDED =
              WS-0011-RA-CORN-ACRES +
              WS-0011-RA-SOY-ACRES
              ON SIZE ERROR
                 MOVE 3335 TO WS-8020-PARAGRAPH-NO
                 MOVE 90017 TO WS-8020-INT-ERROR-NO
                 MOVE 'TOTAL ACRES'
                   TO WS-8020-FIELD-NAME
                 MOVE ZEROS
                   TO WS-8020-BAD-DATA
                 MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                 PERFORM 8020-RECORD-INT-ERROR
                    THRU 8020-RECORD-INT-ERROR-EXIT
           END-COMPUTE
           MOVE WS-3335-TOTAL-ACRES TO WS-3335-TOTAL-ACRES-X

      *    ***************************************************
      *    *  COMPUTE CORN PERCENTAGE                        *
      *    ***************************************************
           COMPUTE WS-3335-CORN-PCT ROUNDED =
              WS-0011-RA-CORN-ACRES /
              WS-3335-TOTAL-ACRES
              ON SIZE ERROR
                 MOVE 3335 TO WS-8020-PARAGRAPH-NO
                 MOVE 90017 TO WS-8020-INT-ERROR-NO
                 MOVE 'RA CORN %'
                   TO WS-8020-FIELD-NAME
                 MOVE ZEROS
                   TO WS-8020-BAD-DATA
                 MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                 PERFORM 8020-RECORD-INT-ERROR
                    THRU 8020-RECORD-INT-ERROR-EXIT
           END-COMPUTE
           MOVE WS-3335-CORN-PCT TO WS-3335-CORN-PCT-X

      $IF DEBUG-SW DEFINED
           DISPLAY 'SOYBEAN ACRES = ', WS-3335-SOY-ACRES-X
           UPON CONSOLE
           DISPLAY 'CORN ACRES    = ', WS-3335-CORN-ACRES-X
           UPON CONSOLE
           DISPLAY 'TOTAL ACRES   = ', WS-3335-TOTAL-ACRES-X
           UPON CONSOLE
           DISPLAY 'CORN %        = ', WS-3335-CORN-PCT-X
           UPON CONSOLE
      $END

      *    ***************************************************
      *    *  DETERMINE WHOLE FARM DISCOUNT FACTOR           *
      *    ***************************************************
           EVALUATE WS-3335-CORN-PCT
               WHEN 0.0
                  MOVE 1.000 TO WS-3335-VALID-WFARM-DISCOUNT
               WHEN 0.1
                  MOVE 0.920 TO WS-3335-VALID-WFARM-DISCOUNT
               WHEN 0.2
                  MOVE 0.860 TO WS-3335-VALID-WFARM-DISCOUNT
               WHEN 0.3
                  MOVE 0.820 TO WS-3335-VALID-WFARM-DISCOUNT
               WHEN 0.4
                  MOVE 0.800 TO WS-3335-VALID-WFARM-DISCOUNT
               WHEN 0.5
                  MOVE 0.800 TO WS-3335-VALID-WFARM-DISCOUNT
               WHEN 0.6
                  MOVE 0.820 TO WS-3335-VALID-WFARM-DISCOUNT
               WHEN 0.7
                  MOVE 0.850 TO WS-3335-VALID-WFARM-DISCOUNT
               WHEN 0.8
                  MOVE 0.890 TO WS-3335-VALID-WFARM-DISCOUNT
               WHEN 0.9
                  MOVE 0.940 TO WS-3335-VALID-WFARM-DISCOUNT
               WHEN 1.0
                  MOVE 1.000 TO WS-3335-VALID-WFARM-DISCOUNT
           END-EVALUATE
           MOVE WS-3335-VALID-WFARM-DISCOUNT
             TO WS-3335-VALID-WFARM-DISCOUNT-X

      $IF DEBUG-SW DEFINED
           DISPLAY 'CORRECT WHOLE FARM DISCOUNT FACTOR = ',
           WS-3335-VALID-WFARM-DISCOUNT-X
           UPON CONSOLE
      $END

      *    ***************************************************
      *    *  CHECK T11 RECORDS FOR CORRECT DISCOUNT         *
      *    ***************************************************

           PERFORM 3335-CHECK-DISCOUNT
              THRU 3335-CHECK-DISCOUNT-EXIT
              WITH TEST AFTER
           VARYING WS-0011-T11-INT-INDEX FROM 1 BY 1
             UNTIL WS-0011-T11-INT-INDEX = WS-0011-T11-REC-COUNT.


       3335-VAL-RA-WFARM-DISCNT-EXIT.
           EXIT.


       3335-CHECK-DISCOUNT.

           SET WS-0011-T11-INDEX TO WS-0011-T11-INT-INDEX

           IF WS-0011-TBL-WFARM-DISC-FCTR(WS-0011-T11-INDEX) <>
              WS-3335-VALID-WFARM-DISCOUNT
              MOVE WS-LITERAL-YES
                TO WS-0011-TBL-TRAN-REJECTED-FLAG(WS-0011-T11-INDEX)
              MOVE WS-LITERAL-IR TO WS-8000-ERROR-TYPE
              MOVE 11100 TO WS-8000-ERROR-CODE
              MOVE WS-0011-TBL-TRAN-SEQ-NO(WS-0011-T11-INDEX)
                TO WS-8000-TRAN-SEQ-NO
              MOVE WS-LITERAL-WHOLE-FARM-DISC TO WS-8000-FIELD-NAME1
              MOVE WS-0011-TBL-WFARM-DISC-FCTR(WS-0011-T11-INDEX)
                TO WS-3335-BAD-WFARM-DISCOUNT-X
              MOVE WS-3335-BAD-WFARM-DISCOUNT-X
                TO WS-8000-BAD-DATA1
              MOVE WS-3335-VALID-WFARM-DISCOUNT-X
                TO WS-8000-CORR-DATA1
              MOVE 11 TO WS-8000-TRAN-TYPE
              MOVE WS-0011-TBL-POLICY-NO(WS-0011-T11-INDEX)
                TO WS-8000-POLICY-NO
              MOVE 3335 TO WS-8000-PARAGRAPH-NO
              MOVE WS-0011-TBL-LOCATION-COUNTY(WS-0011-T11-INDEX)
                TO WS-8000-LOC-COUNTY
              MOVE WS-0011-TBL-INSURANCE-PLAN-CD(WS-0011-T11-INDEX)
                TO WS-8000-INSURANCE-PLAN-ID
              MOVE WS-0011-TBL-CROP-CD(WS-0011-T11-INDEX)
                TO WS-8000-CROP-CD
              MOVE WS-0011-TBL-RECORD-NUM(WS-0011-T11-INDEX)
                TO WS-8000-RECORD-NUM
              MOVE WS-LITERAL-YES TO WS-0006-REJECT-11S-FLAG
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF.


       3335-CHECK-DISCOUNT-EXIT.
           EXIT.





