      ***************************************************************
      * File:      IR3340.CBL
      * Author:    Laura Dittamo
      * Date:      8/23/95
      * Purpose:
      *    This validation routine ensures that assigned risk is
      *    the same for all type 14 transactions which are either high
      *    risk land insured under CAT coverage (High Risk = 1 and
      *    Coverage Flag = 'C') or have the same crop-crop/policy
      *    type combination.
      ***************************************************************

       3340-SAME-ASGD-RISK.

      $IF DEBUG-SW DEFINED
           DISPLAY '3340-VALIDATING SAME ASSIGNED RISK'
           UPON CONSOLE
      $END

      *****************************************************
      *    INITIALIZE LOCAL AND OUTPUT VARIABLES          *
      *****************************************************
           INITIALIZE WS-3340-WORK

      *****************************************************
      *    CHECK PRE-CONDITIONS                           *
      *****************************************************

      $IF DEBUG-SW DEFINED
           DISPLAY 'TYPE 14 RECORD COUNT = ',
           WS-0014-T14-REC-COUNT
           UPON CONSOLE
      $END
      $IF DEBUG-SW DEFINED
           DISPLAY 'T14(01)= ', WS-0014-TBL-TYPE-14(1)
           UPON CONSOLE
           DISPLAY 'T14(01)REJ = ', WS-0014-TBL-TRAN-REJECTED-FLAG(1)
           UPON CONSOLE
           DISPLAY 'T14(02)= ', WS-0014-TBL-TYPE-14(2)
           UPON CONSOLE
           DISPLAY 'T14(02)REJ = ', WS-0014-TBL-TRAN-REJECTED-FLAG(2)
           UPON CONSOLE
           DISPLAY 'T14(03)= ', WS-0014-TBL-TYPE-14(3)
           UPON CONSOLE
           DISPLAY 'T14(03)REJ = ', WS-0014-TBL-TRAN-REJECTED-FLAG(3)
           UPON CONSOLE
           DISPLAY 'T14(04)= ', WS-0014-TBL-TYPE-14(4)
           UPON CONSOLE
           DISPLAY 'T14(04)REJ = ', WS-0014-TBL-TRAN-REJECTED-FLAG(4)
           UPON CONSOLE
           DISPLAY 'T14(05)= ', WS-0014-TBL-TYPE-14(5)
           UPON CONSOLE
           DISPLAY 'T14(05)REJ = ', WS-0014-TBL-TRAN-REJECTED-FLAG(5)
           UPON CONSOLE
      $END

           IF WS-0014-T14-REC-COUNT = ZEROS
              GO TO 3340-SAME-ASGD-RISK-EXIT
           END-IF

           PERFORM 3340-CHECK-ASSIGNED-RISK
              THRU 3340-CHECK-ASSIGNED-RISK-EXIT
              WITH TEST AFTER
           VARYING WS-0014-T14-INT-INDEX
              FROM 1 BY 1
             UNTIL WS-0014-T14-INT-INDEX = WS-0014-T14-REC-COUNT.

       3340-SAME-ASGD-RISK-EXIT.
           EXIT.


       3340-CHECK-ASSIGNED-RISK.
           SET WS-0014-T14-INDEX TO WS-0014-T14-INT-INDEX

      **   POPULATE THE COMPARISION VALUES: CROP POLICY TYPE, DUAL
      **   DUAL COVERAGE FLAG, AND ASSIGNED RISK.  NO COMPARISON VALUE
      **   IS NEEDED FOR CROP CODE.  THE TYPE 14 TRANSACTION TABLE ONLY
      **   HOLDS ONE CROP AT A TIME.

           MOVE WS-0014-TBL-CROP-POLICY-TY(WS-0014-T14-INDEX)
             TO WS-3340-COMPARE-CROP-POLICY-TY
           MOVE WS-0014-TBL-DUAL-COVERAGE-FLG(WS-0014-T14-INDEX)
             TO WS-3340-COMPARE-DUAL-CVG-FLAG
           MOVE WS-0014-TBL-ASSIGNED-RISK(WS-0014-T14-INDEX)
             TO WS-3340-COMPARE-ASSIGNED-RISK

      **   SAVE THE CURRENT VALUE OF THE INDEX.
           MOVE WS-0014-T14-INT-INDEX TO WS-3340-1ST-MAIN-LOOP-INDEX

      **   LOOP THRU THE TYPE 14 TABLE.  SKIP ALL REJECTED RECORDS.
      **   FOR EACH ROW COMPARE THE TABLE VALUES FOR CROP POLICY TYPE
      **   AND DUAL COVERAGE WITH THE STORED COMPARISON VALUES.
      **   WHEN THESE MATCH, COMPARE THE TABLE VALUE FOR ASSIGNED RISK
      **   WITH THE STORED ASSIGNED RISK.  IF THE ASSIGNED RISK DOES
      **   NOT MATCH, REJECT THAT ROW.

           PERFORM 3340-COMP-ASSIGNED-RISK
              THRU 3340-COMP-ASSIGNED-RISK-EXIT
              WITH TEST AFTER
           VARYING WS-0014-T14-INT-INDEX
              FROM 1 BY 1
             UNTIL WS-0014-T14-INT-INDEX = WS-0014-T14-REC-COUNT

      **  RESTORE THE MAIN LOOP INDEX VALUE
          MOVE WS-3340-1ST-MAIN-LOOP-INDEX TO WS-0014-T14-INT-INDEX
          SET WS-0014-T14-INDEX TO WS-0014-T14-INT-INDEX.

       3340-CHECK-ASSIGNED-RISK-EXIT.
           EXIT.


       3340-COMP-ASSIGNED-RISK.
           SET WS-0014-T14-INDEX TO WS-0014-T14-INT-INDEX

      **  SKIP ANY PRE-REJECTED TYPE 14 TRANSACTIONS
      **  THIS PREVENTS MULTIPLE ASSIGNED RISK ERRORS (ERROR CODES
      **  1458 OR 1459) BEING REDUNDANTLY ATTRIBUTED TO A SINGLE ROW.
           IF WS-0014-TBL-TRAN-REJECTED-FLAG(WS-0014-T14-INDEX) =
              WS-LITERAL-YES
              GO TO 3340-COMP-ASSIGNED-RISK-EXIT
           END-IF

           IF WS-0014-TBL-CROP-POLICY-TY(WS-0014-T14-INDEX) =
              WS-3340-COMPARE-CROP-POLICY-TY AND
              WS-0014-TBL-DUAL-COVERAGE-FLG(WS-0014-T14-INDEX) =
              WS-3340-COMPARE-DUAL-CVG-FLAG
      **  WHEN THE CURRENT ROW HAS A MATCHING CROP POLICY TYPE AND
      **  DUAL COVERAGE FLAG SETTING, COMPARE ASSIGNED RISK.  IF
      **  THE ASSIGNED RISK DOES NOT MATCH RECORD AN ERROR FOR THAT
      **  ROW
              IF WS-0014-TBL-ASSIGNED-RISK(WS-0014-T14-INDEX) <>
                 WS-3340-COMPARE-ASSIGNED-RISK
                 MOVE WS-LITERAL-YES
                   TO WS-0014-TBL-TRAN-REJECTED-FLAG(WS-0014-T14-INDEX)
      **  IF THE DUAL COVERAGE FLAG = 1 THE RECORD IS CAT - ALL DUAL
      **  COVERAGE 1 CAT RECORDS MUST HAVE THE SAME ASSIGNED RISK - 1458.
      **  OTHERWISE, THE RECORD IS BUYUP, ALL TYPE 14 RECORDS FOR THE
      **  CROP/CROP POLICY TYPE MUST HAVE THE SAME ASSIGNED RISK - 1459.
                IF WS-0014-TBL-DUAL-COVERAGE-FLG(WS-0014-T14-INDEX) = 1
                   MOVE 14058 TO WS-8000-ERROR-CODE
                ELSE
                   MOVE 14059 TO WS-8000-ERROR-CODE
                END-IF
                MOVE WS-LITERAL-IR TO WS-8000-ERROR-TYPE
                MOVE WS-LITERAL-YES TO ERROR-ASSIGNED-RISK
                MOVE WS-LITERAL-ASSIGNED-RISK TO WS-8000-FIELD-NAME1
                MOVE WS-0014-TBL-ASSIGNED-RISK(WS-0014-T14-INDEX)
                  TO WS-8000-BAD-DATA1
                MOVE WS-3340-COMPARE-ASSIGNED-RISK
                  TO WS-8000-CORR-DATA1
                MOVE WS-0014-TBL-TRAN-SEQ-NO(WS-0014-T14-INDEX)
                  TO WS-8000-TRAN-SEQ-NO
                MOVE 3340 TO WS-8000-PARAGRAPH-NO
                MOVE 14 TO WS-8000-TRAN-TYPE
                MOVE WS-0014-TBL-POLICY-NO(WS-0014-T14-INDEX)
                  TO WS-8000-POLICY-NO
                MOVE WS-0014-TBL-LOCATION-COUNTY(WS-0014-T14-INDEX)
                  TO WS-8000-LOC-COUNTY
                MOVE WS-0014-TBL-INSURANCE-PLAN-CD(WS-0014-T14-INDEX)
                  TO WS-8000-INSURANCE-PLAN-ID
                MOVE WS-0014-TBL-CROP-CD(WS-0014-T14-INDEX)
                  TO WS-8000-CROP-CD
                MOVE WS-0014-TBL-RECORD-NUM(WS-0014-T14-INDEX)
                  TO WS-8000-RECORD-NUM
                MOVE WS-LITERAL-YES TO WS-0006-REJECT-14S-FLAG
                PERFORM 8000-RECORD-TRAN-ERROR
                   THRU 8000-RECORD-TRAN-ERROR-EXIT
             END-IF
           END-IF.

       3340-COMP-ASSIGNED-RISK-EXIT.
           EXIT.

