      ***************************************************************
      * File:      IR3345.CBL
      * Author:    Laura Dittamo
      * Date:      3/27/96
      * Purpose:
      *    This routine ensures that assigned risk is
      *    the same for all type 14 transactions which are either high
      *    risk land insured under CAT coverage (High Risk = 1 and
      *    Coverage Flag = 'C') or have the same crop-crop/policy
      *    type combination.
      *    This edit uses the Assigned Risk table built in 2255-
      *    Determine-Trans-Late.  This table contains all 14
      *    transactions which may update the Assigned Risk setting.
      *
      ***************************************************************

       3345-SAME-ASGD-RISK.

      $IF DEBUG-SW DEFINED
           DISPLAY '3345-VALIDATING SAME ASSIGNED RISK'
           UPON CONSOLE
      $END

      *****************************************************
      *    INITIALIZE LOCAL AND OUTPUT VARIABLES          *
      *****************************************************
           INITIALIZE WS-3345-WORK

      *****************************************************
      *    CHECK PRE-CONDITIONS                           *
      *****************************************************

      *   2255-DETERMINE-TRANS-LATE POPULATED THE ASSIGNED
      *   RISK TABLE WITH TYPE 14 TRANSACTIONS THAT MAY
      *   ESTABLISH/UPDATE ASSIGNED RISK FOR A POLICY.

      $IF DEBUG-SW DEFINED
           DISPLAY 'WS-7014-ASGD-RISK-REC-COUNT',
           WS-7014-ASGD-RISK-REC-COUNT
           UPON CONSOLE
      $END
      $IF DEBUG-SW DEFINED
           DISPLAY 'ASGD RISK(01)= ', WS-7014-ASGD-RISK-REC(1)
           UPON CONSOLE
           DISPLAY 'ASGD RISK(02)= ', WS-7014-ASGD-RISK-REC(2)
           UPON CONSOLE
           DISPLAY 'ASGD RISK(03)= ', WS-7014-ASGD-RISK-REC(3)
           UPON CONSOLE
           DISPLAY 'ASGD RISK(04)= ', WS-7014-ASGD-RISK-REC(4)
           UPON CONSOLE
           DISPLAY 'ASGD RISK(05)= ', WS-7014-ASGD-RISK-REC(5)
           UPON CONSOLE.
      $END

           IF WS-7014-ASGD-RISK-REC-COUNT <= 1
              GO TO 3345-SAME-ASGD-RISK-EXIT
           END-IF

      **   REJECT ANY TYPE 14 TRANSACTIONS THAT DO NOT HAVE THE SAME
      **   ASSIGNED SETTING FOR DUAL COVERAGE 1 CAT RECORDS OR
      **   CROP/CROP-POLICY TYPE.
           PERFORM 3345-CHECK-ASSIGNED-RISK
              THRU 3345-CHECK-ASSIGNED-RISK-EXIT
              WITH TEST AFTER
           VARYING WS-7014-ASGD-RISK-INT-INDEX
              FROM 1 BY 1
             UNTIL WS-7014-ASGD-RISK-INT-INDEX =
                   WS-7014-ASGD-RISK-REC-COUNT.



       3345-SAME-ASGD-RISK-EXIT.
           EXIT.


       3345-CHECK-ASSIGNED-RISK.
           SET WS-7014-ASGD-RISK-INDEX TO WS-7014-ASGD-RISK-INT-INDEX

      **   POPULATE THE COMPARISION VALUES: CROP POLICY TYPE, DUAL
      **   DUAL COVERAGE FLAG, AND ASSIGNED RISK.  NO COMPARISON VALUE
      **   IS NEEDED FOR CROP CODE.  THE TYPE 14 ASSIGNED RISK TABLE
      **   ONLY HOLDS ONE CROP AT A TIME.

           MOVE WS-7014-CROP-POLICY-TYPE(WS-7014-ASGD-RISK-INDEX)
             TO WS-3345-COMPARE-CROP-POLICY-TY
           MOVE WS-7014-DUAL-COVERAGE-FLAG(WS-7014-ASGD-RISK-INDEX)
             TO WS-3345-COMPARE-DUAL-CVG-FLAG
           MOVE WS-7014-ASSIGNED-RISK(WS-7014-ASGD-RISK-INDEX)
             TO WS-3345-COMPARE-ASSIGNED-RISK
           MOVE WS-7014-LOC-COUNTY(WS-7014-ASGD-RISK-INDEX)
             TO WS-3345-COMPARE-LOC-COUNTY

      **   SAVE THE CURRENT VALUE OF THE INDEX.
           MOVE WS-7014-ASGD-RISK-INT-INDEX
             TO WS-3345-MAIN-LOOP-INT-INDEX

      **   LOOP THRU THE TYPE 14 ASSIGNED RISK TABLE.  SKIP ALL
      **   REJECTED RECORDS.  FOR EACH ROW COMPARE THE TABLE VALUES FOR
      **   CROP POLICY TYPE AND DUAL COVERAGE WITH THE STORED
      **   COMPARISON VALUES.  WHEN THESE MATCH, COMPARE THE TABLE VALUE
      **   FOR ASSIGNED RISK WITH THE STORED ASSIGNED RISK.  IF THE
      **   ASSIGNED RISK DOES NOT MATCH, REJECT THAT ROW.

           PERFORM 3345-COMP-ASSIGNED-RISK
              THRU 3345-COMP-ASSIGNED-RISK-EXIT
              WITH TEST AFTER
           VARYING WS-7014-ASGD-RISK-INT-INDEX
              FROM 1 BY 1
             UNTIL WS-7014-ASGD-RISK-INT-INDEX =
                   WS-7014-ASGD-RISK-REC-COUNT

      **  RESTORE THE MAIN LOOP INDEX VALUE
          MOVE WS-3345-MAIN-LOOP-INT-INDEX
            TO WS-7014-ASGD-RISK-INT-INDEX
          SET WS-7014-ASGD-RISK-INDEX TO WS-7014-ASGD-RISK-INT-INDEX.

       3345-CHECK-ASSIGNED-RISK-EXIT.
           EXIT.


       3345-COMP-ASSIGNED-RISK.
           SET WS-7014-ASGD-RISK-INDEX TO WS-7014-ASGD-RISK-INT-INDEX

      **  SKIP ANY PRE-REJECTED TYPE 14 ASSIGNED RISK RECORDS
           IF WS-7014-TRAN-REJECTED-FLAG(WS-7014-ASGD-RISK-INDEX) =
              WS-LITERAL-YES
              GO TO 3345-COMP-ASSIGNED-RISK-EXIT
           END-IF

          IF WS-7014-CROP-POLICY-TYPE(WS-7014-ASGD-RISK-INDEX) =
             WS-3345-COMPARE-CROP-POLICY-TY AND
             WS-7014-DUAL-COVERAGE-FLAG(WS-7014-ASGD-RISK-INDEX) =
             WS-3345-COMPARE-DUAL-CVG-FLAG AND
             WS-7014-LOC-COUNTY(WS-7014-ASGD-RISK-INDEX) =
             WS-3345-COMPARE-LOC-COUNTY
      **  WHEN THE CURRENT ROW HAS A MATCHING CROP POLICY TYPE AND
      **  DUAL COVERAGE FLAG SETTING, COMPARE ASSIGNED RISK.  IF
      **  THE ASSIGNED RISK DOES NOT MATCH RECORD AN ERROR FOR THAT
      **  ROW
             IF WS-7014-ASSIGNED-RISK(WS-7014-ASGD-RISK-INDEX) <>
                WS-3345-COMPARE-ASSIGNED-RISK
                MOVE WS-LITERAL-YES
                  TO WS-7014-TRAN-REJECTED-FLAG
                     (WS-7014-ASGD-RISK-INDEX)

      *         *** CHECK THE TYPE 14 TABLE TO SEE IF THE 14 RECORD
      *         *** THERE HAS BEEN REJECTED.  IF NOT, REJECT IT.
                IF WS-0014-T14-REC-COUNT > 0 THEN
                   PERFORM 3345-REJ-RELATED-14
                      THRU 3345-REJ-RELATED-14-EXIT
                      WITH TEST AFTER
                   VARYING WS-0014-T14-INT-INDEX
                      FROM 1 BY 1
                     UNTIL WS-0014-T14-INT-INDEX =
                           WS-0014-T14-REC-COUNT
                END-IF
             END-IF
           END-IF.

       3345-COMP-ASSIGNED-RISK-EXIT.
           EXIT.


       3345-REJ-RELATED-14.

           SET WS-0014-T14-INDEX TO WS-0014-T14-INT-INDEX

           IF WS-0014-TBL-TRAN-REJECTED-FLAG(WS-0014-T14-INDEX) =
              WS-LITERAL-YES
      ******* ERRORS WERE ENCOUNTERED WITH THIS TYPE 14.
      ******* CHECK THE SPECIFIC NUMERIC AND DERIVED FIELDS USED IN THIS EDIT
              IF WS-0014-TBL-LOCATION-COUNTY(WS-0014-T14-INDEX)
                 IS NOT NUMERIC
                 OR WS-0014-TBL-DUAL-COVERAGE-FLG(WS-0014-T14-INDEX)
                 IS NOT NUMERIC
                 OR WS-0014-TBL-CROP-POLICY-TY(WS-0014-T14-INDEX)
                 EQUAL SPACES
      ******* THIS RECORD IS BYPASSED
                 GO TO 3345-REJ-RELATED-14-EXIT
              END-IF
           END-IF

      $IF DEBUG-SW DEFINED
           DISPLAY 'T14 CROP POLICY TYPE = ',
           WS-0014-TBL-CROP-POLICY-TY(WS-0014-T14-INDEX)
           UPON CONSOLE
           DISPLAY 'COMPARE CPT = ', WS-3345-COMPARE-CROP-POLICY-TY
           UPON CONSOLE
      $END

           IF WS-0014-TBL-CROP-POLICY-TY(WS-0014-T14-INDEX) =
              WS-3345-COMPARE-CROP-POLICY-TY AND
              WS-0014-TBL-DUAL-COVERAGE-FLG(WS-0014-T14-INDEX) =
              WS-3345-COMPARE-DUAL-CVG-FLAG AND
              WS-0014-TBL-LOCATION-COUNTY(WS-0014-T14-INDEX) =
              WS-3345-COMPARE-LOC-COUNTY

      $IF DEBUG-SW DEFINED
           DISPLAY 'T14 MATCH FOUND' UPON CONSOLE
      $END

      **  WHEN THE CURRENT ROW HAS A MATCHING CROP POLICY TYPE AND
      **  DUAL COVERAGE FLAG SETTING, COMPARE ASSIGNED RISK.  IF
      **  THE ASSIGNED RISK DOES NOT MATCH RECORD AN ERROR FOR THAT
      **  ROW
              IF WS-0014-TBL-ASSIGNED-RISK(WS-0014-T14-INDEX) <>
                 WS-3345-COMPARE-ASSIGNED-RISK
      $IF DEBUG-SW DEFINED
           DISPLAY 'T14 ASSIGNED RISK DOES NOT MATCH'
           UPON CONSOLE
      $END
                 MOVE WS-LITERAL-YES
                   TO WS-0014-TBL-TRAN-REJECTED-FLAG(WS-0014-T14-INDEX)
      **  IF THE DUAL COVERAGE FLAG = 1 THE RECORD IS CAT - ALL DUAL
      **  COVERAGE 1 CAT RECORDS MUST HAVE THE SAME ASSIGNED RISK - 1458.
      **  OTHERWISE, THE RECORD IS BUYUP, ALL TYPE 14 RECORDS FOR THE
      **  CROP/CROP POLICY TYPE MUST HAVE THE SAME ASSIGNED RISK - 1459.
                 IF WS-0014-TBL-DUAL-COVERAGE-FLG(WS-0014-T14-INDEX)
                    EQUAL 1
                    MOVE 14058 TO WS-8000-ERROR-CODE
                 ELSE
                    MOVE 14059 TO WS-8000-ERROR-CODE
                 END-IF
                 MOVE WS-LITERAL-IR TO WS-8000-ERROR-TYPE
                 MOVE WS-LITERAL-YES TO ERROR-ASSIGNED-RISK
                 MOVE 'T14 ASSIGNED RISK' TO WS-8000-FIELD-NAME1
                 MOVE WS-0014-TBL-ASSIGNED-RISK(WS-0014-T14-INDEX)
                   TO WS-8000-BAD-DATA1
                 MOVE WS-3345-COMPARE-ASSIGNED-RISK
                   TO WS-8000-CORR-DATA1
                 MOVE WS-0014-TBL-TRAN-SEQ-NO(WS-0014-T14-INDEX)
                   TO WS-8000-TRAN-SEQ-NO
                 MOVE 3345 TO WS-8000-PARAGRAPH-NO
                 MOVE 14 TO WS-8000-TRAN-TYPE
                 MOVE WS-0014-TBL-POLICY-NO(WS-0014-T14-INDEX)
                   TO WS-8000-POLICY-NO
                 MOVE WS-0014-TBL-LOCATION-COUNTY(WS-0014-T14-INDEX)
                   TO WS-8000-LOC-COUNTY
                 MOVE WS-0014-TBL-INSURANCE-PLAN-CD(WS-0014-T14-INDEX)
                   TO WS-8000-INSURANCE-PLAN-ID
                 MOVE WS-0014-TBL-CROP-CD(WS-0014-T14-INDEX)
                   TO WS-8000-CROP-CD
                 MOVE WS-0014-TBL-RECORD-NUM(WS-0014-T14-INDEX)
                   TO WS-8000-RECORD-NUM
                 MOVE WS-LITERAL-YES TO WS-0006-REJECT-14S-FLAG
                 PERFORM 8000-RECORD-TRAN-ERROR
                    THRU 8000-RECORD-TRAN-ERROR-EXIT
              END-IF
           END-IF.

       3345-REJ-RELATED-14-EXIT.
           EXIT.
