      *****************************************************************
      * File:      IR3350.CBL
      * Author:    Laura Dittamo/Mike Ray
      * Date:      8/23/95
      * Purpose:
      *    This validation routine ensures that, in general, one Type
      *    14 transaction is accepted for a crop-crop/policy type in a
      *    particular county.
      *
      *    Two 14s may exist for a crop-crop/policy type in a county
      *    when one is CAT and Dual Coverage 1 and the other is Buyup -
      *    (not CAT) and Dual Coverage 0.
      *
      *****************************************************************

       3350-LIMIT-NO-OF-TYPE-14.

      $IF DEBUG-SW DEFINED
           DISPLAY '3350-LIMIT NUMBER OF TYPE 14S BY COUNTY'
           UPON CONSOLE
      $END

      * THE TYPE 14 TRANSACTION TABLE HOLDS ALL THE TYPE 14 RECORDS FOR
      * ONE CROP UNDER ONE POLICY

      **   INTIALIZE LOCAL WORK VARIABLES
           INITIALIZE WS-3350-TABLE-STATUS
           INITIALIZE WS-3350-T14-COUNTY-CPT-TABLE
           INITIALIZE WS-3350-WORK

      **   IF THE CURRENT CROP POLICY IS FOR REVENUE ASSURANCE,
      **   THIS EDIT DOES NOT APPLY BECAUSE UNDER REVENUE ASSURANCE
      **   MULTIPLE CROPS (TYPE 14 RECORDS) ARE TREATED AS A SINGLE CROP
      **   POLICY.
           IF WS-0006-INS-PLAN-CD = WS-LITERAL-RA
              GO TO 3350-LIMIT-NO-OF-TYPE-14-EXIT
           END-IF

      **   COUNT THE NUMBER OF TYPE 14 RECORDS PER EACH
      **   CROP/CROP-POLICY TYPE AND COUNTY.  THE RESULTS ARE
      **   STORED IN WS-3350-COUNTY-CPT-TABLE.
      **   ALSO STORED ARE THE NUMBER OF CAT HIGH RISK RECORDS
      **   AND THE NUMBER OF NON-HIGH RISK RECORDS.
      **   HIGH RISK RECORDS MUST BE CAT BUT THIS IS CHECKED
      **   IN INTER-FIELD EDIT 2470-VAL-NON-CAT-DUAL-CVG

           PERFORM 3350-BUILD-14-TABLE
              THRU 3350-BUILD-14-TABLE-EXIT
              WITH TEST AFTER
           VARYING WS-0014-T14-INT-INDEX FROM 1 BY 1
             UNTIL WS-0014-T14-INT-INDEX = WS-0014-T14-REC-COUNT

      **   IF ONE CAT DUAL COVERAGE 1 RECORD WAS FOUND FOR A CROP
      **   POLICY TYPE IN A COUNTY, REJECT THE 14.  EACH CAT
      **   DUAL COVERAGE 1 RECORD MUST HAVE A NON-CAT DUAL COVERAGE 0
      **   COUNTERPART IN THE SAME COUNTY.
           IF WS-3350-CNTY-CPT-REC-COUNT > ZERO
              PERFORM 3350-CHECK-TABLE
                 THRU 3350-CHECK-TABLE-EXIT
                 WITH TEST AFTER
              VARYING WS-3350-TBL-INT-INDEX FROM 1 BY 1
                UNTIL WS-3350-TBL-INT-INDEX
                    = WS-3350-CNTY-CPT-REC-COUNT
           END-IF

      **   IF ANY TYPE 14S WERE REJECTED:
           IF WS-3350-TRANS-REJECTED-SW = WS-LITERAL-YES
              PERFORM 3350-CHECK-TYPE-14
                 THRU 3350-CHECK-TYPE-14-EXIT
                 WITH TEST AFTER
                 VARYING WS-0014-T14-INT-INDEX FROM 1 BY 1
                 UNTIL WS-0014-T14-INT-INDEX = WS-0014-T14-REC-COUNT
           END-IF.


       3350-LIMIT-NO-OF-TYPE-14-EXIT.
           EXIT.


      *****************************************************
      *  THIS BUILDS A TABLE OF CROP POLICY TYPES/COUNTIES*
      *  AND KEEPS TRACK OF THE CVG/HIGH RISK SETTINGS    *
      *  FOR THAT COUNTY/CROP POLICY TYPE.                *
      *****************************************************

       3350-BUILD-14-TABLE.

           SET WS-0014-T14-INDEX TO WS-0014-T14-INT-INDEX

           IF WS-0014-TBL-TRAN-REJECTED-FLAG(WS-0014-T14-INDEX)
              = WS-LITERAL-YES
      *       *** ERRORS WERE ENCOUNTERED WITH THIS TYPE 14.
      *       *** CHECK THE SPECIFIC NUMERIC AND DERIVED FIELDS WHICH
      *       *** ARE USED IN THIS EDIT.
              IF WS-0014-TBL-LOCATION-COUNTY(WS-0014-T14-INDEX)
                 IS NOT NUMERIC
                 OR WS-0014-TBL-DUAL-COVERAGE-FLG(WS-0014-T14-INDEX)
                 IS NOT NUMERIC
                 OR WS-0014-TBL-CROP-POLICY-TY(WS-0014-T14-INDEX)
                 = SPACES
                 GO TO 3350-BUILD-14-TABLE-EXIT
              END-IF
           END-IF

           IF WS-3350-CNTY-CPT-REC-COUNT = ZEROS
              SET WS-3350-TBL-INDEX TO 1
              PERFORM 3350-ADD-RECORD
                 THRU 3350-ADD-RECORD-EXIT
           ELSE
              PERFORM 3350-SEARCH-CNTY-CPT-TBL
                 THRU 3350-SEARCH-CNTY-CPT-TBL-EXIT
           END-IF.

       3350-BUILD-14-TABLE-EXIT.
           EXIT.

      ****************************************************************
      *  THIS PARAGRAPH TESTS THE TABLE SIZE LIMIT BEFORE ADDING AN  *
      *  ADDITIONAL RECORD. WHEN THE MAXIMUM TABLE SIZE IS REACHED,  *
      *  MESSAGES ARE DISPLAYED AND EXECUTION IS TERMINATED -        *
      *  OTHERWISE THE NEW TRANSACTION RECORD IS ADDED TO THE TABLE. *
      ****************************************************************

       3350-ADD-RECORD.

           IF WS-3350-TBL-INT-INDEX = WS-3350-MAX-SIZE
              DISPLAY 'TEMPORARY TABLE, CROP POLICY TYPE BY COUNTY, '
              UPON CONSOLE
              DISPLAY '(3350) LIMIT WILL BE EXCEEDED'
              UPON CONSOLE
              DISPLAY ' WITH THE ADDITION OF THIS RECORD'
              UPON CONSOLE
              DISPLAY '**********************************'
              UPON CONSOLE
              DISPLAY 'MAXIMUM TABLE SIZE IS ' WS-3350-MAX-SIZE
                      ' RECORDS' UPON CONSOLE
              PERFORM 0800-ABORT-PROGRAM
                 THRU 0800-ABORT-PROGRAM-EXIT
           ELSE
              ADD 1 TO WS-3350-CNTY-CPT-REC-COUNT
              SET WS-3350-TBL-INDEX TO WS-3350-CNTY-CPT-REC-COUNT
              MOVE WS-0014-TBL-LOCATION-COUNTY(WS-0014-T14-INDEX)
                TO WS-3350-TBL-LOCATION-COUNTY(WS-3350-TBL-INDEX)
              MOVE WS-0014-TBL-CROP-POLICY-TY(WS-0014-T14-INDEX)
                TO WS-3350-TBL-CROP-POLICY-TY(WS-3350-TBL-INDEX)
              ADD +1 TO WS-3350-TBL-14-REC-COUNT(WS-3350-TBL-INDEX)
              IF WS-3350-TBL-REJECTED-FLAG(WS-3350-TBL-INDEX) = SPACES
                 MOVE WS-LITERAL-NO
                   TO WS-3350-TBL-REJECTED-FLAG(WS-3350-TBL-INDEX)
              END-IF
              IF WS-0014-TBL-DUAL-COVERAGE-FLG(WS-0014-T14-INDEX) = 1
                 IF WS-0014-TBL-COVERAGE-FLG(WS-0014-T14-INDEX)
                    = WS-LITERAL-CAT
                    ADD 1
                     TO WS-3350-TBL-CAT-HIGH-RISK-CT(WS-3350-TBL-INDEX)
                 ELSE
      *             *** THIS IS INVALID; HIGH RISK POLICIES MUST BE CAT CVG
                    IF WS-0014-TBL-TRAN-REJECTED-FLAG
                       (WS-0014-T14-INDEX) <> WS-LITERAL-YES
                       MOVE 3350 TO WS-8020-PARAGRAPH-NO
                       MOVE 1418 TO WS-8020-INT-ERROR-NO
                       MOVE 'CVG/DUAL CVG' TO WS-8020-FIELD-NAME
                       MOVE WS-0014-TBL-COVERAGE-FLG(WS-0014-T14-INDEX)
                         TO WS-8020-BAD-DATA
                       MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                       MOVE WS-0014-TBL-TRAN-SEQ-NO(WS-0014-T14-INDEX)
                         TO WS-8020-TRAN-SEQ-NO
                       PERFORM 8020-RECORD-INT-ERROR
                          THRU 8020-RECORD-INT-ERROR-EXIT
                    END-IF
                    MOVE WS-LITERAL-YES
                      TO WS-3350-TBL-REJECTED-FLAG(WS-3350-TBL-INDEX)
                    MOVE WS-LITERAL-YES TO WS-3350-TRANS-REJECTED-SW
                 END-IF
              ELSE
                 IF WS-0014-TBL-COVERAGE-FLG(WS-0014-T14-INDEX)
                    = WS-LITERAL-CAT
                    ADD 1
                     TO WS-3350-TBL-CAT-NOT-HIGH-RK-CT
                        (WS-3350-TBL-INDEX)
                 ELSE
                    ADD 1
                     TO WS-3350-TBL-BUYUP-CT(WS-3350-TBL-INDEX)
                 END-IF
              END-IF
           END-IF.

       3350-ADD-RECORD-EXIT.
           EXIT.


      ****************************************************************
      *  THIS PARAGRAPH DOES A SEARCH OF THE COUNTY CROP POLICY TYPE *
      *  RECORDS TABLE. WHEN A MATCH IS FOUND, THE TWO RECORDS FOR   *
      *  COUNTY-CROP POLICY TYPE ARE COMPARED.
      *
      ****************************************************************

       3350-SEARCH-CNTY-CPT-TBL.

           SET WS-3350-TBL-INDEX TO 1
           SEARCH WS-3350-T14-COUNTY-CPT-REC
              VARYING WS-3350-TBL-INDEX
              AT END
                 PERFORM 3350-ADD-RECORD
                    THRU 3350-ADD-RECORD-EXIT
                 GO TO 3350-SEARCH-CNTY-CPT-TBL-EXIT
              WHEN (WS-0014-TBL-LOCATION-COUNTY(WS-0014-T14-INDEX) =
                   WS-3350-TBL-LOCATION-COUNTY(WS-3350-TBL-INDEX))
              AND  (WS-0014-TBL-CROP-POLICY-TY(WS-0014-T14-INDEX) =
                   WS-3350-TBL-CROP-POLICY-TY(WS-3350-TBL-INDEX))
                 ADD +1
                    TO WS-3350-TBL-14-REC-COUNT(WS-3350-TBL-INDEX)
                 IF WS-0014-TBL-DUAL-COVERAGE-FLG
                    (WS-0014-T14-INDEX) = 1
                    IF WS-0014-TBL-COVERAGE-FLG(WS-0014-T14-INDEX)
                       = WS-LITERAL-CAT
                       ADD 1
                        TO WS-3350-TBL-CAT-HIGH-RISK-CT
                           (WS-3350-TBL-INDEX)
                    ELSE
      *                *** THIS IS INVALID; HIGH RISK POLICIES MUST BE CAT CVG
                       IF WS-0014-TBL-TRAN-REJECTED-FLAG
                          (WS-0014-T14-INDEX) <> WS-LITERAL-YES
                          MOVE 3350 TO WS-8020-PARAGRAPH-NO
                          MOVE 1418 TO WS-8020-INT-ERROR-NO
                          MOVE 'CVG/DUAL CVG' TO WS-8020-FIELD-NAME
                          MOVE WS-0014-TBL-COVERAGE-FLG
                               (WS-0014-T14-INDEX)
                            TO WS-8020-BAD-DATA
                          MOVE WS-0014-TBL-TRAN-SEQ-NO
                               (WS-0014-T14-INDEX)
                            TO WS-8020-TRAN-SEQ-NO
                          MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                          PERFORM 8020-RECORD-INT-ERROR
                             THRU 8020-RECORD-INT-ERROR-EXIT
                       END-IF
                       MOVE WS-LITERAL-YES
                         TO WS-3350-TBL-REJECTED-FLAG
                            (WS-3350-TBL-INDEX)
                       MOVE WS-LITERAL-YES
                         TO WS-3350-TRANS-REJECTED-SW
                    END-IF
                 ELSE
                    IF WS-0014-TBL-COVERAGE-FLG(WS-0014-T14-INDEX)
                       = WS-LITERAL-CAT
                       ADD 1
                         TO WS-3350-TBL-CAT-NOT-HIGH-RK-CT
                            (WS-3350-TBL-INDEX)
                    ELSE
                       ADD 1
                         TO WS-3350-TBL-BUYUP-CT(WS-3350-TBL-INDEX)
                    END-IF
                 END-IF
           END-SEARCH.

       3350-SEARCH-CNTY-CPT-TBL-EXIT.
           EXIT.

      *****************************************************
      *  THIS CHECKS THE TABLE BUILT ABOVE TO ENSURE THAT *
      *  ONLY CORRECT COMBINATIONS OF CVG AND HIGH RISK   *
      *  SETTINGS HAVE BEEN SUBMITTED FOR THE COUNTY/CPT. *
      *****************************************************

       3350-CHECK-TABLE.

           SET WS-3350-TBL-INDEX TO WS-3350-TBL-INT-INDEX
           IF WS-3350-TBL-REJECTED-FLAG(WS-3350-TBL-INDEX)
              = WS-LITERAL-YES
              GO TO 3350-CHECK-TABLE-EXIT
           END-IF

           IF WS-3350-TBL-14-REC-COUNT(WS-3350-TBL-INDEX) = 2
      *       *** THIS IS ONLY VALID WHEN THERE IS A HIGH RISK CAT POLICY
      *       *** AND A NON-HIGH RISK BUYUP POLICY

      *       *** A HIGH RISK CAT POLICY CANNOT BE SUBMITTED IN THE SAME
      *       *** COUNTY WITH A CAT-NOT HIGH RISK-POLICY
              IF (WS-3350-TBL-CAT-HIGH-RISK-CT(WS-3350-TBL-INDEX) > 1)
                 OR
                 (WS-3350-TBL-CAT-NOT-HIGH-RK-CT(WS-3350-TBL-INDEX) > 1)
                 OR
                 (WS-3350-TBL-BUYUP-CT(WS-3350-TBL-INDEX) > 1)
                 OR
                 (WS-3350-TBL-CAT-HIGH-RISK-CT(WS-3350-TBL-INDEX)
                    = 1
                 AND WS-3350-TBL-CAT-NOT-HIGH-RK-CT(WS-3350-TBL-INDEX)
                    = 1)
                 MOVE WS-LITERAL-YES
                   TO WS-3350-TBL-REJECTED-FLAG(WS-3350-TBL-INDEX)
                 MOVE WS-LITERAL-YES TO WS-3350-TRANS-REJECTED-SW
              END-IF
              GO TO 3350-CHECK-TABLE-EXIT
           END-IF

      *    *** THERE NEVER SHOULD BE MORE THAN TWO RECORDS PER CPT/COUNTY
           IF WS-3350-TBL-14-REC-COUNT(WS-3350-TBL-INDEX) > 2
              MOVE WS-LITERAL-YES
                TO WS-3350-TBL-REJECTED-FLAG(WS-3350-TBL-INDEX)
                 MOVE WS-LITERAL-YES TO WS-3350-TRANS-REJECTED-SW
           END-IF.


       3350-CHECK-TABLE-EXIT.
           EXIT.

      *****************************************************
      *  THIS REJECTS TRANSACTIONS WHICH HAVE INVALID     *
      *  SETTINGS WITHIN THEIR COUNTY/CPT GROUP.  IF THE  *
      *  TRAN COUNT WITHIN A COUNTY IS 1 A RECORD IS      *
      *  MISSING WHICH IS REQUIRED, IF THE COUNT IS 2     *
      *  THEN AN INCORRECT COMBINATION WAS SUBMITTED, IF  *
      *  THE COUNT IS > 2 THEN TOO MANY WERE SUBMITTED.   *
      *****************************************************


       3350-CHECK-TYPE-14.

           SET WS-0014-T14-INDEX TO WS-0014-T14-INT-INDEX

           IF WS-0014-TBL-TRAN-REJECTED-FLAG(WS-0014-T14-INDEX) =
              WS-LITERAL-YES
      ******* ERRORS WERE ENCOUNTERED WITH THIS TYPE 14.
      ******* CHECK THE SPECIFIC NUMERIC AND DERIVED FIELDS USED
      ******* TO MATCH A TYPE 14 TRANSACTION WITH TOTALS FOR
      ******* A CROP POLICY TYPE & COUNTY
              IF WS-0014-TBL-LOCATION-COUNTY(WS-0014-T14-INDEX)
                 IS NOT NUMERIC
                 OR WS-0014-TBL-DUAL-COVERAGE-FLG(WS-0014-T14-INDEX)
                 IS NOT NUMERIC
      ******* THIS RECORD IS BYPASSED
                 GO TO 3350-CHECK-TYPE-14-EXIT
              END-IF
           END-IF

           MOVE WS-LITERAL-NO TO WS-3350-MATCH-FOUND-SW

      **   DETERMINE WHETHER CURRENT ROW IN 14 TRANSACTION TABLE
      **   SHOULD BE REJECTED
           PERFORM 3350-FIND-COUNTY-CROP
              THRU 3350-FIND-COUNTY-CROP-EXIT
              WITH TEST AFTER
              VARYING WS-3350-TBL-INT-INDEX FROM 1 BY 1
              UNTIL WS-3350-TBL-INT-INDEX
                    = WS-3350-CNTY-CPT-REC-COUNT
                 OR MATCH-FOUND-3350

           IF NOT MATCH-FOUND-3350
              MOVE 3350 TO WS-8020-PARAGRAPH-NO
              MOVE 90044 TO WS-8020-INT-ERROR-NO
              MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
              MOVE WS-0014-TBL-TRAN-SEQ-NO(WS-0014-T14-INDEX)
                TO WS-8020-TRAN-SEQ-NO
              PERFORM 8020-RECORD-INT-ERROR
                 THRU 8020-RECORD-INT-ERROR-EXIT
           END-IF

           IF WS-3350-TBL-REJECTED-FLAG(WS-3350-TBL-INDEX)
              = WS-LITERAL-YES
              MOVE 14060 TO WS-8000-ERROR-CODE
              MOVE WS-LITERAL-YES
                TO WS-0014-TBL-TRAN-REJECTED-FLAG(WS-0014-T14-INDEX)
              MOVE WS-LITERAL-IR TO WS-8000-ERROR-TYPE
              MOVE 3350 TO WS-8000-PARAGRAPH-NO
              MOVE WS-0014-TBL-TRAN-SEQ-NO(WS-0014-T14-INDEX)
                TO WS-8000-TRAN-SEQ-NO
              MOVE 14 TO WS-8000-TRAN-TYPE
              MOVE WS-0014-TBL-POLICY-NO(WS-0014-T14-INDEX)
                TO WS-8000-POLICY-NO
              MOVE WS-0014-TBL-LOCATION-COUNTY(WS-0014-T14-INDEX)
                TO WS-8000-LOC-COUNTY
              MOVE WS-0014-TBL-INSURANCE-PLAN-CD(WS-0014-T14-INDEX)
                TO WS-8000-INSURANCE-PLAN-ID
              MOVE WS-0014-TBL-CROP-CD(WS-0014-T14-INDEX)
                TO WS-8000-CROP-CD
              MOVE WS-0014-TBL-RECORD-NUM(WS-0014-T14-INDEX)
                TO WS-8000-RECORD-NUM
              MOVE WS-LITERAL-YES TO WS-0006-REJECT-14S-FLAG
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT

              PERFORM 3350-DELETE-T14-ISAM-REC
                 THRU 3350-DELETE-T14ISAMREC-EXIT
           END-IF.


       3350-CHECK-TYPE-14-EXIT.
           EXIT.

      *****************************************************
      *  THIS FINDS THE CORRECT ENTRY IN THE COUNTY/CPT   *
      *  TABLE FOR THE CURRENT TRANSACTION.               *
      *****************************************************

       3350-FIND-COUNTY-CROP.
           SET WS-3350-TBL-INDEX TO WS-3350-TBL-INT-INDEX
           IF (WS-0014-TBL-LOCATION-COUNTY(WS-0014-T14-INDEX) =
               WS-3350-TBL-LOCATION-COUNTY(WS-3350-TBL-INDEX))
           AND (WS-0014-TBL-CROP-POLICY-TY(WS-0014-T14-INDEX) =
               WS-3350-TBL-CROP-POLICY-TY(WS-3350-TBL-INDEX))
               MOVE WS-LITERAL-YES TO WS-3350-MATCH-FOUND-SW
           END-IF.

       3350-FIND-COUNTY-CROP-EXIT.
           EXIT.

       3350-DELETE-T14-ISAM-REC.
      ********************************** (8/97) PER KEITH BEGLEY (KT)**
      *    THIS MODULE SHALL BE PERFORMED ONLY IF THE T14 RECORD IS   *
      *    REJECTED WITH ERROR CODE 14060. THE T14 ISAM RECORD WAS    *
      *    BEING ADDED EARLIER IN THE PROCESS. MULTIPLE T14 RECORDS   *
      *    SUBMITTED FOR A SINGLE CROP/CROP POLICY TYPE IN A COUNTY   *
      *    ARE NOT ALLOWED AND SHOULD NOT BE UPDATED TO T14 ISAM FILE *
      *****************************************************************
           IF NOT TYPE-14-DATES-FILE-OPEN
              GO TO 3350-DELETE-T14ISAMREC-EXIT
           END-IF

           MOVE WS-0014-TBL-REPORTING-ORG(WS-0014-T14-INDEX)
             TO WS-0975-REPORTING-ORG
           MOVE WS-0014-TBL-LOC-STATE(WS-0014-T14-INDEX)
             TO WS-0975-LOCATION-STATE
           MOVE WS-0014-TBL-COMPANY-COUNTY(WS-0014-T14-INDEX)
             TO WS-0975-COMPANY-COUNTY
           MOVE WS-0014-TBL-POLICY-NUM(WS-0014-T14-INDEX)
             TO WS-0975-POLICY-NUM
           MOVE WS-0014-TBL-CROP-YEAR(WS-0014-T14-INDEX)
             TO WS-0975-CROP-YEAR
           MOVE WS-0014-TBL-LOCATION-COUNTY(WS-0014-T14-INDEX)
             TO WS-0975-LOCATION-COUNTY
           MOVE WS-0014-TBL-CROP-CD(WS-0014-T14-INDEX)
             TO WS-0975-CROP-CD
           MOVE WS-0014-TBL-INSURANCE-PLAN-CD(WS-0014-T14-INDEX)
             TO WS-0975-INSURANCE-PLAN-ID
           MOVE WS-0014-TBL-CROP-POLICY-TY(WS-0014-T14-INDEX)
             TO WS-0975-CROP-POLICY-TYPE
           MOVE WS-0014-TBL-DUAL-COVERAGE-FLG(WS-0014-T14-INDEX)
             TO WS-0975-DUAL-CVG-FLG

           MOVE WS-0975-INPUT-KEY TO TYPE-14-DATES-REC-KEY
           DELETE TYPE-14-DATES-FILE RECORD
              INVALID KEY
      $IF DEBUG-SW DEFINED
                 DISPLAY '14060 ERR - CANNOT DELETE T14 ISAM RECORD...'
                 UPON CONSOLE
                 DISPLAY 'DELETING T14 KEY ==> ' TYPE-14-DATES-REC-KEY
                 UPON CONSOLE
      $END
                 CONTINUE
           END-DELETE.

       3350-DELETE-T14ISAMREC-EXIT.
           EXIT.

