      ****************************************************************
      *  File   : IR3355.CBL
      *  Author : MIKE RAY
      *  Date   : 03/15/97
      *  Purpose: Checks the Type 15 table to see if any type 15 record
      *           requires that a reference unit exist to support its
      *           yield floor. If so, scans the table to see if there
      *           is a reference unit with sufficient actual yields to
      *           support the floor percentage.
      ****************************************************************

       3355-FIND-REF-UNITS.

      $IF DEBUG-SW DEFINED
           DISPLAY '3355-VALIDATING REFERENCE UNIT REQUIREMENTS'
           UPON CONSOLE
      $END

      *    ***************************************************
      *    *  INITIALIZE LOCAL WORKING STORAGE               *
      *    ***************************************************
           INITIALIZE WS-3355-LOCAL

      *    ***************************************************
      *    *  SEE IF ANY T15 REQUIRES A REFERENCE UNIT       *
      *    ***************************************************
           MOVE WS-LITERAL-NO TO WS-3355-REFERENCE-UNITS-REQ
           PERFORM 3355-CHECK-UNIT-REQ
              THRU 3355-CHECK-UNIT-REQ-EXIT
              WITH TEST AFTER
           VARYING WS-0015-T15-INT-INDEX FROM 1 BY 1
             UNTIL WS-0015-T15-INT-INDEX = WS-0015-T15-REC-COUNT

      $IF DEBUG-SW DEFINED
           IF WS-3355-REFERENCE-UNITS-REQ = WS-LITERAL-NO
              DISPLAY 'NO REFERENCE UNITS REQUIRED'
              UPON CONSOLE
           ELSE
              DISPLAY 'REFERENCE UNITS REQUIRED'
              UPON CONSOLE
              DISPLAY 'MAX ACTUAL YEARS FOUND = ',
              WS-3355-MAX-ACTUAL-YIELDS
              UPON CONSOLE
           END-IF
      $END

           IF WS-3355-REFERENCE-UNITS-REQ = WS-LITERAL-NO
              GO TO 3355-FIND-REF-UNITS-EXIT
           END-IF

      *    ***************************************************
      *    *  REJECT T15S WHICH NEED MORE ACTUAL YIELDS THAN *
      *    *  WERE FOUND                                     *
      *    ***************************************************
           MOVE WS-LITERAL-NO TO WS-3355-REFERENCE-UNITS-REQ
           PERFORM 3355-CHECK-YLD-REQ
              THRU 3355-CHECK-YLD-REQ-EXIT
              WITH TEST AFTER
           VARYING WS-0015-T15-INT-INDEX FROM 1 BY 1
             UNTIL WS-0015-T15-INT-INDEX = WS-0015-T15-REC-COUNT.



       3355-FIND-REF-UNITS-EXIT.
           EXIT.


       3355-CHECK-UNIT-REQ.

           SET WS-0015-T15-INDEX TO WS-0015-T15-INT-INDEX

           IF WS-0015-TBL-REF-YEARS-REQ(WS-0015-T15-INDEX) >
              WS-0015-TBL-ACTUAL-YEARS(WS-0015-T15-INDEX)
              MOVE WS-LITERAL-YES
                TO WS-3355-REFERENCE-UNITS-REQ
           END-IF
      *    *** STORE THE MAXIMUM NUMBER OF ACTUALS FOUND ***
           IF WS-0015-TBL-ACTUAL-YEARS(WS-0015-T15-INDEX) >
              WS-3355-MAX-ACTUAL-YIELDS
              MOVE WS-0015-TBL-ACTUAL-YEARS(WS-0015-T15-INDEX)
                TO WS-3355-MAX-ACTUAL-YIELDS
           END-IF.

       3355-CHECK-UNIT-REQ-EXIT.
           EXIT.

       3355-CHECK-YLD-REQ.

           SET WS-0015-T15-INDEX TO WS-0015-T15-INT-INDEX

           IF WS-0015-TBL-REF-YEARS-REQ(WS-0015-T15-INDEX) >
              WS-3355-MAX-ACTUAL-YIELDS
              MOVE WS-LITERAL-YES
                TO WS-0015-TBL-TRAN-REJECTED-FLAG(WS-0015-T15-INDEX)
              MOVE WS-LITERAL-IR TO WS-8000-ERROR-TYPE
              MOVE 15096 TO WS-8000-ERROR-CODE
              MOVE WS-0015-TBL-TRAN-SEQ-NO(WS-0015-T15-INDEX)
                TO WS-8000-TRAN-SEQ-NO
              MOVE WS-LITERAL-APPROVED-YLD TO WS-8000-FIELD-NAME1
              MOVE WS-0015-TBL-APPROVED-YIELD(WS-0015-T15-INDEX)
                TO WS-3355-TBL-APPROVED-YIELD-X
              MOVE WS-3355-TBL-APPROVED-YIELD-X
                TO WS-8000-BAD-DATA1
              STRING 'REF ACTUAL YLDS REQ '
               DELIMITED BY SIZE
               WS-0015-TBL-REF-YEARS-REQ(WS-0015-T15-INDEX)
               DELIMITED BY SIZE
               ', MAX FOUND '
               DELIMITED BY SIZE
               WS-3355-MAX-ACTUAL-YIELDS
               DELIMITED BY SIZE
               INTO WS-8000-CORR-DATA1
              END-STRING
              MOVE 15 TO WS-8000-TRAN-TYPE
              MOVE WS-0015-TBL-POLICY-NO(WS-0015-T15-INDEX)
                TO WS-8000-POLICY-NO
              MOVE 3355 TO WS-8000-PARAGRAPH-NO
              MOVE WS-0015-TBL-LOCATION-COUNTY(WS-0015-T15-INDEX)
                TO WS-8000-LOC-COUNTY
              MOVE WS-0015-TBL-INSURANCE-PLAN-CD(WS-0015-T15-INDEX)
                TO WS-8000-INSURANCE-PLAN-ID
              MOVE WS-0015-TBL-CROP-CD(WS-0015-T15-INDEX)
                TO WS-8000-CROP-CD
              MOVE WS-0015-TBL-RECORD-NUM(WS-0015-T15-INDEX)
                TO WS-8000-RECORD-NUM
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF.

       3355-CHECK-YLD-REQ-EXIT.
           EXIT.




