      ****************************************************************
      *  File   : IR3365.CBL
      *  Author : MIKE RAY
      *  Date   : 03/04/97
      *  Purpose: Validates the Revenue Assurance Coverage Level and
      *           Dollar Amount of Insurance for Enterprise and Whole
      *           Farm Units.  Ensures that only valid coverage
      *           combinations are accepted.
      *           Rules are as Follows:
      *           All records can be Whole Farm (WU).
      *           Corn and Soybeans can have different organizations
      *           as long as neither is Whole Farm (WU).
      *           Basic and Optional Units are the same for purposes
      *           of this edit and are considered Basic Unit Organization.
      *           Within each unit organization, all Dollar Amt Ins
      *           fields must be the same and all RA Coverage Levels must
      *           be the same.
      ****************************************************************

       3365-VAL-RA-COVERAGE.

      $IF DEBUG-SW DEFINED
           DISPLAY '3365-VALIDATING REVENUE ASSURANCE COVERAGE'
           UPON CONSOLE
      $END

      *    ***************************************************
      *    *  MAKE SURE THAT WHOLE FARM UNIT VALUES ARE IN   *
      *    *  BOTH SETS OF CROP FIELDS IF WHOLE FARM UNITS   *
      *    *  HAVE BEEN RECEIVED.                            *
      *    ***************************************************
           IF WS-0011-RA-CORN-UNIT-ORG
              = WS-LITERAL-WHOLE-FARM-UNIT OR
              WS-0011-RA-SOY-UNIT-ORG
              = WS-LITERAL-WHOLE-FARM-UNIT
              MOVE WS-LITERAL-WHOLE-FARM-UNIT
                TO WS-0011-RA-CORN-UNIT-ORG
              MOVE WS-LITERAL-WHOLE-FARM-UNIT
                TO WS-0011-RA-SOY-UNIT-ORG
              MOVE WS-0011-RA-WFARM-CVG-LVL-PCT
                TO WS-0011-RA-CORN-CVG-LVL-PCT
              MOVE WS-0011-RA-WFARM-CVG-LVL-PCT
                TO WS-0011-RA-SOY-CVG-LVL-PCT
              MOVE WS-0011-RA-WFARM-DOL-AMT-PROT
                TO WS-0011-RA-CORN-DOL-AMT-PROT
              MOVE WS-0011-RA-WFARM-DOL-AMT-PROT
                TO WS-0011-RA-SOY-DOL-AMT-PROT
           END-IF

           PERFORM 3365-CHECK-COVERAGE
              THRU 3365-CHECK-COVERAGE-EXIT
              WITH TEST AFTER
           VARYING WS-0011-T11-INT-INDEX FROM 1 BY 1
             UNTIL WS-0011-T11-INT-INDEX = WS-0011-T11-REC-COUNT.


       3365-VAL-RA-COVERAGE-EXIT.
           EXIT.


       3365-CHECK-COVERAGE.

           SET WS-0011-T11-INDEX TO WS-0011-T11-INT-INDEX

           INITIALIZE WS-3365-WORK

      $IF DEBUG-SW DEFINED
           MOVE WS-0011-TBL-DOLLAR-AMT-INSUR(WS-0011-T11-INDEX)
             TO WS-3365-T11-DOLLAR-AMT
           MOVE WS-0011-TBL-REV-CVG-LVL-PCT(WS-0011-T11-INDEX)
             TO WS-3365-T11-RA-CVG-LVL
           MOVE WS-0011-TBL-PRICE-ELECTION(WS-0011-T11-INDEX)
             TO WS-3365-T11-PRICE-ELECTION
           MOVE WS-0011-RA-CORN-DOL-AMT-PROT
             TO WS-3365-CORN-DOLLAR-AMT
           MOVE WS-3365-T11-RA-CVG-LVL
             TO WS-3365-CORN-RA-CVG-LVL
           MOVE WS-0011-RA-CORN-PRICE-ELECTION
             TO WS-3365-CORN-PRICE
           MOVE WS-0011-RA-SOY-DOL-AMT-PROT
             TO WS-3365-SOY-DOLLAR-AMT
           MOVE WS-0011-RA-SOY-CVG-LVL-PCT
             TO WS-3365-SOY-RA-CVG-LVL
           MOVE WS-0011-RA-SOY-PRICE-ELECTION
             TO WS-3365-SOY-PRICE
           DISPLAY 'TSEQ# ',
           WS-0011-TBL-TRAN-SEQ-NO(WS-0011-T11-INDEX) UPON CONSOLE
           DISPLAY '$AMT OF INS = $', WS-3365-T11-DOLLAR-AMT,
           ' CORN $AMT = $', WS-3365-CORN-DOLLAR-AMT,
           ' SOY $AMT = $', WS-3365-SOY-DOLLAR-AMT
           UPON CONSOLE
           DISPLAY 'REV CVG LVL% = ', WS-3365-T11-RA-CVG-LVL,
           ' CORN CVG% = ', WS-3365-CORN-RA-CVG-LVL,
           ' SOY CVG% = ', WS-3365-SOY-RA-CVG-LVL
           UPON CONSOLE
           DISPLAY 'PRICE ELECTION = $', WS-3365-T11-PRICE-ELECTION,
           ' CORN PRICE = $', WS-3365-CORN-PRICE,
           ' SOY PRICE = $', WS-3365-SOY-PRICE
           UPON CONSOLE
           DISPLAY 'UNIT ORG = ',
           WS-0011-TBL-UNIT-OPT-CD(WS-0011-T11-INDEX),
           ' CORN UNIT ORG = ', WS-0011-RA-CORN-UNIT-ORG,
           ' SOY UNIT ORG = ', WS-0011-RA-SOY-UNIT-ORG
           UPON CONSOLE
      $END

           EVALUATE WS-0011-TBL-CROP-CD(WS-0011-T11-INDEX)
               WHEN WS-LITERAL-CORN
                  IF WS-0011-TBL-UNIT-OPT-CD(WS-0011-T11-INDEX)
                     <> WS-0011-RA-CORN-UNIT-ORG
                     IF (WS-0011-TBL-UNIT-OPT-CD(WS-0011-T11-INDEX)
                        = WS-LITERAL-OPT-UNIT) AND
                        (WS-0011-RA-CORN-UNIT-ORG
                        = WS-LITERAL-BASIC-UNIT)
                        CONTINUE
                     ELSE
                        MOVE WS-LITERAL-YES TO WS-3365-UNIT-ORG-ERROR
                        MOVE WS-0011-RA-CORN-UNIT-ORG
                          TO WS-3365-CORRECT-UNIT-ORG
                     END-IF
                  END-IF

                  IF (WS-0011-TBL-REV-CVG-LVL-PCT(WS-0011-T11-INDEX)
                     > (WS-0011-RA-CORN-CVG-LVL-PCT + 0.005)) OR
                     (WS-0011-TBL-REV-CVG-LVL-PCT(WS-0011-T11-INDEX)
                     < (WS-0011-RA-CORN-CVG-LVL-PCT - 0.005))
                     MOVE WS-LITERAL-YES
                       TO WS-3365-RA-CVG-ERROR
                     MOVE WS-0011-TBL-REV-CVG-LVL-PCT
                          (WS-0011-T11-INDEX)
                       TO WS-3365-BAD-CVG-LVL
                     MOVE WS-0011-RA-CORN-CVG-LVL-PCT
                       TO WS-3365-CORR-CVG-LVL
                  END-IF

                  IF WS-0011-TBL-PRICE-ELECTION(WS-0011-T11-INDEX)
                     <> WS-0011-RA-CORN-PRICE-ELECTION
                     MOVE WS-LITERAL-YES
                       TO WS-3365-PRICE-ELECTION-ERROR
                     MOVE WS-0011-TBL-PRICE-ELECTION
                          (WS-0011-T11-INDEX)
                       TO WS-3365-BAD-PRICE-ELECTION
                     MOVE WS-0011-RA-CORN-PRICE-ELECTION
                       TO WS-3365-CORR-PRICE-ELECTION
                  END-IF

                  IF WS-0011-TBL-UNIT-OPT-CD(WS-0011-T11-INDEX)
                     = WS-LITERAL-BASIC-UNIT OR WS-LITERAL-OPT-UNIT
                     GO TO 3365-CHECK-COVERAGE-EXIT
                  END-IF

                  IF WS-0011-TBL-DOLLAR-AMT-INSUR
                     (WS-0011-T11-INDEX)
                     > (WS-0011-RA-CORN-DOL-AMT-PROT + 1) OR
                     WS-0011-TBL-DOLLAR-AMT-INSUR
                     (WS-0011-T11-INDEX)
                     < (WS-0011-RA-CORN-DOL-AMT-PROT - 1)
                     MOVE WS-LITERAL-YES
                       TO WS-3365-DOLLAR-AMT-ERROR
                     MOVE WS-0011-TBL-DOLLAR-AMT-INSUR
                          (WS-0011-T11-INDEX)
                       TO WS-3365-BAD-DOLLAR-AMT
                     MOVE WS-0011-RA-CORN-DOL-AMT-PROT
                       TO WS-3365-CORR-DOLLAR-AMT
                  END-IF


               WHEN WS-LITERAL-SOYBEANS
                  IF WS-0011-TBL-UNIT-OPT-CD(WS-0011-T11-INDEX)
                     <> WS-0011-RA-SOY-UNIT-ORG
                     IF (WS-0011-TBL-UNIT-OPT-CD(WS-0011-T11-INDEX)
                        = WS-LITERAL-OPT-UNIT) AND
                        (WS-0011-RA-SOY-UNIT-ORG
                        = WS-LITERAL-BASIC-UNIT)
                        CONTINUE
                     ELSE
                        MOVE WS-LITERAL-YES TO WS-3365-UNIT-ORG-ERROR
                        MOVE WS-0011-RA-SOY-UNIT-ORG
                          TO WS-3365-CORRECT-UNIT-ORG
                     END-IF
                  END-IF

                  IF (WS-0011-TBL-REV-CVG-LVL-PCT(WS-0011-T11-INDEX)
                     > (WS-0011-RA-SOY-CVG-LVL-PCT + 0.005)) OR
                     (WS-0011-TBL-REV-CVG-LVL-PCT(WS-0011-T11-INDEX)
                     < (WS-0011-RA-SOY-CVG-LVL-PCT - 0.005))
                     MOVE WS-LITERAL-YES
                       TO WS-3365-RA-CVG-ERROR
                     MOVE WS-0011-TBL-REV-CVG-LVL-PCT
                          (WS-0011-T11-INDEX)
                       TO WS-3365-BAD-CVG-LVL
                     MOVE WS-0011-RA-SOY-CVG-LVL-PCT
                       TO WS-3365-CORR-CVG-LVL
                  END-IF

                  IF WS-0011-TBL-PRICE-ELECTION(WS-0011-T11-INDEX)
                     <> WS-0011-RA-SOY-PRICE-ELECTION
                     MOVE WS-LITERAL-YES
                       TO WS-3365-PRICE-ELECTION-ERROR
                     MOVE WS-0011-TBL-PRICE-ELECTION
                          (WS-0011-T11-INDEX)
                       TO WS-3365-BAD-PRICE-ELECTION
                     MOVE WS-0011-RA-SOY-PRICE-ELECTION
                       TO WS-3365-CORR-PRICE-ELECTION
                  END-IF

                  IF WS-0011-TBL-UNIT-OPT-CD(WS-0011-T11-INDEX)
                     = WS-LITERAL-BASIC-UNIT OR WS-LITERAL-OPT-UNIT
                     GO TO 3365-CHECK-COVERAGE-EXIT
                  END-IF

                  IF WS-0011-TBL-DOLLAR-AMT-INSUR
                     (WS-0011-T11-INDEX)
                     > (WS-0011-RA-SOY-DOL-AMT-PROT + 1) OR
                     WS-0011-TBL-DOLLAR-AMT-INSUR
                     (WS-0011-T11-INDEX)
                     < (WS-0011-RA-SOY-DOL-AMT-PROT - 1)
                     MOVE WS-LITERAL-YES
                       TO WS-3365-DOLLAR-AMT-ERROR
                     MOVE WS-0011-TBL-DOLLAR-AMT-INSUR
                          (WS-0011-T11-INDEX)
                       TO WS-3365-BAD-DOLLAR-AMT
                     MOVE WS-0011-RA-SOY-DOL-AMT-PROT
                       TO WS-3365-CORR-DOLLAR-AMT
                  END-IF

               WHEN OTHER
                  CONTINUE
           END-EVALUATE

           IF WS-3365-UNIT-ORG-ERROR = WS-LITERAL-YES
              MOVE WS-LITERAL-YES
                TO WS-0011-TBL-TRAN-REJECTED-FLAG(WS-0011-T11-INDEX)
              MOVE WS-LITERAL-IR TO WS-8000-ERROR-TYPE
              MOVE 11095 TO WS-8000-ERROR-CODE
              MOVE WS-0011-TBL-TRAN-SEQ-NO(WS-0011-T11-INDEX)
                TO WS-8000-TRAN-SEQ-NO
              MOVE WS-LITERAL-UNIT-OPT-CD TO WS-8000-FIELD-NAME1
              MOVE WS-0011-TBL-UNIT-OPT-CD(WS-0011-T11-INDEX)
                TO WS-8000-BAD-DATA1
              MOVE WS-3365-CORRECT-UNIT-ORG TO WS-8000-CORR-DATA1
              MOVE 11 TO WS-8000-TRAN-TYPE
              MOVE WS-0011-TBL-POLICY-NO(WS-0011-T11-INDEX)
                TO WS-8000-POLICY-NO
              MOVE 3365 TO WS-8000-PARAGRAPH-NO
              MOVE WS-0011-TBL-LOCATION-COUNTY(WS-0011-T11-INDEX)
                TO WS-8000-LOC-COUNTY
              MOVE WS-0011-TBL-INSURANCE-PLAN-CD(WS-0011-T11-INDEX)
                TO WS-8000-INSURANCE-PLAN-ID
              MOVE WS-0011-TBL-CROP-CD(WS-0011-T11-INDEX)
                TO WS-8000-CROP-CD
              MOVE WS-0011-TBL-RECORD-NUM(WS-0011-T11-INDEX)
                TO WS-8000-RECORD-NUM
              MOVE WS-LITERAL-YES TO WS-0006-REJECT-11S-FLAG
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-3365-DOLLAR-AMT-ERROR = WS-LITERAL-YES
              MOVE WS-LITERAL-YES
                TO WS-0011-TBL-TRAN-REJECTED-FLAG(WS-0011-T11-INDEX)
              MOVE WS-LITERAL-IR TO WS-8000-ERROR-TYPE
              MOVE 11079 TO WS-8000-ERROR-CODE
              MOVE WS-0011-TBL-TRAN-SEQ-NO(WS-0011-T11-INDEX)
                TO WS-8000-TRAN-SEQ-NO
              MOVE WS-LITERAL-DOLLAR-AMT-INSUR
                TO WS-8000-FIELD-NAME1
              MOVE WS-3365-BAD-DOLLAR-AMT
                TO WS-8000-BAD-DATA1
              MOVE WS-3365-CORR-DOLLAR-AMT
                TO WS-8000-CORR-DATA1
              MOVE 11 TO WS-8000-TRAN-TYPE
              MOVE WS-0011-TBL-POLICY-NO(WS-0011-T11-INDEX)
                TO WS-8000-POLICY-NO
              MOVE 3365 TO WS-8000-PARAGRAPH-NO
              MOVE WS-0011-TBL-LOCATION-COUNTY(WS-0011-T11-INDEX)
                TO WS-8000-LOC-COUNTY
              MOVE WS-0011-TBL-INSURANCE-PLAN-CD(WS-0011-T11-INDEX)
                TO WS-8000-INSURANCE-PLAN-ID
              MOVE WS-0011-TBL-CROP-CD(WS-0011-T11-INDEX)
                TO WS-8000-CROP-CD
              MOVE WS-0011-TBL-RECORD-NUM(WS-0011-T11-INDEX)
                TO WS-8000-RECORD-NUM
              MOVE WS-LITERAL-YES TO WS-0006-REJECT-11S-FLAG
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-3365-PRICE-ELECTION-ERROR = WS-LITERAL-YES
              MOVE WS-LITERAL-YES
                TO WS-0011-TBL-TRAN-REJECTED-FLAG(WS-0011-T11-INDEX)
              MOVE WS-LITERAL-IR TO WS-8000-ERROR-TYPE
              MOVE 11015 TO WS-8000-ERROR-CODE
              MOVE WS-0011-TBL-TRAN-SEQ-NO(WS-0011-T11-INDEX)
                TO WS-8000-TRAN-SEQ-NO
              MOVE WS-LITERAL-PRICE-ELECT
                TO WS-8000-FIELD-NAME1
              MOVE WS-3365-BAD-PRICE-ELECTION
                TO WS-8000-BAD-DATA1
              MOVE WS-3365-CORR-PRICE-ELECTION
                TO WS-8000-CORR-DATA1
              MOVE 11 TO WS-8000-TRAN-TYPE
              MOVE WS-0011-TBL-POLICY-NO(WS-0011-T11-INDEX)
                TO WS-8000-POLICY-NO
              MOVE 3365 TO WS-8000-PARAGRAPH-NO
              MOVE WS-0011-TBL-LOCATION-COUNTY(WS-0011-T11-INDEX)
                TO WS-8000-LOC-COUNTY
              MOVE WS-0011-TBL-INSURANCE-PLAN-CD(WS-0011-T11-INDEX)
                TO WS-8000-INSURANCE-PLAN-ID
              MOVE WS-0011-TBL-CROP-CD(WS-0011-T11-INDEX)
                TO WS-8000-CROP-CD
              MOVE WS-0011-TBL-RECORD-NUM(WS-0011-T11-INDEX)
                TO WS-8000-RECORD-NUM
              MOVE WS-LITERAL-YES TO WS-0006-REJECT-11S-FLAG
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-3365-RA-CVG-ERROR = WS-LITERAL-YES
              MOVE WS-LITERAL-YES
                TO WS-0011-TBL-TRAN-REJECTED-FLAG(WS-0011-T11-INDEX)
              MOVE WS-LITERAL-IR TO WS-8000-ERROR-TYPE
              MOVE 11094 TO WS-8000-ERROR-CODE
              MOVE WS-0011-TBL-TRAN-SEQ-NO(WS-0011-T11-INDEX)
                TO WS-8000-TRAN-SEQ-NO
              MOVE WS-LITERAL-REVENUE-CVG-LVL
                TO WS-8000-FIELD-NAME1
              MOVE WS-3365-BAD-CVG-LVL
                TO WS-8000-BAD-DATA1
              MOVE WS-3365-CORR-CVG-LVL
                TO WS-8000-CORR-DATA1
              MOVE 11 TO WS-8000-TRAN-TYPE
              MOVE WS-0011-TBL-POLICY-NO(WS-0011-T11-INDEX)
                TO WS-8000-POLICY-NO
              MOVE 3365 TO WS-8000-PARAGRAPH-NO
              MOVE WS-0011-TBL-LOCATION-COUNTY(WS-0011-T11-INDEX)
                TO WS-8000-LOC-COUNTY
              MOVE WS-0011-TBL-INSURANCE-PLAN-CD(WS-0011-T11-INDEX)
                TO WS-8000-INSURANCE-PLAN-ID
              MOVE WS-0011-TBL-CROP-CD(WS-0011-T11-INDEX)
                TO WS-8000-CROP-CD
              MOVE WS-0011-TBL-RECORD-NUM(WS-0011-T11-INDEX)
                TO WS-8000-RECORD-NUM
              MOVE WS-LITERAL-YES TO WS-0006-REJECT-11S-FLAG
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF.


       3365-CHECK-COVERAGE-EXIT.
           EXIT.





