      ***************************************************************
      * File:      IR3370.CBL
      * Author:    Laura Dittamo/Mike Ray
      * Date:      3/27/96
      * Purpose:
      *    This validation routine ensures that the coverage level
      *    percent is the same for all type 11 transactions which are
      *    either high risk land insured under CAT coverage
      *    (High Risk = 1 and Coverage Flag = 'C') or have the same
      *    crop-crop/policy type combination in a Location County.
      ***************************************************************

       3370-SAME-CVG-LVL-PCT-T11.

      $IF DEBUG-SW DEFINED
           DISPLAY '3370-VALIDATING SAME COVERAGE LEVEL PERCENT FOR T11'
           UPON CONSOLE
      $END

      *****************************************************
      *    INITIALIZE LOCAL VARIABLES                     *
      *****************************************************
           INITIALIZE WS-3370-WORK

      *****************************************************
      *    CHECK PRE-CONDITIONS                           *
      *****************************************************
           IF WS-0011-T11-REC-COUNT <= 1
              GO TO 3370-SAME-CVG-LVL-PCT-T11-EXIT
           END-IF

      $IF DEBUG-SW DEFINED
           DISPLAY 'TYPE 11(01)= ', WS-0011-T11-RECORD(1)
           UPON CONSOLE
           DISPLAY 'TYPE 11(02)= ', WS-0011-T11-RECORD(2)
           UPON CONSOLE
           DISPLAY 'TYPE 11(03)= ', WS-0011-T11-RECORD(3)
           UPON CONSOLE
           DISPLAY 'TYPE 11(04)= ', WS-0011-T11-RECORD(4)
           UPON CONSOLE
           DISPLAY 'TYPE 11(05)= ', WS-0011-T11-RECORD(5)
           UPON CONSOLE.
      $END

      **   REJECT ANY TYPE 11 TRANSACTIONS THAT DO NOT HAVE THE SAME
      **   COVERAGE LEVEL PERCENT FOR DUAL COVERAGE 1 CAT RECORDS OR
      **   CROP/CROP-POLICY TYPE IN A LOCATION COUNTY.
      $IF DEBUG-SW DEFINED
           DISPLAY "WS-0006-CAT-AND-DUAL-CVG-EXIST = "
               WS-0006-CAT-AND-DUAL-CVG-EXIST 
      $END
           IF WS-0006-CAT-AND-DUAL-CVG-EXIST <> WS-LITERAL-YES
              PERFORM 3370-CHECK-CVG-LVL-PCT
                 THRU 3370-CHECK-CVG-LVL-PCT-EXIT
                 WITH TEST AFTER
              VARYING WS-0011-T11-INT-INDEX
                 FROM 1 BY 1
                UNTIL WS-0011-T11-INT-INDEX = WS-0011-T11-REC-COUNT
           ELSE

      **  GET A CAT-CVG-LVL-% AND COMPARE IT TO ALL OTHER CAT-CVG-LVL-%s
      **  IF ANY ARE DIFFERENT - REJECT THEM

               MOVE 0 TO WS-3370-COMPARE-CVG-LVL-PCT
               PERFORM 3370-CHECK-CAT-PCT
                   THRU 3370-CHECK-CAT-PCT-EXIT
                       WITH TEST AFTER
                   VARYING WS-0011-T11-INDEX
                      FROM 1 BY 1
                      UNTIL WS-0011-T11-INDEX =
                           WS-0011-T11-REC-COUNT

      **  GET A NON-CAT-CVG-LVL-% AND COMPARE IT TO ALL OTHER
      **  NON-CAT-CVG-LVL-%s
      **  IF ANY ARE DIFFERENT - REJECT THEM

              MOVE 0 TO WS-3370-COMPARE-CVG-LVL-PCT
              PERFORM 3370-CHECK-NON-CAT-PCT
                   THRU 3370-CHECK-NON-CAT-PCT-EXIT
                       WITH TEST AFTER
                   VARYING WS-0011-T11-INDEX
                      FROM 1 BY 1
                      UNTIL WS-0011-T11-INDEX =
                           WS-0011-T11-REC-COUNT
           END-IF.

       3370-SAME-CVG-LVL-PCT-T11-EXIT.
           EXIT.


       3370-CHECK-CVG-LVL-PCT.

           SET WS-0011-T11-INDEX TO WS-0011-T11-INT-INDEX

           IF WS-0011-TBL-TRAN-REJECTED-FLAG(WS-0011-T11-INDEX)
              = WS-LITERAL-YES

      *       *** ERRORS WERE ENCOUNTERED WITH THIS TYPE 11.
      *       *** CHECK THE SPECIFIC NUMERIC FIELDS WHICH ARE USED TO
      *       *** CHECK THE COVERAGE LEVEL PERCENT.  ALSO CHECK ANY
      *       *** DERIVED FIELDS USED BY THIS EDIT
              IF WS-0011-TBL-COVERAGE-LEVEL-PCT(WS-0011-T11-INDEX)
                 IS NOT NUMERIC
                 OR WS-0011-TBL-LOCATION-COUNTY(WS-0011-T11-INDEX)
                 IS NOT NUMERIC
                 OR WS-0011-TBL-CROP-POLICY-TY(WS-0011-T11-INDEX)
                 EQUAL SPACES
                 GO TO 3370-CHECK-CVG-LVL-PCT-EXIT
              END-IF
           END-IF

      **   POPULATE THE COMPARISION VALUES: CROP POLICY TYPE,
      **   DUAL COVERAGE FLAG, AND COVERAGE LEVEL PERCENT.  NO COMPARISON
      **   VALUE IS NEEDED FOR CROP CODE.  THE TYPE 11 TRANSACTION TABLE
      **   ONLY HOLDS ONE CROP AT A TIME.
           MOVE WS-0011-TBL-CROP-POLICY-TY(WS-0011-T11-INDEX)
             TO WS-3370-COMPARE-CROP-POLICY-TY
           MOVE WS-0011-TBL-COVERAGE-LEVEL-PCT(WS-0011-T11-INDEX)
             TO WS-3370-COMPARE-CVG-LVL-PCT
                WS-3370-COMPARE-CVG-LVL-PCT-x
           MOVE WS-0011-TBL-LOCATION-COUNTY(WS-0011-T11-INDEX)
             TO WS-3370-COMPARE-LOC-COUNTY
           move WS-0011-TBL-INSURANCE-PLAN-CD(WS-0011-T11-INDEX)
             to WS-3370-COMPARE-INS-PLAN-CD

      **   SAVE THE CURRENT VALUE OF THE INDEX.
           MOVE WS-0011-T11-INT-INDEX
             TO WS-3370-MAIN-LOOP-INT-INDEX

      **   LOOP THRU THE TYPE 11 TRAN TABLE.  SKIP ALL REJECTED RECORDS
      **   WITH NON-NUMERIC DATA IN FIELDS USED FOR COMPARISON.
      **   FOR EACH ROW COMPARE CROP POLICY TYPE AND DUAL COVERAGE WITH THE
      **   STORED COMPARISON VALUES.  WHEN THESE MATCH, COMPARE THE TABLE VALUE
      **   FOR COVERAGE LEVEL PERCENT WITH THE STORED COVERAGE LEVEL PERCENT.
      **   IF THE COVERAGE LEVEL PERCENT DOES NOT MATCH, REJECT THAT ROW.

           PERFORM 3370-COMPARE-CVG-LVL-PCT
              THRU 3370-COMPARE-CVG-LVL-PCT-EXIT
              WITH TEST AFTER
           VARYING WS-0011-T11-INT-INDEX
              FROM 1 BY 1
             UNTIL WS-0011-T11-INT-INDEX = WS-0011-T11-REC-COUNT

      **  RESTORE THE MAIN LOOP INDEX VALUE
          MOVE WS-3370-MAIN-LOOP-INT-INDEX
            TO WS-0011-T11-INT-INDEX
          SET WS-0011-T11-INDEX TO WS-0011-T11-INT-INDEX.

       3370-CHECK-CVG-LVL-PCT-EXIT.
           EXIT.

       3370-CHECK-CAT-PCT.
           IF WS-0011-TBL-COVERAGE-FLG(WS-0011-T11-INDEX)
               = 'C'
             IF WS-3370-COMPARE-CVG-LVL-PCT = 0
      ** GET FIRST CVG LVL PERCENT
               MOVE WS-0011-TBL-COVERAGE-LEVEL-PCT
                 (WS-0011-T11-INDEX)
                   TO WS-3370-COMPARE-CVG-LVL-PCT
                      WS-3370-COMPARE-CVG-LVL-PCT-x
             ELSE
               IF WS-0011-TBL-COVERAGE-LEVEL-PCT
                   (WS-0011-T11-INDEX)
                   <> WS-3370-COMPARE-CVG-LVL-PCT
                  MOVE WS-LITERAL-IR TO WS-8000-ERROR-TYPE
                  MOVE 11 TO WS-8000-TRAN-TYPE
                  MOVE 11036 TO WS-8000-ERROR-CODE
                  MOVE 3370 TO WS-8000-PARAGRAPH-NO
                  PERFORM 8007-LOAD-IR-TABLE-ERRORS
                     THRU 8007-LOAD-IR-TABLE-ERRORS-EXIT
                  MOVE 'CAT CVG LVL%' TO WS-8000-FIELD-NAME1
                  MOVE SPACES
                    TO WS-8000-BAD-DATA1
                  MOVE SPACES
                    TO WS-8000-CORR-DATA1
                  PERFORM 8000-RECORD-TRAN-ERROR
                     THRU 8000-RECORD-TRAN-ERROR-EXIT
                  END-IF
               END-IF
           END-IF.
       3370-CHECK-CAT-PCT-EXIT.
           EXIT.

       3370-CHECK-NON-CAT-PCT.
           IF WS-0011-TBL-COVERAGE-FLG(WS-0011-T11-INDEX)
               <> 'C'
             IF WS-3370-COMPARE-CVG-LVL-PCT = 0
      ** GET FIRST CVG LVL PERCENT
               MOVE WS-0011-TBL-COVERAGE-LEVEL-PCT
                 (WS-0011-T11-INDEX)
                   TO WS-3370-COMPARE-CVG-LVL-PCT
                      WS-3370-COMPARE-CVG-LVL-PCT-x
             ELSE
               IF WS-0011-TBL-COVERAGE-LEVEL-PCT
                   (WS-0011-T11-INDEX)
                   <> WS-3370-COMPARE-CVG-LVL-PCT
                  MOVE WS-LITERAL-IR TO WS-8000-ERROR-TYPE
                  MOVE 11 TO WS-8000-TRAN-TYPE
                  MOVE 11037 TO WS-8000-ERROR-CODE
                  MOVE 3370 TO WS-8000-PARAGRAPH-NO
                  PERFORM 8007-LOAD-IR-TABLE-ERRORS
                     THRU 8007-LOAD-IR-TABLE-ERRORS-EXIT
                  MOVE 'NON-CAT CVG LVL%' TO WS-8000-FIELD-NAME1
                  MOVE WS-0011-TBL-COVERAGE-LEVEL-PCT
                   (WS-0011-T11-INDEX)
                    TO WS-8000-BAD-DATA1
                  MOVE WS-3370-COMPARE-CVG-LVL-PCT-X
                    TO WS-8000-CORR-DATA1
                  PERFORM 8000-RECORD-TRAN-ERROR
                     THRU 8000-RECORD-TRAN-ERROR-EXIT
                  END-IF
               END-IF
           END-IF.
       3370-CHECK-NON-CAT-PCT-EXIT.
           EXIT.


       3370-COMPARE-CVG-LVL-PCT.
           SET WS-0011-T11-INDEX TO WS-0011-T11-INT-INDEX

           IF WS-0011-TBL-TRAN-REJECTED-FLAG(WS-0011-T11-INDEX)
              = WS-LITERAL-YES
      *       *** ERRORS WERE ENCOUNTERED WITH THIS TYPE 11.
      *       *** CHECK THE SPECIFIC NUMERIC FIELDS WHICH ARE USED TO
      *       *** CHECK THE COVERAGE LEVEL PERCENT
              IF WS-0011-TBL-COVERAGE-LEVEL-PCT(WS-0011-T11-INDEX)
                 IS NOT NUMERIC
                 OR WS-0011-TBL-LOCATION-COUNTY(WS-0011-T11-INDEX)
                 IS NOT NUMERIC
                 OR WS-0011-TBL-CROP-POLICY-TY(WS-0011-T11-INDEX)
                 = SPACES
                 GO TO 3370-COMPARE-CVG-LVL-PCT-EXIT
              END-IF
           END-IF

      $IF DEBUG-SW DEFINED
           DISPLAY 'T11 CROP POLICY TYPE = ',
           WS-0011-TBL-CROP-POLICY-TY(WS-0011-T11-INDEX)
           UPON CONSOLE
           DISPLAY 'COMPARE CPT = ', WS-3370-COMPARE-CROP-POLICY-TY
           UPON CONSOLE
           display 'T11 INS CD = '
           WS-0011-tbl-insurance-plan-cd(WS-0011-T11-INDEX)
           upon console
           display 'COMPARE INS CD = ', WS-3370-COMPARE-INS-PLAN-CD
           upon console
           display 'T11 CVG LVL = ',
           WS-0011-TBL-COVERAGE-LEVEL-PCT(WS-0011-T11-INDEX)
           display 'COMPARE CVG LVL = ', WS-3370-COMPARE-CVG-LVL-PCT-x
           upon console
      $END

           IF WS-0011-TBL-CROP-POLICY-TY(WS-0011-T11-INDEX) =
              WS-3370-COMPARE-CROP-POLICY-TY AND
              WS-0011-TBL-LOCATION-COUNTY(WS-0011-T11-INDEX) =
              WS-3370-COMPARE-LOC-COUNTY and
            ((WS-3370-COMPARE-INS-PLAN-CD <> ws-literal-ra and
              WS-0011-tbl-insurance-plan-cd(WS-0011-T11-INDEX) <>
              ws-literal-ra) or
             (WS-3370-COMPARE-INS-PLAN-CD = ws-literal-ra and
              WS-0011-tbl-insurance-plan-cd(WS-0011-T11-INDEX)
              = ws-literal-ra))
      **  WHEN THE CURRENT ROW HAS A MATCHING CROP POLICY TYPE AND
      **  DUAL COVERAGE FLAG SETTING, COMPARE COVERAGE LEVEL PERCENT.
      **  IF THE COVERAGE LEVEL PERCENT DOES NOT MATCH,
      **  REJECT ALL TYPE 11S WHICH MATCH THE CURRENT
      **  COMPARISON VALUES FOR CROP POLICY TYPE, DUAL COVERAGE
      **  FLAG, AND LOCATION COUNTY.

              IF WS-0011-TBL-COVERAGE-LEVEL-PCT(WS-0011-T11-INDEX) <>
                 WS-3370-COMPARE-CVG-LVL-PCT

      $IF DEBUG-SW DEFINED
           DISPLAY 'IR3370 T11 COVERAGE LEVEL PERCENT DOES NOT MATCH '
           WS-3370-COMPARE-CVG-LVL-PCT, ' ',
           WS-0011-TBL-COVERAGE-LEVEL-PCT(WS-0011-T11-INDEX), ' ',
           WS-0011-TBL-CROP-CD(WS-0011-T11-INDEX), ' ',
           WS-0011-TBL-POLICY-NUM(WS-0011-T11-INDEX), ' ',
           WS-0011-TBL-UNIT-NUM(WS-0011-T11-INDEX)
           UPON CONSOLE
      $END
                 MOVE WS-0011-TBL-COVERAGE-LEVEL-PCT(WS-0011-T11-INDEX)
                    TO WS-8000-BAD-DATA1
                 MOVE WS-3370-COMPARE-CVG-LVL-PCT-X
                    TO WS-8000-CORR-DATA1
                 PERFORM 3370-REJECT-RELATED-11S
                    THRU 3370-REJECT-RELATED-11S-EXIT
                    WITH TEST AFTER
                 VARYING WS-0011-T11-INT-INDEX FROM 1 BY 1
                   UNTIL WS-0011-T11-INT-INDEX = WS-0011-T11-REC-COUNT
              END-IF
           END-IF.

       3370-COMPARE-CVG-LVL-PCT-EXIT.
           EXIT.


       3370-REJECT-RELATED-11S.

           SET WS-0011-T11-INDEX TO WS-0011-T11-INT-INDEX

           IF WS-0011-TBL-TRAN-REJECTED-FLAG(WS-0011-T11-INDEX)
              = WS-LITERAL-YES
              GO TO 3370-REJECT-RELATED-11S-EXIT
           END-IF

           IF WS-0011-TBL-CROP-POLICY-TY(WS-0011-T11-INDEX) =
              WS-3370-COMPARE-CROP-POLICY-TY AND
              WS-0011-TBL-LOCATION-COUNTY(WS-0011-T11-INDEX) =
              WS-3370-COMPARE-LOC-COUNTY
              MOVE WS-LITERAL-YES
                TO WS-0011-TBL-TRAN-REJECTED-FLAG(WS-0011-T11-INDEX)
      *       ** ALL TYPE 11 RECORDS FOR THE CROP POLICY MUST HAVE
      *       ** THE SAME COVERAGE LEVEL PERCENT.
              MOVE 11037 TO WS-8000-ERROR-CODE
              MOVE WS-LITERAL-IR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-CVG-LVL-PCT TO WS-8000-FIELD-NAME1
              MOVE spaces TO WS-8000-FIELD-NAME1
      *       MOVE WS-0011-TBL-COVERAGE-LEVEL-PCT(WS-0011-T11-INDEX)
              MOVE SPACES
                TO WS-8000-BAD-DATA1
      *       MOVE WS-3370-COMPARE-CVG-LVL-PCT-x
              MOVE SPACES
                TO WS-8000-CORR-DATA1
              MOVE WS-0011-TBL-TRAN-SEQ-NO(WS-0011-T11-INDEX)
                TO WS-8000-TRAN-SEQ-NO
              MOVE 3370 TO WS-8000-PARAGRAPH-NO
              MOVE 11 TO WS-8000-TRAN-TYPE
              MOVE WS-0011-TBL-POLICY-NO(WS-0011-T11-INDEX)
                TO WS-8000-POLICY-NO
              MOVE WS-0011-TBL-LOCATION-COUNTY(WS-0011-T11-INDEX)
                TO WS-8000-LOC-COUNTY
              MOVE WS-0011-TBL-INSURANCE-PLAN-CD(WS-0011-T11-INDEX)
                TO WS-8000-INSURANCE-PLAN-ID
              MOVE WS-0011-TBL-CROP-CD(WS-0011-T11-INDEX)
                TO WS-8000-CROP-CD
              MOVE WS-0011-TBL-RECORD-NUM(WS-0011-T11-INDEX)
                TO WS-8000-RECORD-NUM
              MOVE WS-LITERAL-YES TO WS-0006-REJECT-11S-FLAG
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF.

       3370-REJECT-RELATED-11S-EXIT.
           EXIT.


