      *****************************************************************
      * FILE:      IR3375.CBL                                         *
      * AUTHOR:    CHERYL D. WOOD                                     *
      * DATE:      04/11/96                                           *
      * PURPOSE:   VALIDATES THE TYPE 11 TABLE TO ENSURE THAT THERE   *
      *            IS A CORRESPONDING 15 RECORD FOR EVERY 11 THAT     *
      *            REQUIRES ONE.                                      *
      *                                                               *
      *            SPECIFIC INSURANCE PLANS REQUIRE YIELD (15)        *
      *            RECORDS. THESE CROP PLANS INCLUDE:                 *
      *                                                               *
      *            INCOME PROTECTION (IP)                             *
      *            CROP REVENUE COVERAGE (CRC)                        *
      *            APH AREA SPAN CROPS                                *
      *            APH CROPS                                          *
      *            APH SPAN CROPS                                     *
      *            PREVENTED PLANTING                                 *
      *            AVOCADO REVENUE COVERAGE (ARC)                     *
      *                                                               *
      *            SPECIFIC CROPS REQUIRE YIELD (15) RECORDS.         *
      *            MALT BARLEY TYPE PRACTICE OPTION A REQUIRES A 15.  *
      *                                                               *
      *            THE FOLLOWING FIELDS EXIST ON BOTH TYPE 11 AND 15: *
      *            RATE STATE, RATE COUNTY,                           *
      *            AND ** INSURANCE PLAN.                             *
      *                                                               *
      *            THIS MODULE COMPARES THE VALUES OF THESE FIELDS;   *
      *            THE VALUES MUST MATCH ELSE AN ERROR IS RECORDED.   *
      *            ** WHEN THE 11 HAS A PREVENTED PLANTING INSURANCE  *
      *               PLAN THE CORRESPONDING 15 WILL BE NORMAL APH    *
      *               (90).                                           *
      *                                                               *
      *            THIS MODULE ALSO CONTAINS THE FOLLOWING EDITS:     *
      *            VALIDATE MALT BARLEY TYPE 15                       *
      *            VALIDATE THE YIELD LIMITATION FLAG                 *
      *            VALIDATE PREMIUM RATE SURCHARGE                    *
      *            VALIDATE RATE CLASS                                *
      *                                                               *
      *      *** THE RATE STATE/COUNTY EDITS HAVE BEEN SUSPENDED **   *
      *          12/5/97 by keith begley                              *
      *****************************************************************

       3375-VAL-RELATED-TYPE-15.

      $IF DEBUG-SW DEFINED
           DISPLAY '3375-VALIDATING RELATED TYPE 15 RECORDS'
           UPON CONSOLE
      $END

      $IF DEBUG-SW DEFINED
           DISPLAY 'T15(01)= ', WS-0015-TBL-TYPE-15(1)
           UPON CONSOLE
           DISPLAY 'T15(02)= ', WS-0015-TBL-TYPE-15(2)
           UPON CONSOLE
           DISPLAY 'T15(03)= ', WS-0015-TBL-TYPE-15(3)
           UPON CONSOLE
           DISPLAY 'T15(04)= ', WS-0015-TBL-TYPE-15(4)
           UPON CONSOLE
           DISPLAY 'T15(05)= ', WS-0015-TBL-TYPE-15(5)
           UPON CONSOLE
      $END

      *****************************************************
      *    INITIALIZE LOCAL & OUTPUT VARIABLES            *
      *****************************************************
           INITIALIZE WS-3375-LOCAL

      *****************************************************
      *               VALIDATE T11 TABLE                  *
      *****************************************************

           IF WS-0011-T11-REC-COUNT > 0 THEN
              PERFORM 3375-SEARCH-TABLE-11
                 THRU 3375-SEARCH-TABLE-11-EXIT
                 WITH TEST AFTER
              VARYING WS-0011-T11-INT-INDEX FROM 1 BY 1
                UNTIL WS-0011-T11-INT-INDEX = WS-0011-T11-REC-COUNT
           END-IF.

       3375-VAL-RELATED-TYPE-15-EXIT.
           EXIT.


       3375-SEARCH-TABLE-11.

           SET WS-0011-T11-INDEX TO WS-0011-T11-INT-INDEX
      $IF DEBUG-SW DEFINED
           DISPLAY 'T11 SEQ # = ',
           WS-0011-TBL-TRAN-SEQ-NO(WS-0011-T11-INDEX)
           UPON CONSOLE
      $END

           IF WS-0011-TBL-TRAN-REJECTED-FLAG(WS-0011-T11-INDEX)
              = WS-LITERAL-YES

      ******* ERRORS WERE ENCOUNTERED WITH THIS TYPE 11.
      ******* CHECK THE SPECIFIC NUMERIC FIELDS WHICH ARE USED TO
      ******* MATCH A TYPE 11 WITH A TYPE 15.
              IF WS-0011-TBL-CROP-CD(WS-0011-T11-INDEX)
                 IS NOT NUMERIC
                 or WS-0011-TBL-BASIC-UNIT-NUM(WS-0011-T11-INDEX)
                 IS NOT NUMERIC
                 OR WS-0011-TBL-OPTIONAL-UNIT(WS-0011-T11-INDEX)
                 IS NOT NUMERIC
                 OR WS-0011-TBL-LOCATION-COUNTY(WS-0011-T11-INDEX)
                 IS NOT NUMERIC
                 OR WS-0011-TBL-YIELD(WS-0011-T11-INDEX)
                 IS NOT NUMERIC
                 OR WS-0011-TBL-INSURANCE-PLAN-CD(WS-0011-T11-INDEX)
                 IS NOT NUMERIC
                 OR ((WS-0011-TBL-CROP-CD(WS-0011-T11-INDEX) =
                     WS-LITERAL-COTTON OR
                     WS-0011-TBL-CROP-CD(WS-0011-T11-INDEX) =
                     WS-LITERAL-COTTON-XTRA-LONG) AND
                     (WS-0011-TBL-YLD-CONVR-PCT-FCTR(WS-0011-T11-INDEX)
                     IS NOT NUMERIC OR
                      WS-0011-TBL-YLD-CONVR-PCT-FCTR(WS-0011-T11-INDEX)
                     <= ZERO))
      ******* THIS RECORD CANNOT BE VALIDLY COMPARED WITH A TYPE 15
                 GO TO 3375-SEARCH-TABLE-11-EXIT
              END-IF
           END-IF

      $IF DEBUG-SW DEFINED
           DISPLAY 'T11 SEQ # = ',
           WS-0011-TBL-TRAN-SEQ-NO(WS-0011-T11-INDEX)
           UPON CONSOLE
           DISPLAY 'T11 CNTY ',
           WS-0011-TBL-LOCATION-COUNTY(WS-0011-T11-INDEX), ' TYPE ',
           WS-0011-TBL-TYPE-CD(WS-0011-T11-INDEX), ' PRACT ',
           WS-0011-TBL-PRACTICE-CD(WS-0011-T11-INDEX), ' B UNIT ',
           WS-0011-TBL-BASIC-UNIT-NUM(WS-0011-T11-INDEX), 'O UNIT ',
           WS-0011-TBL-OPTIONAL-UNIT(WS-0011-T11-INDEX), ' CVG ',
      *    WS-0011-TBL-TYPE-PRAC-OPT-CD(WS-0011-T11-INDEX), ' CVG ',
           WS-0011-TBL-COVERAGE-FLG(WS-0011-T11-INDEX), ' YLD ',
           WS-0011-TBL-YIELD(WS-0011-T11-INDEX), 'INS PLAN CD',
           WS-0011-TBL-INSURANCE-PLAN-CD(WS-0011-T11-INDEX)
           UPON CONSOLE
      $END


      **** DETERMINE WHETHER OR NOT A TYPE 15 RECORD IS REQUIRED
      **** BASED ON INSURANCE PLAN
           EVALUATE WS-0011-TBL-INSURANCE-PLAN-CD(WS-0011-T11-INDEX)
               WHEN WS-LITERAL-CRC
                  CONTINUE
               WHEN WS-LITERAL-APH-AREA-SPAN
                  CONTINUE
               WHEN WS-LITERAL-APH-AREA-PLAN
                  CONTINUE
               WHEN WS-LITERAL-APH
                  CONTINUE
               WHEN WS-LITERAL-ARC
                   CONTINUE
               WHEN OTHER
                  GO TO 3375-SEARCH-TABLE-11-EXIT
           END-EVALUATE

      **** DETERMINE WHETHER OR NOT A TYPE 15 RECORD IS REQUIRED
      **** BASED ON CROP/TYPE PRACTICE CODE -
      **** MALT BARLEY TYPE PRACTICE OPTION A REQUIRES TYPE 15 RECORDS
           IF WS-0011-TBL-CROP-CD(WS-0011-T11-INDEX) = WS-LITERAL-BARLEY
              EVALUATE WS-0011-TBL-TYPE-PRAC-OPT-CD(WS-0011-T11-INDEX)
               WHEN WS-LITERAL-MALT-BARLEY-OPT-A
                  CONTINUE
               WHEN WS-LITERAL-MALT-BARLEY-OPT-B
                  GO TO 3375-SEARCH-TABLE-11-EXIT
               WHEN OTHER
                  CONTINUE
              END-EVALUATE
           END-IF

      **** IF CROP IS COTTON, FIGURE IN SKIP ROW FACTOR
           IF WS-0011-TBL-CROP-CD(WS-0011-T11-INDEX)
            = WS-LITERAL-COTTON OR WS-LITERAL-COTTON-XTRA-LONG
            if WS-0011-TBL-YLD-CONVR-PCT-FCTR(WS-0011-T11-INDEX) = 0
              move 1 to
                WS-0011-TBL-YLD-CONVR-PCT-FCTR(WS-0011-T11-INDEX)
            end-if
              COMPUTE WS-3375-T11-COTTON-YLD ROUNDED =
                (WS-0011-TBL-YIELD(WS-0011-T11-INDEX) /
                 WS-0011-TBL-YLD-CONVR-PCT-FCTR(WS-0011-T11-INDEX))
              END-COMPUTE
           END-IF
      *****************************************************
      *               FIND MATCHING T15                   *
      *****************************************************

           MOVE WS-LITERAL-NO TO WS-3375-MATCH-SWITCH
           IF WS-0015-T15-REC-COUNT > 0
              PERFORM 3375-SEARCH-RECNO-15
                 THRU 3375-SEARCH-RECNO-15-EXIT
                 WITH TEST AFTER
              VARYING WS-0015-T15-INT-INDEX FROM 1 BY 1
                UNTIL WS-0015-T15-INT-INDEX = WS-0015-T15-REC-COUNT

                   OR WS-3375-MATCH-SWITCH = WS-LITERAL-YES

              IF WS-3375-MATCH-SWITCH = WS-LITERAL-YES
                 CONTINUE
              ELSE
           IF WS-0015-T15-REC-COUNT > 0
              PERFORM 3375-SEARCH-TABLE-15
                 THRU 3375-SEARCH-TABLE-15-EXIT
                 WITH TEST AFTER
              VARYING WS-0015-T15-INT-INDEX FROM 1 BY 1
                UNTIL WS-0015-T15-INT-INDEX = WS-0015-T15-REC-COUNT
                   OR WS-3375-MATCH-SWITCH = WS-LITERAL-YES
              END-IF
           END-IF
           END-IF

      *****************************************************
      *               NO MATCHING TYPE 15                 *
      *****************************************************
           IF WS-3375-MATCH-SWITCH = WS-LITERAL-NO
              MOVE WS-LITERAL-IR TO WS-8000-ERROR-TYPE
              MOVE 11065 TO WS-8000-ERROR-CODE
              MOVE 3375 TO WS-8000-PARAGRAPH-NO
              MOVE 'NO MATCHING T15' TO WS-8000-FIELD-NAME1
              MOVE 'MATCHING T15' TO WS-8000-CORR-DATA1
              MOVE 11 TO WS-8000-TRAN-TYPE
              PERFORM 8007-LOAD-IR-TABLE-ERRORS
                 THRU 8007-LOAD-IR-TABLE-ERRORS-EXIT
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
              MOVE WS-LITERAL-YES TO WS-0006-REJECT-11S-FLAG
              GO TO 3375-SEARCH-TABLE-11-EXIT
           END-IF

      *****************************************************
      *           MATCHING TYPE 15 IS REJECTED            *
      *****************************************************
           IF WS-0015-TBL-TRAN-REJECTED-FLAG(WS-0015-T15-INDEX)
              = WS-LITERAL-YES
              MOVE WS-LITERAL-IR TO WS-8000-ERROR-TYPE
              MOVE 11 TO WS-8000-TRAN-TYPE
              MOVE 11066 TO WS-8000-ERROR-CODE
              MOVE 3375 TO WS-8000-PARAGRAPH-NO
              PERFORM 8007-LOAD-IR-TABLE-ERRORS
                 THRU 8007-LOAD-IR-TABLE-ERRORS-EXIT
              MOVE 'T15 SEQ NO' TO WS-8000-FIELD-NAME1
              MOVE WS-0015-TBL-TRAN-SEQ-NO(WS-0015-T15-INDEX)
                TO WS-8000-CORR-DATA1
              MOVE WS-0011-TBL-TRAN-SEQ-NO(WS-0011-T11-INDEX)
                TO WS-8000-TRAN-SEQ-NO
              MOVE WS-LITERAL-YES TO WS-0006-REJECT-11S-FLAG
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
              GO TO 3375-SEARCH-TABLE-11-EXIT
           END-IF

      *****************************************************
      *           VALIDATE MATCHING T11-T15 FIELDS        *
      *****************************************************
      *    VALIDATE THE TYPE 15 FOR MALT BARLEY
           IF WS-0011-TBL-CROP-CD(WS-0011-T11-INDEX)
              = WS-LITERAL-BARLEY AND
              WS-0011-TBL-TYPE-PRAC-OPT-CD(WS-0011-T11-INDEX)
              = WS-LITERAL-MALT-BARLEY-OPT-A
              PERFORM 3375-VAL-MALT-BARLEY-15
                 THRU 3375-VAL-MALT-BARLEY-15-EXIT
           END-IF

      *    VALIDATE T15 YIELD LIMITATION FLAG
           PERFORM 3375-VAL-YIELD-LIM-FLAG
              THRU 3375-VAL-YIELD-LIM-FLAG-EXIT

      *    VALIDATE T11 PREMIUM RATE SURCHARGE
           PERFORM 3375-VAL-PREM-RT-SURCHG
              THRU 3375-VAL-PREM-RT-SURCHG-EXIT

      *    VALIDATE T11 RATE CLASSIFICATION
      **** IF CROP IS COTTON, FIGURE IN SKIP ROW FACTOR
           IF WS-0015-TBL-CROP-CD(WS-0015-T15-INDEX)
            = WS-LITERAL-COTTON OR WS-LITERAL-COTTON-XTRA-LONG
            if WS-0011-TBL-YLD-CONVR-PCT-FCTR(WS-0011-T11-INDEX) = 0
              move 1 to
                WS-0011-TBL-YLD-CONVR-PCT-FCTR(WS-0011-T11-INDEX)
            end-if
              COMPUTE WS-3375-T15-COTTON-YLD ROUNDED =
                (WS-0015-TBL-AVG-APH-YIELD(WS-0015-T15-INDEX) *
                 WS-0011-TBL-YLD-CONVR-PCT-FCTR(WS-0011-T11-INDEX))
              END-COMPUTE
           END-IF
           PERFORM 3375-VAL-RATE-CLASS
              THRU 3375-VAL-RATE-CLASS-EXIT.

       3375-SEARCH-TABLE-11-EXIT.
           EXIT.



       3375-SEARCH-TABLE-15.

           SET WS-0015-T15-INDEX TO WS-0015-T15-INT-INDEX

           IF WS-0015-TBL-TRAN-REJECTED-FLAG(WS-0015-T15-INDEX)
              = WS-LITERAL-YES

      ******* ERRORS WERE ENCOUNTERED WITH THIS TYPE 15.
      ******* CHECK THE SPECIFIC NUMERIC FIELDS WHICH ARE USED TO
      ******* MATCH A TYPE 11 WITH A TYPE 15.
              IF WS-0015-TBL-CROP-CD(WS-0015-T15-INDEX)
                 IS NOT NUMERIC
                 OR WS-0015-TBL-BASIC-UNIT-NUM(WS-0015-T15-INDEX)
                 IS NOT NUMERIC
                 OR WS-0015-TBL-OPTIONAL-UNIT(WS-0015-T15-INDEX)
                 IS NOT NUMERIC
                 OR WS-0015-TBL-LOCATION-COUNTY(WS-0015-T15-INDEX)
                 IS NOT NUMERIC
                 OR WS-0015-TBL-APPROVED-YIELD(WS-0015-T15-INDEX)
                 IS NOT NUMERIC
                 OR WS-0015-TBL-INSURANCE-PLAN-CD(WS-0015-T15-INDEX)
                 IS NOT NUMERIC
      ******* THIS RECORD CANNOT BE VALIDLY COMPARED WITH A TYPE 11
                 GO TO 3375-SEARCH-TABLE-15-EXIT
              END-IF
           END-IF

      $IF DEBUG-SW DEFINED
           DISPLAY 'T15 CNTY ',
           WS-0015-TBL-LOCATION-COUNTY(WS-0015-T15-INDEX), ' TYPE ',
           WS-0015-TBL-TYPE-CD(WS-0015-T15-INDEX), ' PRACT ',
           WS-0015-TBL-PRACTICE-CD(WS-0015-T15-INDEX), ' B UNIT ',
           WS-0015-TBL-BASIC-UNIT-NUM(WS-0015-T15-INDEX), ' O UNIT ',
           WS-0015-TBL-OPTIONAL-UNIT(WS-0015-T15-INDEX), ' CVG ',
           WS-0015-TBL-COVERAGE-FLG(WS-0015-T15-INDEX), ' YLD ',
           WS-0015-TBL-APPROVED-YIELD(WS-0015-T15-INDEX), 'INS PLAN',
           WS-0015-TBL-INSURANCE-PLAN-CD(WS-0015-T15-INDEX)
           UPON CONSOLE
      $END

           IF (WS-0015-TBL-BASIC-UNIT-NUM(WS-0015-T15-INDEX) =
              WS-0011-TBL-BASIC-UNIT-NUM(WS-0011-T11-INDEX)) AND
              (WS-0015-TBL-OPTIONAL-UNIT(WS-0015-T15-INDEX) =
              WS-0011-TBL-OPTIONAL-UNIT(WS-0011-T11-INDEX)) AND
              (WS-0015-TBL-TYPE-CD(WS-0015-T15-INDEX) =
              WS-0011-TBL-TYPE-CD(WS-0011-T11-INDEX)) AND
              (WS-0015-TBL-PRACTICE-CD(WS-0015-T15-INDEX) =
              WS-0011-TBL-PRACTICE-CD(WS-0011-T11-INDEX)) AND
              (WS-0015-TBL-COVERAGE-FLG(WS-0015-T15-INDEX) =
              WS-0011-TBL-COVERAGE-FLG(WS-0011-T11-INDEX)) AND
              (WS-0015-TBL-LOCATION-COUNTY(WS-0015-T15-INDEX) =
              WS-0011-TBL-LOCATION-COUNTY (WS-0011-T11-INDEX)) AND

            ((WS-0015-TBL-APPROVED-YIELD(WS-0015-T15-INDEX) =
               WS-0011-TBL-YIELD(WS-0011-T11-INDEX)) OR

              (WS-0011-TBL-LOW-YIELD(WS-0011-T11-INDEX) <
               WS-0015-TBL-AVG-APH-YIELD(WS-0015-T15-INDEX) AND
               WS-0011-TBL-HIGH-YIELD(WS-0011-T11-INDEX) >
               WS-0015-TBL-AVG-APH-YIELD(WS-0015-T15-INDEX)) OR

               (WS-0015-TBL-CROP-CD(WS-0015-T15-INDEX) =
                WS-LITERAL-COTTON OR WS-LITERAL-COTTON-XTRA-LONG AND
                WS-0015-TBL-APPROVED-YIELD(WS-0015-T15-INDEX) =
                WS-3375-T11-COTTON-YLD) OR

               (WS-0015-TBL-INSURANCE-PLAN-CD(WS-0015-T15-INDEX) =
                WS-LITERAL-ARC AND
                WS-0015-TBL-FARM-APR-AVG-REV(WS-0015-T15-INDEX) =
                WS-0011-TBL-DOLLAR-AMT-INSUR(WS-0011-T11-INDEX))) AND

              (WS-0015-TBL-INSURANCE-PLAN-CD(WS-0015-T15-INDEX) =
              WS-0011-TBL-INSURANCE-PLAN-CD(WS-0011-T11-INDEX)) AND

              ((WS-0015-TBL-RECORD-NUM(WS-0015-T15-INDEX) > 0 AND
                WS-0015-TBL-RECORD-NUM(WS-0015-T15-INDEX)
                = WS-0011-TBL-TYPE15-REC-NO(WS-0011-T11-INDEX)) OR


              (WS-0011-TBL-PREM-RATE-SURCHG(WS-0011-T11-INDEX)
                    = SPACES AND
               WS-0015-TBL-YIELD-LIMIT-FLG(WS-0015-T15-INDEX) = 1 OR
               WS-0015-TBL-YIELD-LIMIT-FLG(WS-0015-T15-INDEX) = 2 OR
               WS-0015-TBL-YIELD-LIMIT-FLG(WS-0015-T15-INDEX) = 4) OR

               (WS-0011-TBL-PREM-RATE-SURCHG(WS-0011-T11-INDEX)
                    = 'Y' AND
                WS-0015-TBL-YIELD-LIMIT-FLG(WS-0015-T15-INDEX) = 3) OR

              ((WS-0015-TBL-YIELD-LIMIT-FLG(WS-0015-T15-INDEX) = 5 OR
                WS-0015-TBL-YIELD-LIMIT-FLG(WS-0015-T15-INDEX) = 6 OR
                WS-0015-TBL-YIELD-LIMIT-FLG(WS-0015-T15-INDEX) = 7 OR
                WS-0015-TBL-YIELD-LIMIT-FLG(WS-0015-T15-INDEX) = 8)
                AND
                WS-0011-TBL-NCS-FCIC-2-FL(WS-0011-T11-INDEX) <>
                WS-LITERAL-NCS-INSURED AND
                WS-0011-TBL-NCS-FCIC-2-FL(WS-0011-T11-INDEX) <>
                WS-LITERAL-NCS-BY-LEGAL AND
                WS-0011-TBL-NCS-FCIC-2-FL(WS-0011-T11-INDEX) <>
                WS-LITERAL-NCS-BY-ASSOCIATION))

              MOVE WS-LITERAL-YES TO WS-3375-MATCH-SWITCH

           END-IF.

       3375-SEARCH-TABLE-15-EXIT.
           EXIT.


       3375-REJECT-15S-BY-UNIT.
           SET WS-0015-T15-INDEX TO WS-3375-T15-REJ-INDEX

           IF WS-0015-TBL-TRAN-REJECTED-FLAG(WS-0015-T15-INDEX)
              = WS-LITERAL-YES

      ******* ERRORS WERE ENCOUNTERED WITH THIS TYPE 15.
      ******* CHECK THE SPECIFIC NUMERIC FIELDS WHICH ARE USED TO
      ******* REJECT TYPE 15S RELATED TO A TYPE 11
              IF WS-0015-TBL-CROP-CD(WS-0015-T15-INDEX)
                 IS NOT NUMERIC
                 OR WS-0015-TBL-BASIC-UNIT-NUM(WS-0015-T15-INDEX)
                 IS NOT NUMERIC
                 OR WS-0015-TBL-OPTIONAL-UNIT(WS-0015-T15-INDEX)
                 IS NOT NUMERIC
                 OR WS-0015-TBL-LOCATION-COUNTY(WS-0015-T15-INDEX)
                 IS NOT NUMERIC
      ******* THIS RECORD CANNOT BE VALIDLY COMPARED WITH A TYPE 11
                 GO TO 3375-REJECT-15S-BY-UNIT-EXIT
              END-IF
           END-IF

           IF (WS-0015-TBL-BASIC-UNIT-NUM(WS-0015-T15-INDEX) =
              WS-0011-TBL-BASIC-UNIT-NUM(WS-0011-T11-INDEX)) AND
              (WS-0015-TBL-OPTIONAL-UNIT(WS-0015-T15-INDEX) =
              WS-0011-TBL-OPTIONAL-UNIT(WS-0011-T11-INDEX)) AND
              (WS-0015-TBL-TYPE-CD(WS-0015-T15-INDEX) =
              WS-0011-TBL-TYPE-CD(WS-0011-T11-INDEX)) AND
              (WS-0015-TBL-PRACTICE-CD(WS-0015-T15-INDEX) =
              WS-0011-TBL-PRACTICE-CD(WS-0011-T11-INDEX)) AND
              (WS-0015-TBL-COVERAGE-FLG(WS-0015-T15-INDEX) =
              WS-0011-TBL-COVERAGE-FLG(WS-0011-T11-INDEX)) AND
              (WS-0015-TBL-LOCATION-COUNTY(WS-0015-T15-INDEX) =
              WS-0011-TBL-LOCATION-COUNTY (WS-0011-T11-INDEX))
              MOVE WS-LITERAL-IR TO WS-8000-ERROR-TYPE
              MOVE 15 TO WS-8000-TRAN-TYPE
              MOVE 15084 TO WS-8000-ERROR-CODE
              MOVE 3375 TO WS-8000-PARAGRAPH-NO
              PERFORM 8007-LOAD-IR-TABLE-ERRORS
                 THRU 8007-LOAD-IR-TABLE-ERRORS-EXIT
              MOVE 'T11 SEQ NO' TO WS-8000-FIELD-NAME1
              MOVE WS-0011-TBL-TRAN-SEQ-NO(WS-0011-T11-INDEX)
                TO WS-8000-CORR-DATA1
              MOVE WS-LITERAL-YES TO WS-0006-REJECT-15S-FLAG
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF.

       3375-REJECT-15S-BY-UNIT-EXIT.
           EXIT.


       3375-VAL-MALT-BARLEY-15.

           IF WS-0015-TBL-TRAN-REJECTED-FLAG(WS-0015-T15-INDEX)
              = WS-LITERAL-YES
      ******* ERRORS WERE ENCOUNTERED WITH THIS TYPE 15.
      ******* CHECK THE SPECIFIC NUMERIC FIELDS WHICH ARE USED IN THIS EDIT
              IF WS-0015-TBL-CROP-CD(WS-0015-T15-INDEX)
                 IS NOT NUMERIC
                 OR WS-0015-TBL-YIELD-LIMIT-FLG(WS-0015-T15-INDEX)
                 IS NOT NUMERIC
                 OR WS-0015-TBL-YIELD-YEAR10(WS-0015-T15-INDEX)
                 IS NOT NUMERIC
                 GO TO 3375-VAL-MALT-BARLEY-15-EXIT
              END-IF
           END-IF

      **** VALIDATE THE CORRESPONDING MALT BARLEY TYPE 15
      ****
      **** - THERE MUST BE AT LEAST 4 YEARS OF ACTUAL YIELDS
      **** - THE YIELD LIMITATION FLAG MUST BE SET TO 4
      **** - YIELD YEAR 10 MUST NOT BE GREATER THAN CROP YEAR - 1
      ****
           MOVE WS-0015-TBL-YIELD-TYPE-YEAR1(WS-0015-T15-INDEX)
             TO WS-3375-YIELD-TYPE1
           MOVE WS-0015-TBL-YIELD-TYPE-YEAR2(WS-0015-T15-INDEX)
             TO WS-3375-YIELD-TYPE2
           MOVE WS-0015-TBL-YIELD-TYPE-YEAR3(WS-0015-T15-INDEX)
             TO WS-3375-YIELD-TYPE3
           MOVE WS-0015-TBL-YIELD-TYPE-YEAR4(WS-0015-T15-INDEX)
             TO WS-3375-YIELD-TYPE4
           MOVE WS-0015-TBL-YIELD-TYPE-YEAR5(WS-0015-T15-INDEX)
             TO WS-3375-YIELD-TYPE5
           MOVE WS-0015-TBL-YIELD-TYPE-YEAR6(WS-0015-T15-INDEX)
             TO WS-3375-YIELD-TYPE6
           MOVE WS-0015-TBL-YIELD-TYPE-YEAR7(WS-0015-T15-INDEX)
             TO WS-3375-YIELD-TYPE7
           MOVE WS-0015-TBL-YIELD-TYPE-YEAR8(WS-0015-T15-INDEX)
             TO WS-3375-YIELD-TYPE8
           MOVE WS-0015-TBL-YIELD-TYPE-YEAR9(WS-0015-T15-INDEX)
             TO WS-3375-YIELD-TYPE9
           MOVE WS-0015-TBL-YIELD-TYPE-YEAR10(WS-0015-T15-INDEX)
             TO WS-3375-YIELD-TYPE10

      **************************************************
      *        COUNT YIELD YEARS BY YIELD TYPE         *
      * THERE MUST BE AT LEAST 4 YEARS OF ACTUAL YIELDS*
      **************************************************

           SET WS-3375-YIELD-TYPE-INDEX TO 1
           PERFORM 3375-COUNT-YIELD-TYPES
              THRU 3375-COUNT-YIELD-TYPES-EXIT
              WITH TEST AFTER
           VARYING WS-3375-YIELD-TYPE-INT-INDEX FROM 1 BY 1
             UNTIL WS-3375-YIELD-TYPE-INT-INDEX = 10

           IF WS-3375-ACTUAL-COUNT < 4

      ********** REJECT THE 11
              MOVE WS-LITERAL-IR TO WS-8000-ERROR-TYPE
              MOVE 11 TO WS-8000-TRAN-TYPE
              MOVE 11084 TO WS-8000-ERROR-CODE
              MOVE 3375 TO WS-8000-PARAGRAPH-NO
              PERFORM 8007-LOAD-IR-TABLE-ERRORS
                 THRU 8007-LOAD-IR-TABLE-ERRORS-EXIT
              MOVE 'T11 MALT BARLEY'
                TO WS-8000-FIELD-NAME1
              MOVE WS-0015-TBL-CROP-CD(WS-0015-T15-INDEX)
                TO WS-8000-BAD-DATA1
              MOVE 'T15 SEQ NO' TO WS-8000-FIELD-NAME2
              MOVE WS-0015-TBL-TRAN-SEQ-NO(WS-0015-T15-INDEX)
                TO WS-8000-CORR-DATA2
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT

      ********** REJECT THE 15
              MOVE WS-LITERAL-IR TO WS-8000-ERROR-TYPE
              MOVE 15 TO WS-8000-TRAN-TYPE
              MOVE 15090 TO WS-8000-ERROR-CODE
              MOVE 3375 TO WS-8000-PARAGRAPH-NO
              PERFORM 8007-LOAD-IR-TABLE-ERRORS
                 THRU 8007-LOAD-IR-TABLE-ERRORS-EXIT
              MOVE 'T15 ACTUAL YLD YEARS'
                TO WS-8000-FIELD-NAME1
              MOVE WS-3375-ACTUAL-COUNT TO WS-8000-BAD-DATA1
              MOVE 'T11 SEQ NO' TO WS-8000-FIELD-NAME2
              MOVE 'AT LEAST 4 YEARS' TO WS-8000-CORR-DATA1
              MOVE WS-0011-TBL-TRAN-SEQ-NO(WS-0011-T11-INDEX)
                TO WS-8000-CORR-DATA2
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

      **************************************************
      *      VALIDATE THE YIELD LIMITATION FLAG        *
      *   THE YIELD LIMITATION FLAG MUST BE SET TO 4   *
      **************************************************
           IF WS-0015-TBL-YIELD-LIMIT-FLG(WS-0015-T15-INDEX)
              <> 4

      ********** REJECT THE 11
              MOVE WS-LITERAL-IR TO WS-8000-ERROR-TYPE
              MOVE 11 TO WS-8000-TRAN-TYPE
              MOVE 11085 TO WS-8000-ERROR-CODE
              MOVE 3375 TO WS-8000-PARAGRAPH-NO
              PERFORM 8007-LOAD-IR-TABLE-ERRORS
                 THRU 8007-LOAD-IR-TABLE-ERRORS-EXIT
              MOVE WS-LITERAL-IR TO WS-8000-ERROR-TYPE
              MOVE 'T11 MALT BARLEY'
                TO WS-8000-FIELD-NAME1
              MOVE WS-0015-TBL-CROP-CD(WS-0015-T15-INDEX)
                TO WS-8000-BAD-DATA1
              MOVE 'T15 SEQ NO' TO WS-8000-FIELD-NAME2
              MOVE WS-0015-TBL-TRAN-SEQ-NO(WS-0015-T15-INDEX)
                TO WS-8000-CORR-DATA2
              MOVE WS-LITERAL-YES TO WS-0006-REJECT-11S-FLAG
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT

      ********** REJECT THE 15
              MOVE WS-LITERAL-IR TO WS-8000-ERROR-TYPE
              MOVE 15 TO WS-8000-TRAN-TYPE
              MOVE 15091 TO WS-8000-ERROR-CODE
              MOVE 3375 TO WS-8000-PARAGRAPH-NO
              PERFORM 8007-LOAD-IR-TABLE-ERRORS
                 THRU 8007-LOAD-IR-TABLE-ERRORS-EXIT
              MOVE 'T15 YLD LIMIT FLG'
                TO WS-8000-FIELD-NAME1
              MOVE WS-0015-TBL-YIELD-LIMIT-FLG(WS-0015-T15-INDEX)
                TO WS-8000-BAD-DATA1
              MOVE 'T11 SEQ NO' TO WS-8000-FIELD-NAME2
              MOVE WS-0011-TBL-TRAN-SEQ-NO(WS-0011-T11-INDEX)
                TO WS-8000-CORR-DATA2
              MOVE '4' TO WS-8000-CORR-DATA1
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

      ********************************************************
      *             VALIDATE YIELD YEAR 10                   *
      * YIELD YEAR 10 MUST NOT BE GREATER THAN CROP YEAR - 1 *
      ********************************************************

           IF WS-0015-TBL-YIELD-YEAR10(WS-0015-T15-INDEX) >
              (WS-0015-TBL-CROP-YEAR(WS-0015-T15-INDEX) - 1)
      ********** REJECT THE 11
              MOVE WS-LITERAL-IR TO WS-8000-ERROR-TYPE
              MOVE 11 TO WS-8000-TRAN-TYPE
              MOVE 11086 TO WS-8000-ERROR-CODE
              MOVE 3375 TO WS-8000-PARAGRAPH-NO
              PERFORM 8007-LOAD-IR-TABLE-ERRORS
                 THRU 8007-LOAD-IR-TABLE-ERRORS-EXIT
              MOVE 'T11 MALT BARLEY'
                TO WS-8000-FIELD-NAME1
              MOVE WS-0015-TBL-CROP-CD(WS-0015-T15-INDEX)
                TO WS-8000-BAD-DATA1
              MOVE 'T15 SEQ NO' TO WS-8000-FIELD-NAME2
              MOVE WS-0015-TBL-TRAN-SEQ-NO(WS-0015-T15-INDEX)
                TO WS-8000-CORR-DATA2
              MOVE WS-LITERAL-YES TO WS-0006-REJECT-11S-FLAG
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT

      ********** REJECT THE 15
              MOVE WS-LITERAL-IR TO WS-8000-ERROR-TYPE
              MOVE 15 TO WS-8000-TRAN-TYPE
              MOVE 15092 TO WS-8000-ERROR-CODE
              MOVE 3375 TO WS-8000-PARAGRAPH-NO
              PERFORM 8007-LOAD-IR-TABLE-ERRORS
                 THRU 8007-LOAD-IR-TABLE-ERRORS-EXIT
              MOVE 'T15 YLD YR 10'
                TO WS-8000-FIELD-NAME1
              MOVE WS-0015-TBL-YIELD-YEAR10(WS-0015-T15-INDEX)
                TO WS-8000-BAD-DATA1
              STRING '< = CROP YEAR ('
               DELIMITED BY SIZE
               WS-0015-TBL-CROP-YEAR(WS-0015-T15-INDEX)
               DELIMITED BY SIZE
               ') MINUS ONE'
               DELIMITED BY SIZE
               INTO WS-8000-CORR-DATA1
              END-STRING
              MOVE 'T11 SEQ NO' TO WS-8000-FIELD-NAME2
              MOVE WS-0011-TBL-TRAN-SEQ-NO(WS-0011-T11-INDEX)
                TO WS-8000-CORR-DATA2
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF.


       3375-VAL-MALT-BARLEY-15-EXIT.
           EXIT.


       3375-COUNT-YIELD-TYPES.

           SET WS-3375-YIELD-TYPE-INDEX
            TO WS-3375-YIELD-TYPE-INT-INDEX

      $IF DEBUG-SW DEFINED
           DISPLAY 'YEAR ', WS-3375-YIELD-TYPE-INT-INDEX, ' TYPE ',
           WS-3375-TBL-YIELD-TYPE(WS-3375-YIELD-TYPE-INDEX)
           UPON CONSOLE
      $END

           EVALUATE WS-3375-TBL-YIELD-TYPE(WS-3375-YIELD-TYPE-INDEX)
               WHEN WS-LITERAL-A-YLD
                  ADD 1 TO WS-3375-ACTUAL-COUNT
               WHEN OTHER
                  CONTINUE
           END-EVALUATE.


       3375-COUNT-YIELD-TYPES-EXIT.
           EXIT.


       3375-VAL-YIELD-LIM-FLAG.

      *    THIS MODULE VALIDATES THE YIELD LIMITATION FLAG USING
      *    THE NCS/FCIC2 FLAG AND THE PREMIUM RATE SURCHARGE

           IF WS-0015-TBL-TRAN-REJECTED-FLAG(WS-0015-T15-INDEX)
              = WS-LITERAL-YES
      ******* ERRORS WERE ENCOUNTERED WITH THIS TYPE 15.
      ******* CHECK THE SPECIFIC NUMERIC FIELDS WHICH ARE USED IN THIS EDIT
              IF WS-0015-TBL-YIELD-LIMIT-FLG(WS-0015-T15-INDEX)
                 IS NOT NUMERIC
                 OR WS-0015-TBL-CROP-CD(WS-0015-T15-INDEX)
                 IS NOT NUMERIC
                 GO TO 3375-VAL-YIELD-LIM-FLAG-EXIT
              END-IF
           END-IF

      *    IF THE YIELD LIMITATION FLAG IS 5, 6, 7, OR 8
      *      THE PRODUCER CANNOT HAVE NCS RATES.

           IF (WS-0015-TBL-YIELD-LIMIT-FLG(WS-0015-T15-INDEX) = 5
              OR WS-0015-TBL-YIELD-LIMIT-FLG(WS-0015-T15-INDEX) = 6
              OR WS-0015-TBL-YIELD-LIMIT-FLG(WS-0015-T15-INDEX) = 7
              OR WS-0015-TBL-YIELD-LIMIT-FLG(WS-0015-T15-INDEX) = 8)
              AND
              (WS-0011-TBL-NCS-FCIC-2-FL(WS-0011-T11-INDEX) =
              WS-LITERAL-NCS-INSURED
              OR WS-0011-TBL-NCS-FCIC-2-FL(WS-0011-T11-INDEX) =
              WS-LITERAL-NCS-BY-LEGAL
              OR WS-0011-TBL-NCS-FCIC-2-FL(WS-0011-T11-INDEX) =
              WS-LITERAL-NCS-BY-ASSOCIATION)
      ********** REJECT THE 11
              MOVE WS-LITERAL-IR TO WS-8000-ERROR-TYPE
              MOVE 11 TO WS-8000-TRAN-TYPE
              MOVE 11088 TO WS-8000-ERROR-CODE
              MOVE 3375 TO WS-8000-PARAGRAPH-NO
              PERFORM 8007-LOAD-IR-TABLE-ERRORS
                 THRU 8007-LOAD-IR-TABLE-ERRORS-EXIT
              MOVE 'T11 NCS/FCIC2 FL'
                TO WS-8000-FIELD-NAME1
              MOVE WS-0011-TBL-NCS-FCIC-2-FL(WS-0011-T11-INDEX)
                TO WS-8000-BAD-DATA1
              MOVE 'R, P, W, F' TO WS-8000-CORR-DATA1                   ]97c-jlh
              MOVE 'T15 SEQ NO' TO WS-8000-FIELD-NAME2
              MOVE WS-0015-TBL-TRAN-SEQ-NO(WS-0015-T15-INDEX)
                TO WS-8000-CORR-DATA2
              MOVE WS-LITERAL-YES TO WS-0006-REJECT-11S-FLAG
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT

      ********** REJECT THE 15
              MOVE WS-LITERAL-IR TO WS-8000-ERROR-TYPE
              MOVE 15 TO WS-8000-TRAN-TYPE
              MOVE 15095 TO WS-8000-ERROR-CODE
              MOVE 3375 TO WS-8000-PARAGRAPH-NO
              PERFORM 8007-LOAD-IR-TABLE-ERRORS
                 THRU 8007-LOAD-IR-TABLE-ERRORS-EXIT
              MOVE 'T15 YLD LIMIT FLG'
                TO WS-8000-FIELD-NAME1
              MOVE WS-0015-TBL-YIELD-LIMIT-FLG(WS-0015-T15-INDEX)
                TO WS-8000-BAD-DATA1
              MOVE 'T11 SEQ NO' TO WS-8000-FIELD-NAME2
              MOVE WS-0011-TBL-TRAN-SEQ-NO(WS-0011-T11-INDEX)
                TO WS-8000-CORR-DATA2
              MOVE SPACES TO WS-8000-CORR-DATA1
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

      *    IF THE YIELD LIMITATION FLAG IS SET TO EITHER:
      *    - 3
      *    OR
      *    - 5, 6, 7, OR 8 AND THE CROP IS A SELECTED CATEGORY C
      *      CROP
      *    THEN THE PREMIUM RATE SURCHARGE ON THE TYPE 11 MUST BE 'Y'

           MOVE WS-0015-TBL-CROP-CD(WS-0015-T15-INDEX)
             TO WS-0009-CROP-CATEGORIES

           IF WS-0011-TBL-PREM-RATE-SURCHG(WS-0011-T11-INDEX)
              = WS-LITERAL-YES
              GO TO 3375-VAL-YIELD-LIM-FLAG-EXIT
           END-IF

      *********** THE FOLLOWING LOGIC EVALUATES THE YIELD LIMITATION
      *********** FLAG WHEN THE PREMIUM RATE SURCHARGE IS NOT 'Y'
           EVALUATE WS-0015-TBL-YIELD-LIMIT-FLG(WS-0015-T15-INDEX)
               WHEN 1
                  GO TO 3375-VAL-YIELD-LIM-FLAG-EXIT

               WHEN 2
                  GO TO 3375-VAL-YIELD-LIM-FLAG-EXIT

               WHEN 3
      *********** RECORD ERROR BELOW; PREMIUM RATE SURCHARGE SHOULD BE Y
                  CONTINUE

               WHEN 4
                  GO TO 3375-VAL-YIELD-LIM-FLAG-EXIT

               WHEN 5 THRU 8
                  IF (CATEGORY-C-CROP-0009
                     AND WS-0015-TBL-CROP-CD(WS-0015-T15-INDEX) <>
                         WS-LITERAL-BLUEBERRIES
                     AND WS-0015-TBL-CROP-CD(WS-0015-T15-INDEX) <>
                         WS-LITERAL-APPLES
                     AND WS-0015-TBL-CROP-CD(WS-0015-T15-INDEX) <>
                         WS-LITERAL-PEACHES)
      *********** RECORD ERROR BELOW; PREMIUM RATE SURCHARGE SHOULD BE Y
                     CONTINUE
                  ELSE
      *********** PREMIUM RATE SURCHARGE IS VALID FOR CROP
                     GO TO 3375-VAL-YIELD-LIM-FLAG-EXIT
                  END-IF

               WHEN OTHER
      *********** INVALID VALUE FOR YIELD LIMITATION FLAG;
      *********** TRANSACTION ERROR ALREADY RECORDED
      *********** PREMIUM RATE SURCHARGE IS VALID
                  GO TO 3375-VAL-YIELD-LIM-FLAG-EXIT
           END-EVALUATE


      ********** REJECT THE 11
           MOVE WS-LITERAL-IR TO WS-8000-ERROR-TYPE
           MOVE 11 TO WS-8000-TRAN-TYPE
           MOVE 11067 TO WS-8000-ERROR-CODE
           MOVE 3375 TO WS-8000-PARAGRAPH-NO
              PERFORM 8007-LOAD-IR-TABLE-ERRORS
                 THRU 8007-LOAD-IR-TABLE-ERRORS-EXIT
           MOVE 'T11 PREM RATE SURCHG'
             TO WS-8000-FIELD-NAME1
           MOVE WS-0011-TBL-PREM-RATE-SURCHG(WS-0011-T11-INDEX)
             TO WS-8000-BAD-DATA1
           MOVE 'Y' TO WS-8000-CORR-DATA1
           MOVE 'T15 SEQ NO' TO WS-8000-FIELD-NAME2
           MOVE WS-0015-TBL-TRAN-SEQ-NO(WS-0015-T15-INDEX)
             TO WS-8000-CORR-DATA2
           MOVE WS-LITERAL-YES TO WS-0006-REJECT-11S-FLAG
           PERFORM 8000-RECORD-TRAN-ERROR
              THRU 8000-RECORD-TRAN-ERROR-EXIT

      ********** REJECT THE 15
           MOVE WS-LITERAL-IR TO WS-8000-ERROR-TYPE
           MOVE 15 TO WS-8000-TRAN-TYPE
           MOVE 15081 TO WS-8000-ERROR-CODE
           MOVE 3375 TO WS-8000-PARAGRAPH-NO
              PERFORM 8007-LOAD-IR-TABLE-ERRORS
                 THRU 8007-LOAD-IR-TABLE-ERRORS-EXIT
           MOVE 'T15 YLD LIMIT FLG'
             TO WS-8000-FIELD-NAME1
           MOVE WS-0015-TBL-YIELD-LIMIT-FLG(WS-0015-T15-INDEX)
             TO WS-8000-BAD-DATA1
           MOVE 'T11 SEQ NO' TO WS-8000-FIELD-NAME2
           MOVE WS-0011-TBL-TRAN-SEQ-NO(WS-0011-T11-INDEX)
             TO WS-8000-CORR-DATA2
           MOVE SPACES TO WS-8000-CORR-DATA1
           PERFORM 8000-RECORD-TRAN-ERROR
              THRU 8000-RECORD-TRAN-ERROR-EXIT.


       3375-VAL-YIELD-LIM-FLAG-EXIT.
           EXIT.


       3375-VAL-PREM-RT-SURCHG.

           IF WS-0015-TBL-TRAN-REJECTED-FLAG(WS-0015-T15-INDEX)
              = WS-LITERAL-YES
      ******* ERRORS WERE ENCOUNTERED WITH THIS TYPE 15.
      ******* CHECK THE SPECIFIC NUMERIC FIELDS WHICH ARE USED IN THIS EDIT
              IF WS-0015-TBL-YIELD-LIMIT-FLG(WS-0015-T15-INDEX)
                 IS NOT NUMERIC
                 OR WS-0015-TBL-CROP-CD(WS-0015-T15-INDEX)
                 IS NOT NUMERIC
                 GO TO 3375-VAL-PREM-RT-SURCHG-EXIT
              END-IF
           END-IF

      *    IF THE PREMIUM RATE SURCHARGE IS 'Y', THE YIELD LIMITATION
      *    FLAG ON THE CORRESPONDING TYPE 15 YIELD RECORD MUST BE:
      *    - 3
      *    OR
      *    - 5, 6, 7, OR 8 AND THE CROP MUST BE ONE OF THE SELECTED
      *      CATEGORY C CROPS

           MOVE WS-0015-TBL-CROP-CD(WS-0015-T15-INDEX)
             TO WS-0009-CROP-CATEGORIES

           IF WS-0011-TBL-PREM-RATE-SURCHG(WS-0011-T11-INDEX)
              <> WS-LITERAL-YES
              GO TO 3375-VAL-PREM-RT-SURCHG-EXIT
           END-IF

      **** THE FOLLOWING LOGIC EVALUATES THE YIELD LIMITATION
      **** FLAG WHEN THE PREMIUM RATE SURCHARGE = 'Y'

           EVALUATE WS-0015-TBL-YIELD-LIMIT-FLG(WS-0015-T15-INDEX)
               WHEN 1
      *********** RECORD ERROR BELOW
                  CONTINUE

               WHEN 2
      *********** RECORD ERROR BELOW
                  CONTINUE

               WHEN 3
      *********** VALID YIELD LIMITATION FLAG
                  GO TO 3375-VAL-PREM-RT-SURCHG-EXIT

               WHEN 4
      *********** RECORD ERROR BELOW
                  CONTINUE

               WHEN 5 THRU 8
                  IF (CATEGORY-C-CROP-0009
                     AND WS-0015-TBL-CROP-CD(WS-0015-T15-INDEX) <>
                         WS-LITERAL-BLUEBERRIES
                     AND WS-0015-TBL-CROP-CD(WS-0015-T15-INDEX) <>
                         WS-LITERAL-APPLES
                     AND WS-0015-TBL-CROP-CD(WS-0015-T15-INDEX) <>
                         WS-LITERAL-PEACHES)
                     OR WS-0015-TBL-INSURANCE-PLAN-CD(WS-0015-T15-INDEX)
                      = WS-LITERAL-APH-AREA-PLAN
      *********** VALID YIELD LIMITATION FLAG
                     GO TO 3375-VAL-PREM-RT-SURCHG-EXIT
                  ELSE
      *********** RECORD ERROR BELOW; PREMIUM RATE SURCHARGE 'Y'
      *********** IS ONLY VALID FOR SELECTED CATEGORY C CROPS
                     CONTINUE
                  END-IF

               WHEN OTHER
      ********** INVALID VALUE FOR YIELD LIMITATION FLAG
      ********** RECORD ERROR BELOW
                  CONTINUE
           END-EVALUATE

      ********** REJECT THE 11
           MOVE WS-LITERAL-IR TO WS-8000-ERROR-TYPE
           MOVE 11 TO WS-8000-TRAN-TYPE
           MOVE 11087 TO WS-8000-ERROR-CODE
           MOVE 3375 TO WS-8000-PARAGRAPH-NO
           PERFORM 8007-LOAD-IR-TABLE-ERRORS
              THRU 8007-LOAD-IR-TABLE-ERRORS-EXIT
           MOVE 'T11 PREM RATE SURCHG'
             TO WS-8000-FIELD-NAME1
           MOVE WS-0011-TBL-PREM-RATE-SURCHG(WS-0011-T11-INDEX)
             TO WS-8000-BAD-DATA1
           MOVE 'NOT Y' TO WS-8000-CORR-DATA1
           MOVE 'T15 SEQ NO' TO WS-8000-FIELD-NAME2
           MOVE WS-0015-TBL-TRAN-SEQ-NO(WS-0015-T15-INDEX)
             TO WS-8000-CORR-DATA2
           MOVE WS-LITERAL-YES TO WS-0006-REJECT-11S-FLAG
           PERFORM 8000-RECORD-TRAN-ERROR
              THRU 8000-RECORD-TRAN-ERROR-EXIT

      ********** REJECT THE 15
           MOVE WS-LITERAL-IR TO WS-8000-ERROR-TYPE
           MOVE 15 TO WS-8000-TRAN-TYPE
           MOVE 15094 TO WS-8000-ERROR-CODE
           MOVE 3375 TO WS-8000-PARAGRAPH-NO
              PERFORM 8007-LOAD-IR-TABLE-ERRORS
                 THRU 8007-LOAD-IR-TABLE-ERRORS-EXIT
           MOVE 'T15 YLD LIMIT FLG'
             TO WS-8000-FIELD-NAME1
           MOVE WS-0015-TBL-YIELD-LIMIT-FLG(WS-0015-T15-INDEX)
             TO WS-8000-BAD-DATA1
           MOVE 'T11 SEQ NO' TO WS-8000-FIELD-NAME2
           MOVE WS-0011-TBL-TRAN-SEQ-NO(WS-0011-T11-INDEX)
             TO WS-8000-CORR-DATA2
           MOVE SPACES TO WS-8000-CORR-DATA1
           PERFORM 8000-RECORD-TRAN-ERROR
              THRU 8000-RECORD-TRAN-ERROR-EXIT.


       3375-VAL-PREM-RT-SURCHG-EXIT.
           EXIT.


       3375-VAL-RATE-CLASS.

           IF WS-0011-TBL-TRAN-REJECTED-FLAG(WS-0011-T11-INDEX)
              = WS-LITERAL-YES
      ******* ERRORS WERE ENCOUNTERED WITH THIS TYPE 11.
      ******* CHECK THE DERIVED FIELDS WHICH ARE USED IN THIS EDIT
              IF WS-0011-TBL-LOW-YIELD(WS-0011-T11-INDEX)
                 IS NOT NUMERIC
                 OR WS-0011-TBL-HIGH-YIELD(WS-0011-T11-INDEX)
                 IS NOT NUMERIC
                 GO TO 3375-VAL-RATE-CLASS-EXIT
              END-IF
           END-IF

           IF WS-0015-TBL-TRAN-REJECTED-FLAG(WS-0015-T15-INDEX)
              = WS-LITERAL-YES
      ******* ERRORS WERE ENCOUNTERED WITH THIS TYPE 15.
      ******* CHECK THE SPECIFIC NUMERIC FIELDS WHICH ARE USED IN THIS EDIT
              IF WS-0015-TBL-YIELD-LIMIT-FLG(WS-0015-T15-INDEX)
                 IS NOT NUMERIC
                 OR WS-0015-TBL-CROP-CD(WS-0015-T15-INDEX)
                 IS NOT NUMERIC
                 GO TO 3375-VAL-RATE-CLASS-EXIT
              END-IF
           END-IF

      *    IF THE YIELD LIMITATION FLAG ON THE 15 = 5,6,7 OR 8 AND
      *    THE CROP IS A CATEGORY B CROP, THE
      *    AVERAGE YIELD (FROM THE 15) MUST FALL WITHIN THE HIGH AND
      *    LOW YIELD RANGES INDICATED IN THE ADM FOR THE
      *    RATE CLASSIFICATION SPECIFIED ON THE TYPE 11.

           MOVE WS-0015-TBL-CROP-CD(WS-0015-T15-INDEX)
             TO WS-0009-CROP-CATEGORIES

           IF (WS-0015-TBL-YIELD-LIMIT-FLG(WS-0015-T15-INDEX) = 5
              OR WS-0015-TBL-YIELD-LIMIT-FLG(WS-0015-T15-INDEX) = 6
              OR WS-0015-TBL-YIELD-LIMIT-FLG(WS-0015-T15-INDEX) = 7
              OR WS-0015-TBL-YIELD-LIMIT-FLG(WS-0015-T15-INDEX) = 8)
              AND WS-0015-TBL-INSURANCE-PLAN-CD(WS-0015-T15-INDEX) <>
                   WS-LITERAL-APH-AREA-PLAN
              CONTINUE
           ELSE
              GO TO 3375-VAL-RATE-CLASS-EXIT
           END-IF

      **** THE LOW AND HIGH YIELDS WERE RETRIEVED IN
      **** 2342-LOOKUP-YIELD-QTY AND PLACED IN THE TYPE 11 TABLE

           IF WS-0011-TBL-LOW-YIELD(WS-0011-T11-INDEX) = ZERO OR
              WS-0011-TBL-HIGH-YIELD(WS-0011-T11-INDEX) = ZERO
              GO TO 3375-VAL-RATE-CLASS-EXIT
           END-IF

           IF WS-0015-TBL-CROP-CD(WS-0015-T15-INDEX)
              = WS-LITERAL-COTTON OR WS-LITERAL-COTTON-XTRA-LONG
              IF (WS-0011-TBL-LOW-YIELD(WS-0011-T11-INDEX) <=
                 WS-3375-T15-COTTON-YLD) AND
                 (WS-0011-TBL-HIGH-YIELD(WS-0011-T11-INDEX) >=
                  WS-3375-T15-COTTON-YLD)
                 GO TO 3375-VAL-RATE-CLASS-EXIT
              END-IF
           ELSE
               IF (WS-0011-TBL-LOW-YIELD(WS-0011-T11-INDEX) <=
                   WS-0015-TBL-AVG-APH-YIELD(WS-0015-T15-INDEX)) AND
                  (WS-0011-TBL-HIGH-YIELD(WS-0011-T11-INDEX) >=
                   WS-0015-TBL-AVG-APH-YIELD(WS-0015-T15-INDEX))
                   GO TO 3375-VAL-RATE-CLASS-EXIT
               END-IF
           END-IF

      *    *** MOVE LOW AND HIGH YIELDS TO DISPLAYABLE FIELDS
           INITIALIZE WS-3375-DISPLAY-FIELDS
           MOVE WS-0011-TBL-LOW-YIELD(WS-0011-T11-INDEX)
             TO WS-3375-DISPLAY-LOW-YIELD-X
           MOVE WS-0011-TBL-HIGH-YIELD(WS-0011-T11-INDEX)
             TO WS-3375-DISPLAY-HIGH-YIELD-X
           MOVE WS-0015-TBL-AVG-APH-YIELD(WS-0015-T15-INDEX)
             TO WS-3375-DISPLAY-APPROV-YIELD-X

      ********** REJECT THE 11
              MOVE WS-LITERAL-IR TO WS-8000-ERROR-TYPE
              MOVE 11 TO WS-8000-TRAN-TYPE
              MOVE 11072 TO WS-8000-ERROR-CODE
              MOVE 3375 TO WS-8000-PARAGRAPH-NO
              PERFORM 8007-LOAD-IR-TABLE-ERRORS
                 THRU 8007-LOAD-IR-TABLE-ERRORS-EXIT
              MOVE 'T11 RATE CLASS' TO WS-8000-FIELD-NAME1
              MOVE WS-0011-TBL-RATE-CLASS(WS-0011-T11-INDEX)
                TO WS-8000-BAD-DATA1
              STRING 'T15 AVG APH YIELD = '
                  DELIMITED BY SIZE
                  WS-3375-DISPLAY-APPROV-YIELD-X
                  DELIMITED BY SIZE
                  INTO WS-8000-CORR-DATA1
              END-STRING
              MOVE 'T15 SEQ NO' TO WS-8000-FIELD-NAME2
              MOVE WS-0015-TBL-TRAN-SEQ-NO(WS-0015-T15-INDEX)
                TO WS-8000-CORR-DATA2
              MOVE WS-LITERAL-YES TO WS-0006-REJECT-11S-FLAG
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT

      ********** REJECT THE 15
              MOVE WS-LITERAL-IR TO WS-8000-ERROR-TYPE
              MOVE 15 TO WS-8000-TRAN-TYPE
              MOVE 15079 TO WS-8000-ERROR-CODE
              MOVE 3375 TO WS-8000-PARAGRAPH-NO
              PERFORM 8007-LOAD-IR-TABLE-ERRORS
                 THRU 8007-LOAD-IR-TABLE-ERRORS-EXIT
              MOVE 'T15 AVG YLD' TO WS-8000-FIELD-NAME1
      *    ** POPULATE DISPLAY FIELD
              IF WS-0015-TBL-CROP-CD(WS-0015-T15-INDEX)
               = WS-LITERAL-COTTON OR WS-LITERAL-COTTON-XTRA-LONG
                 MOVE WS-3375-T15-COTTON-YLD
                   TO WS-3375-AVG-APH-YIELD-X
              ELSE
                 MOVE WS-0015-TBL-AVG-APH-YIELD(WS-0015-T15-INDEX)
                   TO WS-3375-AVG-APH-YIELD-X
              END-IF
              MOVE WS-3375-AVG-APH-YIELD-X TO WS-8000-BAD-DATA1
              STRING 'YIELD RANGE '
                  DELIMITED BY SIZE
                  WS-3375-DISPLAY-LOW-YIELD-X
                  DELIMITED BY SIZE
                  ' - '
                  DELIMITED BY SIZE
                  WS-3375-DISPLAY-HIGH-YIELD-X
                  DELIMITED BY SIZE
                  INTO WS-8000-CORR-DATA1
              END-STRING
              MOVE 'T11 SEQ NO' TO WS-8000-FIELD-NAME2
              MOVE WS-0011-TBL-TRAN-SEQ-NO(WS-0011-T11-INDEX)
                TO WS-8000-CORR-DATA2
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT.

       3375-VAL-RATE-CLASS-EXIT.
           EXIT.

       3375-SEARCH-RECNO-15.

           SET WS-0015-T15-INDEX TO WS-0015-T15-INT-INDEX

           IF WS-0015-TBL-TRAN-REJECTED-FLAG(WS-0015-T15-INDEX)
              = WS-LITERAL-YES
                 GO TO 3375-SEARCH-RECNO-15-EXIT
           END-IF

           IF WS-0015-TBL-RECORD-NUM(WS-0015-T15-INDEX) NUMERIC
             IF WS-0011-TBL-TYPE15-REC-NO(WS-0011-T11-INDEX) NUMERIC
               IF WS-0015-TBL-RECORD-NUM(WS-0015-T15-INDEX) =
                 WS-0011-TBL-TYPE15-REC-NO(WS-0011-T11-INDEX)
                 MOVE WS-LITERAL-YES TO WS-3375-MATCH-SWITCH
               END-IF
             END-IF
           END-IF.

       3375-SEARCH-RECNO-15-EXIT.
           EXIT.


