      ***************************************************************
      * File:      IR3380.CBL
      * Author:    Laura Dittamo
      * Date:      4/11/96
      * Purpose:
      *    A corresponding type 14 record must exist for each type
      *    11.  The following fields are used to pair type 14 records
      *    with type 11s:  Reporting Organization, Location State,
      *    Company/County, Policy Number, Crop Year, Location County,
      *    Insurance Plane, Crop Code, and Coverage Flag.
      *    Type Code was removed from the comparison at Keith's request
      *    It doesn't make sense to include it. There could be
      *    more than one Type 11 related to a single 14 -type codes
      *    do not need to match.
      *
      *    The following fields exist on both Type 11 and 14:
      *    Loc State and Loc County
      *
      *    This module compares the values of these fields; the
      *    values must match else an error is recorded.
      ***************************************************************

       3380-VAL-RELATED-TYPE-14.

      $IF DEBUG-SW DEFINED
           DISPLAY '3380-VALIDATING RELATED TYPE 14 RECORDS'
           UPON CONSOLE
      $END

      $IF DEBUG-SW DEFINED
           DISPLAY 'T14(01)= ', WS-0014-TBL-TYPE-14(1)
           UPON CONSOLE
           DISPLAY 'T14(02)= ', WS-0014-TBL-TYPE-14(2)
           UPON CONSOLE
           DISPLAY 'T14(03)= ', WS-0014-TBL-TYPE-14(3)
           UPON CONSOLE
           DISPLAY 'T14(04)= ', WS-0014-TBL-TYPE-14(4)
           UPON CONSOLE
           DISPLAY 'T14(05)= ', WS-0014-TBL-TYPE-14(5)
           UPON CONSOLE
           DISPLAY 'T14 RECORD COUNT = ', WS-0014-T14-REC-COUNT
           UPON CONSOLE
      $END

      *****************************************************
      *    INITIALIZE LOCAL VARIABLES                     *
      *****************************************************
           INITIALIZE WS-3380-LOCAL

           IF WS-0011-T11-REC-COUNT > ZERO
               PERFORM 3380-VAL-TYPE-11
                  THRU 3380-VAL-TYPE-11-EXIT
                  WITH TEST AFTER
               VARYING WS-0011-T11-INT-INDEX FROM 1 BY 1
                 UNTIL WS-0011-T11-INT-INDEX = WS-0011-T11-REC-COUNT
           END-IF.


       3380-VAL-RELATED-TYPE-14-EXIT.
           EXIT.



       3380-VAL-TYPE-11.

           SET WS-0011-T11-INDEX TO WS-0011-T11-INT-INDEX
      $IF DEBUG-SW DEFINED
           DISPLAY 'T11 SEQ # = ',
           WS-0011-TBL-TRAN-SEQ-NO(WS-0011-T11-INDEX)
           UPON CONSOLE
      $END

           IF WS-0011-TBL-TRAN-REJECTED-FLAG(WS-0011-T11-INDEX)
              = WS-LITERAL-YES

      *       *** ERRORS WERE ENCOUNTERED WITH THIS TYPE 11.
      *       *** CHECK THE SPECIFIC NUMERIC FIELDS WHICH ARE USED TO
      *       *** MATCH A TYPE 11 WITH A TYPE 14.  ALSO, CHECK WHETHER ANY
      *       *** DERIVED FIELDS USED IN THIS EDIT ARE IN ERROR.
              IF WS-0011-TBL-CROP-CD(WS-0011-T11-INDEX)
                 IS NOT NUMERIC
                 OR WS-0011-TBL-LOCATION-COUNTY(WS-0011-T11-INDEX)
                 IS NOT NUMERIC
                 OR WS-0011-TBL-INSURANCE-PLAN-CD(WS-0011-T11-INDEX)
                 IS NOT NUMERIC
                 OR WS-0011-TBL-CROP-POLICY-TY(WS-0011-T11-INDEX)
                 EQUAL SPACES
      *          THIS RECORD CANNOT BE VALIDLY COMPARED WITH A TYPE 14
                 GO TO 3380-VAL-TYPE-11-EXIT
              END-IF
           END-IF

      $IF DEBUG-SW DEFINED
           DISPLAY 'T11 SEQ # = ',
           WS-0011-TBL-TRAN-SEQ-NO(WS-0011-T11-INDEX)
           UPON CONSOLE
           DISPLAY 'T11 CROP ',
           WS-0011-TBL-CROP-CD(WS-0011-T11-INDEX), ' COUNTY ',
           WS-0011-TBL-LOCATION-COUNTY(WS-0011-T11-INDEX), ' CPT ',
           WS-0011-TBL-CROP-POLICY-TY(WS-0011-T11-INDEX), ' CVG CD ',
           WS-0011-TBL-COVERAGE-FLG(WS-0011-T11-INDEX), ' INS PLAN ',
           WS-0011-TBL-INSURANCE-PLAN-CD(WS-0011-T11-INDEX)
           UPON CONSOLE
      $END

           MOVE WS-LITERAL-NO TO WS-3380-TYPE-14-MATCH-FOUND-SW

      **** DETERMINE WHETHER A MATCHING TYPE 14 RECORD EXISTS

           IF WS-0014-T14-REC-COUNT > ZEROS
              PERFORM 3380-LOOKUP-MATCHING-14
                 THRU 3380-LOOKUP-MATCHING-14-EXIT
                 WITH TEST AFTER
              VARYING WS-0014-T14-INT-INDEX FROM 1 BY 1
                UNTIL WS-0014-T14-INT-INDEX = WS-0014-T14-REC-COUNT
                   OR WS-3380-TYPE-14-MATCH-FOUND-SW = WS-LITERAL-YES
           ELSE
              MOVE WS-LITERAL-NO TO WS-3380-TYPE-14-MATCH-FOUND-SW
           END-IF

           IF WS-3380-TYPE-14-MATCH-FOUND-SW = WS-LITERAL-NO
      ******* THERE IS NO CORRESPONDING TYPE 14 FOR THIS TYPE 11 RECORD
              MOVE WS-LITERAL-YES
                TO WS-0011-TBL-TRAN-REJECTED-FLAG(WS-0011-T11-INDEX)
              MOVE WS-0011-TBL-TRAN-SEQ-NO(WS-0011-T11-INDEX)
                TO WS-8000-TRAN-SEQ-NO
              MOVE WS-LITERAL-IR TO WS-8000-ERROR-TYPE
              MOVE 11068 TO WS-8000-ERROR-CODE
              MOVE 3380 TO WS-8000-PARAGRAPH-NO
              MOVE 'NO MATCHING T14'          TO WS-8000-FIELD-NAME1
              MOVE 'NEED MATCHING T14 RECORD' TO WS-8000-CORR-DATA1
              MOVE 11 TO WS-8000-TRAN-TYPE
              MOVE WS-0011-TBL-POLICY-NO(WS-0011-T11-INDEX)
                TO WS-8000-POLICY-NO
              MOVE WS-0011-TBL-LOCATION-COUNTY(WS-0011-T11-INDEX)
                TO WS-8000-LOC-COUNTY
              MOVE WS-0011-TBL-INSURANCE-PLAN-CD(WS-0011-T11-INDEX)
                TO WS-8000-INSURANCE-PLAN-ID
              MOVE WS-0011-TBL-CROP-CD(WS-0011-T11-INDEX)
                TO WS-8000-CROP-CD
              MOVE WS-0011-TBL-RECORD-NUM(WS-0011-T11-INDEX)
                TO WS-8000-RECORD-NUM
              MOVE WS-LITERAL-YES TO WS-0006-REJECT-11S-FLAG
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           ELSE
              IF WS-0014-TBL-TRAN-REJECTED-FLAG(WS-0014-T14-INDEX)
                 EQUAL WS-LITERAL-YES
      ******  MATCHING 14 WAS REJECTED
                 MOVE WS-LITERAL-YES
                   TO WS-0011-TBL-TRAN-REJECTED-FLAG
                      (WS-0011-T11-INDEX)
                 MOVE WS-0011-TBL-TRAN-SEQ-NO(WS-0011-T11-INDEX)
                   TO WS-8000-TRAN-SEQ-NO
                 MOVE WS-LITERAL-IR TO WS-8000-ERROR-TYPE
                 MOVE 11069 TO WS-8000-ERROR-CODE
                 MOVE 3380 TO WS-8000-PARAGRAPH-NO
                 MOVE 'T14 IN ERROR' TO WS-8000-FIELD-NAME1
                 MOVE WS-0014-TBL-TRAN-SEQ-NO(WS-0014-T14-INDEX)
                   TO WS-8000-CORR-DATA1
                 MOVE 11 TO WS-8000-TRAN-TYPE
                 MOVE WS-0011-TBL-POLICY-NO(WS-0011-T11-INDEX)
                   TO WS-8000-POLICY-NO
                 MOVE WS-0011-TBL-LOCATION-COUNTY(WS-0011-T11-INDEX)
                   TO WS-8000-LOC-COUNTY
                 MOVE WS-0011-TBL-INSURANCE-PLAN-CD
                      (WS-0011-T11-INDEX)
                   TO WS-8000-INSURANCE-PLAN-ID
                 MOVE WS-0011-TBL-CROP-CD(WS-0011-T11-INDEX)
                   TO WS-8000-CROP-CD
                 MOVE WS-0011-TBL-RECORD-NUM(WS-0011-T11-INDEX)
                   TO WS-8000-RECORD-NUM
                 MOVE WS-LITERAL-YES TO WS-0006-REJECT-11S-FLAG
                 PERFORM 8000-RECORD-TRAN-ERROR
                    THRU 8000-RECORD-TRAN-ERROR-EXIT
              END-IF

           END-IF.


       3380-VAL-TYPE-11-EXIT.
           EXIT.


       3380-LOOKUP-MATCHING-14.

           SET WS-0014-T14-INDEX TO WS-0014-T14-INT-INDEX


           IF WS-0014-TBL-TRAN-REJECTED-FLAG(WS-0014-T14-INDEX)
              EQUAL WS-LITERAL-YES

      *       *** ERRORS WERE ENCOUNTERED WITH THIS TYPE 14.
      *       *** CHECK THE SPECIFIC NUMERIC FIELDS WHICH ARE USED TO
      *       *** MATCH A TYPE 11 WITH A TYPE 14.  ALSO, CHECK WHETHER ANY
      *       *** DERIVED FIELDS USED BY THIS EDIT ARE IN ERROR.
              IF WS-0014-TBL-CROP-CD(WS-0014-T14-INDEX)
                 IS NOT NUMERIC
                 OR WS-0014-TBL-LOCATION-COUNTY(WS-0014-T14-INDEX)
                 IS NOT NUMERIC
                 OR WS-0014-TBL-INSURANCE-PLAN-CD(WS-0014-T14-INDEX)
                 IS NOT NUMERIC
                 OR WS-0014-TBL-CROP-POLICY-TY(WS-0014-T14-INDEX)
                 EQUAL SPACES
      *          THIS RECORD CANNOT BE VALIDLY COMPARED WITH A TYPE 11
                 GO TO 3380-LOOKUP-MATCHING-14-EXIT
              END-IF
           END-IF

      $IF DEBUG-SW DEFINED
           DISPLAY 'T14 SEQ # = ',
           WS-0014-TBL-TRAN-SEQ-NO(WS-0014-T14-INDEX)
           UPON CONSOLE
           DISPLAY 'T14 CROP ',
             WS-0014-TBL-CROP-CD(WS-0014-T14-INDEX), ' COUNTY ',
             WS-0014-TBL-LOCATION-COUNTY(WS-0014-T14-INDEX), ' CPT ',
             WS-0014-TBL-CROP-POLICY-TY(WS-0014-T14-INDEX),
             ' CVG CD ',
             WS-0014-TBL-COVERAGE-FLG(WS-0014-T14-INDEX),
             ' INS PLAN ',
             WS-0014-TBL-INSURANCE-PLAN-CD(WS-0014-T14-INDEX)
           UPON CONSOLE
      $END

           IF (((ws-0011-tbl-crop-cd(WS-0011-T11-INDEX)
                   = ws-literal-grapes and
               ws-0011-tbl-loc-state(WS-0011-T11-INDEX) 
                   = ws-literal-california) or
                   (ws-0011-tbl-crop-cd(WS-0011-T11-INDEX)
                       = ws-literal-citrus and
                   ws-0011-tbl-loc-state(WS-0011-T11-INDEX)
                       = ws-literal-florida)) and
              WS-0014-TBL-CROP-CD(WS-0014-T14-INDEX)
              = WS-0011-TBL-CROP-CD(WS-0011-T11-INDEX) AND
              WS-0014-TBL-LOCATION-COUNTY(WS-0014-T14-INDEX)
              = WS-0011-TBL-LOCATION-COUNTY(WS-0011-T11-INDEX) AND
              WS-0014-TBL-CROP-POLICY-TY(WS-0014-T14-INDEX)
              = WS-0011-TBL-CROP-POLICY-TY(WS-0011-T11-INDEX) AND
              WS-0014-TBL-COVERAGE-FLG(WS-0014-T14-INDEX)
              = WS-0011-TBL-COVERAGE-FLG(WS-0011-T11-INDEX) AND
              WS-0014-TBL-INSURANCE-PLAN-CD(WS-0014-T14-INDEX)
              = WS-0011-TBL-INSURANCE-PLAN-CD(WS-0011-T11-INDEX))

              or
                   ((WS-0014-TBL-CROP-CD(WS-0014-T14-INDEX)
                   = WS-0011-TBL-CROP-CD(WS-0011-T11-INDEX)) AND
                   (WS-0014-TBL-LOCATION-COUNTY(WS-0014-T14-INDEX)
                   = WS-0011-TBL-LOCATION-COUNTY(WS-0011-T11-INDEX)) AND
                   (WS-0014-TBL-COVERAGE-FLG(WS-0014-T14-INDEX)
                   = WS-0011-TBL-COVERAGE-FLG(WS-0011-T11-INDEX)) AND
                   (WS-0014-TBL-INSURANCE-PLAN-CD(WS-0014-T14-INDEX)
                   = WS-0011-TBL-INSURANCE-PLAN-CD(WS-0011-T11-INDEX)))

      *    IF ((WS-0014-TBL-CROP-CD(WS-0014-T14-INDEX)
      *       = WS-0011-TBL-CROP-CD(WS-0011-T11-INDEX)) AND
      *       (WS-0014-TBL-LOCATION-COUNTY(WS-0014-T14-INDEX)
      *       = WS-0011-TBL-LOCATION-COUNTY(WS-0011-T11-INDEX)) AND
      *       (WS-0014-TBL-CROP-POLICY-TY(WS-0014-T14-INDEX)
      *       = WS-0011-TBL-CROP-POLICY-TY(WS-0011-T11-INDEX)) AND
      *       (WS-0014-TBL-COVERAGE-FLG(WS-0014-T14-INDEX)
      *       = WS-0011-TBL-COVERAGE-FLG(WS-0011-T11-INDEX)) AND
      *       (WS-0014-TBL-INSURANCE-PLAN-CD(WS-0014-T14-INDEX)
      *       = WS-0011-TBL-INSURANCE-PLAN-CD(WS-0011-T11-INDEX)))

              MOVE WS-LITERAL-YES TO WS-3380-TYPE-14-MATCH-FOUND-SW
      *       *** THE FOLLOWING LOGIC ENSURES THAT FIELDS SHARED BY
      *       *** BOTH THE 11 AND 14 HAVE MATCHING VALUES
              IF WS-0014-TBL-LOC-STATE(WS-0014-T14-INDEX)
                 IS NUMERIC
                 AND WS-0011-TBL-LOC-STATE(WS-0011-T11-INDEX)
                 IS NUMERIC
                 IF WS-0014-TBL-LOC-STATE(WS-0014-T14-INDEX)
                    NOT EQUAL TO
                    WS-0011-TBL-LOC-STATE(WS-0011-T11-INDEX)
      *             *** REJECT THE 11
                    MOVE WS-LITERAL-YES
                      TO WS-0011-TBL-TRAN-REJECTED-FLAG
                         (WS-0011-T11-INDEX)
                    MOVE WS-LITERAL-IR TO WS-8000-ERROR-TYPE
                    MOVE 11075 TO WS-8000-ERROR-CODE
                    MOVE WS-0011-TBL-TRAN-SEQ-NO(WS-0011-T11-INDEX)
                      TO WS-8000-TRAN-SEQ-NO
                    MOVE 'T11 LOC STATE'
                      TO WS-8000-FIELD-NAME1
                    MOVE WS-0011-TBL-LOC-STATE(WS-0011-T11-INDEX)
                      TO WS-8000-BAD-DATA1
                    STRING 'T14 LOC STATE = '
                       DELIMITED BY SIZE
                       WS-0014-TBL-LOC-STATE(WS-0014-T14-INDEX)
                       DELIMITED BY SIZE
                       INTO WS-8000-CORR-DATA1
                    END-STRING
                    MOVE 'T14 ERROR' TO WS-8000-FIELD-NAME2
                    MOVE WS-0014-TBL-TRAN-SEQ-NO(WS-0014-T14-INDEX)
                      TO WS-8000-CORR-DATA2
                    MOVE 3380 TO WS-8000-PARAGRAPH-NO
                    MOVE 11 TO WS-8000-TRAN-TYPE
                    MOVE WS-0011-TBL-POLICY-NO(WS-0011-T11-INDEX)
                      TO WS-8000-POLICY-NO
                    MOVE WS-0011-TBL-LOCATION-COUNTY
                         (WS-0011-T11-INDEX)
                      TO WS-8000-LOC-COUNTY
                    MOVE WS-0011-TBL-INSURANCE-PLAN-CD
                         (WS-0011-T11-INDEX)
                      TO WS-8000-INSURANCE-PLAN-ID
                    MOVE WS-0011-TBL-CROP-CD(WS-0011-T11-INDEX)
                      TO WS-8000-CROP-CD
                    MOVE WS-0011-TBL-RECORD-NUM(WS-0011-T11-INDEX)
                      TO WS-8000-RECORD-NUM
                    MOVE WS-LITERAL-YES TO WS-0006-REJECT-11S-FLAG
                    PERFORM 8000-RECORD-TRAN-ERROR
                       THRU 8000-RECORD-TRAN-ERROR-EXIT

      ********** REJECT THE 14
                    MOVE WS-LITERAL-YES
                      TO WS-0014-TBL-TRAN-REJECTED-FLAG
                         (WS-0014-T14-INDEX)
                    MOVE WS-LITERAL-IR TO WS-8000-ERROR-TYPE
                    MOVE 14075 TO WS-8000-ERROR-CODE
                    MOVE WS-0014-TBL-TRAN-SEQ-NO(WS-0014-T14-INDEX)
                      TO WS-8000-TRAN-SEQ-NO
                    MOVE 'T14 LOC STATE'
                      TO WS-8000-FIELD-NAME1
                    MOVE WS-0014-TBL-LOC-STATE(WS-0014-T14-INDEX)
                      TO WS-8000-BAD-DATA1
                    STRING 'T11 LOC STATE = '
                       DELIMITED BY SIZE
                       WS-0011-TBL-LOC-STATE(WS-0011-T11-INDEX)
                       DELIMITED BY SIZE
                       INTO WS-8000-CORR-DATA1
                    END-STRING
                    MOVE 'T11 SEQ NO' TO WS-8000-FIELD-NAME2
                    MOVE WS-0011-TBL-TRAN-SEQ-NO(WS-0011-T11-INDEX)
                      TO WS-8000-CORR-DATA2
                    MOVE 3380 TO WS-8000-PARAGRAPH-NO
                    MOVE 14 TO WS-8000-TRAN-TYPE
                    MOVE WS-0014-TBL-POLICY-NO(WS-0014-T14-INDEX)
                      TO WS-8000-POLICY-NO
                    MOVE WS-0014-TBL-LOCATION-COUNTY
                         (WS-0014-T14-INDEX)
                      TO WS-8000-LOC-COUNTY
                    MOVE WS-0014-TBL-INSURANCE-PLAN-CD
                         (WS-0014-T14-INDEX)
                      TO WS-8000-INSURANCE-PLAN-ID
                    MOVE WS-0014-TBL-CROP-CD(WS-0014-T14-INDEX)
                      TO WS-8000-CROP-CD
                    MOVE WS-0014-TBL-RECORD-NUM(WS-0014-T14-INDEX)
                      TO WS-8000-RECORD-NUM
                    MOVE WS-LITERAL-YES TO WS-0006-REJECT-14S-FLAG
                    PERFORM 8000-RECORD-TRAN-ERROR
                       THRU 8000-RECORD-TRAN-ERROR-EXIT
                 END-IF
              END-IF
           END-IF.


       3380-LOOKUP-MATCHING-14-EXIT.
           EXIT.


