      ****************************************************************
      * FILE:      IR3390.CBL                                        *
      * AUTHOR:    Mike Ray                                          *
      * DATE:      12/13/95                                          *
      * PURPOSE:   Validates Non-Cat (buyup)Quota Tobacco & Peanut   *
      *            Type 11 records to ensure that each               *
      *            FSN has one and only one unique unit number       *
      *            assigned to it.                                   *
      *            Unit Number = Basic Unit + Optional Unit          *
      *            (The same unit CAN be in different counties.)     *
      *            Crop type code is no longer a consideration.      * 
      *                                                              *
      *            If different unit numbers are discovered for the  *
      *            same FSN or the same unit numbers for different   *
      *            FSNs then all                                     *
      *            type 11 records for the crop are rejected         *
      *                                                              *
      *                                                              *
      *            CAT Quota Tobacco & Peanut Type 11 records can    *
      *            have can have more than one unit number with the  *
      *            with the same Share ONLY if they are shared       *
      *            with different persons.  Since we do not have the *
      *            information on the persons sharing, we needed to  *
      *            remove this edit.                                 *
      *                                                              *
      ****************************************************************

       3390-VAL-UNIQUE-FSN-UNIT.

      $IF DEBUG-SW DEFINED
           DISPLAY '3390-VALIDATING UNIQUE UNITS BY FSN'
           UPON CONSOLE
      $END

      *****************************************************
      *    INITIALIZE LOCAL VARIABLES                     *
      *****************************************************
           INITIALIZE WS-3390-LOCAL.
           INITIALIZE WS-3390-FARM-UNIT-LAST.
           MOVE 0 TO  WS-3390-BAD-ONE

      *****************************************************
      *    CHECK PRECONDITIONS                            *
      *****************************************************
           IF WS-0011-T11-REC-COUNT <= 1
              GO TO 3390-VAL-UNIQUE-FSN-UNIT-EXIT
           END-IF

           IF WS-0006-INS-PLAN-CD = WS-LITERAL-PEANUTS-PLAN OR
              WS-0006-INS-PLAN-CD = WS-LITERAL-QUOTA-TOBACCO
              CONTINUE
           ELSE
              GO TO 3390-VAL-UNIQUE-FSN-UNIT-EXIT
           END-IF

      *****************************************************
      *    PRIMARY LOOP THROUGH T11 TABLE                 *
      *****************************************************

           PERFORM 3390-SEARCH-T11-TABLE
              THRU 3390-SEARCH-T11-TABLE-EXIT
              WITH TEST AFTER
           VARYING WS-3390-PRIMARY-INDEX FROM 1 BY 1
             UNTIL WS-3390-PRIMARY-INDEX = WS-0011-T11-REC-COUNT
                OR WS-3390-REJECT-ALL = WS-LITERAL-YES

           IF WS-3390-REJECT-ALL = WS-LITERAL-YES
              PERFORM 3390-REJECT-ALL
                 THRU 3390-REJECT-ALL-EXIT
           END-IF.

       3390-VAL-UNIQUE-FSN-UNIT-EXIT.
           EXIT.

       3390-SEARCH-T11-TABLE.

           SET WS-0011-T11-INDEX TO WS-3390-PRIMARY-INDEX

           IF WS-0011-TBL-TRAN-REJECTED-FLAG(WS-0011-T11-INDEX)
              = WS-LITERAL-YES

      ******* ERRORS WERE ENCOUNTERED WITH THIS TYPE 11.
      ******* CHECK THE SPECIFIC NUMERIC FIELDS WHICH ARE USED
      ******* IN THIS EDIT.  ALSO, CHECK DERIVED FIELDS USED BY THIS EDIT
              IF WS-0011-TBL-BASIC-UNIT-NUM(WS-0011-T11-INDEX)
                 IS NOT NUMERIC
                 OR WS-0011-TBL-OPTIONAL-UNIT(WS-0011-T11-INDEX)
                 IS NOT NUMERIC
      ******* BYPASS THIS TYPE 11
                 GO TO 3390-SEARCH-T11-TABLE-EXIT
              END-IF
           END-IF

      *    *** DO NOT APPLY THE EDIT TO CAT POLICIES
           IF WS-0011-TBL-COVERAGE-FLG(WS-0011-T11-INDEX)
              IS EQUAL WS-LITERAL-CAT
              GO TO 3390-SEARCH-T11-TABLE-EXIT
           END-IF

           INITIALIZE WS-3390-FARM-UNIT-NO
           MOVE WS-0011-TBL-FARM-SERIAL-NUM(WS-0011-T11-INDEX)
             TO WS-3390-FSN
           MOVE WS-0011-TBL-BASIC-UNIT-NUM(WS-0011-T11-INDEX)
             TO WS-3390-BASIC-UNIT
           MOVE WS-0011-TBL-OPTIONAL-UNIT(WS-0011-T11-INDEX)
             TO WS-3390-OPTIONAL-UNIT

           SET WS-0011-T11-INDEX TO 1

           PERFORM 3390-SEARCH-T11-TABLE-2
              THRU 3390-SEARCH-T11-TABLE-2-EXIT
              WITH TEST AFTER
           VARYING WS-0011-T11-INT-INDEX FROM 1 BY 1
             UNTIL WS-0011-T11-INT-INDEX = WS-0011-T11-REC-COUNT
                OR WS-3390-REJECT-ALL = WS-LITERAL-YES

           SET WS-0011-T11-INDEX TO WS-3390-PRIMARY-INDEX.

           MOVE WS-0011-TBL-FARM-SERIAL-NUM(WS-0011-T11-INDEX)
             TO WS-3390-FSN-LAST
           MOVE WS-0011-TBL-BASIC-UNIT-NUM(WS-0011-T11-INDEX)
             TO WS-3390-BASIC-UNIT-LAST
           MOVE WS-0011-TBL-OPTIONAL-UNIT(WS-0011-T11-INDEX)
             TO WS-3390-OPTIONAL-UNIT-LAST.

       3390-SEARCH-T11-TABLE-EXIT.
           EXIT.


       3390-SEARCH-T11-TABLE-2.

           SET WS-0011-T11-INDEX TO WS-0011-T11-INT-INDEX

           IF WS-0011-TBL-TRAN-REJECTED-FLAG(WS-0011-T11-INDEX)
              = WS-LITERAL-YES

      ******* ERRORS WERE ENCOUNTERED WITH THIS TYPE 11.
      ******* CHECK THE SPECIFIC NUMERIC FIELDS WHICH ARE USED
      ******* IN THIS EDIT.  ALSO, CHECK DERIVED FIELDS USED BY THIS EDIT
              IF WS-0011-TBL-BASIC-UNIT-NUM(WS-0011-T11-INDEX)
                 IS NOT NUMERIC
                 OR WS-0011-TBL-OPTIONAL-UNIT(WS-0011-T11-INDEX)
                 IS NOT NUMERIC
      ******* BYPASS THIS TYPE 11
                 GO TO 3390-SEARCH-T11-TABLE-EXIT
              END-IF
           END-IF

      *    *** DO NOT APPLY THE EDIT TO CAT POLICIES
           IF WS-0011-TBL-COVERAGE-FLG(WS-0011-T11-INDEX)
              IS EQUAL WS-LITERAL-CAT
              GO TO 3390-SEARCH-T11-TABLE-2-EXIT
           END-IF

           IF WS-0011-TBL-FARM-SERIAL-NUM(WS-0011-T11-INDEX)
              = WS-3390-FSN
              IF WS-0011-TBL-BASIC-UNIT-NUM(WS-0011-T11-INDEX)
                 IS NOT = WS-3390-BASIC-UNIT
                 OR WS-0011-TBL-OPTIONAL-UNIT(WS-0011-T11-INDEX)
                 IS NOT = WS-3390-OPTIONAL-UNIT
                 MOVE WS-LITERAL-YES TO WS-3390-REJECT-ALL
              END-IF
           END-IF.

           IF WS-0011-TBL-FARM-SERIAL-NUM(WS-0011-T11-INDEX)
              <> WS-3390-FSN-LAST
              IF WS-0011-TBL-BASIC-UNIT-NUM(WS-0011-T11-INDEX)
                  = WS-3390-BASIC-UNIT-LAST
                 AND WS-0011-TBL-OPTIONAL-UNIT(WS-0011-T11-INDEX)
                  = WS-3390-OPTIONAL-UNIT-LAST
                 MOVE WS-LITERAL-YES TO WS-3390-REJECT-ALL
                 MOVE WS-LITERAL-YES TO WS-3390-ERROR-LAST
              END-IF
           END-IF

          IF WS-3390-REJECT-ALL = WS-LITERAL-YES
              SET WS-3390-BAD-INDEX TO WS-0011-T11-INDEX
           ELSE
              ADD 1 TO  WS-3390-BAD-ONE
           END-IF.

        3390-SEARCH-T11-TABLE-2-EXIT.
           EXIT.



       3390-REJECT-ALL.

           PERFORM 3390-REJECT-TRAN
              THRU 3390-REJECT-TRAN-EXIT
              WITH TEST AFTER
           VARYING WS-0011-T11-INT-INDEX FROM 1 BY 1
             UNTIL WS-0011-T11-INT-INDEX = WS-0011-T11-REC-COUNT.

       3390-REJECT-ALL-EXIT.
           EXIT.

       3390-REJECT-TRAN.

           SET WS-0011-T11-INDEX TO WS-0011-T11-INT-INDEX
           MOVE WS-0011-TBL-FARM-SERIAL-NUM(WS-0011-T11-INDEX)
             TO WS-3390-FSN-D
           MOVE WS-0011-TBL-BASIC-UNIT-NUM(WS-0011-T11-INDEX)
             TO WS-3390-BASIC-UNIT-D
           MOVE WS-0011-TBL-OPTIONAL-UNIT(WS-0011-T11-INDEX)
             TO WS-3390-OPTIONAL-UNIT-D

           SET WS-3390-BAD-ONE TO WS-0011-T11-INDEX

           IF WS-3390-BAD-INDEX = WS-3390-BAD-ONE
               MOVE 11073 TO WS-8000-ERROR-CODE
           ELSE
              if WS-0011-TBL-TRAN-REJECTED-FLAG(WS-0011-T11-INDEX)
                 <> ws-literal-yes
                     MOVE 11033 TO WS-8000-ERROR-CODE
              else
                  go to 3390-REJECT-TRAN-EXIT
              end-if
           END-IF

           IF WS-3390-BAD-INDEX = WS-3390-BAD-ONE
              IF WS-3390-ERROR-LAST = WS-LITERAL-YES
                 MOVE 11106 TO WS-8000-ERROR-CODE
              END-IF
           END-IF

           MOVE WS-LITERAL-IR   TO WS-8000-ERROR-TYPE
           MOVE 11              TO WS-8000-TRAN-TYPE
           MOVE 3390            TO WS-8000-PARAGRAPH-NO

           PERFORM 8007-LOAD-IR-TABLE-ERRORS
              THRU 8007-LOAD-IR-TABLE-ERRORS-EXIT
           MOVE SPACES TO WS-8000-field-name1
           MOVE SPACES TO WS-8000-BAD-DATA1
           IF WS-8000-ERROR-CODE = 11073
               MOVE 'UNIT NO'       TO WS-8000-FIELD-NAME1
               MOVE WS-3390-DISPLAY TO WS-8000-BAD-DATA1
           END-IF
           PERFORM 8000-RECORD-TRAN-ERROR
              THRU 8000-RECORD-TRAN-ERROR-EXIT.

       3390-REJECT-TRAN-EXIT.
           EXIT.


