      ****************************************************************
      * FILE:      IR3395.CBL                                        *
      * AUTHOR:    MIKE RAY                                          *
      * DATE:      12/14/95                                          *
      * PURPOSE:                                                     *
      *            Validates the sum of all type 11 Prevented        *
      *            Planting acreage for each unit to ensure that     *
      *            that sum is greater than or equal to the lesser   *
      *            of 20% of the total (Prevented and Non-Prevented  *
      *            Planting) acreage or 20 acres.                    *
      *                                                              *
      * INTERPRETATIONS:                                             *
      *            Assumes that M-13 specifies that the SUM of all   *
      *            prevented planting Type 11 records must be >=     *
      *            MIN( 20% Total Unit Acres OR 20 Acres) instead    *
      *            of requiring EACH type 11 prevented planting      *
      *            record to be greater than the cutoff amount.      *
      *                                                              *
      * Unit  ==   Crop + Crop Type + Loc County + Basic Unit No +   *
      *            Optional Unit No.                                 *
      *            This is also not stated in M-13.                  *
      *                                                              *
      * ACTION:                                                      *
      *            If the sum of the Prevented Planting Records      *
      *            does not meet or exceed the cutoff value, all     *
      *            Type 11 records for that unit will be rejected.   *
      *                                                              *
      ****************************************************************

       3395-VAL-PP-ACRES.

      $IF DEBUG-SW DEFINED
           DISPLAY '3395-VALIDATING PREVENTED PLANTING ACRES'
           UPON CONSOLE
      $END

      *****************************************************
      *    INITIALIZE LOCAL VARIABLES                     *
      *****************************************************
           INITIALIZE WS-3395-LOCAL.
           INITIALIZE WS-3395-UNIT-TBL.
           MOVE 100 TO WS-3395-MAX-SIZE

      *****************************************************
      *    CHECK PRECONDITIONS                            *
      *****************************************************
           IF WS-0011-T11-REC-COUNT = 0
              GO TO 3395-VAL-PP-ACRES-EXIT
           END-IF

      ******************************************************
      * LOOK TO SEE IF THERE ARE ANY PREV PLANTING RECORDS *
      ******************************************************

           MOVE ZEROS TO WS-0011-T11-INT-INDEX
           PERFORM 3395-LOOK-FOR-PP-RECS
              THRU 3395-LOOK-FOR-PP-RECS-EXIT
              WITH TEST AFTER
           VARYING WS-0011-T11-INT-INDEX FROM 1 BY 1
             UNTIL WS-0011-T11-INT-INDEX = WS-0011-T11-REC-COUNT
                OR WS-3395-PP-RECORD-FOUND = WS-LITERAL-YES

           IF WS-3395-PP-RECORD-FOUND NOT = WS-LITERAL-YES
              GO TO 3395-VAL-PP-ACRES-EXIT
           END-IF

      *****************************************************
      *    BUILD ACREAGE TABLE                            *
      *****************************************************

           MOVE ZEROS TO WS-0011-T11-INT-INDEX
           PERFORM 3395-BUILD-ACREAGE-TABLE
              THRU 3395-BUILD-ACREAGE-TABLE-EXIT
              WITH TEST AFTER
           VARYING WS-0011-T11-INT-INDEX FROM 1 BY 1
             UNTIL WS-0011-T11-INT-INDEX = WS-0011-T11-REC-COUNT


      *****************************************************
      *    VALIDATE ACREAGE TABLE                         *
      *****************************************************
           IF WS-3395-UNIT-REC-COUNT > 0
              MOVE ZEROS TO WS-3395-UNIT-INT-INDEX
              PERFORM 3395-VAL-ACREAGE-TABLE
                 THRU 3395-VAL-ACREAGE-TABLE-EXIT
                 WITH TEST AFTER
              VARYING WS-3395-UNIT-INT-INDEX FROM 1 BY 1
                UNTIL WS-3395-UNIT-INT-INDEX = WS-3395-UNIT-REC-COUNT
           END-IF.


       3395-VAL-PP-ACRES-EXIT.
           EXIT.

       3395-LOOK-FOR-PP-RECS.

           SET WS-0011-T11-INDEX TO WS-0011-T11-INT-INDEX

           IF WS-0011-TBL-TRAN-REJECTED-FLAG(WS-0011-T11-INDEX)
              = WS-LITERAL-YES

      ******* ERRORS WERE ENCOUNTERED WITH THIS TYPE 11.
      ******* CHECK THE SPECIFIC NUMERIC FIELDS WHICH ARE USED
      ******* IN THIS EDIT
              IF WS-0011-TBL-INSURANCE-PLAN-CD(WS-0011-T11-INDEX)
                 IS NOT NUMERIC
                 OR WS-0011-TBL-LOCATION-COUNTY(WS-0011-T11-INDEX)
                 IS NOT NUMERIC
                 OR WS-0011-TBL-OPTIONAL-UNIT(WS-0011-T11-INDEX)
                 IS NOT NUMERIC
                 OR WS-0011-TBL-REPORTED-ACRES(WS-0011-T11-INDEX)
                 IS NOT NUMERIC
      ******* BYPASS THIS TYPE 11
                 GO TO 3395-LOOK-FOR-PP-RECS-EXIT
              END-IF
           END-IF

           IF WS-0011-TBL-GUARANTEE-RED-FLG(WS-0011-T11-INDEX)
              = WS-LITERAL-PP
              MOVE WS-LITERAL-YES
                TO WS-3395-PP-RECORD-FOUND
           END-IF.

       3395-LOOK-FOR-PP-RECS-EXIT.
           EXIT.


       3395-BUILD-ACREAGE-TABLE.

           SET WS-0011-T11-INDEX TO WS-0011-T11-INT-INDEX

           IF WS-0011-TBL-TRAN-REJECTED-FLAG(WS-0011-T11-INDEX)
              = WS-LITERAL-YES

      ******* ERRORS WERE ENCOUNTERED WITH THIS TYPE 11.
      ******* CHECK THE SPECIFIC NUMERIC AND DERIVED FIELDS WHICH ARE USED
      ******* IN THIS EDIT
              IF WS-0011-TBL-INSURANCE-PLAN-CD(WS-0011-T11-INDEX)
                 IS NOT NUMERIC
                 OR WS-0011-TBL-LOCATION-COUNTY(WS-0011-T11-INDEX)
                 IS NOT NUMERIC
                 OR WS-0011-TBL-OPTIONAL-UNIT(WS-0011-T11-INDEX)
                 IS NOT NUMERIC
                 OR WS-0011-TBL-REPORTED-ACRES(WS-0011-T11-INDEX)
                 IS NOT NUMERIC
      ******* BYPASS THIS TYPE 11
                 GO TO 3395-BUILD-ACREAGE-TABLE-EXIT
              END-IF
           END-IF

           IF WS-3395-UNIT-REC-COUNT = ZEROS
              SET WS-3395-UNIT-INDEX TO 1
              PERFORM 3395-ADD-RECORD
                 THRU 3395-ADD-RECORD-EXIT
           ELSE
              PERFORM 3395-UPDATE-UNIT-TBL
                 THRU 3395-UPDATE-UNIT-TBL-EXIT
           END-IF.

       3395-BUILD-ACREAGE-TABLE-EXIT.
           EXIT.


       3395-UPDATE-UNIT-TBL.

           SET WS-3395-UNIT-INDEX TO 1
           SEARCH WS-3395-UNIT-RECORD VARYING WS-3395-UNIT-INDEX
                AT END
                    PERFORM 3395-ADD-RECORD
                       THRU 3395-ADD-RECORD-EXIT
                    GO TO 3395-UPDATE-UNIT-TBL-EXIT
                WHEN (WS-3395-TBL-CROP-TYPE(WS-3395-UNIT-INDEX)
                     = WS-0011-TBL-TYPE-CD(WS-0011-T11-INDEX))
                 AND (WS-3395-TBL-LOC-COUNTY(WS-3395-UNIT-INDEX)
                     = WS-0011-TBL-LOCATION-COUNTY(WS-0011-T11-INDEX))
                 AND (WS-3395-TBL-BASIC-UNIT(WS-3395-UNIT-INDEX)
                     = WS-0011-TBL-BASIC-UNIT-NUM(WS-0011-T11-INDEX))
                 AND (WS-3395-TBL-OPTIONAL-UNIT(WS-3395-UNIT-INDEX)
                     = WS-0011-TBL-OPTIONAL-UNIT(WS-0011-T11-INDEX))

                     ADD WS-0011-TBL-REPORTED-ACRES(WS-0011-T11-INDEX)
                      TO WS-3395-TBL-TOTAL-ACRES(WS-3395-UNIT-INDEX)

                     IF WS-0011-TBL-GUARANTEE-RED-FLG
                     (WS-0011-T11-INDEX) = WS-LITERAL-PP

                        ADD WS-0011-TBL-REPORTED-ACRES
                            (WS-0011-T11-INDEX)
                         TO WS-3395-TBL-PP-ACRES
                            (WS-3395-UNIT-INDEX)
                     END-IF
           END-SEARCH.

       3395-UPDATE-UNIT-TBL-EXIT.
           EXIT.

      ****************************************************************
      *  THIS PARAGRAPH TESTS THE TABLE SIZE LIMIT BEFORE ADDING AN  *
      *  ADDITIONAL RECORD. WHEN THE MAXIMUM TABLE SIZE IS REACHED,  *
      *  MESSAGES ARE DISPLAYED AND EXECUTION IS TERMINATED -        *
      *  OTHERWISE THE NEW TRANSACTION RECORD IS ADDED TO THE TABLE. *
      ****************************************************************

       3395-ADD-RECORD.

           IF WS-3395-UNIT-REC-COUNT = WS-3395-MAX-SIZE
              DISPLAY 'PREV PLANTING UNIT TABLE LIMIT WILL BE EXCEEDED'
              UPON CONSOLE
              DISPLAY ' WITH THE ADDITION OF THIS RECORD'
              UPON CONSOLE
              DISPLAY '**********************************'
              UPON CONSOLE
              DISPLAY 'MAXIMUM TABLE SIZE IS ' WS-3395-MAX-SIZE
                      ' RECORDS' UPON CONSOLE
              PERFORM 0800-ABORT-PROGRAM
                 THRU 0800-ABORT-PROGRAM-EXIT
           ELSE
              ADD 1 TO WS-3395-UNIT-REC-COUNT
              SET WS-3395-UNIT-INDEX TO WS-3395-UNIT-REC-COUNT
              MOVE WS-0011-TBL-TYPE-CD(WS-0011-T11-INDEX)
                TO WS-3395-TBL-CROP-TYPE(WS-3395-UNIT-INDEX)
              MOVE WS-0011-TBL-LOCATION-COUNTY(WS-0011-T11-INDEX)
                TO WS-3395-TBL-LOC-COUNTY(WS-3395-UNIT-INDEX)
              MOVE WS-0011-TBL-BASIC-UNIT-NUM(WS-0011-T11-INDEX)
                TO WS-3395-TBL-BASIC-UNIT(WS-3395-UNIT-INDEX)
              MOVE WS-0011-TBL-OPTIONAL-UNIT(WS-0011-T11-INDEX)
                TO WS-3395-TBL-OPTIONAL-UNIT(WS-3395-UNIT-INDEX)
              MOVE WS-0011-TBL-REPORTED-ACRES(WS-0011-T11-INDEX)
                TO WS-3395-TBL-TOTAL-ACRES(WS-3395-UNIT-INDEX)
              IF ((WS-0011-TBL-INSURANCE-PLAN-CD (WS-0011-T11-INDEX)
                    = WS-LITERAL-APH OR
                   WS-0011-TBL-INSURANCE-PLAN-CD (WS-0011-T11-INDEX)
                    = WS-LITERAL-YLD-BASED-DOL-AMT) AND
                   WS-0011-TBL-GUARANTEE-RED-FLG (WS-0011-T11-INDEX)
                    = WS-LITERAL-PP)
                 MOVE WS-0011-TBL-REPORTED-ACRES(WS-0011-T11-INDEX)
                   TO WS-3395-TBL-PP-ACRES(WS-3395-UNIT-INDEX)
              END-IF

           END-IF.

       3395-ADD-RECORD-EXIT.
           EXIT.


       3395-VAL-ACREAGE-TABLE.

           SET WS-3395-UNIT-INDEX TO WS-3395-UNIT-INT-INDEX
      *    *** IF THERE ARE NO PREVENTED PLANTING ACRES
      *    *** FOR THE UNIT, SKIP IT.
           IF WS-3395-TBL-PP-ACRES(WS-3395-UNIT-INDEX) = ZEROS
              GO TO 3395-VAL-ACREAGE-TABLE-EXIT
           END-IF

      *    *** IF THE NUMBER OF PREVENTED PLANTING ACRES
      *    *** IS >= THE MINIMUM (20), THE UNIT IS OK, SKIP IT.
           IF WS-3395-TBL-PP-ACRES(WS-3395-UNIT-INDEX)
              >= WS-3395-LITERAL-MIN-PP-ACRES
              GO TO 3395-VAL-ACREAGE-TABLE-EXIT
           END-IF

      *    *** CALCULATE MIN % (20) OF THE TOTAL ACRES
           INITIALIZE WS-3395-MIN-PP-ACRES
           COMPUTE WS-3395-MIN-PP-ACRES ROUNDED =
              WS-3395-TBL-TOTAL-ACRES(WS-3395-UNIT-INDEX)
              * WS-3395-LITERAL-MIN-PCT
              ON SIZE ERROR
                 MOVE 3395 TO WS-8020-PARAGRAPH-NO
                 MOVE 90017 TO WS-8020-INT-ERROR-NO
                 MOVE 'ACRES * MIN %'
                   TO WS-8020-FIELD-NAME
                 MOVE SPACES
                   TO WS-8020-BAD-DATA
                 MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                 PERFORM 8020-RECORD-INT-ERROR
                    THRU 8020-RECORD-INT-ERROR-EXIT
           END-COMPUTE

      *    *** IF THE NUMBER OF PREVENTED PLANTING ACRES
      *    *** IS >= THE CALCULATED MINIMUM ACRES, THE UNIT IS OK.
           IF WS-3395-TBL-PP-ACRES(WS-3395-UNIT-INDEX)
              >= WS-3395-MIN-PP-ACRES
              GO TO 3395-VAL-ACREAGE-TABLE-EXIT
           ELSE
              PERFORM 3395-REJECT-UNIT
                 THRU 3395-REJECT-UNIT-EXIT
           END-IF.


       3395-VAL-ACREAGE-TABLE-EXIT.
           EXIT.


       3395-REJECT-UNIT.

           MOVE ZEROS TO WS-0011-T11-INT-INDEX
           PERFORM 3395-REJECT-TRAN
              THRU 3395-REJECT-TRAN-EXIT
              WITH TEST AFTER
           VARYING WS-0011-T11-INT-INDEX FROM 1 BY 1
             UNTIL WS-0011-T11-INT-INDEX = WS-0011-T11-REC-COUNT.

       3395-REJECT-UNIT-EXIT.
           EXIT.


       3395-REJECT-TRAN.

           SET WS-0011-T11-INDEX TO WS-0011-T11-INT-INDEX

           IF WS-0011-TBL-TRAN-REJECTED-FLAG(WS-0011-T11-INDEX)
              = WS-LITERAL-YES

      ******* ERRORS WERE ENCOUNTERED WITH THIS TYPE 11.
      ******* CHECK THE SPECIFIC NUMERIC AND DERIVED FIELDS WHICH ARE USED
      ******* IN THIS EDIT
              IF WS-0011-TBL-INSURANCE-PLAN-CD(WS-0011-T11-INDEX)
                 IS NOT NUMERIC
                 OR WS-0011-TBL-LOCATION-COUNTY(WS-0011-T11-INDEX)
                 IS NOT NUMERIC
                 OR WS-0011-TBL-OPTIONAL-UNIT(WS-0011-T11-INDEX)
                 IS NOT NUMERIC
                 OR WS-0011-TBL-REPORTED-ACRES(WS-0011-T11-INDEX)
                 IS NOT NUMERIC
      ******* BYPASS THIS TYPE 11
                 GO TO 3395-REJECT-TRAN-EXIT
              END-IF
           END-IF


           IF (WS-3395-TBL-CROP-TYPE(WS-3395-UNIT-INDEX)
               = WS-0011-TBL-TYPE-CD(WS-0011-T11-INDEX))
              AND (WS-3395-TBL-LOC-COUNTY(WS-3395-UNIT-INDEX)
               = WS-0011-TBL-LOCATION-COUNTY(WS-0011-T11-INDEX))
              AND (WS-3395-TBL-BASIC-UNIT(WS-3395-UNIT-INDEX)
               = WS-0011-TBL-BASIC-UNIT-NUM(WS-0011-T11-INDEX))
              AND (WS-3395-TBL-OPTIONAL-UNIT(WS-3395-UNIT-INDEX)
               = WS-0011-TBL-OPTIONAL-UNIT(WS-0011-T11-INDEX))
              MOVE WS-LITERAL-YES
                TO WS-0011-TBL-TRAN-REJECTED-FLAG(WS-0011-T11-INDEX)
              MOVE 11064 TO WS-8000-ERROR-CODE
              MOVE WS-LITERAL-IR TO WS-8000-ERROR-TYPE
              MOVE 'PREV PLANT ACRES' TO WS-8000-FIELD-NAME1
      *       *** RECORD THE PP ACRES, NOT THE REGULAR ACRES
              MOVE WS-3395-TBL-PP-ACRES(WS-3395-UNIT-INDEX)
                TO WS-3395-DISPLAY-PP-ACRES
              MOVE WS-3395-DISPLAY-PP-ACRES TO WS-8000-BAD-DATA1
              STRING '20 OR '
               DELIMITED BY SIZE
               WS-3395-MIN-PP-ACRES
               DELIMITED BY SIZE
               INTO WS-8000-CORR-DATA1
              END-STRING
              MOVE WS-0011-TBL-TRAN-SEQ-NO(WS-0011-T11-INDEX)
                TO WS-8000-TRAN-SEQ-NO
              MOVE 3395 TO WS-8000-PARAGRAPH-NO
              MOVE 11 TO WS-8000-TRAN-TYPE
              MOVE WS-0011-TBL-POLICY-NO(WS-0011-T11-INDEX)
                TO WS-8000-POLICY-NO
              MOVE WS-0011-TBL-LOCATION-COUNTY(WS-0011-T11-INDEX)
                TO WS-8000-LOC-COUNTY
              MOVE WS-0011-TBL-INSURANCE-PLAN-CD(WS-0011-T11-INDEX)
                TO WS-8000-INSURANCE-PLAN-ID
              MOVE WS-0011-TBL-CROP-CD(WS-0011-T11-INDEX)
                TO WS-8000-CROP-CD
              MOVE WS-0011-TBL-RECORD-NUM(WS-0011-T11-INDEX)
                TO WS-8000-RECORD-NUM
              MOVE WS-LITERAL-YES TO WS-0006-REJECT-11S-FLAG
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF.

       3395-REJECT-TRAN-EXIT.
           EXIT.
