      ****************************************************************
      * File:      IR3410.CBL
      * Author:    Linda Funn & Laura Dittamo
      * Date:      11/27/95
      * Purpose:   Validate Prepayment Flag
      *            If a Type 11 exists for the contract then Prepayment
      *            Flag should equal 0.  If no Type 11 currently exists
      *            for the contract and the Paid Amount > 0, the
      *            Prepayment Flag should equal 1.
      ****************************************************************

       3410-VAL-PREPAYMENT-FLG.

      $IF DEBUG-SW DEFINED
           DISPLAY '3410-VALIDATING FEE PREPAYMENT FLAG'
           UPON CONSOLE
      $END

           MOVE ZEROS TO WS-0012-T12-INT-INDEX

           PERFORM 3410-PROCESS-TYPE-12
              THRU 3410-PROCESS-TYPE-12-EXIT
              WITH TEST AFTER
           VARYING WS-0012-T12-INT-INDEX FROM 1 BY 1
             UNTIL WS-0012-T12-INT-INDEX = WS-0012-T12-REC-COUNT.


       3410-VAL-PREPAYMENT-FLG-EXIT.
           EXIT.


       3410-PROCESS-TYPE-12.

      ****************************************************************
      *   IF THE TYPE 11 TABLE CONTAINS ANY RECORDS, THE PREPAYMENT
      *   FLAG SHOULD EQUAL 0.  IF THE TYPE 11 TABLE IS EMPTY AND THE
      *   THE PAID AMOUNT IS GREATER THAN 0, THE PREPAYMENT FLAG
      *   SHOULD EQUAL 1.
      ****************************************************************
           SET WS-0012-T12-INDEX TO WS-0012-T12-INT-INDEX

      $IF DEBUG-SW DEFINED
           DISPLAY 'T12 SEQ # = ',
           WS-0012-TBL-TRAN-SEQ-NO(WS-0012-T12-INDEX)
           UPON CONSOLE
      $END

           IF WS-0012-TBL-TRAN-REJECTED-FLAG(WS-0012-T12-INDEX)
              = WS-LITERAL-YES

      ******* ERRORS WERE ENCOUNTERED WITH THIS TYPE 12.
      ******* CHECK THE SPECIFIC NUMERIC FIELDS WHICH ARE USED
      ******* IN THIS EDIT
              IF WS-0012-TBL-PAID-AMOUNT(WS-0012-T12-INDEX)
                 IS NOT NUMERIC
                 OR WS-0012-TBL-PREPAYMENT-FLG(WS-0012-T12-INDEX)
                 IS NOT NUMERIC
      ******* BYPASS THIS TYPE 12
                 GO TO 3410-PROCESS-TYPE-12-EXIT
              END-IF
           END-IF

      ********************************************************
            MOVE WS-LITERAL-YES TO WS-3410-REJECT-11-FLAG
            IF WS-0005-TYPE-11-COUNT > 0
               PERFORM 3410-CHECK-11S
                  THRU 3410-CHECK-11S-EXIT
                  WITH TEST AFTER
               VARYING WS-0011-T11-INT-INDEX FROM 1 BY 1
                 UNTIL WS-0011-T11-INT-INDEX = WS-0005-TYPE-11-COUNT
            END-IF
      ********************************************************

           IF WS-0005-TYPE-11-COUNT > 0
              IF WS-0012-TBL-PREPAYMENT-FLG(WS-0012-T12-INDEX) <> 0
                 MOVE WS-LITERAL-YES
                   TO WS-0012-TBL-TRAN-REJECTED-FLAG(WS-0012-T12-INDEX)
                 MOVE 12051 TO WS-8000-ERROR-CODE
                 MOVE WS-LITERAL-IR TO WS-8000-ERROR-TYPE
                 MOVE WS-LITERAL-PREPMT-FL TO WS-8000-FIELD-NAME1
                 MOVE WS-0012-TBL-PREPAYMENT-FLG(WS-0012-T12-INDEX)
                   TO WS-8000-BAD-DATA1
                 MOVE '0' TO WS-8000-CORR-DATA1
                 MOVE WS-0012-TBL-TRAN-SEQ-NO(WS-0012-T12-INDEX)
                   TO WS-8000-TRAN-SEQ-NO
                 MOVE 12 TO WS-8000-TRAN-TYPE
                 MOVE WS-0012-TBL-POLICY-NO(WS-0012-T12-INDEX)
                   TO WS-8000-POLICY-NO
                 MOVE 3410 TO WS-8000-PARAGRAPH-NO
                 MOVE WS-0012-TBL-RECORD-NUM(WS-0012-T12-INDEX)
                   TO WS-8000-RECORD-NUM
                 PERFORM 8000-RECORD-TRAN-ERROR
                    THRU 8000-RECORD-TRAN-ERROR-EXIT

      ** REJECT ALL OTHER 12S
                 PERFORM 3410-REJECT-12S
                    THRU 3410-REJECT-12S-EXIT
                    WITH TEST AFTER
                 VARYING WS-0012-T12-INT-INDEX FROM 1 BY 1
                   UNTIL WS-0012-T12-INT-INDEX = WS-0012-T12-REC-COUNT
              END-IF
           ELSE
              IF WS-0012-TBL-PAID-AMOUNT(WS-0012-T12-INDEX) > 0
                 AND WS-0012-TBL-PREPAYMENT-FLG(WS-0012-T12-INDEX) <> 1
                 MOVE WS-LITERAL-YES
                   TO WS-0012-TBL-TRAN-REJECTED-FLAG(WS-0012-T12-INDEX)
                 MOVE 12052 TO WS-8000-ERROR-CODE
                 MOVE WS-LITERAL-IR TO WS-8000-ERROR-TYPE
                 MOVE WS-LITERAL-PREPMT-FL TO WS-8000-FIELD-NAME1
                 MOVE WS-0012-TBL-PREPAYMENT-FLG(WS-0012-T12-INDEX)
                   TO WS-8000-BAD-DATA1
                 MOVE '1' TO WS-8000-CORR-DATA1
                 MOVE WS-0012-TBL-TRAN-SEQ-NO(WS-0012-T12-INDEX)
                   TO WS-8000-TRAN-SEQ-NO
                 MOVE WS-0012-TBL-POLICY-NO(WS-0012-T12-INDEX)
                   TO WS-8000-POLICY-NO
                 MOVE WS-0012-TBL-RECORD-NUM(WS-0012-T12-INDEX)
                   TO WS-8000-RECORD-NUM
                 MOVE 3410 TO WS-8000-PARAGRAPH-NO
                 PERFORM 8000-RECORD-TRAN-ERROR
                    THRU 8000-RECORD-TRAN-ERROR-EXIT

      ** REJECT ALL OTHER 12S
                 PERFORM 3410-REJECT-12S
                    THRU 3410-REJECT-12S-EXIT
                    WITH TEST AFTER
                 VARYING WS-0012-T12-INT-INDEX FROM 1 BY 1
                   UNTIL WS-0012-T12-INT-INDEX = WS-0012-T12-REC-COUNT
              END-IF
           END-IF.


       3410-PROCESS-TYPE-12-EXIT.
           EXIT.


       3410-REJECT-12S.

           SET WS-0012-T12-INDEX TO WS-0012-T12-INT-INDEX
           MOVE WS-LITERAL-YES
             TO WS-0012-TBL-TRAN-REJECTED-FLAG(WS-0012-T12-INDEX)
           MOVE 12033 TO WS-8000-ERROR-CODE
           MOVE WS-LITERAL-IR TO WS-8000-ERROR-TYPE
           MOVE WS-0012-TBL-TRAN-SEQ-NO(WS-0012-T12-INDEX)
             TO WS-8000-TRAN-SEQ-NO
           MOVE 12 TO WS-8000-TRAN-TYPE
           MOVE WS-0012-TBL-POLICY-NO(WS-0012-T12-INDEX)
             TO WS-8000-POLICY-NO
           MOVE WS-0012-TBL-RECORD-NUM(WS-0012-T12-INDEX)
             TO WS-8000-RECORD-NUM
           MOVE 3410 TO WS-8000-PARAGRAPH-NO
           PERFORM 8000-RECORD-TRAN-ERROR
              THRU 8000-RECORD-TRAN-ERROR-EXIT.


       3410-REJECT-12S-EXIT.
           EXIT.

       3410-CHECK-11S.
           SET WS-0011-T11-INDEX TO WS-0011-T11-INT-INDEX
           IF WS-0011-TBL-TRAN-REJECTED-FLAG(WS-0011-T11-INT-INDEX) <>
              WS-LITERAL-YES
              MOVE WS-LITERAL-NO TO WS-3410-REJECT-11-FLAG
           END-IF.
       3410-CHECK-11S-EXIT.
           EXIT.
