      ****************************************************************
      *  File   : IR3425.CBL
      *  Author : Yo-I Tsui
      *  Date   : 06/13/96
      *  Purpose:
      *    A corresponding type 11 record must exist for each type
      *    21.  The following fields are used to pair type 11 records
      *    with type 21s:  Reporting Organization, Location State,
      *    Company/County, Policy Number, Crop Year, Location County,
      *    Crop Code, Type Code, Coverage Flag, Dual Coverage Flag,
      *    Practice Code, Basic Unit Number and Optional Unit Number.
      *
      *    If no match is found using these fields, a second comparison
      *    is made using all of the above fields except Practice Code.
      *
      *    The following fields exist on both Type 21 and 11:
      *    Coverage Level Percent, Farm Serial Number
      *    Insured Share, Rate Class, Yield, and Price Election.
      *
      *    This module compares the values of these fields; the
      *    values must match on one type 11 or else an error is recorded.
      *
      *    This module also contains the following edits:
      *    - Validate T21 Loss Cause Code for Apples
      *      A corresponding Type 11 for a Type 21 record must have
      *      the Sunburn Additional Option Code
      ****************************************************************

       3425-VAL-RELATED-TYPE-11.

      $IF DEBUG-SW DEFINED
           DISPLAY '3425-VALIDATING RELATED TYPE 11 RECORDS'
           UPON CONSOLE
      $END

      $IF DEBUG-SW DEFINED
           DISPLAY 'T11(01)= ', WS-0011-TBL-TYPE-11(1)
           UPON CONSOLE
           DISPLAY 'T11(02)= ', WS-0011-TBL-TYPE-11(2)
           UPON CONSOLE
           DISPLAY 'T11(03)= ', WS-0011-TBL-TYPE-11(3)
           UPON CONSOLE
           DISPLAY 'T11(04)= ', WS-0011-TBL-TYPE-11(4)
           UPON CONSOLE
           DISPLAY 'T11(05)= ', WS-0011-TBL-TYPE-11(5)
           UPON CONSOLE
      $END

           IF WS-0021-T21-REC-COUNT > 0
              PERFORM 3425-PROCESS-TYPE-21
                 THRU 3425-PROCESS-TYPE-21-EXIT
                 WITH TEST AFTER
              VARYING WS-0021-T21-INT-INDEX FROM 1 BY 1
                UNTIL WS-0021-T21-INT-INDEX = WS-0021-T21-REC-COUNT
           END-IF.

       3425-VAL-RELATED-TYPE-11-EXIT.
           EXIT.


       3425-PROCESS-TYPE-21.

           SET WS-0021-T21-INDEX TO WS-0021-T21-INT-INDEX

      $IF DEBUG-SW DEFINED
           DISPLAY 'T21 SEQ # =',
           WS-0021-TBL-TRAN-SEQ-NO(WS-0021-T21-INDEX),
           ' T21 INDEX # = ', WS-0021-T21-INT-INDEX
           UPON CONSOLE
      $END

           IF WS-0021-TBL-TRAN-REJECTED-FLAG(WS-0021-T21-INDEX)
              = WS-LITERAL-YES
      *       *** CHECK THE SPECIFIC NUMERIC FIELDS WHICH ARE USED TO
      *       *** MATCH A TYPE 21 WITH A TYPE 11.
              IF WS-0021-TBL-OPTIONAL-UNIT(WS-0021-T21-INDEX)
                 IS NOT NUMERIC
                 OR WS-0021-TBL-LOCATION-COUNTY(WS-0021-T21-INDEX)
                 IS NOT NUMERIC
                 OR WS-0021-TBL-CLAIM-NUM(WS-0021-T21-INDEX)
                 IS NOT NUMERIC
                 GO TO 3425-PROCESS-TYPE-21-EXIT
              END-IF
           END-IF


      $IF DEBUG-SW DEFINED
           DISPLAY 'T21 SEQ # = ',
           WS-0021-TBL-TRAN-SEQ-NO(WS-0021-T21-INDEX)
           UPON CONSOLE
           DISPLAY 'T21 CNTY ',
           WS-0021-TBL-LOCATION-COUNTY(WS-0021-T21-INDEX),
           ' TYPE ', WS-0021-TBL-TYPE-CD(WS-0021-T21-INDEX),
           ' PRACT ', WS-0021-TBL-PRACTICE-CD(WS-0021-T21-INDEX),
           ' B UNIT ', WS-0021-TBL-BASIC-UNIT-NUM(WS-0021-T21-INDEX),
           ' O UNIT ', WS-0021-TBL-OPTIONAL-UNIT(WS-0021-T21-INDEX),
           ' CVG ', WS-0021-TBL-COVERAGE-FLG(WS-0021-T21-INDEX)
           UPON CONSOLE
      $END

      *    *** CHECK THE CORRESPONDING TYPE 11 RECORDS ***
           INITIALIZE WS-3425-WORK
           MOVE WS-LITERAL-NO TO WS-3425-BASIC-MATCH-SWITCH
           MOVE WS-LITERAL-NO TO WS-3425-MATCH-SWITCH
           IF WS-0011-T11-REC-COUNT > 0
              PERFORM 3425-CHECK-TYPE-11
                 THRU 3425-CHECK-TYPE-11-EXIT
                 WITH TEST AFTER
              VARYING WS-0011-T11-INT-INDEX FROM 1 BY 1
                UNTIL WS-0011-T11-INT-INDEX = WS-0011-T11-REC-COUNT
                   OR WS-3425-MATCH-SWITCH = WS-LITERAL-YES
           END-IF

      *    *** SET INDEXES TO MATCHING RECORDS ***
           SET WS-0021-T21-INDEX TO WS-0021-T21-INT-INDEX
           SET WS-0011-T11-INDEX TO WS-0011-T11-INT-INDEX

      **********************************************************************
      *     THERE IS NO CORRESPONDING TYPE 11 FOR THIS TYPE 21 RECORD      *
      *     BASED UPON TYPE/BASIC UNIT/OPTIONAL UNIT/CVG FLAG/DUAL CVG     *
      **********************************************************************
           IF WS-3425-BASIC-MATCH-SWITCH = WS-LITERAL-NO
              MOVE WS-LITERAL-IR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES
                TO WS-0021-TBL-TRAN-REJECTED-FLAG(WS-0021-T21-INDEX)
              MOVE WS-0021-TBL-TRAN-SEQ-NO(WS-0021-T21-INDEX)
                TO WS-8000-TRAN-SEQ-NO
              MOVE 21056 TO WS-8000-ERROR-CODE
              MOVE 3425 TO WS-8000-PARAGRAPH-NO
              MOVE 21 TO WS-8000-TRAN-TYPE
              MOVE WS-0021-TBL-POLICY-NO(WS-0021-T21-INDEX)
                TO WS-8000-POLICY-NO
              MOVE WS-0021-TBL-RECORD-NUM(WS-0021-T21-INDEX)
                TO WS-8000-RECORD-NUM
              MOVE WS-0021-TBL-LOCATION-COUNTY(WS-0021-T21-INDEX)
                TO WS-8000-LOC-COUNTY
              MOVE WS-0021-TBL-INSURANCE-PLAN-CD(WS-0021-T21-INDEX)
                TO WS-8000-INSURANCE-PLAN-ID
              MOVE WS-0021-TBL-CROP-CD(WS-0021-T21-INDEX)
                TO WS-8000-CROP-CD
              MOVE WS-0021-TBL-RECORD-NUM(WS-0021-T21-INDEX)
                TO WS-8000-RECORD-NUM
              MOVE WS-LITERAL-YES TO WS-0006-REJECT-21S-FLAG
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
      ******* POPULATE THE CLAIM NUMBER USED TO REJECT 20/21 RECORDS
              MOVE WS-0021-TBL-CLAIM-NUM(WS-0021-T21-INDEX)
                TO WS-3425-CLAIM-NO
      ******* REJECT ALL 21S AND 20S WITH WS-3425-CLAIM-NO
              IF WS-0021-T21-REC-COUNT > 0
                 PERFORM 3425-REJECT-ASSOC-21
                    THRU 3425-REJECT-ASSOC-21-EXIT
                    WITH TEST AFTER
                 VARYING WS-3425-T21-ERROR-INDEX FROM 1 BY 1
                   UNTIL WS-3425-T21-ERROR-INDEX
                       = WS-0021-T21-REC-COUNT
      *** RESTORE MAIN LOOP T21 INDEX VALUE
                 SET WS-0021-T21-INDEX TO WS-0021-T21-INT-INDEX
              END-IF
              IF WS-0020-T20-REC-COUNT > 0
                 PERFORM 3425-REJECT-ASSOC-20
                    THRU 3425-REJECT-ASSOC-20-EXIT
                    WITH TEST AFTER
                 VARYING WS-0020-T20-INT-INDEX FROM 1 BY 1
                   UNTIL WS-0020-T20-INT-INDEX
                       = WS-0020-T20-REC-COUNT
              END-IF
              GO TO 3425-PROCESS-TYPE-21-EXIT
           END-IF

      **********************************************************************
      *     THERE IS NO CORRESPONDING TYPE 11 FOR THIS TYPE 21 RECORD      *
      *     BASED UPON CVG LEVEL/INS SHARE/RATE CLASS/YIELD                *
      **********************************************************************

      ************ MOD TO MATCH OLD CODE *********************

           IF WS-0021-TBL-STAGE-CD(WS-0021-T21-INDEX) = 'R'
              AND
              WS-0021-TBL-100-PCT-REPLANT-FL(WS-0021-T21-INDEX) = 'Y'
              CONTINUE
           ELSE

      ************ MOD TO MATCH OLD CODE *********************

           IF WS-3425-MATCH-SWITCH = WS-LITERAL-NO
      *       *** RECORD COVERAGE LEVEL ERROR IF NECESSARY ***
              IF WS-3425-CVG-LVL-MATCH = WS-LITERAL-NO
                 MOVE WS-LITERAL-IR TO WS-8000-ERROR-TYPE
                 MOVE WS-LITERAL-YES
                   TO WS-0021-TBL-TRAN-REJECTED-FLAG(WS-0021-T21-INDEX)
                 MOVE WS-0021-TBL-TRAN-SEQ-NO(WS-0021-T21-INDEX)
                   TO WS-8000-TRAN-SEQ-NO
                 MOVE 21058 TO WS-8000-ERROR-CODE
                 MOVE 3425 TO WS-8000-PARAGRAPH-NO
                 MOVE 'T21 CVG LVL'
                   TO WS-8000-FIELD-NAME1
                 MOVE WS-3425-BAD-T21-CVG-LVL
                   TO WS-8000-BAD-DATA1
                 STRING 'CLOSEST T11 CVG LVL = '
                   DELIMITED BY SIZE
                   WS-3425-BAD-T11-CVG-LVL
                   DELIMITED BY SIZE
                   INTO WS-8000-CORR-DATA1
                 END-STRING
                 MOVE 21 TO WS-8000-TRAN-TYPE
                 MOVE WS-0021-TBL-POLICY-NO(WS-0021-T21-INDEX)
                   TO WS-8000-POLICY-NO
                 MOVE WS-0021-TBL-RECORD-NUM(WS-0021-T21-INDEX)
                   TO WS-8000-RECORD-NUM
                 MOVE WS-0021-TBL-LOCATION-COUNTY(WS-0021-T21-INDEX)
                   TO WS-8000-LOC-COUNTY
                 MOVE WS-0021-TBL-INSURANCE-PLAN-CD(WS-0021-T21-INDEX)
                   TO WS-8000-INSURANCE-PLAN-ID
                 MOVE WS-0021-TBL-CROP-CD(WS-0021-T21-INDEX)
                   TO WS-8000-CROP-CD
                 MOVE WS-0021-TBL-RECORD-NUM(WS-0021-T21-INDEX)
                   TO WS-8000-RECORD-NUM
                 MOVE WS-LITERAL-YES TO WS-0006-REJECT-21S-FLAG
                 PERFORM 8000-RECORD-TRAN-ERROR
                    THRU 8000-RECORD-TRAN-ERROR-EXIT
              END-IF

      *       *** RECORD INS SHARE ERROR IF NECESSARY ***
              IF WS-3425-INS-SHARE-MATCH = WS-LITERAL-NO
                 MOVE WS-LITERAL-IR TO WS-8000-ERROR-TYPE
                 MOVE WS-LITERAL-YES
                   TO WS-0021-TBL-TRAN-REJECTED-FLAG(WS-0021-T21-INDEX)
                 MOVE WS-0021-TBL-TRAN-SEQ-NO(WS-0021-T21-INDEX)
                   TO WS-8000-TRAN-SEQ-NO
                 MOVE 21058 TO WS-8000-ERROR-CODE
                 MOVE 3425 TO WS-8000-PARAGRAPH-NO
                 MOVE 'T21 INS SHARE'
                   TO WS-8000-FIELD-NAME1
                 MOVE WS-3425-BAD-T21-INS-SHARE
                   TO WS-8000-BAD-DATA1
                 STRING 'CLOSEST T11 INS SHARE = '
                   DELIMITED BY SIZE
                   WS-3425-BAD-T11-INS-SHARE
                   DELIMITED BY SIZE
                   INTO WS-8000-CORR-DATA1
                 END-STRING
                 MOVE 21 TO WS-8000-TRAN-TYPE
                 MOVE WS-0021-TBL-POLICY-NO(WS-0021-T21-INDEX)
                   TO WS-8000-POLICY-NO
                 MOVE WS-0021-TBL-RECORD-NUM(WS-0021-T21-INDEX)
                   TO WS-8000-RECORD-NUM
                 MOVE WS-0021-TBL-LOCATION-COUNTY(WS-0021-T21-INDEX)
                   TO WS-8000-LOC-COUNTY
                 MOVE WS-0021-TBL-INSURANCE-PLAN-CD(WS-0021-T21-INDEX)
                   TO WS-8000-INSURANCE-PLAN-ID
                 MOVE WS-0021-TBL-CROP-CD(WS-0021-T21-INDEX)
                   TO WS-8000-CROP-CD
                 MOVE WS-0021-TBL-RECORD-NUM(WS-0021-T21-INDEX)
                   TO WS-8000-RECORD-NUM
                 MOVE WS-LITERAL-YES TO WS-0006-REJECT-21S-FLAG
                 PERFORM 8000-RECORD-TRAN-ERROR
                    THRU 8000-RECORD-TRAN-ERROR-EXIT
              END-IF

      *       *** RECORD RATE CLASS ERROR IF NECESSARY ***
              IF WS-3425-RATE-CLASS-MATCH = WS-LITERAL-NO
                 MOVE WS-LITERAL-IR TO WS-8000-ERROR-TYPE
                 MOVE WS-LITERAL-YES
                   TO WS-0021-TBL-TRAN-REJECTED-FLAG(WS-0021-T21-INDEX)
                 MOVE WS-0021-TBL-TRAN-SEQ-NO(WS-0021-T21-INDEX)
                   TO WS-8000-TRAN-SEQ-NO
                 MOVE 21058 TO WS-8000-ERROR-CODE
                 MOVE 3425 TO WS-8000-PARAGRAPH-NO
                 MOVE 'T21 RATE CLASS'
                   TO WS-8000-FIELD-NAME1
                 MOVE WS-3425-BAD-T21-RATE-CLASS
                   TO WS-8000-BAD-DATA1
                 STRING 'CLOSEST T11 RATE CLASS = '
                   DELIMITED BY SIZE
                   WS-3425-BAD-T21-RATE-CLASS
                   DELIMITED BY SIZE
                   INTO WS-8000-CORR-DATA1
                 END-STRING
                 MOVE 21 TO WS-8000-TRAN-TYPE
                 MOVE WS-0021-TBL-POLICY-NO(WS-0021-T21-INDEX)
                   TO WS-8000-POLICY-NO
                 MOVE WS-0021-TBL-RECORD-NUM(WS-0021-T21-INDEX)
                   TO WS-8000-RECORD-NUM
                 MOVE WS-0021-TBL-LOCATION-COUNTY(WS-0021-T21-INDEX)
                   TO WS-8000-LOC-COUNTY
                 MOVE WS-0021-TBL-INSURANCE-PLAN-CD(WS-0021-T21-INDEX)
                   TO WS-8000-INSURANCE-PLAN-ID
                 MOVE WS-0021-TBL-CROP-CD(WS-0021-T21-INDEX)
                   TO WS-8000-CROP-CD
                 MOVE WS-0021-TBL-RECORD-NUM(WS-0021-T21-INDEX)
                   TO WS-8000-RECORD-NUM
                 MOVE WS-LITERAL-YES TO WS-0006-REJECT-21S-FLAG
                 PERFORM 8000-RECORD-TRAN-ERROR
                    THRU 8000-RECORD-TRAN-ERROR-EXIT
              END-IF


      *       *** RECORD YIELD ERROR IF NECESSARY ***
              IF   WS-3425-BASIC-MATCH-SWITCH =
                   WS-LITERAL-YES
              IF   WS-3425-MATCH-SWITCH =
                   WS-LITERAL-YES

              IF WS-3425-YIELD-MATCH = WS-LITERAL-NO
                 MOVE WS-LITERAL-IR TO WS-8000-ERROR-TYPE
                 MOVE WS-LITERAL-YES
                   TO WS-0021-TBL-TRAN-REJECTED-FLAG(WS-0021-T21-INDEX)
                 MOVE WS-0021-TBL-TRAN-SEQ-NO(WS-0021-T21-INDEX)
                   TO WS-8000-TRAN-SEQ-NO
                 MOVE 21058 TO WS-8000-ERROR-CODE
                 MOVE 3425 TO WS-8000-PARAGRAPH-NO
                 MOVE 'T21 YIELD'
                   TO WS-8000-FIELD-NAME1
                 MOVE WS-3425-BAD-T21-YIELD
                   TO WS-8000-BAD-DATA1
                 STRING 'CLOSEST T11 YIELD = '
                   DELIMITED BY SIZE
                   WS-3425-BAD-T21-YIELD
                   DELIMITED BY SIZE
                   INTO WS-8000-CORR-DATA1
                 END-STRING
                 MOVE 21 TO WS-8000-TRAN-TYPE
                 MOVE WS-0021-TBL-POLICY-NO(WS-0021-T21-INDEX)
                   TO WS-8000-POLICY-NO
                 MOVE WS-0021-TBL-RECORD-NUM(WS-0021-T21-INDEX)
                   TO WS-8000-RECORD-NUM
                 MOVE WS-0021-TBL-LOCATION-COUNTY(WS-0021-T21-INDEX)
                   TO WS-8000-LOC-COUNTY
                 MOVE WS-0021-TBL-INSURANCE-PLAN-CD(WS-0021-T21-INDEX)
                   TO WS-8000-INSURANCE-PLAN-ID
                 MOVE WS-0021-TBL-CROP-CD(WS-0021-T21-INDEX)
                   TO WS-8000-CROP-CD
                 MOVE WS-0021-TBL-RECORD-NUM(WS-0021-T21-INDEX)
                   TO WS-8000-RECORD-NUM
                 MOVE WS-LITERAL-YES TO WS-0006-REJECT-21S-FLAG
                 PERFORM 8000-RECORD-TRAN-ERROR
                    THRU 8000-RECORD-TRAN-ERROR-EXIT
              END-IF
              END-IF
              END-IF

      ******* POPULATE THE CLAIM NUMBER USED TO REJECT 20/21 RECORDS
              MOVE WS-0021-TBL-CLAIM-NUM(WS-0021-T21-INDEX)
                TO WS-3425-CLAIM-NO
      ******* REJECT ALL 21S AND 20S WITH WS-3425-CLAIM-NO
              IF WS-0021-T21-REC-COUNT > 0
                 PERFORM 3425-REJECT-ASSOC-21
                    THRU 3425-REJECT-ASSOC-21-EXIT
                    WITH TEST AFTER
                 VARYING WS-3425-T21-ERROR-INDEX FROM 1 BY 1
                   UNTIL WS-3425-T21-ERROR-INDEX
                       = WS-0021-T21-REC-COUNT
      *** RESTORE MAIN LOOP T21 INDEX VALUE
                 SET WS-0021-T21-INDEX TO WS-0021-T21-INT-INDEX
              END-IF
              IF WS-0020-T20-REC-COUNT > 0
                 PERFORM 3425-REJECT-ASSOC-20
                    THRU 3425-REJECT-ASSOC-20-EXIT
                    WITH TEST AFTER
                 VARYING WS-0020-T20-INT-INDEX FROM 1 BY 1
                   UNTIL WS-0020-T20-INT-INDEX
                       = WS-0020-T20-REC-COUNT
              END-IF
              GO TO 3425-PROCESS-TYPE-21-EXIT
           END-IF
           END-IF

      *********************************************************
      * THE CORRESPONDING TYPE 11 FOR THIS TYPE 21 RECORD HAS *
      * BEEN REJECTED                                         *
      *********************************************************
           IF WS-0011-TBL-TRAN-REJECTED-FLAG(WS-0011-T11-INDEX)
              = WS-LITERAL-YES
              MOVE WS-0021-TBL-TRAN-SEQ-NO(WS-0021-T21-INDEX)
                TO WS-8000-TRAN-SEQ-NO
              MOVE WS-LITERAL-YES
                TO WS-0021-TBL-TRAN-REJECTED-FLAG(WS-0021-T21-INDEX)
              MOVE 21057 TO WS-8000-ERROR-CODE
              MOVE WS-LITERAL-IR TO WS-8000-ERROR-TYPE
              MOVE 'T11 SEQ NO' TO WS-8000-FIELD-NAME1
              MOVE WS-0011-TBL-TRAN-SEQ-NO(WS-0011-T11-INDEX)
                TO WS-8000-CORR-DATA1
              MOVE WS-0021-TBL-TRAN-SEQ-NO(WS-0021-T21-INDEX)
                TO WS-8000-TRAN-SEQ-NO
              MOVE 3425 TO WS-8000-PARAGRAPH-NO
              MOVE 21 TO WS-8000-TRAN-TYPE
              MOVE WS-0021-TBL-POLICY-NO(WS-0021-T21-INDEX)
                TO WS-8000-POLICY-NO
              MOVE WS-0021-TBL-LOCATION-COUNTY(WS-0021-T21-INDEX)
                TO WS-8000-LOC-COUNTY
              MOVE WS-0021-TBL-INSURANCE-PLAN-CD(WS-0021-T21-INDEX)
                TO WS-8000-INSURANCE-PLAN-ID
              MOVE WS-0021-TBL-CROP-CD(WS-0021-T21-INDEX)
                TO WS-8000-CROP-CD
              MOVE WS-0021-TBL-RECORD-NUM(WS-0021-T21-INDEX)
                TO WS-8000-RECORD-NUM
              MOVE WS-LITERAL-YES TO WS-0006-REJECT-21S-FLAG
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
      *       *** POPULATE THE CLAIM NUMBER USED TO REJECT 20/21 RECORDS
              MOVE WS-0021-TBL-CLAIM-NUM(WS-0021-T21-INDEX)
                TO WS-3425-CLAIM-NO
      *       *** REJECT ALL 21S AND 20S WITH WS-3425-CLAIM-NO
              IF WS-0021-T21-REC-COUNT > 0
                 PERFORM 3425-REJECT-ASSOC-21
                    THRU 3425-REJECT-ASSOC-21-EXIT
                    WITH TEST AFTER
                 VARYING WS-3425-T21-ERROR-INDEX FROM 1 BY 1
                   UNTIL WS-3425-T21-ERROR-INDEX
                       = WS-0021-T21-REC-COUNT
      *       *** RESTORE MAIN LOOP T21 INDEX VALUE
                 SET WS-0021-T21-INDEX TO WS-0021-T21-INT-INDEX
              END-IF
              IF WS-0020-T20-REC-COUNT > 0
                 PERFORM 3425-REJECT-ASSOC-20
                    THRU 3425-REJECT-ASSOC-20-EXIT
                    WITH TEST AFTER
                 VARYING WS-0020-T20-INT-INDEX FROM 1 BY 1
                   UNTIL WS-0020-T20-INT-INDEX
                       = WS-0020-T20-REC-COUNT
              END-IF
              GO TO 3425-PROCESS-TYPE-21-EXIT
           END-IF

      *********************************************************
      * THE CORRESPONDING TYPE 11 FOR THIS TYPE 21 RECORD HAS *
      * NOT BEEN REJECTED                                     *
      *********************************************************


      ******* VALIDATE THE LOSS CAUSE CODE, EXCESS SUN, FOR APPLES.
      ******* EACH T21 RECORD THAT SITES EXCESS SUN AS A CAUSE OF LOSS
      ******* MUST HAVE THE SUNBURN OPTION ON ITS CORRESPONDING T11
           IF WS-0021-TBL-CROP-CD(WS-0021-T21-INDEX)
              = WS-LITERAL-APPLES AND
              (WS-0021-TBL-PRIMARY-CAUSE(WS-0021-T21-INDEX) = 22 OR
              WS-0021-TBL-SECONDARY-CAUSE(WS-0021-T21-INDEX) = 22)
              IF WS-3425-SUNBURN-OPTION-MATCH <> WS-LITERAL-YES
                 MOVE WS-LITERAL-YES
                   TO WS-0021-TBL-TRAN-REJECTED-FLAG
                      (WS-0021-T21-INDEX)
                 MOVE WS-LITERAL-IR TO WS-8000-ERROR-TYPE
                 MOVE 21078 TO WS-8000-ERROR-CODE
                 MOVE WS-0021-TBL-TRAN-SEQ-NO(WS-0021-T21-INDEX)
                   TO WS-8000-TRAN-SEQ-NO
                 IF WS-0021-TBL-PRIMARY-CAUSE
                    (WS-0021-T21-INDEX) = 22
                    MOVE WS-LITERAL-PRIMARY-CAUSE
                      TO WS-8000-FIELD-NAME1
                    MOVE WS-0021-TBL-PRIMARY-CAUSE
                         (WS-0021-T21-INDEX)
                      TO WS-8000-BAD-DATA1
                 ELSE
                    MOVE WS-LITERAL-SECONDRY-CAUSE
                      TO WS-8000-FIELD-NAME1
                    MOVE WS-0021-TBL-SECONDARY-CAUSE
                         (WS-0021-T21-INDEX)
                      TO WS-8000-BAD-DATA1
                 END-IF
                 MOVE SPACES TO WS-8000-CORR-DATA1
                 MOVE 'T11 SEQ NO' TO WS-8000-FIELD-NAME2
                 MOVE WS-0011-TBL-TRAN-SEQ-NO(WS-0011-T11-INDEX)
                   TO WS-8000-CORR-DATA2
                 MOVE 3425 TO WS-8000-PARAGRAPH-NO
                 MOVE 21 TO WS-8000-TRAN-TYPE
                 MOVE WS-0021-TBL-POLICY-NO(WS-0021-T21-INDEX)
                   TO WS-8000-POLICY-NO
                 MOVE WS-0021-TBL-LOCATION-COUNTY(WS-0021-T21-INDEX)
                   TO WS-8000-LOC-COUNTY
                 MOVE WS-0021-TBL-INSURANCE-PLAN-CD(WS-0021-T21-INDEX)
                   TO WS-8000-INSURANCE-PLAN-ID
                 MOVE WS-0021-TBL-CROP-CD(WS-0021-T21-INDEX)
                   TO WS-8000-CROP-CD
                 MOVE WS-0021-TBL-RECORD-NUM(WS-0021-T21-INDEX)
                   TO WS-8000-RECORD-NUM
                 MOVE WS-LITERAL-YES TO WS-0006-REJECT-21S-FLAG
                 PERFORM 8000-RECORD-TRAN-ERROR
                    THRU 8000-RECORD-TRAN-ERROR-EXIT

      *          *** POPULATE THE CLAIM NUMBER USED TO REJECT 20/21
      *          *** RECORDS
                 MOVE WS-0021-TBL-CLAIM-NUM(WS-0021-T21-INDEX)
                   TO WS-3425-CLAIM-NO
      *          *** REJECT ALL 21S AND 20S WITH WS-3425-CLAIM-NO
                 IF WS-0021-T21-REC-COUNT > 0
                    PERFORM 3425-REJECT-ASSOC-21
                       THRU 3425-REJECT-ASSOC-21-EXIT
                       WITH TEST AFTER
                    VARYING WS-3425-T21-ERROR-INDEX FROM 1 BY 1
                      UNTIL WS-3425-T21-ERROR-INDEX
                          = WS-0021-T21-REC-COUNT
      *             RESTORE MAIN LOOP T21 INDEX VALUE
                    SET WS-0021-T21-INDEX TO WS-0021-T21-INT-INDEX
                 END-IF

                 IF WS-0020-T20-REC-COUNT > 0
                    PERFORM 3425-REJECT-ASSOC-20
                       THRU 3425-REJECT-ASSOC-20-EXIT
                       WITH TEST AFTER
                    VARYING WS-0020-T20-INT-INDEX FROM 1 BY 1
                      UNTIL WS-0020-T20-INT-INDEX
                          = WS-0020-T20-REC-COUNT
                 END-IF
           END-IF


      ***************************************************************
      *     Validate T21 loss stage code. If the T11 guarantee
      *     reduction flag = 'P', the corresponding T21 must carry
      *     a valid prevented planting stage code (P1,P2,H3,U3 or PU).
      *     Each T21 record that has a prevented planting stage code
      *     (P1,P2,H3,U3,PU) must have the guarantee reduction flag
      *     = 'P' on its corresponding T11.
      ***************************************************************

           IF ((WS-0021-TBL-STAGE-CD(WS-0021-T21-INDEX)
              = WS-LITERAL-PREV-PLANT-OPT-1 OR
                WS-LITERAL-PREV-PLANT-OPT-2 OR
                WS-LITERAL-PP-OPT3-HARVESTED OR
                WS-LITERAL-PP-OPT3-UNHARVESTED OR
                WS-LITERAL-PP-UNINSURED-LOSS)
              AND WS-0011-TBL-GUARANTEE-RED-FLG(WS-0011-T11-INDEX)
                 <> WS-LITERAL-PP)
              OR
              ((WS-0021-TBL-STAGE-CD(WS-0021-T21-INDEX)
               <> WS-LITERAL-PREV-PLANT-OPT-1 OR
                  WS-LITERAL-PREV-PLANT-OPT-2 OR
                  WS-LITERAL-PP-OPT3-HARVESTED OR
                  WS-LITERAL-PP-OPT3-UNHARVESTED OR
                  WS-LITERAL-PP-UNINSURED-LOSS)
              AND WS-0011-TBL-GUARANTEE-RED-FLG(WS-0011-T11-INDEX)
                  = WS-LITERAL-PP)
              MOVE WS-LITERAL-YES
                TO WS-0011-TBL-TRAN-REJECTED-FLAG(WS-0011-T11-INDEX)
              MOVE WS-LITERAL-IR TO WS-8000-ERROR-TYPE
              IF WS-0011-TBL-GUARANTEE-RED-FLG(WS-0011-T11-INDEX)
                 = WS-LITERAL-PP
                 MOVE 11107 TO WS-8000-ERROR-CODE
              ELSE
                 MOVE 11045 TO WS-8000-ERROR-CODE
              END-IF
              MOVE WS-0011-TBL-TRAN-SEQ-NO(WS-0011-T11-INDEX)
                TO WS-8000-TRAN-SEQ-NO
              MOVE 'T21 STAGE CODE'
                TO WS-8000-FIELD-NAME1
              MOVE WS-0021-TBL-STAGE-CD(WS-0021-T21-INDEX)
                TO WS-8000-BAD-DATA1
              MOVE 'T21 SEQ NO' TO WS-8000-FIELD-NAME2
              MOVE WS-0021-TBL-TRAN-SEQ-NO(WS-0021-T21-INDEX)
                TO WS-8000-CORR-DATA2
              MOVE 3425 TO WS-8000-PARAGRAPH-NO
              MOVE 11 TO WS-8000-TRAN-TYPE
              MOVE WS-0011-TBL-POLICY-NO(WS-0011-T11-INDEX)
                TO WS-8000-POLICY-NO
              MOVE WS-0011-TBL-LOCATION-COUNTY(WS-0011-T11-INDEX)
                TO WS-8000-LOC-COUNTY
              MOVE WS-0011-TBL-INSURANCE-PLAN-CD(WS-0011-T11-INDEX)
                TO WS-8000-INSURANCE-PLAN-ID
              MOVE WS-0011-TBL-CROP-CD(WS-0011-T11-INDEX)
                TO WS-8000-CROP-CD
              MOVE WS-0011-TBL-RECORD-NUM(WS-0011-T11-INDEX)
                TO WS-8000-RECORD-NUM
              MOVE WS-LITERAL-YES TO WS-0006-REJECT-11S-FLAG
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT

      *       *** POPULATE THE CLAIM NUMBER USED TO REJECT 20/21
      *       *** RECORDS
              MOVE WS-0021-TBL-CLAIM-NUM(WS-0021-T21-INDEX)
                TO WS-3425-CLAIM-NO
      *       *** REJECT ALL 21S AND 20S WITH WS-3425-CLAIM-NO
              IF WS-0021-T21-REC-COUNT > 0
                 PERFORM 3425-REJECT-ASSOC-21
                    THRU 3425-REJECT-ASSOC-21-EXIT
                    WITH TEST AFTER
                 VARYING WS-3425-T21-ERROR-INDEX FROM 1 BY 1
                   UNTIL WS-3425-T21-ERROR-INDEX
                       = WS-0021-T21-REC-COUNT
      *          RESTORE MAIN LOOP T21 INDEX VALUE
                 SET WS-0021-T21-INDEX TO WS-0021-T21-INT-INDEX
              END-IF

              IF WS-0020-T20-REC-COUNT > 0
                 PERFORM 3425-REJECT-ASSOC-20
                    THRU 3425-REJECT-ASSOC-20-EXIT
                    WITH TEST AFTER
                 VARYING WS-0020-T20-INT-INDEX FROM 1 BY 1
                   UNTIL WS-0020-T20-INT-INDEX
                       = WS-0020-T20-REC-COUNT
              END-IF
           END-IF

      ***************************************************************
      * If the T21 stage code is for prevented planting, the guarantee
      * reduction percent on the T11 must be correct for the crop code
      * under the prevented planting option indicated by the stage code
      * on the T21.
      ***************************************************************
           IF (WS-0021-TBL-STAGE-CD(WS-0021-T21-INDEX)
              <> WS-LITERAL-PREV-PLANT-OPT-1 OR
                 WS-LITERAL-PREV-PLANT-OPT-2 OR
                 WS-LITERAL-PP-OPT3-HARVESTED OR
                 WS-LITERAL-PP-OPT3-UNHARVESTED OR
                 WS-LITERAL-PP-UNINSURED-LOSS)
                 GO TO 3425-PROCESS-TYPE-21-EXIT
           END-IF


           IF (WS-0021-TBL-STAGE-CD(WS-0021-T21-INDEX)
              = WS-LITERAL-PREV-PLANT-OPT-1) OR
              (WS-0021-TBL-STAGE-CD(WS-0021-T21-INDEX)
              = WS-LITERAL-PP-UNINSURED-LOSS)

              IF (WS-0021-TBL-CROP-CD(WS-0021-T21-INDEX) =
                  WS-LITERAL-HYBRID-CORN-SEED AND
                  WS-0011-TBL-GUARANTEE-RED-PCT(WS-0011-T11-INDEX)
                  = .200)
                 GO TO 3425-PROCESS-TYPE-21-EXIT
              END-IF

              IF (WS-0011-TBL-GUARANTEE-RED-PCT(WS-0011-T11-INDEX)
                 = .250) AND
                 (WS-0021-TBL-CROP-CD(WS-0021-T21-INDEX)
                 = WS-LITERAL-HYBRID-SORGHUM-SEED OR
                 WS-0021-TBL-CROP-CD(WS-0021-T21-INDEX)
                 = WS-LITERAL-WHEAT OR
                 WS-0021-TBL-CROP-CD(WS-0021-T21-INDEX)
                 = WS-LITERAL-CANOLA OR
                 WS-0021-TBL-CROP-CD(WS-0021-T21-INDEX)
                 = WS-LITERAL-OATS OR
                 WS-0021-TBL-CROP-CD(WS-0021-T21-INDEX)
                 = WS-LITERAL-FLAX OR
                 WS-0021-TBL-CROP-CD(WS-0021-T21-INDEX)
                 = WS-LITERAL-CORN OR
                 WS-0021-TBL-CROP-CD(WS-0021-T21-INDEX)
                 = WS-LITERAL-GRAIN-SORGHUM OR
                 WS-0021-TBL-CROP-CD(WS-0021-T21-INDEX)
                 = WS-LITERAL-SUNFLOWERS OR
                 WS-0021-TBL-CROP-CD(WS-0021-T21-INDEX)
                 = WS-LITERAL-SOYBEANS OR
                 WS-0021-TBL-CROP-CD(WS-0021-T21-INDEX)
                 = WS-LITERAL-BARLEY OR
                 WS-0021-TBL-CROP-CD(WS-0021-T21-INDEX)
                 = WS-LITERAL-RYE)
                 GO TO 3425-PROCESS-TYPE-21-EXIT
              END-IF

              IF (WS-0011-TBL-GUARANTEE-RED-PCT(WS-0011-T11-INDEX)
                 = .175) AND
                 (WS-0021-TBL-CROP-CD(WS-0021-T21-INDEX)
                 = WS-LITERAL-RICE OR
                 WS-0021-TBL-CROP-CD(WS-0021-T21-INDEX)
                 = WS-LITERAL-COTTON OR
                 WS-0021-TBL-CROP-CD(WS-0021-T21-INDEX)
                 = WS-LITERAL-COTTON-XTRA-LONG)
                 GO TO 3425-PROCESS-TYPE-21-EXIT
              END-IF
           END-IF

           IF (WS-0021-TBL-CROP-CD(WS-0021-T21-INDEX) =
               WS-LITERAL-HYBRID-CORN-SEED AND
               WS-0011-TBL-GUARANTEE-RED-PCT(WS-0011-T11-INDEX)
               = .400)
               GO TO 3425-PROCESS-TYPE-21-EXIT
           END-IF

           IF (WS-0011-TBL-GUARANTEE-RED-PCT(WS-0011-T11-INDEX)
              = .500) AND
              (WS-0021-TBL-CROP-CD(WS-0021-T21-INDEX)
              = WS-LITERAL-HYBRID-SORGHUM-SEED OR
              WS-0021-TBL-CROP-CD(WS-0021-T21-INDEX)
              = WS-LITERAL-WHEAT OR
              WS-0021-TBL-CROP-CD(WS-0021-T21-INDEX)
              = WS-LITERAL-CANOLA OR
              WS-0021-TBL-CROP-CD(WS-0021-T21-INDEX)
              = WS-LITERAL-OATS OR
              WS-0021-TBL-CROP-CD(WS-0021-T21-INDEX)
              = WS-LITERAL-FLAX OR
              WS-0021-TBL-CROP-CD(WS-0021-T21-INDEX)
              = WS-LITERAL-CORN OR
              WS-0021-TBL-CROP-CD(WS-0021-T21-INDEX)
              = WS-LITERAL-GRAIN-SORGHUM OR
              WS-0021-TBL-CROP-CD(WS-0021-T21-INDEX)
              = WS-LITERAL-SUNFLOWERS OR
              WS-0021-TBL-CROP-CD(WS-0021-T21-INDEX)
              = WS-LITERAL-SOYBEANS OR
              WS-0021-TBL-CROP-CD(WS-0021-T21-INDEX)
              = WS-LITERAL-BARLEY OR
              WS-0021-TBL-CROP-CD(WS-0021-T21-INDEX)
              = WS-LITERAL-RYE)
              GO TO 3425-PROCESS-TYPE-21-EXIT
           END-IF

           IF (WS-0011-TBL-GUARANTEE-RED-PCT(WS-0011-T11-INDEX)
               = .350) AND
               WS-0021-TBL-CROP-CD(WS-0021-T21-INDEX)
               = WS-LITERAL-RICE OR
               WS-0021-TBL-CROP-CD(WS-0021-T21-INDEX)
               = WS-LITERAL-COTTON OR
               WS-0021-TBL-CROP-CD(WS-0021-T21-INDEX)
               = WS-LITERAL-COTTON-XTRA-LONG
               GO TO 3425-PROCESS-TYPE-21-EXIT
           END-IF

      *    *** RECORD ERROR ***
           MOVE WS-LITERAL-YES
             TO WS-0011-TBL-TRAN-REJECTED-FLAG(WS-0011-T11-INDEX)
           MOVE WS-LITERAL-IR TO WS-8000-ERROR-TYPE
           IF WS-0021-TBL-STAGE-CD(WS-0021-T21-INDEX)
              = WS-LITERAL-PREV-PLANT-OPT-1
              MOVE 11095 TO WS-8000-ERROR-CODE
           END-IF
           MOVE WS-0011-TBL-TRAN-SEQ-NO(WS-0011-T11-INDEX)
             TO WS-8000-TRAN-SEQ-NO
           MOVE 'T21 STAGE CODE'
             TO WS-8000-FIELD-NAME1
           MOVE WS-0021-TBL-STAGE-CD(WS-0021-T21-INDEX)
             TO WS-8000-BAD-DATA1
           STRING '.'
                DELIMITED BY SIZE
                WS-0011-TBL-GUAR-RED-PCT-X(WS-0011-T11-INDEX)
                DELIMITED BY SIZE
                INTO WS-8000-BAD-DATA2
           MOVE 'T21 SEQ NO' TO WS-8000-FIELD-NAME2
           MOVE WS-0021-TBL-TRAN-SEQ-NO(WS-0021-T21-INDEX)
             TO WS-8000-CORR-DATA2
           MOVE 3425 TO WS-8000-PARAGRAPH-NO
           MOVE 11 TO WS-8000-TRAN-TYPE
           MOVE WS-0011-TBL-POLICY-NO(WS-0011-T11-INDEX)
             TO WS-8000-POLICY-NO
           MOVE WS-0011-TBL-LOCATION-COUNTY(WS-0011-T11-INDEX)
             TO WS-8000-LOC-COUNTY
           MOVE WS-0011-TBL-INSURANCE-PLAN-CD(WS-0011-T11-INDEX)
             TO WS-8000-INSURANCE-PLAN-ID
           MOVE WS-0011-TBL-CROP-CD(WS-0011-T11-INDEX)
             TO WS-8000-CROP-CD
           MOVE WS-0011-TBL-RECORD-NUM(WS-0011-T11-INDEX)
             TO WS-8000-RECORD-NUM
           MOVE WS-LITERAL-YES TO WS-0006-REJECT-11S-FLAG
           PERFORM 8000-RECORD-TRAN-ERROR
              THRU 8000-RECORD-TRAN-ERROR-EXIT

      *    *** POPULATE THE CLAIM NUMBER USED TO REJECT 20/21
      *    *** RECORDS
           MOVE WS-0021-TBL-CLAIM-NUM(WS-0021-T21-INDEX)
             TO WS-3425-CLAIM-NO
      *    *** REJECT ALL 21S AND 20S WITH WS-3425-CLAIM-NO
           IF WS-0021-T21-REC-COUNT > 0
              PERFORM 3425-REJECT-ASSOC-21
                 THRU 3425-REJECT-ASSOC-21-EXIT
                 WITH TEST AFTER
              VARYING WS-3425-T21-ERROR-INDEX FROM 1 BY 1
                UNTIL WS-3425-T21-ERROR-INDEX
                    = WS-0021-T21-REC-COUNT
      *       RESTORE MAIN LOOP T21 INDEX VALUE
              SET WS-0021-T21-INDEX TO WS-0021-T21-INT-INDEX
           END-IF

           IF WS-0020-T20-REC-COUNT > 0
              PERFORM 3425-REJECT-ASSOC-20
                 THRU 3425-REJECT-ASSOC-20-EXIT
                 WITH TEST AFTER
              VARYING WS-0020-T20-INT-INDEX FROM 1 BY 1
                UNTIL WS-0020-T20-INT-INDEX
                    = WS-0020-T20-REC-COUNT
           END-IF.

       3425-PROCESS-TYPE-21-EXIT.
           EXIT.


       3425-CHECK-TYPE-11.

           SET WS-0011-T11-INDEX TO WS-0011-T11-INT-INDEX

      *    *** RESET FLAGS ***
           MOVE WS-LITERAL-NO TO WS-3425-MATCH-SWITCH
           MOVE WS-LITERAL-NO TO WS-3425-CVG-LVL-MATCH
           MOVE WS-LITERAL-NO TO WS-3425-FSN-MATCH
           MOVE WS-LITERAL-NO TO WS-3425-INS-SHARE-MATCH
           MOVE WS-LITERAL-NO TO WS-3425-RATE-CLASS-MATCH
           MOVE WS-LITERAL-NO TO WS-3425-YIELD-MATCH
           MOVE WS-LITERAL-NO TO WS-3425-PRICE-ELECTION-MATCH
           MOVE WS-LITERAL-NO TO WS-3425-SUNBURN-OPTION-MATCH
           MOVE ZEROS TO WS-3425-MATCH-COUNT

      *************************************************************

           MOVE ZEROS TO WS-3425-BAD-MATCH-COUNT

      *************************************************************


           IF WS-0011-TBL-TRAN-REJECTED-FLAG(WS-0011-T11-INDEX)
              = WS-LITERAL-YES
      ******* ERRORS WERE ENCOUNTERED WITH THIS TYPE 11.
      ******* CHECK THE SPECIFIC NUMERIC FIELDS WHICH ARE USED TO
      ******* MATCH A TYPE 11 WITH A TYPE 21.
              IF WS-0011-TBL-OPTIONAL-UNIT(WS-0011-T11-INDEX)
                 IS NOT NUMERIC
                 OR WS-0011-TBL-LOCATION-COUNTY(WS-0011-T11-INDEX)
                 IS NOT NUMERIC
                 GO TO 3425-CHECK-TYPE-11-EXIT
              END-IF
           END-IF

      $IF DEBUG-SW DEFINED
           DISPLAY 'T11 SEQ # = ',
           WS-0011-TBL-TRAN-SEQ-NO(WS-0011-T11-INDEX),
           ' T11 INDEX # = ', WS-0011-T11-INT-INDEX
           UPON CONSOLE
           DISPLAY 'T11 CNTY ',
           WS-0011-TBL-LOCATION-COUNTY(WS-0011-T11-INDEX),
           ' TYPE ', WS-0011-TBL-TYPE-CD(WS-0011-T11-INDEX),
           ' PRACT ', WS-0011-TBL-PRACTICE-CD(WS-0011-T11-INDEX),
           ' B UNIT ', WS-0011-TBL-BASIC-UNIT-NUM(WS-0011-T11-INDEX),
           ' O UNIT ', WS-0011-TBL-OPTIONAL-UNIT(WS-0011-T11-INDEX),
           ' CVG ', WS-0011-TBL-COVERAGE-FLG(WS-0011-T11-INDEX)
           UPON CONSOLE
      $END

      ****************************************************************
      *        COMPARE WITH PRACTICE CODE
      ****************************************************************
           IF WS-0021-TBL-LOCATION-COUNTY(WS-0021-T21-INDEX) =
              WS-0011-TBL-LOCATION-COUNTY(WS-0011-T11-INDEX) AND
              WS-0021-TBL-PRACTICE-CD(WS-0021-T21-INDEX) =
              WS-0011-TBL-PRACTICE-CD(WS-0011-T11-INDEX) AND
              WS-0021-TBL-TYPE-CD(WS-0021-T21-INDEX) =
              WS-0011-TBL-TYPE-CD(WS-0011-T11-INDEX) AND
              WS-0021-TBL-BASIC-UNIT-NUM(WS-0021-T21-INDEX) =
              WS-0011-TBL-BASIC-UNIT-NUM(WS-0011-T11-INDEX) AND
              WS-0021-TBL-OPTIONAL-UNIT(WS-0021-T21-INDEX) =
              WS-0011-TBL-OPTIONAL-UNIT(WS-0011-T11-INDEX) AND
              WS-0021-TBL-COVERAGE-FLG(WS-0021-T21-INDEX) =
              WS-0011-TBL-COVERAGE-FLG(WS-0011-T11-INDEX)
              MOVE WS-LITERAL-YES TO WS-3425-BASIC-MATCH-SWITCH
           ELSE
      ****************************************************************
      *        COMPARE WITHOUT PRACTICE CODE
      ****************************************************************
              IF WS-0021-TBL-LOCATION-COUNTY(WS-0021-T21-INDEX) =
                 WS-0011-TBL-LOCATION-COUNTY(WS-0011-T11-INDEX) AND
                 WS-0021-TBL-TYPE-CD(WS-0021-T21-INDEX) =
                 WS-0011-TBL-TYPE-CD(WS-0011-T11-INDEX) AND
                 WS-0021-TBL-BASIC-UNIT-NUM(WS-0021-T21-INDEX) =
                 WS-0011-TBL-BASIC-UNIT-NUM(WS-0011-T11-INDEX) AND
                 WS-0021-TBL-COVERAGE-FLG(WS-0021-T21-INDEX) =
                 WS-0011-TBL-COVERAGE-FLG(WS-0011-T11-INDEX) AND
                 WS-0021-TBL-OPTIONAL-UNIT(WS-0021-T21-INDEX) =
                 WS-0011-TBL-OPTIONAL-UNIT(WS-0011-T11-INDEX)
                 MOVE WS-LITERAL-YES TO WS-3425-BASIC-MATCH-SWITCH
              ELSE
                 GO TO 3425-CHECK-TYPE-11-EXIT
              END-IF
           END-IF

      ****************************************************************
      *    COMPARE COVERAGE LEVEL PERCENT
      ****************************************************************
           IF WS-0011-TBL-COVERAGE-LEVEL-PCT(WS-0011-T11-INDEX)
              IS NUMERIC
              AND WS-0021-TBL-COVERAGE-LEVEL-PCT(WS-0021-T21-INDEX)
              IS NUMERIC
              IF WS-0011-TBL-COVERAGE-LEVEL-PCT(WS-0011-T11-INDEX) =
                 WS-0021-TBL-COVERAGE-LEVEL-PCT(WS-0021-T21-INDEX)
                 MOVE WS-LITERAL-YES
                   TO WS-3425-CVG-LVL-MATCH
                 ADD 1 TO WS-3425-MATCH-COUNT
              END-IF
           END-IF


      ****************************************************************
      *    COMPARE FARM SERIAL NUMBER
      ****************************************************************
           IF WS-0011-TBL-FARM-SERIAL-NUM(WS-0011-T11-INDEX) =
              WS-0021-TBL-FARM-SERIAL-NUM(WS-0021-T21-INDEX)
              MOVE WS-LITERAL-YES
                TO WS-3425-FSN-MATCH
           END-IF

      ****************************************************************
      *    COMPARE INSURED SHARE
      ****************************************************************
           IF WS-0011-TBL-INSURED-SHARE(WS-0011-T11-INDEX)
              IS NUMERIC
              AND WS-0021-TBL-INSURED-SHARE(WS-0021-T21-INDEX)
              IS NUMERIC
              IF WS-0011-TBL-INSURED-SHARE(WS-0011-T11-INDEX) =
                 WS-0021-TBL-INSURED-SHARE(WS-0021-T21-INDEX)
                 MOVE WS-LITERAL-YES
                   TO WS-3425-INS-SHARE-MATCH
                 ADD 1 TO WS-3425-MATCH-COUNT
              END-IF
           END-IF

      ****************************************************************
      *    COMPARE RATE CLASS
      ****************************************************************
           IF WS-0011-TBL-RATE-CLASS(WS-0011-T11-INDEX) =
              WS-0021-TBL-RATE-CLASS(WS-0021-T21-INDEX)
              MOVE WS-LITERAL-YES
                TO WS-3425-RATE-CLASS-MATCH
                 ADD 1 TO WS-3425-MATCH-COUNT
           END-IF

      ****************************************************************
      *    COMPARE YIELD
      ****************************************************************

           IF WS-0011-TBL-YIELD(WS-0011-T11-INDEX)
              IS NUMERIC
              AND WS-0021-TBL-YIELD(WS-0021-T21-INDEX)
              IS NUMERIC
              IF WS-0011-TBL-YIELD(WS-0011-T11-INDEX) =
                 WS-0021-TBL-YIELD(WS-0021-T21-INDEX)
                 MOVE WS-LITERAL-YES
                   TO WS-3425-YIELD-MATCH
                 ADD 1 TO WS-3425-MATCH-COUNT
              END-IF
           END-IF

      ****************************************************************
      *    COMPARE PRICE ELECTION
      ****************************************************************
           IF WS-0021-TBL-PRICE-ELECTION(WS-0021-T21-INDEX)
              IS NUMERIC
              AND WS-0011-TBL-PRICE-ELECTION(WS-0011-T11-INDEX)
              IS NUMERIC
              AND WS-0011-TBL-INSURANCE-PLAN-CD(WS-0011-T11-INDEX)
              IS NUMERIC

      *    ** CRC POLICIES MAY HAVE EITHER THE SPRING OR FALL
      *    ** MARKET PRICE ON THE TYPE 21 WHEREAS THE TYPE 11
      *    ** WILL ALWAYS REFLECT THE SPRING MARKET PRICE.
              IF WS-0011-TBL-PRICE-ELECTION(WS-0011-T11-INDEX) =
                 WS-0021-TBL-PRICE-ELECTION(WS-0021-T21-INDEX) OR
                 WS-0011-TBL-INSURANCE-PLAN-CD(WS-0011-T11-INDEX) =
                 WS-LITERAL-CRC
                 MOVE WS-LITERAL-YES
                   TO WS-3425-PRICE-ELECTION-MATCH
              END-IF
           END-IF

      ****************************************************************
      *    CHECK SUNBURN OPTION
      ****************************************************************
           IF WS-0011-TBL-CROP-CD(WS-0011-T11-INDEX)
              = WS-LITERAL-APPLES AND
              (WS-0011-TBL-ADDITIONAL-OPT-CD(WS-0011-T11-INDEX) =
              'S  ' OR
              WS-0011-TBL-ADDITIONAL-OPT-CD(WS-0011-T11-INDEX)
              = 'GS ')
              MOVE WS-LITERAL-YES
                TO WS-3425-SUNBURN-OPTION-MATCH
           END-IF


      ****************************************************************
      *    SEE IF THIS IS A MATCH
      ****************************************************************

           IF WS-3425-CVG-LVL-MATCH = WS-LITERAL-YES AND
              WS-3425-INS-SHARE-MATCH = WS-LITERAL-YES
      *********************************************************
      ***     WS-3425-RATE-CLASS-MATCH = WS-LITERAL-YES
      ***     WS-3425-YIELD-MATCH = WS-LITERAL-YES
      *********************************************************
              MOVE WS-LITERAL-YES
                TO WS-3425-MATCH-SWITCH
           ELSE
              IF WS-3425-MATCH-COUNT > WS-3425-BAD-MATCH-COUNT
                 INITIALIZE WS-3425-BAD-DATA
                 MOVE WS-3425-MATCH-COUNT
                   TO WS-3425-BAD-MATCH-COUNT
      *          *** SAVE BAD CVG LVL DATA ***
                 IF WS-3425-CVG-LVL-MATCH <> WS-LITERAL-YES AND
                    WS-0011-TBL-COVERAGE-LEVEL-PCT(WS-0011-T11-INDEX)
                    IS NUMERIC AND
                    WS-0021-TBL-COVERAGE-LEVEL-PCT(WS-0021-T21-INDEX)
                    IS NUMERIC
                    MOVE WS-0011-TBL-COVERAGE-LEVEL-PCT
                         (WS-0011-T11-INDEX)
                      TO WS-3425-BAD-T11-CVG-LVL
                    MOVE WS-0021-TBL-COVERAGE-LEVEL-PCT
                         (WS-0021-T21-INDEX)
                      TO WS-3425-BAD-T21-CVG-LVL
                 END-IF
      *          *** SAVE BAD INS SHARE DATA ***
                 IF WS-3425-INS-SHARE-MATCH <> WS-LITERAL-YES AND
                    WS-0011-TBL-INSURED-SHARE(WS-0011-T11-INDEX)
                    IS NUMERIC AND
                    WS-0021-TBL-INSURED-SHARE(WS-0021-T21-INDEX)
                    IS NUMERIC
                    MOVE WS-0011-TBL-INSURED-SHARE(WS-0011-T11-INDEX)
                      TO WS-3425-BAD-T11-INS-SHARE
                    MOVE WS-0021-TBL-INSURED-SHARE(WS-0021-T21-INDEX)
                      TO WS-3425-BAD-T21-INS-SHARE
                 END-IF
      *          *** SAVE BAD RATE CLASS DATA ***
                 IF WS-3425-RATE-CLASS-MATCH <> WS-LITERAL-YES
                    MOVE WS-0011-TBL-RATE-CLASS(WS-0011-T11-INDEX)
                      TO WS-3425-BAD-T11-RATE-CLASS
                    MOVE WS-0021-TBL-RATE-CLASS(WS-0021-T21-INDEX)
                      TO WS-3425-BAD-T21-RATE-CLASS
                 END-IF
      *          *** SAVE BAD YIELD DATA ***
                 IF WS-3425-YIELD-MATCH <> WS-LITERAL-YES AND
                    WS-0011-TBL-YIELD(WS-0011-T11-INDEX)
                    IS NUMERIC AND
                    WS-0021-TBL-YIELD(WS-0021-T21-INDEX)
                    IS NUMERIC
                    MOVE WS-0011-TBL-YIELD(WS-0011-T11-INDEX)
                      TO WS-3425-BAD-T11-YIELD
                    MOVE WS-0021-TBL-YIELD(WS-0021-T21-INDEX)
                      TO WS-3425-BAD-T21-YIELD
                 END-IF
              END-IF
           END-IF.

       3425-CHECK-TYPE-11-EXIT.
           EXIT.


      ************************************************************
      *   REJECT ALL TYPE 21S WITH SAME CLAIM NUMBER
      ************************************************************
       3425-REJECT-ASSOC-21.

           SET WS-0021-T21-INDEX TO WS-3425-T21-ERROR-INDEX

           IF WS-0021-TBL-TRAN-REJECTED-FLAG(WS-0021-T21-INDEX)
              = WS-LITERAL-YES
              GO TO 3425-REJECT-ASSOC-21-EXIT
           END-IF

           IF WS-0021-TBL-CLAIM-NUM(WS-0021-T21-INDEX) =
              WS-3425-CLAIM-NO
              MOVE WS-LITERAL-YES
                TO WS-0021-TBL-TRAN-REJECTED-FLAG(WS-0021-T21-INDEX)
              MOVE WS-LITERAL-IR TO WS-8000-ERROR-TYPE
              MOVE 21039 TO WS-8000-ERROR-CODE
              MOVE WS-0021-TBL-TRAN-SEQ-NO(WS-0021-T21-INDEX)
                TO WS-8000-TRAN-SEQ-NO
              MOVE 'BAD MATCH 21-11' TO WS-8000-FIELD-NAME1
              MOVE 'T11 SEQ NO' TO WS-8000-BAD-DATA1
              MOVE 3425 TO WS-8000-PARAGRAPH-NO
              MOVE 21 TO WS-8000-TRAN-TYPE
              MOVE WS-0021-TBL-POLICY-NO(WS-0021-T21-INDEX)
                TO WS-8000-POLICY-NO
              MOVE WS-0021-TBL-LOCATION-COUNTY(WS-0021-T21-INDEX)
                TO WS-8000-LOC-COUNTY
              MOVE WS-0021-TBL-INSURANCE-PLAN-CD(WS-0021-T21-INDEX)
                TO WS-8000-INSURANCE-PLAN-ID
              MOVE WS-0021-TBL-CROP-CD(WS-0021-T21-INDEX)
                TO WS-8000-CROP-CD
              MOVE WS-0021-TBL-RECORD-NUM(WS-0021-T21-INDEX)
                TO WS-8000-RECORD-NUM
              MOVE WS-LITERAL-YES TO WS-0006-REJECT-21S-FLAG
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF.

       3425-REJECT-ASSOC-21-EXIT.
           EXIT.


      ************************************************************
      *    REJECT ALL TYPE 20S WITH SAME TYPE 21 CLAIM NUMBER
      ************************************************************
       3425-REJECT-ASSOC-20.

           SET WS-0020-T20-INDEX TO WS-0020-T20-INT-INDEX

           IF WS-0020-TBL-TRAN-REJECTED-FLAG(WS-0020-T20-INDEX)
              = WS-LITERAL-YES
              GO TO 3425-REJECT-ASSOC-20-EXIT
           END-IF

           IF WS-0020-TBL-CLAIM-NUM(WS-0020-T20-INDEX) =
              WS-3425-CLAIM-NO
              MOVE WS-LITERAL-YES
                TO WS-0020-TBL-TRAN-REJECTED-FLAG(WS-0020-T20-INDEX)
              MOVE WS-LITERAL-IR TO WS-8000-ERROR-TYPE
              MOVE 20039 TO WS-8000-ERROR-CODE
              MOVE WS-0020-TBL-TRAN-SEQ-NO(WS-0020-T20-INDEX)
                TO WS-8000-TRAN-SEQ-NO
              MOVE 'BAD MATCH 21-11' TO WS-8000-FIELD-NAME1
              MOVE 'T11 SEQ NO' TO WS-8000-BAD-DATA1
              MOVE 3425 TO WS-8000-PARAGRAPH-NO
              MOVE 20 TO WS-8000-TRAN-TYPE
              MOVE WS-0020-TBL-POLICY-NO(WS-0020-T20-INDEX)
                TO WS-8000-POLICY-NO
              MOVE WS-0020-TBL-RECORD-NUM(WS-0020-T20-INDEX)
                TO WS-8000-RECORD-NUM
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF.

       3425-REJECT-ASSOC-20-EXIT.
           EXIT.

