      ***************************************************************
      * File:      IR3430.CBL
      * Author:    Laura Dittamo
      * Date:      7/10/96
      * Purpose:
      *    A corresponding type 14 record must exist for each type
      *    15.  The following fields are used to pair type 14 records
      *    with type 15s:  Reporting Organization, Location State,
      *    Company/County, Policy Number, Crop Year, Location County,
      *    Insurance Plan, Crop Code, and Coverage Flag.
      *    The following fields exist on both Type 15 and 14:
      *    Rate State and Rate County
      *
      *    This module compares the values of these fields; the
      *    values must match else an error is recorded.
      ***************************************************************

       3430-FIND-T14-FOR-T15.

      $IF DEBUG-SW DEFINED
           DISPLAY '3430-FIND/VALIDATE RELATED TYPE 14 RECORDS'
           UPON CONSOLE
      $END

      $IF DEBUG-SW DEFINED
           DISPLAY 'T14(01)= ', WS-0014-TBL-TYPE-14(1)
           UPON CONSOLE
           DISPLAY 'T14(02)= ', WS-0014-TBL-TYPE-14(2)
           UPON CONSOLE
           DISPLAY 'T14(03)= ', WS-0014-TBL-TYPE-14(3)
           UPON CONSOLE
           DISPLAY 'T14(04)= ', WS-0014-TBL-TYPE-14(4)
           UPON CONSOLE
           DISPLAY 'T14(05)= ', WS-0014-TBL-TYPE-14(5)
           UPON CONSOLE
           DISPLAY 'T14 RECORD COUNT = ', WS-0014-T14-REC-COUNT
           UPON CONSOLE
      $END

           INITIALIZE WS-3430-LOCAL

           IF WS-0015-T15-REC-COUNT > ZERO
              PERFORM 3430-PROCESS-TYPE-15
                 THRU 3430-PROCESS-TYPE-15-EXIT
                 WITH TEST AFTER
              VARYING WS-0015-T15-INT-INDEX FROM 1 BY 1
                UNTIL WS-0015-T15-INT-INDEX = WS-0015-T15-REC-COUNT
           END-IF.


       3430-FIND-T14-FOR-T15-EXIT.
           EXIT.



       3430-PROCESS-TYPE-15.

           SET WS-0015-T15-INDEX TO WS-0015-T15-INT-INDEX
      $IF DEBUG-SW DEFINED
           DISPLAY 'T15 SEQ # = ',
           WS-0015-TBL-TRAN-SEQ-NO(WS-0015-T15-INDEX)
           UPON CONSOLE
      $END

           IF WS-0015-TBL-TRAN-REJECTED-FLAG(WS-0015-T15-INDEX)
              = WS-LITERAL-YES
      *       *** CHECK THE SPECIFIC NUMERIC FIELDS WHICH ARE USED TO
      *       *** MATCH A TYPE 15 WITH A TYPE 14.  ALSO, CHECK WHETHER ANY
      *       *** DERIVED FIELDS USED IN THIS EDIT ARE IN ERROR.
              IF WS-0015-TBL-CROP-CD(WS-0015-T15-INDEX)
                 IS NOT NUMERIC
                 OR WS-0015-TBL-LOCATION-COUNTY(WS-0015-T15-INDEX)
                 IS NOT NUMERIC
                 OR WS-0015-TBL-INSURANCE-PLAN-CD(WS-0015-T15-INDEX)
                 IS NOT NUMERIC
                 OR WS-0015-TBL-CROP-POLICY-TY(WS-0015-T15-INDEX)
                 EQUAL SPACES
                 GO TO 3430-PROCESS-TYPE-15-EXIT
              END-IF
           END-IF

      $IF DEBUG-SW DEFINED
           DISPLAY 'T15 SEQ # = ',
           WS-0015-TBL-TRAN-SEQ-NO(WS-0015-T15-INDEX)
           UPON CONSOLE
           DISPLAY 'T15 CROP ',
           WS-0015-TBL-CROP-CD(WS-0015-T15-INDEX), ' COUNTY ',
           WS-0015-TBL-LOCATION-COUNTY(WS-0015-T15-INDEX), ' CPT ',
           WS-0015-TBL-CROP-POLICY-TY(WS-0015-T15-INDEX), ' CVG CD ',
           WS-0015-TBL-COVERAGE-FLG(WS-0015-T15-INDEX), ' INS PLAN '
           WS-0015-TBL-INSURANCE-PLAN-CD(WS-0015-T15-INDEX)
           UPON CONSOLE
      $END

           MOVE WS-LITERAL-NO TO WS-3430-TYPE-14-MATCH-FOUND-SW

      **** DETERMINE WHETHER A MATCHING TYPE 14 RECORD EXISTS

           IF WS-0014-T14-REC-COUNT > ZEROS
              PERFORM 3430-LOOKUP-MATCHING-14
                 THRU 3430-LOOKUP-MATCHING-14-EXIT
                 WITH TEST AFTER
              VARYING WS-0014-T14-INT-INDEX FROM 1 BY 1
                UNTIL WS-0014-T14-INT-INDEX = WS-0014-T14-REC-COUNT
                   OR WS-3430-TYPE-14-MATCH-FOUND-SW = WS-LITERAL-YES
           ELSE
              MOVE WS-LITERAL-NO TO WS-3430-TYPE-14-MATCH-FOUND-SW
           END-IF

           IF WS-3430-TYPE-14-MATCH-FOUND-SW = WS-LITERAL-NO
      ******* THERE IS NO CORRESPONDING TYPE 14 FOR THIS TYPE 15 RECORD
              MOVE WS-LITERAL-YES
                TO WS-0015-TBL-TRAN-REJECTED-FLAG(WS-0015-T15-INDEX)
              MOVE WS-0015-TBL-TRAN-SEQ-NO(WS-0015-T15-INDEX)
                TO WS-8000-TRAN-SEQ-NO
              MOVE WS-LITERAL-IR TO WS-8000-ERROR-TYPE
              MOVE 15087 TO WS-8000-ERROR-CODE
              MOVE 3430 TO WS-8000-PARAGRAPH-NO
              MOVE 'NO MATCHING T14'          TO WS-8000-FIELD-NAME1
              MOVE 'NEED MATCHING T14 RECORD' TO WS-8000-CORR-DATA1
              MOVE 15 TO WS-8000-TRAN-TYPE
              MOVE WS-0015-TBL-POLICY-NO(WS-0015-T15-INDEX)
                TO WS-8000-POLICY-NO
              MOVE WS-0015-TBL-LOCATION-COUNTY(WS-0015-T15-INDEX)
                TO WS-8000-LOC-COUNTY
              MOVE WS-0015-TBL-INSURANCE-PLAN-CD(WS-0015-T15-INDEX)
                TO WS-8000-INSURANCE-PLAN-ID
              MOVE WS-0015-TBL-CROP-CD(WS-0015-T15-INDEX)
                TO WS-8000-CROP-CD
              MOVE WS-0015-TBL-RECORD-NUM(WS-0015-T15-INDEX)
                TO WS-8000-RECORD-NUM
              MOVE WS-LITERAL-YES TO WS-0006-REJECT-15S-FLAG
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           ELSE
              IF WS-0014-TBL-TRAN-REJECTED-FLAG(WS-0014-T14-INDEX)
                 EQUAL WS-LITERAL-YES
      ******  MATCHING 14 WAS REJECTED
                 MOVE WS-LITERAL-YES
                   TO WS-0015-TBL-TRAN-REJECTED-FLAG(WS-0015-T15-INDEX)
                 MOVE WS-0015-TBL-TRAN-SEQ-NO(WS-0015-T15-INDEX)
                   TO WS-8000-TRAN-SEQ-NO
                 MOVE WS-LITERAL-IR TO WS-8000-ERROR-TYPE
                 MOVE 15088 TO WS-8000-ERROR-CODE
                 MOVE 3430 TO WS-8000-PARAGRAPH-NO
                 MOVE 'T14 IN ERROR' TO WS-8000-FIELD-NAME1
                 MOVE WS-0014-TBL-TRAN-SEQ-NO(WS-0014-T14-INDEX)
                   TO WS-8000-CORR-DATA1
                 MOVE 15 TO WS-8000-TRAN-TYPE
                 MOVE WS-0015-TBL-POLICY-NO(WS-0015-T15-INDEX)
                   TO WS-8000-POLICY-NO
                 MOVE WS-0015-TBL-LOCATION-COUNTY(WS-0015-T15-INDEX)
                   TO WS-8000-LOC-COUNTY
                 MOVE WS-0015-TBL-INSURANCE-PLAN-CD(WS-0015-T15-INDEX)
                   TO WS-8000-INSURANCE-PLAN-ID
                 MOVE WS-0015-TBL-CROP-CD(WS-0015-T15-INDEX)
                   TO WS-8000-CROP-CD
                 MOVE WS-0015-TBL-RECORD-NUM(WS-0015-T15-INDEX)
                   TO WS-8000-RECORD-NUM
                 MOVE WS-LITERAL-YES TO WS-0006-REJECT-15S-FLAG
                 PERFORM 8000-RECORD-TRAN-ERROR
                    THRU 8000-RECORD-TRAN-ERROR-EXIT
              END-IF

           END-IF.


       3430-PROCESS-TYPE-15-EXIT.
           EXIT.


       3430-LOOKUP-MATCHING-14.

           SET WS-0014-T14-INDEX TO WS-0014-T14-INT-INDEX


           IF WS-0014-TBL-TRAN-REJECTED-FLAG(WS-0014-T14-INDEX)
              EQUAL WS-LITERAL-YES

      ******* ERRORS WERE ENCOUNTERED WITH THIS TYPE 14.
      ******* CHECK THE SPECIFIC NUMERIC FIELDS WHICH ARE USED TO
      ******* MATCH A TYPE 15 WITH A TYPE 14.  ALSO, CHECK WHETHER ANY
      ******* DERIVED FIELDS USED BY THIS EDIT ARE IN ERROR.
              IF WS-0014-TBL-CROP-CD(WS-0014-T14-INDEX)
                 IS NOT NUMERIC
                 OR WS-0014-TBL-LOCATION-COUNTY(WS-0014-T14-INDEX)
                 IS NOT NUMERIC
                 OR WS-0014-TBL-INSURANCE-PLAN-CD(WS-0014-T14-INDEX)
                 IS NOT NUMERIC
                 OR WS-0014-TBL-CROP-POLICY-TY(WS-0014-T14-INDEX)
                 EQUAL SPACES
                 GO TO 3430-LOOKUP-MATCHING-14-EXIT
              END-IF
           END-IF

      $IF DEBUG-SW DEFINED
           DISPLAY 'T14 SEQ # = ',
           WS-0014-TBL-TRAN-SEQ-NO(WS-0014-T14-INDEX)
           UPON CONSOLE
           DISPLAY 'T14 CROP ',
             WS-0014-TBL-CROP-CD(WS-0014-T14-INDEX), ' COUNTY ',
             WS-0014-TBL-LOCATION-COUNTY(WS-0014-T14-INDEX), ' CPT ',
             WS-0014-TBL-CROP-POLICY-TY(WS-0014-T14-INDEX),
             ' CVG CD ',
             WS-0014-TBL-COVERAGE-FLG(WS-0014-T14-INDEX),
             ' INS PLAN '
             WS-0014-TBL-INSURANCE-PLAN-CD(WS-0014-T14-INDEX)
           UPON CONSOLE
      $END

           IF ((WS-0014-TBL-CROP-CD(WS-0014-T14-INDEX)
              = WS-0015-TBL-CROP-CD(WS-0015-T15-INDEX)) AND
              (WS-0014-TBL-LOCATION-COUNTY(WS-0014-T14-INDEX)
              = WS-0015-TBL-LOCATION-COUNTY(WS-0015-T15-INDEX)) AND
              (WS-0014-TBL-CROP-POLICY-TY(WS-0014-T14-INDEX)
              = WS-0015-TBL-CROP-POLICY-TY(WS-0015-T15-INDEX)) AND
              (WS-0014-TBL-COVERAGE-FLG(WS-0014-T14-INDEX)
              = WS-0015-TBL-COVERAGE-FLG(WS-0015-T15-INDEX)) AND
              (WS-0014-TBL-INSURANCE-PLAN-CD(WS-0014-T14-INDEX)
              = WS-0015-TBL-INSURANCE-PLAN-CD(WS-0015-T15-INDEX)))

              MOVE WS-LITERAL-YES TO WS-3430-TYPE-14-MATCH-FOUND-SW

      *       THE FOLLOWING LOGIC ENSURES THAT FIELDS SHARED BY
      *       BOTH THE 15 AND 14 HAVE MATCHING VALUES
              IF WS-0014-TBL-RATE-STATE(WS-0014-T14-INDEX) <>
                 WS-0015-TBL-RATE-STATE(WS-0015-T15-INDEX)
      *          THE RATE STATE OF THE CORRESPONDING TYPE 14 DOES
      *          NOT MATCH THAT OF THE CURRENT TYPE 15

      ********** REJECT THE 15
                 MOVE WS-LITERAL-YES
                   TO WS-0015-TBL-TRAN-REJECTED-FLAG
                      (WS-0015-T15-INDEX)
                 MOVE WS-LITERAL-IR TO WS-8000-ERROR-TYPE
                 MOVE 15089 TO WS-8000-ERROR-CODE
                 MOVE WS-0015-TBL-TRAN-SEQ-NO(WS-0015-T15-INDEX)
                   TO WS-8000-TRAN-SEQ-NO
                 MOVE 'T15 RATE STATE'
                   TO WS-8000-FIELD-NAME1
                 MOVE WS-0015-TBL-RATE-STATE(WS-0015-T15-INDEX)
                   TO WS-8000-BAD-DATA1
                 STRING 'T14 RATE STATE = '
                    DELIMITED BY SIZE
                    WS-0014-TBL-RATE-STATE(WS-0014-T14-INDEX)
                    DELIMITED BY SIZE
                    INTO WS-8000-CORR-DATA1
                 END-STRING
                 MOVE 'T14 ERROR' TO WS-8000-FIELD-NAME2
                 MOVE WS-0014-TBL-TRAN-SEQ-NO(WS-0014-T14-INDEX)
                   TO WS-8000-CORR-DATA2
                 MOVE 3430 TO WS-8000-PARAGRAPH-NO
                 MOVE 15 TO WS-8000-TRAN-TYPE
                 MOVE WS-0015-TBL-POLICY-NO(WS-0015-T15-INDEX)
                   TO WS-8000-POLICY-NO
                 MOVE WS-0015-TBL-LOCATION-COUNTY
                      (WS-0015-T15-INDEX)
                   TO WS-8000-LOC-COUNTY
                 MOVE WS-0015-TBL-INSURANCE-PLAN-CD
                      (WS-0015-T15-INDEX)
                   TO WS-8000-INSURANCE-PLAN-ID
                 MOVE WS-0015-TBL-CROP-CD(WS-0015-T15-INDEX)
                   TO WS-8000-CROP-CD
                 MOVE WS-0015-TBL-RECORD-NUM(WS-0015-T15-INDEX)
                   TO WS-8000-RECORD-NUM
                 PERFORM 8000-RECORD-TRAN-ERROR
                    THRU 8000-RECORD-TRAN-ERROR-EXIT
              END-IF
           END-IF.


       3430-LOOKUP-MATCHING-14-EXIT.
           EXIT.


