      ****************************************************************
      *  File   : IR3485.CBL
      *  Author : Yo-I Tsui
      *  Date   : 6/28/96
      *  Purpose: THIS MODULE VALIDATES UNIT INDEMNITY AND ACRES.
      *           IT USES THE TYPE 21 UNIT TABLE AND TYPE 11 UNIT
      *           LIABILITY TABLE.  THESE TABLES WERE BUILT AS THE
      *           TYPE 21 AND TYPE 11 TRANSACTION TABLES WERE
      *           POPULATED FOR INTER RECORD EDITS.
      *
      * IN THIS EDIT:
      *  - THE TOTAL INDEMNITY FOR A UNIT CANNOT BE NEGATIVE
      *
      *  - IF THE TYPE 21 IS UNDER A GROUP INSURANCE PLAN
      *       TOTAL UNIT INDEMNITY MUST BE > 5% OF TOTAL UNIT LIABILITY
      *
      *  - (TOTAL UNIT LIABILITY - TOTAL UNIT INDEMNITY) MUST BE <=
      *    10 DOLLARS AND <= 1/10 OF 1% (.001) OF TOTAL UNIT LIABILITY
      *
      *  - THE HIGHEST STAGE GUARANTEE FOR THE T21 UNIT MUST BE <=
      *    THE HIGHEST GUARANTEE PER ACRE FOR THE CORRESPONDING T11 UNIT
      *
      *  - THE HIGHEST LOSS GUARANTEE FOR THE T21 UNIT MUST BE <=
      *    THE HIGHEST TOTAL GUARANTEE FOR THE CORRESPONDING T11 UNIT
      *
      *  - IF THE UNIT HAS REPLANTED ACREAGE, THE TOTAL REPLANTED
      *    ACREAGE FOR THE UNIT MUST BE >= THE LESSER OF
      *    (20 ACRES OR 20% OF TYPE 11 TOTAL UNIT ACREAGE).
      *
      *    HOWEVER:
      *    - FORAGE SEEDING HAS NO MINIMUM REPLANT ACREAGE
      *    - PEANUTS MUST BE >= THE LESSER OF
      *      (10 ACRES OR 10% OF THE TYPE 11 TOTAL UNIT ACREAGE)
      ****************************************************************

       3485-COMP-UNIT-TOT-21-11.

      $IF DEBUG-SW DEFINED
           DISPLAY '3485-COMPARE T21 UNIT INDEM AND T11 UNIT LIABILITY'
           UPON CONSOLE
      $END

      $IF DEBUG-SW DEFINED
           DISPLAY 'T11(01) = ' WS-0011-UNIT-TBL-REC(1)
           UPON CONSOLE
           DISPLAY 'T11(02) = ' WS-0011-UNIT-TBL-REC(2)
           UPON CONSOLE
           DISPLAY 'T11(03) = ' WS-0011-UNIT-TBL-REC(3)
           UPON CONSOLE
           DISPLAY 'T11(04) = ' WS-0011-UNIT-TBL-REC(4)
           UPON CONSOLE
           DISPLAY 'T11(05) = ' WS-0011-UNIT-TBL-REC(5)
           UPON CONSOLE
      $END

           IF WS-0021-UNIT-REC-COUNT > 0 THEN
              PERFORM 3485-PROCESS-TYPE-21
                 THRU 3485-PROCESS-TYPE-21-EXIT
                 WITH TEST AFTER
              VARYING WS-0021-UNIT-INT-INDEX FROM 1 BY 1
                UNTIL WS-0021-UNIT-INT-INDEX = WS-0021-UNIT-REC-COUNT
           END-IF.

       3485-COMP-UNIT-TOT-21-11-EXIT.
           EXIT.


       3485-PROCESS-TYPE-21.

           SET WS-0021-UNIT-INDEX TO WS-0021-UNIT-INT-INDEX
           INITIALIZE WS-3485-WORK
           IF WS-0021-UNIT-TBL-CLAIM-NUMBER(WS-0021-UNIT-INDEX)
              IS NOT NUMERIC
              OR WS-0021-UNIT-TBL-CROP(WS-0021-UNIT-INDEX)
              IS NOT NUMERIC
              OR WS-0021-UNIT-TBL-LOC-COUNTY(WS-0021-UNIT-INDEX)
              IS NOT NUMERIC
              OR WS-0021-UNIT-TBL-OPTIONAL-UNIT(WS-0021-UNIT-INDEX)
              IS NOT NUMERIC
              OR WS-0021-UNIT-TBL-INS-PLAN-CD(WS-0021-UNIT-INDEX)
              IS NOT NUMERIC
              OR WS-0021-UNIT-TBL-TOT-INDEMNITY(WS-0021-UNIT-INDEX)
              IS NOT NUMERIC
              OR WS-0021-UNIT-TBL-TOT-DET-ACRE(WS-0021-UNIT-INDEX)
              IS NOT NUMERIC
              OR WS-0021-UNIT-TBL-REPLANT-ACRES(WS-0021-UNIT-INDEX)
              IS NOT NUMERIC
              OR WS-0021-UNIT-TBL-STAGE-GUAR(WS-0021-UNIT-INDEX)
              IS NOT NUMERIC
              OR WS-0021-UNIT-TBL-LOSS-GUAR(WS-0021-UNIT-INDEX)
              IS NOT NUMERIC
      ******* THIS RECORD CANNOT BE VALIDLY COMPARED WITH
      ******* TYPE 11 UNIT LIABILITY
              GO TO 3485-PROCESS-TYPE-21-EXIT
           END-IF


      $IF DEBUG-SW DEFINED
           DISPLAY 'T21 VALUES ',
           ' CLAIM NO ',
           WS-0021-UNIT-TBL-CLAIM-NUMBER(WS-0021-UNIT-INDEX),
           ' CROP CD ',
           WS-0021-UNIT-TBL-CROP(WS-0021-UNIT-INDEX),
           ' CROP TYPE ',
           WS-0021-UNIT-TBL-CROP-TYPE(WS-0021-UNIT-INDEX),
           ' COUNTY ',
           WS-0021-UNIT-TBL-LOC-COUNTY(WS-0021-UNIT-INDEX),
           ' BASIC UNIT ',
           WS-0021-UNIT-TBL-BASIC-UNIT(WS-0021-UNIT-INDEX),
           ' OPT UNIT ',
           WS-0021-UNIT-TBL-OPTIONAL-UNIT(WS-0021-UNIT-INDEX),
           ' INS PLAN CD ',
           WS-0021-UNIT-TBL-INS-PLAN-CD(WS-0021-UNIT-INDEX),
           ' TOT INDEMNITY = ',
           WS-0021-UNIT-TBL-TOT-INDEMNITY(WS-0021-UNIT-INDEX)
           ' TOT DET ACRE ',
           WS-0021-UNIT-TBL-TOT-DET-ACRE(WS-0021-UNIT-INDEX)
           ' REPLANT ACRES ',
           WS-0021-UNIT-TBL-REPLANT-ACRES(WS-0021-UNIT-INDEX)
           ' STAGE GUARANTEE ',
           WS-0021-UNIT-TBL-STAGE-GUAR(WS-0021-UNIT-INDEX)
           ' LOSS GUARANTEE ',
           WS-0021-UNIT-TBL-LOSS-GUAR(WS-0021-UNIT-INDEX)
           UPON CONSOLE
      $END

      ******* THE TOTAL INDEMNITY CANNOT BE LESS THAN 0
           IF WS-0021-UNIT-TBL-TOT-INDEMNITY(WS-0021-UNIT-INDEX) < 0
              MOVE 21067 TO WS-3485-ERROR-CODE
              MOVE 'TOTAL T21 UNIT INDEM' TO WS-3485-FIELD-NAME1
              MOVE WS-0021-UNIT-TBL-TOT-INDEMNITY(WS-0021-UNIT-INDEX)
                TO WS-3485-BAD-DATA1
              MOVE '>= 0' TO WS-3485-CORR-DATA1

      ******* POPULATE THE CLAIM NUMBER USED TO REJECT 20/21 RECORDS
              MOVE WS-0021-UNIT-TBL-CLAIM-NUMBER(WS-0021-UNIT-INDEX)
                TO WS-3485-T21-CLAIM-NO

      ******* REJECT ALL 21S AND 20S WITH WS-3485-T21-CLAIM-NO
              IF WS-0021-T21-REC-COUNT > ZERO
                 PERFORM 3485-REJECT-ASSOC-21
                    THRU 3485-REJECT-ASSOC-21-EXIT
                    WITH TEST AFTER
                 VARYING WS-3485-T21-ERROR-INDEX FROM 1 BY 1
                   UNTIL WS-3485-T21-ERROR-INDEX
                       = WS-0021-T21-REC-COUNT
      ***     RESTORE MAIN LOOP T21 INDEX VALUE
                 SET WS-0021-T21-INDEX TO WS-0021-T21-INT-INDEX
              END-IF

              IF WS-0020-T20-REC-COUNT > ZERO
                 PERFORM 3485-REJECT-ASSOC-20
                    THRU 3485-REJECT-ASSOC-20-EXIT
                    WITH TEST AFTER
                 VARYING WS-0020-T20-INT-INDEX FROM 1 BY 1
                   UNTIL WS-0020-T20-INT-INDEX
                       = WS-0020-T20-REC-COUNT
              END-IF

              GO TO 3485-PROCESS-TYPE-21-EXIT
           END-IF

           MOVE WS-LITERAL-NO TO WS-3485-T11-UNIT-FOUND-SW

           IF WS-0011-UNIT-REC-COUNT > 0
              PERFORM 3485-FIND-T11-UNIT-LIAB
                 THRU 3485-FIND-T11-UNIT-LIAB-EXIT
                 WITH TEST AFTER
              VARYING WS-0011-UNIT-INT-INDEX FROM 1 BY 1
                UNTIL WS-0011-UNIT-INT-INDEX = WS-0011-UNIT-REC-COUNT
                   OR WS-3485-T11-UNIT-FOUND-SW = WS-LITERAL-YES
           END-IF


           IF WS-3485-T11-UNIT-FOUND-SW = WS-LITERAL-YES
              INITIALIZE WS-3485-WORK
              PERFORM 3485-COMP-GRP-INDEM-LIAB
                 THRU 3485-COMP-GRP-INDEM-LIAB-EXIT

              INITIALIZE WS-3485-WORK
              PERFORM 3485-COMPARE-INDEM-W-LIAB
                 THRU 3485-COMPARE-INDEM-W-LIAB-EXIT

              INITIALIZE WS-3485-WORK
              PERFORM 3485-COMP-STAGE-W-GPA
                 THRU 3485-COMP-STAGE-W-GPA-EXIT

              INITIALIZE WS-3485-WORK
              PERFORM 3485-COMP-LOSS-W-TOT-GUAR
                 THRU 3485-COMP-LOSS-W-TOT-GUAR-EXIT

              INITIALIZE WS-3485-WORK
              PERFORM 3485-VAL-REPLANT-ACREAGE
                 THRU 3485-VAL-REPLANT-ACREAGE-EXIT
           ELSE
              MOVE 3485 TO WS-8020-PARAGRAPH-NO
              MOVE 90051 TO WS-8020-INT-ERROR-NO
              MOVE 'T21 UNIT INDEM' TO WS-8020-FIELD-NAME
              MOVE SPACES TO WS-8020-BAD-DATA
              MOVE WS-LITERAL-NO TO WS-8020-ABORT-PROGRAM
              PERFORM 8020-RECORD-INT-ERROR
                 THRU 8020-RECORD-INT-ERROR-EXIT
           END-IF.


       3485-PROCESS-TYPE-21-EXIT.
           EXIT.


       3485-FIND-T11-UNIT-LIAB.

           SET WS-0011-UNIT-INDEX TO WS-0011-UNIT-INT-INDEX

           IF WS-0011-UNIT-TBL-LOC-COUNTY(WS-0011-UNIT-INDEX)
              IS NOT NUMERIC
              OR WS-0011-UNIT-TBL-OPTIONAL-UNIT(WS-0011-UNIT-INDEX)
              IS NOT NUMERIC
              OR WS-0011-UNIT-TBL-INS-PLAN-CD(WS-0011-UNIT-INDEX)
              IS NOT NUMERIC
              OR WS-0011-UNIT-TBL-TOT-LIABILITY(WS-0011-UNIT-INDEX)
              IS NOT NUMERIC
              OR WS-0011-UNIT-TBL-TOT-RPT-ACRES(WS-0011-UNIT-INDEX)
              IS NOT NUMERIC
              OR WS-0011-UNIT-TBL-TOT-GUARANTEE(WS-0011-UNIT-INDEX)
              IS NOT NUMERIC
              OR WS-0011-UNIT-TBL-GUAR-PER-ACRE(WS-0011-UNIT-INDEX)
              IS NOT NUMERIC
      ******* THIS RECORD CANNOT BE VALIDLY COMPARED WITH
      ******* TYPE 21 UNIT INDEMNITY
              GO TO 3485-FIND-T11-UNIT-LIAB-EXIT
           END-IF


      $IF DEBUG-SW DEFINED
           DISPLAY 'T11 VALUES ',
           ' CROP TYPE ',
           WS-0011-UNIT-TBL-CROP-TYPE(WS-0011-UNIT-INDEX),
           ' COUNTY ',
           WS-0011-UNIT-TBL-LOC-COUNTY(WS-0011-UNIT-INDEX),
           ' BASIC UNIT ',
           WS-0011-UNIT-TBL-BASIC-UNIT(WS-0011-UNIT-INDEX),
           ' OPT UNIT ',
           WS-0011-UNIT-TBL-OPTIONAL-UNIT(WS-0011-UNIT-INDEX),
           ' INS PLAN ',
           WS-0011-UNIT-TBL-INS-PLAN-CD(WS-0011-UNIT-INDEX),
           ' TOT LIABILITY = ',
           WS-0011-UNIT-TBL-TOT-LIABILITY(WS-0011-UNIT-INDEX)
           ' TOT RPT ACRES ',
           WS-0011-UNIT-TBL-TOT-RPT-ACRES(WS-0011-UNIT-INDEX)
           ' TOT GUAR ',
           WS-0011-UNIT-TBL-TOT-GUARANTEE(WS-0011-UNIT-INDEX)
           ' GUAR PER ACRE '
           WS-0011-UNIT-TBL-GUAR-PER-ACRE(WS-0011-UNIT-INDEX)
           UPON CONSOLE
      $END

      ******* FIND THE MATCHING T11 UNIT FOR THE T21
           IF WS-0011-UNIT-TBL-CROP-TYPE(WS-0011-UNIT-INDEX) =
              WS-0021-UNIT-TBL-CROP-TYPE(WS-0021-UNIT-INDEX) AND
              WS-0011-UNIT-TBL-LOC-COUNTY(WS-0011-UNIT-INDEX) =
              WS-0021-UNIT-TBL-LOC-COUNTY(WS-0021-UNIT-INDEX) AND
              WS-0011-UNIT-TBL-BASIC-UNIT(WS-0011-UNIT-INDEX) =
              WS-0021-UNIT-TBL-BASIC-UNIT(WS-0021-UNIT-INDEX) AND
              WS-0011-UNIT-TBL-OPTIONAL-UNIT(WS-0011-UNIT-INDEX) =
              WS-0021-UNIT-TBL-OPTIONAL-UNIT(WS-0021-UNIT-INDEX)

              MOVE WS-LITERAL-YES TO WS-3485-T11-UNIT-FOUND-SW
           END-IF.


       3485-FIND-T11-UNIT-LIAB-EXIT.
           EXIT.


       3485-COMP-GRP-INDEM-LIAB.

      $IF DEBUG-SW DEFINED
           DISPLAY 'CHECKING TOTAL UNIT INDEMNITY vs LIABILITY FOR GRP'
           UPON CONSOLE
      $END

      ******* IF TYPE 21 INSURANCE PLAN = GRP THEN TOTAL UNIT INDEMNITY
      ******* MUST BE > 5% OF TOTAL UNIT LIABILITY
           IF WS-0021-UNIT-TBL-INS-PLAN-CD(WS-0021-UNIT-INDEX)
              = WS-LITERAL-GRP
              COMPUTE WS-3485-5-PCT-OF-T11-UNIT-LIAB ROUNDED =
                 WS-0011-UNIT-TBL-TOT-LIABILITY(WS-0011-UNIT-INDEX)
                 * WS-3485-LITERAL-5-PCT
                 ON SIZE ERROR
                    MOVE 3485 TO WS-8020-PARAGRAPH-NO
                    MOVE 90017 TO WS-8020-INT-ERROR-NO
                    MOVE 'UNIT LIAB*5%' TO WS-8020-FIELD-NAME
                    MOVE WS-3485-5-PCT-OF-T11-UNIT-LIAB
                      TO WS-8020-BAD-DATA
                    MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                    PERFORM 8020-RECORD-INT-ERROR
                       THRU 8020-RECORD-INT-ERROR-EXIT
              END-COMPUTE

      $IF DEBUG-SW DEFINED
           DISPLAY '25% UNIT LIABILITY = ',
           WS-3485-5-PCT-OF-T11-UNIT-LIAB
           UPON CONSOLE
           DISPLAY 'UNIT INDEMNITY = ',
           WS-0021-UNIT-TBL-TOT-INDEMNITY(WS-0021-UNIT-INDEX)
           UPON CONSOLE
      $END

              IF WS-0021-UNIT-TBL-TOT-INDEMNITY(WS-0021-UNIT-INDEX)
                 <= WS-3485-5-PCT-OF-T11-UNIT-LIAB
                 MOVE 21068 TO WS-3485-ERROR-CODE
                 MOVE 'T21 UNIT INDEM' TO WS-3485-FIELD-NAME1
                 MOVE WS-0021-UNIT-TBL-TOT-INDEMNITY
                      (WS-0021-UNIT-INDEX)
                   TO WS-3485-BAD-DATA1
                 STRING 'UNIT INDEM MUST BE > THAN '
                   DELIMITED BY SIZE
                   WS-3485-5-PCT-OF-T11-UNIT-LIAB
                   DELIMITED BY SIZE
                   INTO WS-3485-CORR-DATA1
                 END-STRING

      ******* POPULATE THE CLAIM NUMBER USED TO REJECT 20/21 RECORDS
                 MOVE WS-0021-UNIT-TBL-CLAIM-NUMBER
                      (WS-0021-UNIT-INDEX)
                   TO WS-3485-T21-CLAIM-NO

      ******* REJECT ALL 21S AND 20S WITH WS-3485-T21-CLAIM-NO
                 IF WS-0021-T21-REC-COUNT > 0
                    PERFORM 3485-REJECT-ASSOC-21
                       THRU 3485-REJECT-ASSOC-21-EXIT
                       WITH TEST AFTER
                    VARYING WS-3485-T21-ERROR-INDEX FROM 1 BY 1
                      UNTIL WS-3485-T21-ERROR-INDEX
                          = WS-0021-T21-REC-COUNT
      ***     RESTORE MAIN LOOP T21 INDEX VALUE
                    SET WS-0021-T21-INDEX TO WS-0021-T21-INT-INDEX
                 END-IF

                 IF WS-0020-T20-REC-COUNT > 0
                    PERFORM 3485-REJECT-ASSOC-20
                       THRU 3485-REJECT-ASSOC-20-EXIT
                       WITH TEST AFTER
                    VARYING WS-0020-T20-INT-INDEX FROM 1 BY 1
                      UNTIL WS-0020-T20-INT-INDEX
                          = WS-0020-T20-REC-COUNT
                 END-IF
              END-IF.


       3485-COMP-GRP-INDEM-LIAB-EXIT.
           EXIT.


       3485-COMPARE-INDEM-W-LIAB.

      $IF DEBUG-SW DEFINED
           DISPLAY 'CHECKING UNIT LIABLITY vs INDEMNITY'
           UPON CONSOLE
      $END

      ***  IF 21 TOTAL UNIT INDEMNITY > TYPE 11 TOTAL LIABILITY
      ***  THE DIFFERENCE CANNOT BE MORE THAN THE GREATER OF ($10
      ***  OR 1/10% OF TYPE 11 TOTAL UNIT LIABILITY

           IF WS-0021-UNIT-TBL-TOT-INDEMNITY(WS-0021-UNIT-INDEX)
              <= WS-0011-UNIT-TBL-TOT-LIABILITY(WS-0011-UNIT-INDEX)
              GO TO 3485-COMPARE-INDEM-W-LIAB-EXIT
           END-IF

           COMPUTE WS-3485-T11-ADJUSTED-UNIT-LIAB ROUNDED =
              WS-0011-UNIT-TBL-TOT-LIABILITY(WS-0011-UNIT-INDEX)
              * WS-3485-LITERAL-TENTH-OF-1-PCT
              ON SIZE ERROR
                 MOVE 3485 TO WS-8020-PARAGRAPH-NO
                 MOVE 90017 TO WS-8020-INT-ERROR-NO
                 MOVE 'UNIT LIAB*.001' TO WS-8020-FIELD-NAME
                 MOVE WS-3485-T11-ADJUSTED-UNIT-LIAB
                   TO WS-8020-BAD-DATA
                 MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                 PERFORM 8020-RECORD-INT-ERROR
                    THRU 8020-RECORD-INT-ERROR-EXIT
           END-COMPUTE

      $IF DEBUG-SW DEFINED
           DISPLAY '0.1% OF TOTAL UNIT LIABILITY = ',
           WS-3485-T11-ADJUSTED-UNIT-LIAB
           UPON CONSOLE
      $END

           MOVE ZERO TO WS-3485-INDEMNITY-DELTA
           COMPUTE WS-3485-INDEMNITY-DELTA
               = WS-0011-UNIT-TBL-TOT-LIABILITY
               (WS-0011-UNIT-INDEX) - WS-0021-UNIT-TBL-TOT-INDEMNITY
               (WS-0021-UNIT-INDEX)
              ON SIZE ERROR
                 MOVE 3485 TO WS-8020-PARAGRAPH-NO
                 MOVE 90017 TO WS-8020-INT-ERROR-NO
                 MOVE 'LIAB - INDEM' TO WS-8020-FIELD-NAME
                 MOVE ZEROS TO WS-8020-BAD-DATA
                 MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                 PERFORM 8020-RECORD-INT-ERROR
                    THRU 8020-RECORD-INT-ERROR-EXIT
           END-COMPUTE
           MOVE WS-3485-INDEMNITY-DELTA TO WS-3485-INDEMNITY-DELTA-X

      $IF DEBUG-SW DEFINED
           DISPLAY 'UNIT LIABILITY - UNIT INDEMNITY = ',
           WS-3485-INDEMNITY-DELTA-X
           UPON CONSOLE
      $END

      *    *** IF 1/10% OF LIABILITY < 10 THEN 10 BECOMES
      *    *** THE NUMBER WHICH CANNOT BE EXCEEDED
           IF WS-3485-T11-ADJUSTED-UNIT-LIAB < 10
              MOVE 10 TO WS-3485-T11-ADJUSTED-UNIT-LIAB
           END-IF

           IF WS-3485-INDEMNITY-DELTA
               > WS-3485-T11-ADJUSTED-UNIT-LIAB
              MOVE 21069 TO WS-3485-ERROR-CODE
              MOVE 'UNIT LIAB-INDEM' TO WS-3485-FIELD-NAME1
              MOVE WS-3485-INDEMNITY-DELTA-X
                TO WS-3485-BAD-DATA1
              STRING  'MUST BE < '
                DELIMITED BY SIZE
                WS-3485-T11-ADJUSTED-UNIT-LIAB
                DELIMITED BY SIZE
                INTO WS-3485-CORR-DATA1
              END-STRING

      ******* POPULATE THE CLAIM NUMBER USED TO REJECT 20/21 RECORDS
              MOVE WS-0021-UNIT-TBL-CLAIM-NUMBER(WS-0021-UNIT-INDEX)
                TO WS-3485-T21-CLAIM-NO

      ******* REJECT ALL 21S AND 20S WITH WS-3485-T21-CLAIM-NO
              IF WS-0021-T21-REC-COUNT > 0
                 PERFORM 3485-REJECT-ASSOC-21
                    THRU 3485-REJECT-ASSOC-21-EXIT
                    WITH TEST AFTER
                 VARYING WS-3485-T21-ERROR-INDEX FROM 1 BY 1
                   UNTIL WS-3485-T21-ERROR-INDEX
                       = WS-0021-T21-REC-COUNT
      ***     RESTORE MAIN LOOP T21 INDEX VALUE
                 SET WS-0021-T21-INDEX TO WS-0021-T21-INT-INDEX
              END-IF

              IF WS-0020-T20-REC-COUNT > 0
                 PERFORM 3485-REJECT-ASSOC-20
                    THRU 3485-REJECT-ASSOC-20-EXIT
                    WITH TEST AFTER
                 VARYING WS-0020-T20-INT-INDEX FROM 1 BY 1
                   UNTIL WS-0020-T20-INT-INDEX
                       = WS-0020-T20-REC-COUNT
              END-IF
           END-IF.


       3485-COMPARE-INDEM-W-LIAB-EXIT.
           EXIT.


       3485-COMP-STAGE-W-GPA.

      ******* THE HIGHEST STAGE GUARANTEE FOR THE T21 UNIT CANNOT BE
      ******* GREATER THAN THE HIGHEST GUARANTEE PER ACRE FOR THE
      ******* T11 UNIT
           IF WS-0021-UNIT-TBL-STAGE-GUAR(WS-0021-UNIT-INDEX) >
              WS-0011-UNIT-TBL-GUAR-PER-ACRE(WS-0011-UNIT-INDEX)
              MOVE 21075 TO WS-3485-ERROR-CODE
              MOVE 'T21 UNIT STAGE GUAR' TO WS-3485-FIELD-NAME1
              MOVE WS-0021-UNIT-TBL-STAGE-GUAR(WS-0021-UNIT-INDEX)
                TO WS-3485-STAGE-GUARANTEE-X
              MOVE WS-3485-STAGE-GUARANTEE-X TO WS-3485-BAD-DATA1
              MOVE WS-0011-UNIT-TBL-GUAR-PER-ACRE(WS-0011-UNIT-INDEX)
                TO WS-3485-GUARANTEE-PER-ACRE-X
              STRING '<= T11 UNIT GPA - '
               DELIMITED BY SIZE
               WS-3485-GUARANTEE-PER-ACRE-X
               DELIMITED BY SIZE
               INTO WS-3485-CORR-DATA1
              END-STRING

      ******* POPULATE THE CLAIM NUMBER USED TO REJECT 20/21 RECORDS
              MOVE WS-0021-UNIT-TBL-CLAIM-NUMBER(WS-0021-UNIT-INDEX)
                TO WS-3485-T21-CLAIM-NO

      ******* REJECT ALL 21S AND 20S WITH WS-3485-T21-CLAIM-NO
              IF WS-0021-T21-REC-COUNT > 0
                 PERFORM 3485-REJECT-ASSOC-21
                    THRU 3485-REJECT-ASSOC-21-EXIT
                    WITH TEST AFTER
                 VARYING WS-3485-T21-ERROR-INDEX FROM 1 BY 1
                   UNTIL WS-3485-T21-ERROR-INDEX
                       = WS-0021-T21-REC-COUNT
      ***     RESTORE MAIN LOOP T21 INDEX VALUE
                 SET WS-0021-T21-INDEX TO WS-0021-T21-INT-INDEX
              END-IF

              IF WS-0020-T20-REC-COUNT > 0
                 PERFORM 3485-REJECT-ASSOC-20
                    THRU 3485-REJECT-ASSOC-20-EXIT
                    WITH TEST AFTER
                 VARYING WS-0020-T20-INT-INDEX FROM 1 BY 1
                   UNTIL WS-0020-T20-INT-INDEX
                       = WS-0020-T20-REC-COUNT
              END-IF
           END-IF.

       3485-COMP-STAGE-W-GPA-EXIT.
           EXIT.


       3485-COMP-LOSS-W-TOT-GUAR.

      ******* COMPARE 21'S LOSS GUARANTEE AND 11'S TOTAL GUARANTEE
           IF WS-0021-UNIT-TBL-LOSS-GUAR(WS-0021-UNIT-INDEX) >
      ***     WS-0011-UNIT-TBL-TOT-GUARANTEE(WS-0011-UNIT-INDEX)
              (WS-0011-UNIT-TBL-TOT-GUARANTEE(WS-0011-UNIT-INDEX) + 3)
              MOVE 21076 TO WS-3485-ERROR-CODE
              MOVE 'T21 UNIT LOSS GUAR' TO WS-3485-FIELD-NAME1
              MOVE WS-0021-UNIT-TBL-LOSS-GUAR(WS-0021-UNIT-INDEX)
                TO WS-3485-LOSS-GUARANTEE-X
              MOVE WS-3485-LOSS-GUARANTEE-X TO WS-3485-BAD-DATA1
              MOVE WS-0011-UNIT-TBL-TOT-GUARANTEE(WS-0011-UNIT-INDEX)
                TO WS-3485-TOTAL-GUARANTEE-X
              STRING '<= T11 UNIT TOT GUAR - '
               DELIMITED BY SIZE
               WS-3485-TOTAL-GUARANTEE-X
               DELIMITED BY SIZE
               INTO WS-3485-CORR-DATA1
              END-STRING

      ******* POPULATE THE CLAIM NUMBER USED TO REJECT 20/21 RECORDS
              MOVE WS-0021-UNIT-TBL-CLAIM-NUMBER(WS-0021-UNIT-INDEX)
                TO WS-3485-T21-CLAIM-NO

      ******* REJECT ALL 21S AND 20S WITH WS-3485-T21-CLAIM-NO
              IF WS-0021-T21-REC-COUNT > 0
                 PERFORM 3485-REJECT-ASSOC-21
                    THRU 3485-REJECT-ASSOC-21-EXIT
                    WITH TEST AFTER
                 VARYING WS-3485-T21-ERROR-INDEX FROM 1 BY 1
                   UNTIL WS-3485-T21-ERROR-INDEX
                       = WS-0021-T21-REC-COUNT
      ***     RESTORE MAIN LOOP T21 INDEX VALUE
                 SET WS-0021-T21-INDEX TO WS-0021-T21-INT-INDEX
              END-IF

              IF WS-0020-T20-REC-COUNT > 0
                 PERFORM 3485-REJECT-ASSOC-20
                    THRU 3485-REJECT-ASSOC-20-EXIT
                    WITH TEST AFTER
                 VARYING WS-0020-T20-INT-INDEX FROM 1 BY 1
                   UNTIL WS-0020-T20-INT-INDEX
                       = WS-0020-T20-REC-COUNT
              END-IF
           END-IF.

       3485-COMP-LOSS-W-TOT-GUAR-EXIT.
           EXIT.


       3485-VAL-REPLANT-ACREAGE.

           IF WS-0021-UNIT-TBL-REPLANT-ACRES(WS-0021-UNIT-INDEX)
              = ZERO
      *    ** THERE IS NO REPLANTED ACREAGE IN THIS UNIT
              GO TO 3485-VAL-REPLANT-ACREAGE-EXIT
           END-IF

           MOVE WS-0021-UNIT-TBL-REPLANT-ACRES(WS-0021-UNIT-INDEX)
             TO WS-3485-REPLANT-ACRES-X

           EVALUATE WS-0021-UNIT-TBL-CROP(WS-0021-UNIT-INDEX)
               WHEN WS-LITERAL-FORAGE-SEED
      *    ** NO MINIMUM ACREAGE APPLIES FOR FORAGE SEEDING
                  CONTINUE

               WHEN WS-LITERAL-PEANUTS
      *    ** REPLANTED ACREAGE MUST BE >= THE LESSER OF
      *    ** (10 ACRES OR 10% OF THE TYPE 11 UNIT ACREAGE)
                  IF WS-0021-UNIT-TBL-REPLANT-ACRES
                     (WS-0021-UNIT-INDEX)
                     < 10
                     COMPUTE WS-3485-10-PCT-UNIT-ACREAGE =
                        WS-0011-UNIT-TBL-TOT-RPT-ACRES
                        (WS-0011-UNIT-INDEX)
                        * WS-3485-LITERAL-10-PCT
                        ON SIZE ERROR
                           MOVE 3485 TO WS-8020-PARAGRAPH-NO
                           MOVE 90017 TO WS-8020-INT-ERROR-NO
                           MOVE 'UNIT ACRES*10%'
                             TO WS-8020-FIELD-NAME
                           MOVE WS-3485-10-PCT-UNIT-ACREAGE
                             TO WS-3485-10-PCT-UNIT-ACREAGE-X
                           MOVE WS-3485-10-PCT-UNIT-ACREAGE-X
                             TO WS-8020-BAD-DATA
                           MOVE WS-LITERAL-YES
                             TO WS-8020-ABORT-PROGRAM
                           PERFORM 8020-RECORD-INT-ERROR
                              THRU 8020-RECORD-INT-ERROR-EXIT
                     END-COMPUTE

                     IF WS-0021-UNIT-TBL-REPLANT-ACRES
                        (WS-0021-UNIT-INDEX)
                        < WS-3485-10-PCT-UNIT-ACREAGE
                        MOVE 21070 TO WS-3485-ERROR-CODE
                        MOVE 'T21 REPLANT ACRES'
                          TO WS-3485-FIELD-NAME1
                        MOVE WS-3485-REPLANT-ACRES-X
                          TO WS-3485-BAD-DATA1
                        MOVE WS-3485-10-PCT-UNIT-ACREAGE
                          TO WS-3485-10-PCT-UNIT-ACREAGE-X
                        STRING 'MUST >= LESSER AMT 10 OR '
                          DELIMITED BY SIZE
                          WS-3485-10-PCT-UNIT-ACREAGE-X
                          DELIMITED BY SIZE
                          INTO WS-3485-CORR-DATA1
                        END-STRING

      ******* POPULATE THE CLAIM NUMBER USED TO REJECT 20/21 RECORDS
                        MOVE WS-0021-UNIT-TBL-CLAIM-NUMBER
                             (WS-0021-UNIT-INDEX)
                          TO WS-3485-T21-CLAIM-NO

      ******* REJECT ALL 21S AND 20S WITH WS-3485-T21-CLAIM-NO
                        IF WS-0021-T21-REC-COUNT > ZERO
                           PERFORM 3485-REJECT-ASSOC-21
                              THRU 3485-REJECT-ASSOC-21-EXIT
                              WITH TEST AFTER
                           VARYING WS-3485-T21-ERROR-INDEX FROM 1 BY 1
                             UNTIL WS-3485-T21-ERROR-INDEX
                                 = WS-0021-T21-REC-COUNT
      ***     RESTORE MAIN LOOP T21 INDEX VALUE
                           SET WS-0021-T21-INDEX
                             TO WS-0021-T21-INT-INDEX
                        END-IF
                        IF WS-0020-T20-REC-COUNT > ZERO
                           PERFORM 3485-REJECT-ASSOC-20
                              THRU 3485-REJECT-ASSOC-20-EXIT
                              WITH TEST AFTER
                           VARYING WS-0020-T20-INT-INDEX FROM 1 BY 1
                             UNTIL WS-0020-T20-INT-INDEX =
                                   WS-0020-T20-REC-COUNT
                        END-IF
                     END-IF
                  END-IF

               WHEN OTHER
      *    ** REPLANTED ACREAGE MUST BE >= THE LESSER OF
      *    ** (20 ACRES OR 20% OF THE TYPE 11 UNIT ACREAGE)
                  IF WS-0021-UNIT-TBL-REPLANT-ACRES
                     (WS-0021-UNIT-INDEX)
                     < 20
                     COMPUTE WS-3485-20-PCT-UNIT-ACREAGE =
                        WS-0011-UNIT-TBL-TOT-RPT-ACRES
                        (WS-0011-UNIT-INDEX)
                        * WS-3485-LITERAL-20-PCT
                        ON SIZE ERROR
                           MOVE 3485 TO WS-8020-PARAGRAPH-NO
                           MOVE 90017 TO WS-8020-INT-ERROR-NO
                           MOVE 'UNIT ACRES*20%'
                             TO WS-8020-FIELD-NAME
                           MOVE WS-3485-20-PCT-UNIT-ACREAGE
                             TO WS-3485-20-PCT-UNIT-ACREAGE-X
                           MOVE WS-3485-20-PCT-UNIT-ACREAGE-X
                             TO WS-8020-BAD-DATA
                           MOVE WS-LITERAL-YES
                             TO WS-8020-ABORT-PROGRAM
                           PERFORM 8020-RECORD-INT-ERROR
                              THRU 8020-RECORD-INT-ERROR-EXIT
                     END-COMPUTE

                     IF WS-0021-UNIT-TBL-REPLANT-ACRES
                        (WS-0021-UNIT-INDEX)
                        < WS-3485-20-PCT-UNIT-ACREAGE
                        MOVE 21062 TO WS-3485-ERROR-CODE
                        MOVE 'T21 REPLANT ACRES'
                          TO WS-3485-FIELD-NAME1
                        MOVE WS-3485-REPLANT-ACRES-X
                          TO WS-3485-BAD-DATA1
                        MOVE WS-3485-20-PCT-UNIT-ACREAGE
                          TO WS-3485-20-PCT-UNIT-ACREAGE-X
                        STRING 'MUST >= LESSER AMT 20 OR '
                          DELIMITED BY SIZE
                          WS-3485-20-PCT-UNIT-ACREAGE-X
                          DELIMITED BY SIZE
                          INTO WS-3485-CORR-DATA1
                        END-STRING

      ******* POPULATE THE CLAIM NUMBER USED TO REJECT 20/21 RECORDS
                        MOVE WS-0021-UNIT-TBL-CLAIM-NUMBER
                             (WS-0021-UNIT-INDEX)
                          TO WS-3485-T21-CLAIM-NO

      ******* REJECT ALL 21S AND 20S WITH WS-3485-T21-CLAIM-NO
                           IF WS-0021-T21-REC-COUNT > 0
                              PERFORM 3485-REJECT-ASSOC-21
                                 THRU 3485-REJECT-ASSOC-21-EXIT
                                 WITH TEST AFTER
                              VARYING WS-3485-T21-ERROR-INDEX
                                 FROM 1 BY 1
                                UNTIL WS-3485-T21-ERROR-INDEX
                                    = WS-0021-T21-REC-COUNT
      ***     RESTORE MAIN LOOP T21 INDEX VALUE
                              SET WS-0021-T21-INDEX
                                TO WS-0021-T21-INT-INDEX
                           END-IF

                           IF WS-0020-T20-REC-COUNT > 0
                              PERFORM 3485-REJECT-ASSOC-20
                                 THRU 3485-REJECT-ASSOC-20-EXIT
                                 WITH TEST AFTER
                              VARYING WS-0020-T20-INT-INDEX
                                 FROM 1 BY 1
                                UNTIL WS-0020-T20-INT-INDEX
                                    = WS-0020-T20-REC-COUNT
                           END-IF
                     END-IF
                  END-IF

           END-EVALUATE.


       3485-VAL-REPLANT-ACREAGE-EXIT.
           EXIT.


      ************************************************************
      *   REJECT ALL TYPE 21S WITH SAME CLAIM NUMBER
      ************************************************************
       3485-REJECT-ASSOC-21.

           SET WS-0021-T21-INDEX TO WS-3485-T21-ERROR-INDEX

           IF WS-0021-TBL-TRAN-REJECTED-FLAG(WS-0021-T21-INDEX)
              = WS-LITERAL-YES
              GO TO 3485-REJECT-ASSOC-21-EXIT
           END-IF

           IF WS-0021-TBL-CLAIM-NUM(WS-0021-T21-INDEX) =
              WS-3485-T21-CLAIM-NO
              MOVE WS-LITERAL-YES
                TO WS-0021-TBL-TRAN-REJECTED-FLAG(WS-0021-T21-INDEX)
              MOVE WS-LITERAL-IR TO WS-8000-ERROR-TYPE
              MOVE WS-3485-ERROR-CODE TO WS-8000-ERROR-CODE
              MOVE WS-3485-FIELD-NAME1 TO WS-8000-FIELD-NAME1
              MOVE WS-3485-BAD-DATA1 TO WS-8000-BAD-DATA1
              MOVE WS-3485-CORR-DATA1 TO WS-8000-CORR-DATA1
              MOVE WS-0021-TBL-TRAN-SEQ-NO(WS-0021-T21-INDEX)
                TO WS-8000-TRAN-SEQ-NO
              MOVE 3485 TO WS-8000-PARAGRAPH-NO
              MOVE 21 TO WS-8000-TRAN-TYPE
              MOVE WS-0021-TBL-POLICY-NO(WS-0021-T21-INDEX)
                TO WS-8000-POLICY-NO
              MOVE WS-0021-TBL-LOCATION-COUNTY(WS-0021-T21-INDEX)
                TO WS-8000-LOC-COUNTY
              MOVE WS-0021-TBL-INSURANCE-PLAN-CD(WS-0021-T21-INDEX)
                TO WS-8000-INSURANCE-PLAN-ID
              MOVE WS-0021-TBL-CROP-CD(WS-0021-T21-INDEX)
                TO WS-8000-CROP-CD
              MOVE WS-0021-TBL-RECORD-NUM(WS-0021-T21-INDEX)
                TO WS-8000-RECORD-NUM
              MOVE WS-LITERAL-YES TO WS-0006-REJECT-21S-FLAG
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF.

       3485-REJECT-ASSOC-21-EXIT.
           EXIT.


      ************************************************************
      *    REJECT ALL TYPE 20S WITH SAME TYPE 21 CLAIM NUMBER
      ************************************************************
       3485-REJECT-ASSOC-20.

           SET WS-0020-T20-INDEX TO WS-0020-T20-INT-INDEX

           IF WS-0020-TBL-TRAN-REJECTED-FLAG(WS-0020-T20-INDEX)
              = WS-LITERAL-YES
              GO TO 3485-REJECT-ASSOC-20-EXIT
           END-IF

           IF WS-0020-TBL-CLAIM-NUM(WS-0020-T20-INDEX) =
              WS-3485-T21-CLAIM-NO
              MOVE WS-LITERAL-YES
                TO WS-0020-TBL-TRAN-REJECTED-FLAG(WS-0020-T20-INDEX)
              MOVE WS-LITERAL-IR TO WS-8000-ERROR-TYPE
              MOVE 20039 TO WS-8000-ERROR-CODE
              MOVE 'TOTAL T21 UNIT' TO WS-8000-FIELD-NAME1
              MOVE WS-0020-TBL-TRAN-SEQ-NO(WS-0020-T20-INDEX)
                TO WS-8000-TRAN-SEQ-NO
              MOVE 3485 TO WS-8000-PARAGRAPH-NO
              MOVE 20 TO WS-8000-TRAN-TYPE
              MOVE WS-0020-TBL-POLICY-NO(WS-0020-T20-INDEX)
                TO WS-8000-POLICY-NO
              MOVE WS-0020-TBL-RECORD-NUM(WS-0020-T20-INDEX)
                TO WS-8000-RECORD-NUM
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF.

       3485-REJECT-ASSOC-20-EXIT.
           EXIT.

