      ****************************************************************
      *  File   : IR3505.CBL
      *  Author : Yo-I Tsui
      *  Date   : 7/1/96
      *  Purpose: Validate Type 21 records for Crops which use either
      *           the Simplified Claim or Self-Certified Replant Claim
      *           indicator.
      *
      *           For crop claims that use the Simplified Claim
      *           flag, the total crop indemnity cannot be greater
      *           than $1,000.  Almonds must not be greater than $2,000.
      *
      *           For crop claims that use the Self-Certified Replant
      *           Claim flag, the total crop determined acreage must
      *           not be greater than 50 acres.
      ****************************************************************

       3505-COMP-CROP-TOT-21-11.

      $IF DEBUG-SW DEFINED
           DISPLAY '3505 CROP LEVEL TOTALS FOR TYPE 21 AND TYPE 11'
           UPON CONSOLE
      $END

           IF WS-0021-CROP-REC-COUNT > ZERO
              PERFORM 3505-PROCESS-CROP-TOTALS
                 THRU 3505-PROCESS-CROP-TOTALS-EXIT
                 WITH TEST AFTER
              VARYING WS-0021-CROP-INT-INDEX FROM 1 BY 1
                UNTIL WS-0021-CROP-INT-INDEX = WS-0021-CROP-REC-COUNT
           END-IF.

       3505-COMP-CROP-TOT-21-11-EXIT.
           EXIT.


       3505-PROCESS-CROP-TOTALS.

           SET WS-0021-CROP-INDEX TO WS-0021-CROP-INT-INDEX

           IF WS-0021-CROP-TBL-TOT-INDEMNITY(WS-0021-CROP-INDEX)
              IS NOT NUMERIC
              OR WS-0021-CROP-TBL-TOT-DET-ACRE(WS-0021-CROP-INDEX)
              IS NOT NUMERIC
              OR WS-0021-CROP-TBL-CLAIM-NUMBER(WS-0021-CROP-INDEX)
              IS NOT NUMERIC
              OR WS-0021-CROP-TBL-CROP(WS-0021-CROP-INDEX)
              IS NOT NUMERIC

              GO TO 3505-PROCESS-CROP-TOTALS-EXIT
           END-IF

           INITIALIZE WS-3505-WORK

           EVALUATE WS-0021-CROP-TBL-SIMPLE-CLAIM(WS-0021-CROP-INDEX)
               WHEN WS-LITERAL-SIMPLIFIED-CLAIM
                  PERFORM 3505-PROCESS-SIMPLE-CLAIM
                     THRU 3505-PROCESS-SIMPLE-CLAIM-EXIT

               WHEN WS-LITERAL-SELF-CERT-REPLANT
                  PERFORM 3505-PROCESS-REPLNT-CLAIM
                     THRU 3505-PROCESS-REPLNT-CLAIM-EXIT

               WHEN OTHER
                  CONTINUE

           END-EVALUATE.


       3505-PROCESS-CROP-TOTALS-EXIT.
           EXIT.


       3505-PROCESS-SIMPLE-CLAIM.
      ******* IF THIS CROP RECORD IS A SIMPLIFIED CLAIM CROP,
      ******* TOTAL INDEMNITY MUST NOT BE GREATER THAN $1,000.
      ******* BUT - IF THE CROP IS ALMONDS, TOTAL INDEMNITY MUST NOT
      ******* BE GREATER THAN $2,000.

           IF WS-0021-CROP-TBL-CROP(WS-0021-CROP-INDEX)
              = WS-LITERAL-ALMONDS
              MOVE WS-3505-ALMOND-INDEM
                TO WS-3505-MAXIMUM-TOT-INDEMNITY
           ELSE
              MOVE WS-3505-MAX-CROP-INDEM
                TO WS-3505-MAXIMUM-TOT-INDEMNITY
           END-IF

           IF WS-0021-CROP-TBL-TOT-INDEMNITY(WS-0021-CROP-INDEX)
              > WS-3505-MAXIMUM-TOT-INDEMNITY
              IF WS-0021-CROP-TBL-CROP(WS-0021-CROP-INDEX)
                 = WS-LITERAL-ALMONDS
                 MOVE 21073 TO WS-3505-ERROR-CODE
              ELSE
                 MOVE 21072 TO WS-3505-ERROR-CODE
              END-IF
              MOVE 'CROP TOT INDEMNITY' TO WS-3505-FIELD-NAME1
              MOVE WS-0021-CROP-TBL-TOT-INDEMNITY(WS-0021-CROP-INDEX)
                TO WS-3505-BAD-DATA1
              STRING 'MUST BE <= '
                DELIMITED BY SIZE
                WS-3505-MAXIMUM-TOT-INDEMNITY
                DELIMITED BY SIZE
                INTO WS-3505-CORR-DATA1
              END-STRING

      ******* REJECT ALL 21S AND 20S WITH THE CROP REC'S CLAIM NUMBER
              IF WS-0021-T21-REC-COUNT > ZERO
                 PERFORM 3505-REJECT-ASSOC-21
                    THRU 3505-REJECT-ASSOC-21-EXIT
                    WITH TEST AFTER
                 VARYING WS-3505-T21-ERROR-INDEX FROM 1 BY 1
                   UNTIL WS-3505-T21-ERROR-INDEX
                       = WS-0021-T21-REC-COUNT
      ***     RESTORE MAIN LOOP T21 INDEX VALUE
                 SET WS-0021-T21-INDEX TO WS-0021-T21-INT-INDEX
              END-IF
              IF WS-0020-T20-REC-COUNT > ZERO
                 PERFORM 3505-REJECT-ASSOC-20
                    THRU 3505-REJECT-ASSOC-20-EXIT
                    WITH TEST AFTER
                 VARYING WS-0020-T20-INT-INDEX FROM 1 BY 1
                   UNTIL WS-0020-T20-INT-INDEX
                       = WS-0020-T20-REC-COUNT
              END-IF
           END-IF.


       3505-PROCESS-SIMPLE-CLAIM-EXIT.
           EXIT.


       3505-PROCESS-REPLNT-CLAIM.
      ******* IF THIS CROP RECORD IS A SELF-CERTIFIED REPLANT CROP,
      ******* TOTAL DETERMINED ACRES (WHICH IN THIS CASE IS ALSO TOTAL
      ******* REPLANTED ACRES) MUST NOT BE GREATER THAN 50 ACRES.

           IF WS-0021-CROP-TBL-TOT-DET-ACRE(WS-0021-CROP-INDEX) >
              WS-3505-MAX-ACRES
              MOVE 21071 TO WS-3505-ERROR-CODE
              MOVE 'T21 REPLANTED ACRES' TO WS-3505-FIELD-NAME1
              MOVE WS-0021-CROP-TBL-TOT-DET-ACRE(WS-0021-CROP-INDEX)
                TO WS-3505-TOT-REPLANTED-ACRES-X
              MOVE WS-3505-TOT-REPLANTED-ACRES-X
                TO WS-3505-BAD-DATA1
              STRING ' <= '
               DELIMITED BY SIZE
               WS-3505-MAX-ACRES
               DELIMITED BY SIZE
               INTO WS-3505-CORR-DATA1
              END-STRING

      ******* REJECT ALL 21S AND 20S WITH CROP RECORD'S CLAIM NUMBER
              IF WS-0021-T21-REC-COUNT > ZERO
                 PERFORM 3505-REJECT-ASSOC-21
                    THRU 3505-REJECT-ASSOC-21-EXIT
                    WITH TEST AFTER
                 VARYING WS-3505-T21-ERROR-INDEX FROM 1 BY 1
                   UNTIL WS-3505-T21-ERROR-INDEX
                       = WS-0021-T21-REC-COUNT
      ***     RESTORE MAIN LOOP T21 INDEX VALUE
                 SET WS-0021-T21-INDEX TO WS-0021-T21-INT-INDEX
              END-IF
              IF WS-0020-T20-REC-COUNT > ZERO
                 PERFORM 3505-REJECT-ASSOC-20
                    THRU 3505-REJECT-ASSOC-20-EXIT
                    WITH TEST AFTER
                 VARYING WS-0020-T20-INT-INDEX FROM 1 BY 1
                   UNTIL WS-0020-T20-INT-INDEX
                       = WS-0020-T20-REC-COUNT
              END-IF
           END-IF.


       3505-PROCESS-REPLNT-CLAIM-EXIT.
           EXIT.


      ************************************************************
      *   REJECT ALL TYPE 21S WITH SAME CLAIM NUMBER
      ************************************************************
       3505-REJECT-ASSOC-21.

           SET WS-0021-T21-INDEX TO WS-3505-T21-ERROR-INDEX

           IF WS-0021-TBL-TRAN-REJECTED-FLAG(WS-0021-T21-INDEX)
              = WS-LITERAL-YES
              GO TO 3505-REJECT-ASSOC-21-EXIT
           END-IF

           IF WS-0021-TBL-CLAIM-NUM(WS-0021-T21-INDEX) =
              WS-0021-CROP-TBL-CLAIM-NUMBER(WS-0021-CROP-INDEX)
              MOVE WS-LITERAL-YES
                TO WS-0021-TBL-TRAN-REJECTED-FLAG(WS-0021-T21-INDEX)
              MOVE WS-LITERAL-IR TO WS-8000-ERROR-TYPE
              MOVE WS-3505-ERROR-CODE TO WS-8000-ERROR-CODE
              MOVE WS-3505-FIELD-NAME1 TO WS-8000-FIELD-NAME1
              MOVE WS-3505-BAD-DATA1 TO WS-8000-BAD-DATA1
              MOVE WS-3505-CORR-DATA1 TO WS-8000-CORR-DATA1
              MOVE 3505 TO WS-8000-PARAGRAPH-NO
              MOVE 21 TO WS-8000-TRAN-TYPE
              MOVE WS-0021-TBL-POLICY-NO(WS-0021-T21-INDEX)
                TO WS-8000-POLICY-NO
              MOVE WS-0021-TBL-TRAN-SEQ-NO(WS-0021-T21-INDEX)
                TO WS-8000-TRAN-SEQ-NO
              MOVE WS-0021-TBL-LOCATION-COUNTY(WS-0021-T21-INDEX)
                TO WS-8000-LOC-COUNTY
              MOVE WS-0021-TBL-INSURANCE-PLAN-CD(WS-0021-T21-INDEX)
                TO WS-8000-INSURANCE-PLAN-ID
              MOVE WS-0021-TBL-CROP-CD(WS-0021-T21-INDEX)
                TO WS-8000-CROP-CD
              MOVE WS-0021-TBL-RECORD-NUM(WS-0021-T21-INDEX)
                TO WS-8000-RECORD-NUM
              MOVE WS-LITERAL-YES TO WS-0006-REJECT-21S-FLAG
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF.

       3505-REJECT-ASSOC-21-EXIT.
           EXIT.


      ************************************************************
      *    REJECT ALL TYPE 20S WITH SAME TYPE 21 CLAIM NUMBER
      ************************************************************
       3505-REJECT-ASSOC-20.

           SET WS-0020-T20-INDEX TO WS-0020-T20-INT-INDEX

           IF WS-0020-TBL-TRAN-REJECTED-FLAG(WS-0020-T20-INDEX)
              = WS-LITERAL-YES
              GO TO 3505-REJECT-ASSOC-20-EXIT
           END-IF

           IF WS-0020-TBL-CLAIM-NUM(WS-0020-T20-INDEX) =
              WS-0021-CROP-TBL-CLAIM-NUMBER(WS-0021-CROP-INDEX)
              MOVE WS-LITERAL-YES
                TO WS-0020-TBL-TRAN-REJECTED-FLAG(WS-0020-T20-INDEX)
              MOVE WS-LITERAL-IR TO WS-8000-ERROR-TYPE
              MOVE 20039 TO WS-8000-ERROR-CODE
              MOVE 'CROP TOTALS' TO WS-8000-FIELD-NAME1
              MOVE 3505 TO WS-8000-PARAGRAPH-NO
              MOVE 20 TO WS-8000-TRAN-TYPE
              MOVE WS-0020-TBL-POLICY-NO(WS-0020-T20-INDEX)
                TO WS-8000-POLICY-NO
              MOVE WS-0020-TBL-TRAN-SEQ-NO(WS-0020-T20-INDEX)
                TO WS-8000-TRAN-SEQ-NO
              MOVE WS-0020-TBL-RECORD-NUM(WS-0020-T20-INDEX)
                TO WS-8000-RECORD-NUM
              MOVE WS-LITERAL-YES TO WS-0006-REJECT-21S-FLAG
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF.

       3505-REJECT-ASSOC-20-EXIT.
           EXIT.

