      *****************************************************************
      * File:      M0707.CBL                                          *
      * Author:    Mike Ray                                           *
      * Date:      03/19/96                                           *
      * Purpose:                                                      *
      *    Creates the error report returned to the Reinsured         *
      *    companies from the rejected file and the temporary error   *
      *    file.                                                      *
      *****************************************************************


       0707-PRODUCE-ERROR-RPT.

      $IF DEBUG-SW DEFINED
           DISPLAY '0707-PRODUCING ERROR REPORT'
           UPON CONSOLE
      $END

      *************************************************************
      *    INITIALIZE                                             *
      *************************************************************
           INITIALIZE WS-TRAN-400
           INITIALIZE WS-0707-STATUS
           MOVE WS-LITERAL-NO TO WS-0707-TRAN-EOF
           MOVE WS-LITERAL-NO TO WS-0707-ERROR-EOF
           MOVE ZEROS TO WS-0707-CURRENT-PAGE-NO

      *************************************************************
      *    CHECK PARAMETERS                                       *
      *************************************************************


           IF WS-0707-PAGE-LENGTH <= ZEROS
      *       *** USER DOES NOT WANT AN ERROR REPORT
              GO TO 0707-PRODUCE-ERROR-RPT-EXIT
           END-IF

           IF WS-0707-PAGE-LENGTH = ZEROS
              MOVE 0707 TO WS-8020-PARAGRAPH-NO
              MOVE 90003 TO WS-8020-INT-ERROR-NO
              MOVE WS-TRAN-SEQ-NO TO WS-8020-TRAN-SEQ-NO
              MOVE 'PAGE LENGTH' TO WS-8020-FIELD-NAME
              MOVE ZEROS TO WS-8020-BAD-DATA
              MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
              PERFORM 8020-RECORD-INT-ERROR
                 THRU 8020-RECORD-INT-ERROR-EXIT
           END-IF

           IF WS-0707-PAGE-LENGTH < 20 OR
              WS-0707-PAGE-LENGTH > 132
              MOVE 0707 TO WS-8020-PARAGRAPH-NO
              MOVE 90047 TO WS-8020-INT-ERROR-NO
              MOVE 'PAGE LENGTH' TO WS-8020-FIELD-NAME
              MOVE WS-0707-PAGE-LENGTH TO WS-8020-BAD-DATA
              MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
              PERFORM 8020-RECORD-INT-ERROR
                 THRU 8020-RECORD-INT-ERROR-EXIT
           END-IF

      *************************************************************
      *    SORT INPUT FILES                                       *
      *************************************************************

           IF WS-0004-ERR-SEQ-NO > ZEROS
              PERFORM 0960-SORT-REJECT-FILE
                 THRU 0960-SORT-REJECT-FILE-EXIT

              PERFORM 0965-SORT-ERROR-FILE
                 THRU 0965-SORT-ERROR-FILE-EXIT
           END-IF

      *************************************************************
      *    OPEN INPUT FILES                                       *
      *************************************************************

           IF WS-0004-ERR-SEQ-NO > ZEROS
              OPEN INPUT INPUT-ERROR-FILE
              MOVE WS-LITERAL-YES TO WS-0900-IN-ERR-FILE-OPEN
              ADD 1 TO WS-0004-FILES-OPEN
              IF WS-0004-FILES-OPEN > WS-0008-MAX-FILES-OPENED
                 MOVE WS-0004-FILES-OPEN TO WS-0008-MAX-FILES-OPENED
              END-IF

              OPEN INPUT REJECTED-TRANSACTION-FILE
              MOVE WS-LITERAL-YES TO WS-0900-REJECT-FILE-OPEN
              ADD 1 TO WS-0004-FILES-OPEN
              IF WS-0004-FILES-OPEN > WS-0008-MAX-FILES-OPENED
                 MOVE WS-0004-FILES-OPEN TO WS-0008-MAX-FILES-OPENED
              END-IF
           END-IF


      *************************************************************
      *    CREATE REPORT                                          *
      *************************************************************
           PERFORM 0707-WRITE-PAGE-HEADER
              THRU 0707-WRITE-PAGE-HEADER-EXIT

           IF WS-0004-ERR-SEQ-NO > ZEROS
              PERFORM 0707-CREATE-REPORT
                 THRU 0707-CREATE-REPORT-EXIT
                UNTIL WS-0707-TRAN-EOF = WS-LITERAL-YES
                   OR WS-0707-ERROR-EOF = WS-LITERAL-YES
           ELSE
              MOVE SPACES TO ERROR-REPT-RECORD
              WRITE ERROR-REPT-RECORD
              ADD 1 TO WS-0707-CURRENT-LINE-COUNT
              WRITE ERROR-REPT-RECORD
              ADD 1 TO WS-0707-CURRENT-LINE-COUNT
              MOVE '     *** CONGRATULATIONS! - NO ERRORS! ***'
                TO ERROR-REPT-RECORD
              WRITE ERROR-REPT-RECORD
              ADD 1 TO WS-0707-CURRENT-LINE-COUNT
           END-IF

      *    *** WRITE TO END OF PAGE
           IF WS-0707-CURRENT-LINE-COUNT < WS-0707-PAGE-LENGTH
              PERFORM 0707-WRITE-BLANK-LN
                 THRU 0707-WRITE-BLANK-LN-EXIT
                 WITH TEST AFTER
              VARYING WS-0707-CURRENT-LINE-COUNT
                 FROM WS-0707-CURRENT-LINE-COUNT BY 1
                UNTIL WS-0707-CURRENT-LINE-COUNT = WS-0707-PAGE-LENGTH
           END-IF.

      $IF DEBUG-SW DEFINED
           IF WS-0707-ERROR-EOF <> WS-LITERAL-YES AND
              WS-0004-ERR-SEQ-NO > ZERO
              DISPLAY 'ERRORS WERE SKIPPED!'
              UPON CONSOLE
           END-IF.
      $END


       0707-PRODUCE-ERROR-RPT-EXIT.
           EXIT.

      *************************************************************
      *    CREATE REPORT                                          *
      *************************************************************

       0707-CREATE-REPORT.

           READ REJECTED-TRANSACTION-FILE INTO WS-TRAN-400
              AT END
                 MOVE WS-LITERAL-YES TO WS-0707-TRAN-EOF
                 GO TO 0707-CREATE-REPORT-EXIT
           END-READ

      $IF DEBUG-SW DEFINED
           DISPLAY '0707-READ REJECTED TRANS #', WS-TRAN-SEQ-NO
           UPON CONSOLE
      $END


      *    *** IF THIS IS A DIFFERENT POLICY WRITE A NEW HEADER
           IF WS-POLICY-NO <> WS-0707-CURRENT-POLICY-NO
              MOVE WS-POLICY-NO TO WS-0707-CURRENT-POLICY-NO
              PERFORM 0707-WRITE-POLICY-HDR
                 THRU 0707-WRITE-POLICY-HDR-EXIT
              MOVE ZERO TO WS-0707-CURRENT-TRAN-TYPE
           END-IF

      *    *** IF THIS IS A DIFFERENT TRAN TYPE WRITE A NEW HEADER
           IF WS-TRAN-TYPE <> WS-0707-CURRENT-TRAN-TYPE
              IF WS-0707-CURRENT-TRAN-TYPE <> SPACES
      *          *** MAKE SURE THERE IS ROOM ON THE PAGE
                 IF (WS-0707-CURRENT-LINE-COUNT + 5)
                    < WS-0707-PAGE-LENGTH
                    PERFORM 0707-WRITE-BLANK-LN
                       THRU 0707-WRITE-BLANK-LN-EXIT
                    MOVE WS-TRAN-TYPE TO WS-0707-CURRENT-TRAN-TYPE
                    PERFORM 0707-WRITE-TRAN-HDR
                       THRU 0707-WRITE-TRAN-HDR-EXIT
                 ELSE
                    MOVE WS-TRAN-TYPE TO WS-0707-CURRENT-TRAN-TYPE
                    PERFORM 0707-WRITE-NEW-PAGE
                       THRU 0707-WRITE-NEW-PAGE-EXIT
                 END-IF
              ELSE
                 MOVE WS-TRAN-TYPE TO WS-0707-CURRENT-TRAN-TYPE
                 PERFORM 0707-WRITE-TRAN-HDR
                    THRU 0707-WRITE-TRAN-HDR-EXIT
              END-IF
           END-IF

      *    *** WRITE OUT THE TRANSACTION YOU JUST READ
           PERFORM 0707-WRITE-TRAN-DTL
              THRU 0707-WRITE-TRAN-DTL-EXIT

           IF WS-0707-ERROR-HELD-FLAG = WS-LITERAL-YES
              EVALUATE WS-0707-HELD-ERROR-TRAN-NO
               WHEN < WS-TRAN-SEQ-NO
                 MOVE 0707 TO WS-8020-PARAGRAPH-NO
                 MOVE 90045 TO WS-8020-INT-ERROR-NO
                 MOVE WS-TRAN-SEQ-NO TO WS-8020-TRAN-SEQ-NO
                 MOVE 'HELD ERROR TRAN#' TO WS-8020-FIELD-NAME
                 MOVE WS-0707-HELD-ERROR-TRAN-NO TO WS-8020-BAD-DATA
                 MOVE WS-LITERAL-NO TO WS-8020-ABORT-PROGRAM
                 PERFORM 8020-RECORD-INT-ERROR
                    THRU 8020-RECORD-INT-ERROR-EXIT
                 MOVE WS-LITERAL-NO TO WS-0707-ERROR-HELD-FLAG
                 MOVE ZEROS TO WS-0707-HELD-ERROR-TRAN-NO
               WHEN > WS-TRAN-SEQ-NO
                 MOVE 0707 TO WS-8020-PARAGRAPH-NO
                 MOVE 90045 TO WS-8020-INT-ERROR-NO
                 MOVE WS-TRAN-SEQ-NO TO WS-8020-TRAN-SEQ-NO
                 MOVE 'HELD ERROR TRAN#' TO WS-8020-FIELD-NAME
                 MOVE WS-0707-HELD-ERROR-TRAN-NO TO WS-8020-BAD-DATA
                 MOVE WS-LITERAL-NO TO WS-8020-ABORT-PROGRAM
                 PERFORM 8020-RECORD-INT-ERROR
                    THRU 8020-RECORD-INT-ERROR-EXIT
                 MOVE WS-LITERAL-NO TO WS-0707-NEXT-TRAN-FLAG
                 MOVE WS-LITERAL-NO TO WS-0707-ERROR-HELD-FLAG
                 MOVE ZEROS TO WS-0707-HELD-ERROR-TRAN-NO
                 GO TO 0707-CREATE-REPORT-EXIT
               WHEN OTHER
                 PERFORM 0707-WRITE-ERROR
                    THRU 0707-WRITE-ERROR-EXIT
                 MOVE WS-LITERAL-NO TO WS-0707-ERROR-HELD-FLAG
                 MOVE ZEROS TO WS-0707-HELD-ERROR-TRAN-NO
              END-EVALUATE
           END-IF

      *    *** PROCESS ERRORS
           MOVE WS-LITERAL-NO TO WS-0707-ERROR-EOF
           MOVE WS-LITERAL-NO TO WS-0707-NEXT-TRAN-FLAG
           MOVE WS-LITERAL-NO TO WS-0707-ERROR-HELD-FLAG
           MOVE ZEROS TO WS-0707-HELD-ERROR-TRAN-NO

           IF WS-0707-ERROR-EOF <> WS-LITERAL-YES
              PERFORM 0707-PROCESS-ERRORS
                 THRU 0707-PROCESS-ERRORS-EXIT
                UNTIL (WS-0707-NEXT-TRAN-FLAG = WS-LITERAL-YES)
                   OR (WS-0707-ERROR-EOF = WS-LITERAL-YES)
           END-IF.

       0707-CREATE-REPORT-EXIT.
           EXIT.


      *************************************************************
      *    PROCESS ERRORS                                         *
      *************************************************************

       0707-PROCESS-ERRORS.

           READ INPUT-ERROR-FILE INTO WS-0707-ERROR-REC
              AT END
                 MOVE WS-LITERAL-YES TO WS-0707-ERROR-EOF
                 GO TO 0707-PROCESS-ERRORS-EXIT
           END-READ

      $IF DEBUG-SW DEFINED
           DISPLAY '0707-READ ERROR MSG # ', WS-0707-ERR-SEQ-NO,
             ' FOR TRANS # ', WS-0707-TRAN-SEQ-NO UPON CONSOLE
      $END

      *    *** IF AN ERROR HAS NO SEQUENCE NUMBER THEN
      *    *** ABORT THE PROGRAM.
           IF WS-0707-TRAN-SEQ-NO NOT NUMERIC
              MOVE 0707 TO WS-8020-PARAGRAPH-NO
              MOVE 90001 TO WS-8020-INT-ERROR-NO
              MOVE WS-TRAN-SEQ-NO TO WS-8020-TRAN-SEQ-NO
              MOVE 'WS-0707-TRAN-SEQ-NO' TO WS-8020-FIELD-NAME
              MOVE ZEROS TO WS-8020-BAD-DATA
              MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
              PERFORM 8020-RECORD-INT-ERROR
                 THRU 8020-RECORD-INT-ERROR-EXIT
           END-IF

           IF WS-0707-TRAN-SEQ-NO = ZEROS
              MOVE 0707 TO WS-8020-PARAGRAPH-NO
              MOVE 90046 TO WS-8020-INT-ERROR-NO
              MOVE WS-TRAN-SEQ-NO TO WS-8020-TRAN-SEQ-NO
              MOVE 'WS-0707-TRAN-SEQ-NO' TO WS-8020-FIELD-NAME
              MOVE ZEROS TO WS-8020-BAD-DATA
              MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
              PERFORM 8020-RECORD-INT-ERROR
                 THRU 8020-RECORD-INT-ERROR-EXIT
           END-IF

           IF WS-0707-TRAN-SEQ-NO = WS-TRAN-SEQ-NO
              PERFORM 0707-WRITE-ERROR
                 THRU 0707-WRITE-ERROR-EXIT
           ELSE
      *       *** IF THE ERROR IS FOR A DIFFERENT TRANSACTION
      *       *** HOLD IT AND READ THE NEXT TRANSACTION
              MOVE WS-LITERAL-YES TO WS-0707-ERROR-HELD-FLAG
              MOVE WS-0707-TRAN-SEQ-NO TO WS-0707-HELD-ERROR-TRAN-NO
              MOVE WS-LITERAL-YES TO WS-0707-NEXT-TRAN-FLAG
           END-IF.


       0707-PROCESS-ERRORS-EXIT.
           EXIT.


      *************************************************************
      *    WRITE POLICY HEADER                                    *
      *************************************************************

       0707-WRITE-POLICY-HDR.

      *    *** MAKE SURE THERE IS ROOM ON THE PAGE
           IF (WS-0707-CURRENT-LINE-COUNT + 6) < WS-0707-PAGE-LENGTH

      *       *** WRITE BLANK LINE
              MOVE SPACES TO ERROR-REPT-RECORD
              WRITE ERROR-REPT-RECORD
              ADD 1 TO WS-0707-CURRENT-LINE-COUNT

      *       *** WRITE POLICY LINE
              INITIALIZE WS-0707-POLICY-LN1
              MOVE WS-0707-REPORTING-ORG TO WS-0707-POLICY-RO
              MOVE WS-0707-LOC-STATE TO WS-0707-POLICY-LOC-STATE
              MOVE WS-0707-COMPANY-COUNTY TO WS-0707-POLICY-COMPANY
              MOVE WS-0707-POLICY-NUM TO WS-0707-POLICY-NUMBER
              MOVE WS-0707-CROP-YEAR TO WS-0707-POLICY-CROP-YEAR
              MOVE WS-0707-POLICY-LN1 TO ERROR-REPT-RECORD
              WRITE ERROR-REPT-RECORD
              ADD 1 TO WS-0707-CURRENT-LINE-COUNT
              INITIALIZE WS-0707-POLICY-LN1
           ELSE
              PERFORM 0707-WRITE-NEW-PAGE
                 THRU 0707-WRITE-NEW-PAGE-EXIT
           END-IF.

       0707-WRITE-POLICY-HDR-EXIT.
           EXIT.


      *************************************************************
      *    WRITE TRANSACTION HEADER                               *
      *************************************************************

       0707-WRITE-TRAN-HDR.

      *    *** MAKE SURE THERE IS ROOM ON THE PAGE
           IF (WS-0707-CURRENT-LINE-COUNT + 4) < WS-0707-PAGE-LENGTH

      *       *** WRITE TRAN HEADER LINE
              EVALUATE WS-0707-CURRENT-TRAN-TYPE
               WHEN 10
                  MOVE WS-0707-TYPE-10-HDR TO ERROR-REPT-RECORD
               WHEN 11
                  MOVE WS-0707-TYPE-11-HDR TO ERROR-REPT-RECORD
               WHEN 12
                  MOVE WS-0707-TYPE-12-HDR TO ERROR-REPT-RECORD
               WHEN 14
                  MOVE WS-0707-TYPE-14-HDR TO ERROR-REPT-RECORD
               WHEN 15
                  MOVE WS-0707-TYPE-15-HDR TO ERROR-REPT-RECORD
               WHEN 16
                  MOVE WS-0707-TYPE-16-HDR TO ERROR-REPT-RECORD
               WHEN 20
                  MOVE WS-0707-TYPE-20-HDR TO ERROR-REPT-RECORD
               WHEN 21
                  MOVE WS-0707-TYPE-21-HDR TO ERROR-REPT-RECORD
               WHEN 33
                  MOVE WS-0707-TYPE-33-HDR TO ERROR-REPT-RECORD
               WHEN 49
                  MOVE WS-0707-TYPE-49-HDR TO ERROR-REPT-RECORD
               WHEN 50
                  MOVE WS-0707-TYPE-50-HDR TO ERROR-REPT-RECORD
               WHEN 55
                  MOVE WS-0707-TYPE-55-HDR TO ERROR-REPT-RECORD
               WHEN 56
                  MOVE WS-0707-TYPE-56-HDR TO ERROR-REPT-RECORD
               WHEN 65
                  MOVE WS-0707-TYPE-65-HDR TO ERROR-REPT-RECORD
               WHEN OTHER
                  MOVE '***** NO TRANSACTION HEADER FOR THIS TRAN TYPE'
                    TO ERROR-REPT-RECORD
              END-EVALUATE
              WRITE ERROR-REPT-RECORD
              ADD 1 TO WS-0707-CURRENT-LINE-COUNT
           ELSE
              PERFORM 0707-WRITE-NEW-PAGE
                 THRU 0707-WRITE-NEW-PAGE-EXIT
           END-IF.


       0707-WRITE-TRAN-HDR-EXIT.
           EXIT.

      *************************************************************
      *    WRITE TRANSACTION DETAIL                               *
      *************************************************************

       0707-WRITE-TRAN-DTL.

      *    *** MAKE SURE THERE IS ROOM ON THE PAGE
           IF (WS-0707-CURRENT-LINE-COUNT + 3) < WS-0707-PAGE-LENGTH
      *       *** WRITE TRAN DETAIL LINE
              EVALUATE WS-0707-CURRENT-TRAN-TYPE
               WHEN 10
                  INITIALIZE WS-0707-TYPE-10-DTL
                  MOVE WS-TRAN-TYPE TO WS-0707-T10-TYPE
                  MOVE WS-T10-RECORD-NUM-X TO WS-0707-T10-REC-NO
                  IF WS-T10-ENTITY-TYPE = WS-LITERAL-INDIVIDUAL
                     STRING WS-T10-PROD-FRST-NAME
                      DELIMITED BY SPACE
                      ' '
                      DELIMITED BY SIZE
                      WS-T10-PROD-LST-NAME
                      DELIMITED BY SPACE
                      INTO WS-0707-T10-NAME
                     END-STRING
                  ELSE
                     MOVE WS-T10-BUSINESS-NAME TO WS-0707-T10-NAME
                  END-IF
                  MOVE WS-T10-ENTITY-TYPE TO WS-0707-T10-ENTITY-TYPE
                  MOVE WS-T10-ID-TYPE-X TO WS-0707-T10-ID-TYPE
                  IF WS-0707-REMOVE-ID-FLAG = WS-LITERAL-YES
                     IF WS-0707-T10-ID-TYPE = '1'
                        MOVE '???-??-????' TO WS-0707-T10-ID-NUMBER
                     ELSE
                        MOVE '???????????' TO WS-0707-T10-ID-NUMBER
                     END-IF
                  ELSE
                     MOVE WS-T10-ID-NUM-X TO WS-0707-T10-ID-NUMBER
                  END-IF
                  MOVE WS-TRAN-SEQ-NO TO WS-0707-T10-TRAN-SEQ-NO
                  MOVE WS-0707-TYPE-10-DTL TO ERROR-REPT-RECORD

               WHEN 11
                  INITIALIZE WS-0707-TYPE-11-DTL
                  MOVE WS-TRAN-TYPE TO WS-0707-T11-TYPE
                  MOVE WS-T11-RECORD-NUM-X TO WS-0707-T11-REC-NO
                  MOVE WS-T11-LOCATION-COUNTY-X
                    TO WS-0707-T11-LOC-CNTY
                  MOVE WS-T11-INSUR-PLAN-CD-X
                    TO WS-0707-T11-INS-PLAN
                  MOVE WS-T11-CROP-CD-X TO WS-0707-T11-CROP
                  MOVE WS-T11-TYPE-CD-X TO WS-0707-T11-CROP-TYPE
                  MOVE WS-T11-PRACTICE-CD-x TO WS-0707-T11-PRACTICE
                  MOVE WS-T11-UNIT-NUM-X
                    TO WS-0707-T11-UNIT
                  MOVE WS-T11-COVERAGE-FLG TO WS-0707-T11-CVG-CODE
                  MOVE WS-T11-TOTAL-PREMIUM-X
                       TO WS-0707-T11-TOTAL-PREMIUM
                  MOVE WS-TRAN-SEQ-NO TO WS-0707-T11-TRAN-SEQ-NO
                  MOVE WS-0707-TYPE-11-DTL TO ERROR-REPT-RECORD

               WHEN 12
                  INITIALIZE WS-0707-TYPE-12-DTL
                  MOVE WS-TRAN-TYPE TO WS-0707-T12-TYPE
                  MOVE WS-T12-RECORD-NUM-X TO WS-0707-T12-REC-NO
                  MOVE WS-T12-PAID-DATE-X TO WS-0707-T12-PAYMENT-DATE
                  MOVE WS-T12-PAYMENT-TYPE-X
                    TO WS-0707-T12-PAYMENT-TYPE
                  MOVE WS-T12-PAID-AMOUNT-X
                    TO WS-0707-T12-PAYMENT-AMOUNT
                  MOVE WS-T12-PREPAYMENT-FLG-X
                    TO WS-0707-T12-PREPAY-FLAG
                  MOVE WS-TRAN-SEQ-NO TO WS-0707-T12-TRAN-SEQ-NO
                  MOVE WS-0707-TYPE-12-DTL TO ERROR-REPT-RECORD

               WHEN 14
                  INITIALIZE WS-0707-TYPE-14-DTL
                  MOVE WS-TRAN-TYPE TO WS-0707-T14-TYPE
                  MOVE WS-T14-RECORD-NUM-X TO WS-0707-T14-REC-NO
                  MOVE WS-T14-LOCATION-COUNTY-X
                    TO WS-0707-T14-LOC-CNTY
                  MOVE WS-T14-CROP-CD-X TO WS-0707-T14-CROP
                  MOVE WS-T14-TYPE-CD TO WS-0707-T14-CROP-TYPE
                  MOVE WS-T14-COVERAGE-FLG TO WS-0707-T14-CVG-CODE
                  MOVE WS-T14-INSURANCE-PLAN-ID-X
                    TO WS-0707-T14-insurance-plan-id
                  MOVE WS-TRAN-SEQ-NO TO WS-0707-T14-TRAN-SEQ-NO
                  MOVE WS-0707-TYPE-14-DTL TO ERROR-REPT-RECORD

               WHEN 15
                  INITIALIZE WS-0707-TYPE-15-DTL
                  MOVE WS-TRAN-TYPE TO WS-0707-T15-TYPE
                  MOVE WS-T15-RECORD-NUMBER-X TO WS-0707-T15-REC-NO
                  MOVE WS-T15-LOCATION-COUNTY-X
                    TO WS-0707-T15-LOC-CNTY
                  MOVE WS-T15-INS-PLAN-CD-X TO WS-0707-T15-INS-PLAN
                  MOVE WS-T15-CROP-CD-X TO WS-0707-T15-CROP
                  MOVE WS-T15-TYPE-CD TO WS-0707-T15-CROP-TYPE
                  MOVE WS-T15-PRACTICE-CD TO WS-0707-T15-PRACTICE
                  MOVE WS-T15-BASIC-UNIT-NUM-X TO WS-0707-T15-BASIC-UNIT
                  MOVE WS-T15-OPTIONAL-UNIT-X TO WS-0707-T15-OPT-UNIT
                  MOVE WS-T15-COVERAGE-FLG TO WS-0707-T15-CVG-CODE
                  MOVE WS-TRAN-SEQ-NO TO WS-0707-T15-TRAN-SEQ-NO
                  MOVE WS-0707-TYPE-15-DTL TO ERROR-REPT-RECORD

               WHEN 16
                  INITIALIZE WS-0707-TYPE-16-DTL
                  MOVE WS-TRAN-TYPE TO WS-0707-T16-TYPE
                  MOVE WS-T16-RECORD-NUM-X TO WS-0707-T16-REC-NO
                  STRING WS-T16-3RD-PARTY-FIRST-NAME
                    DELIMITED BY SPACE
                    ' '
                    DELIMITED BY SIZE
                    WS-T16-3RD-PARTY-LAST-NAME
                    DELIMITED BY SPACE
                    INTO WS-0707-T16-NAME
                  END-STRING
                  MOVE WS-T16-LOCATION-COUNTY-X
                    TO WS-0707-T16-LOC-CNTY
                  MOVE WS-T16-3RD-PARTY-ID-TYPE-X
                    TO WS-0707-T16-ID-TYPE
                  MOVE WS-T16-3RD-PARTY-ID-NUM-X
                    TO WS-0707-T16-ID-NUMBER
                  MOVE WS-TRAN-SEQ-NO TO WS-0707-T16-TRAN-SEQ-NO
                  MOVE WS-0707-TYPE-16-DTL TO ERROR-REPT-RECORD

               WHEN 20
                  INITIALIZE WS-0707-TYPE-20-DTL
                  MOVE WS-TRAN-TYPE TO WS-0707-T20-TYPE
                  MOVE WS-T20-RECORD-NUM-X TO WS-0707-T20-REC-NO
                  MOVE WS-T20-CLAIM-NUM-X TO WS-0707-T20-CLAIM-NO
                  MOVE WS-TRAN-SEQ-NO TO WS-0707-T20-TRAN-SEQ-NO
                  MOVE WS-0707-TYPE-20-DTL TO ERROR-REPT-RECORD

               WHEN 21
                  INITIALIZE WS-0707-TYPE-21-DTL
                  MOVE WS-TRAN-TYPE TO WS-0707-T21-TYPE
                  MOVE WS-T21-RECORD-NUM-X TO WS-0707-T21-REC-NO
                  MOVE WS-T21-CLAIM-NUM-X TO WS-0707-T21-CLAIM-NO
                  MOVE WS-T21-LOCATION-COUNTY-X
                    TO WS-0707-T21-LOC-CNTY
                  MOVE WS-T21-CROP-CD-X TO WS-0707-T21-CROP
                  MOVE WS-T21-TYPE-CD TO WS-0707-T21-CROP-TYPE
                  MOVE WS-T21-PRACTICE-CD TO WS-0707-T21-PRACTICE
                  MOVE WS-T21-BASIC-UNIT-NUM-X
                    TO WS-0707-T21-BASIC-UNIT
                  MOVE WS-T21-OPTIONAL-UNIT-X
                    TO WS-0707-T21-OPT-UNIT
                  MOVE WS-T21-COVERAGE-FLG TO WS-0707-T21-CVG-CODE
                  MOVE WS-TRAN-SEQ-NO TO WS-0707-T21-TRAN-SEQ-NO
                  MOVE WS-0707-TYPE-21-DTL TO ERROR-REPT-RECORD

               WHEN 33
                  INITIALIZE WS-0707-TYPE-33-DTL
                  MOVE WS-TRAN-TYPE TO WS-0707-T33-TYPE
                  MOVE WS-T33-RECORD-NUM-X TO WS-0707-T33-REC-NO
                  MOVE WS-T33-CROP-CD-X TO WS-0707-T33-CROP
                  MOVE WS-T33-ESTIMATE-PREM-X
                    TO WS-0707-T33-EST-PREMIUM
                  MOVE WS-T33-ESTIMATE-LOSS-X
                    TO WS-0707-T33-EST-LOSS
                  MOVE WS-TRAN-SEQ-NO TO WS-0707-T33-TRAN-SEQ-NO
                  MOVE WS-0707-TYPE-33-DTL TO ERROR-REPT-RECORD

               WHEN 49
                  INITIALIZE WS-0707-TYPE-49-DTL
                  MOVE WS-TRAN-TYPE TO WS-0707-T49-TYPE
                  MOVE WS-TRAN-SEQ-NO TO WS-0707-T49-TRAN-SEQ-NO
                  MOVE WS-0707-TYPE-49-DTL TO ERROR-REPT-RECORD

               WHEN 50
                  INITIALIZE WS-0707-TYPE-50-DTL
                  MOVE WS-TRAN-TYPE TO WS-0707-T50-TYPE
                  MOVE WS-T50-PRIVATE-POLICY-CD
                    TO WS-0707-T50-POLICY-TYPE
                  MOVE WS-T50-PRIVATE-POLICY-NUM
                    TO WS-0707-T50-POLICY-NO
                  MOVE WS-T50-LOCATION-COUNTY-X
                    TO WS-0707-T50-LOC-CNTY
                  MOVE WS-T50-CROP-CD-X TO WS-0707-T50-CROP
                  MOVE WS-T50-COVERAGE-LVL-PCT-X
                    TO WS-0707-T50-COVERAGE-PCT
                  MOVE WS-T50-REPORTED-ACRES-X
                    TO WS-0707-T50-ACRES
                  MOVE WS-T50-LIABILITY-X
                    TO WS-0707-T50-LIABILITY
                  MOVE WS-T50-TOTAL-PREMIUM-X
                    TO WS-0707-T50-PREMIUM
                  MOVE WS-T50-TOTAL-INDEMNITY-X
                    TO WS-0707-T50-INDEMNITY
                  MOVE WS-TRAN-SEQ-NO TO WS-0707-T50-TRAN-SEQ-NO
                  MOVE WS-0707-TYPE-50-DTL TO ERROR-REPT-RECORD

               WHEN 55
                  INITIALIZE WS-0707-TYPE-55-DTL
                  MOVE WS-TRAN-TYPE TO WS-0707-T55-TYPE
                  STRING WS-T55-AGENT-FIRST-NAME
                   DELIMITED BY SPACE
                   ' '
                   DELIMITED BY SIZE
                   WS-T55-AGENT-LAST-NAME
                   DELIMITED BY SPACE
                   INTO WS-0707-T55-AGENT-NAME
                  END-STRING
                  MOVE WS-T55-TYPE-OF-ID-CODE TO WS-0707-T55-ID-TYPE
                  MOVE WS-T55-AGENT-ID TO WS-0707-T55-ID-NUMBER
                  MOVE WS-T55-AGENCY-NAME TO WS-0707-T55-AGENCY-NAME
                  MOVE WS-T55-PHONE-NUM TO WS-0707-T55-PHONE-NUMBER
                  MOVE WS-TRAN-SEQ-NO TO WS-0707-T55-TRAN-SEQ-NO
                  MOVE WS-0707-TYPE-55-DTL TO ERROR-REPT-RECORD

               WHEN 56
                  INITIALIZE WS-0707-TYPE-56-DTL
                  MOVE WS-TRAN-TYPE TO WS-0707-T56-TYPE
                  STRING WS-T56-ADJ-FIRST-NAME
                   DELIMITED BY SPACE
                   ' '
                   DELIMITED BY SIZE
                   WS-T56-ADJ-LAST-NAME
                   DELIMITED BY SPACE
                   INTO WS-0707-T56-ADJUSTER-NAME
                  END-STRING
                  MOVE WS-T56-ADJUSTER-ID TO WS-0707-T56-ID-NUMBER
                  MOVE WS-T56-ADJUSTER-SSN-X TO WS-0707-T56-SSN
                  MOVE WS-TRAN-SEQ-NO TO WS-0707-T56-TRAN-SEQ-NO
                  MOVE WS-0707-TYPE-56-DTL TO ERROR-REPT-RECORD

               WHEN 65
                  INITIALIZE WS-0707-TYPE-65-DTL
                  MOVE WS-TRAN-TYPE TO WS-0707-T65-TYPE
                  MOVE WS-T65-LOC-COUNTY-X TO WS-0707-T65-LOC-CNTY
                  MOVE WS-TRAN-SEQ-NO TO WS-0707-T65-TRAN-SEQ-NO
                  MOVE WS-0707-TYPE-65-DTL TO ERROR-REPT-RECORD

               WHEN OTHER
                  MOVE '***** NO TRANSACTION DETAIL FORMAT'
                    TO ERROR-REPT-RECORD
              END-EVALUATE
              WRITE ERROR-REPT-RECORD
              ADD 1 TO WS-0707-CURRENT-LINE-COUNT
           ELSE
              PERFORM 0707-WRITE-NEW-PAGE
                 THRU 0707-WRITE-NEW-PAGE-EXIT
           END-IF.

       0707-WRITE-TRAN-DTL-EXIT.
           EXIT.

      *************************************************************
      *    WRITE PAGE HEADER                                      *
      *************************************************************

       0707-WRITE-PAGE-HEADER.

           MOVE 1 TO WS-0707-CURRENT-LINE-COUNT
      *    *** WRITE BLANK LINE
           MOVE SPACES TO ERROR-REPT-RECORD
           WRITE ERROR-REPT-RECORD
           ADD 1 TO WS-0707-CURRENT-LINE-COUNT

      *    *** WRITE HEADER LINE 1
           ADD 1 TO WS-0707-CURRENT-PAGE-NO
           INITIALIZE WS-0707-HEADER-LN1
           MOVE WS-0004-INS-PROVIDER-NAME TO WS-0707-REP-ORG
           MOVE WS-0004-REINS-YR TO WS-0707-REINS-YR
           MOVE WS-0707-CURRENT-PAGE-NO TO WS-0707-PRINT-PAGE-NO
           MOVE WS-0707-HEADER-LN1 TO ERROR-REPT-RECORD
           WRITE ERROR-REPT-RECORD
           ADD 1 TO WS-0707-CURRENT-LINE-COUNT

      *    *** WRITE HEADER LINE 2
           INITIALIZE WS-0707-HEADER-LN2
           IF WS-0707-RERUN-INDICATOR = WS-LITERAL-YES
              MOVE '*********** THIS IS A RERUN ************'
                TO WS-0707-RERUN-BANNER
           END-IF
           MOVE WS-0004-SYS-DATE TO WS-0707-REPT-DATE
           MOVE WS-0004-SYS-TIME TO WS-0707-REPT-TIME
           MOVE WS-0707-HEADER-LN2 TO ERROR-REPT-RECORD
           WRITE ERROR-REPT-RECORD
           ADD 1 TO WS-0707-CURRENT-LINE-COUNT
           INITIALIZE WS-0707-HEADER-LN2

      *    *** WRITE HEADER LINE 3
           INITIALIZE WS-0707-HEADER-LN3
           MOVE WS-0004-FILE-NAME TO WS-0707-REPT-FILE-NAME
           MOVE WS-0004-BATCH-INS-PROV TO WS-0707-REPT-BATCH-NO-RO
           MOVE WS-0004-REINS-YR TO WS-0707-REPT-BATCH-NO-YR
           MOVE WS-0004-BATCH-NO TO WS-0707-REPT-BATCH-NO
           MOVE WS-0004-FCIC-PROC-DATE   TO WS-0707-REPT-FCIC-DT
           MOVE WS-0004-FCIC-PROC-TIME   TO WS-0707-REPT-FCIC-TIME
           MOVE WS-0707-HEADER-LN3 TO ERROR-REPT-RECORD
           WRITE ERROR-REPT-RECORD
           ADD 1 TO WS-0707-CURRENT-LINE-COUNT
           INITIALIZE WS-0707-HEADER-LN3

      *    *** WRITE BLANK LINE
           MOVE SPACES TO ERROR-REPT-RECORD
           WRITE ERROR-REPT-RECORD
           ADD 1 TO WS-0707-CURRENT-LINE-COUNT.

       0707-WRITE-PAGE-HEADER-EXIT.
           EXIT.

      *************************************************************
      *    WRITE NEW PAGE                                         *
      *************************************************************

       0707-WRITE-NEW-PAGE.

      *    *** WRITE TO END OF PAGE
           IF WS-0707-CURRENT-LINE-COUNT < WS-0707-PAGE-LENGTH
              PERFORM 0707-WRITE-BLANK-LN
                 THRU 0707-WRITE-BLANK-LN-EXIT
                 WITH TEST AFTER
              VARYING WS-0707-CURRENT-LINE-COUNT
                 FROM WS-0707-CURRENT-LINE-COUNT BY 1
                UNTIL WS-0707-CURRENT-LINE-COUNT = WS-0707-PAGE-LENGTH
           END-IF

           PERFORM 0707-WRITE-PAGE-HEADER
              THRU 0707-WRITE-PAGE-HEADER-EXIT

      *    *** IF THERE IS A CURRENT POLICY WRITE THE HEADER
           IF WS-0707-CURRENT-POLICY-NO <> SPACES
              PERFORM 0707-WRITE-POLICY-HDR
                 THRU 0707-WRITE-POLICY-HDR-EXIT
           END-IF

      *    *** IF THERE IS A CURRENT TRANSACTION RE-WRITE IT
           IF WS-0707-CURRENT-TRAN-TYPE <> SPACES
              PERFORM 0707-WRITE-TRAN-HDR
                 THRU 0707-WRITE-TRAN-HDR-EXIT
              PERFORM 0707-WRITE-TRAN-DTL
                 THRU 0707-WRITE-TRAN-DTL-EXIT
           END-IF.

       0707-WRITE-NEW-PAGE-EXIT.
           EXIT.


      *************************************************************
      *    WRITE BLANK LINE                                       *
      *************************************************************

       0707-WRITE-BLANK-LN.

           MOVE SPACES TO ERROR-REPT-RECORD
           WRITE ERROR-REPT-RECORD.

       0707-WRITE-BLANK-LN-EXIT.
           EXIT.

      *************************************************************
      *    WRITE ERROR RECORD                                     *
      *************************************************************

       0707-WRITE-ERROR.

      *    *** MAKE SURE THERE IS ROOM ON THE PAGE
           IF (WS-0707-CURRENT-LINE-COUNT + 2) >= WS-0707-PAGE-LENGTH
              PERFORM 0707-WRITE-NEW-PAGE
                 THRU 0707-WRITE-NEW-PAGE-EXIT
           END-IF

      *    *** WRITE ERROR LINE
           IF WS-0707-PARAGRAPH-NO-FLAG = WS-LITERAL-YES
              INITIALIZE WS-0707-ERROR-LN1A
              MOVE WS-0707-PARAGRAPH-NO
                TO WS-0707-ERR1A-PARAGRAPH-NO
              MOVE WS-0707-ERROR-CODE TO WS-0707-ERR1A-ERROR-CODE
              MOVE WS-0707-FIELD-NAME1 TO WS-0707-ERR1A-FIELD-NAME
              MOVE WS-0707-BAD-DATA1 TO WS-0707-ERR1A-BAD-DATA
              MOVE WS-0707-CORR-DATA1 TO WS-0707-ERR1A-EXPECTED
              MOVE WS-0707-ERROR-LN1A TO ERROR-REPT-RECORD
           ELSE
              INITIALIZE WS-0707-ERROR-LN1B
              MOVE WS-0707-ERROR-CODE TO WS-0707-ERR1B-ERROR-CODE
              MOVE WS-0707-FIELD-NAME1 TO WS-0707-ERR1B-FIELD-NAME
              MOVE WS-0707-BAD-DATA1 TO WS-0707-ERR1B-BAD-DATA
              MOVE WS-0707-CORR-DATA1 TO WS-0707-ERR1B-EXPECTED
              MOVE WS-0707-ERROR-LN1B TO ERROR-REPT-RECORD
           END-IF
           WRITE ERROR-REPT-RECORD
           ADD 1 TO WS-0707-CURRENT-LINE-COUNT

      *    *** WRITE ERROR MESSAGE
           IF WS-0707-ERROR-MESSAGE-FLAG = WS-LITERAL-YES
              INITIALIZE WS-0707-ERROR-LN2
              INITIALIZE WS-7285-ERROR-NO
              MOVE WS-0707-ERROR-CODE TO WS-7285-ERROR-NO
              PERFORM 7285-LOOKUP-ERROR-MSG-TBL
                 THRU 7285-LOOKUP-ERROR-MSG-TBL-EXIT
              IF NOT MATCH-FOUND-7285
                 MOVE 0707 TO WS-8020-PARAGRAPH-NO
                 MOVE 90031 TO WS-8020-INT-ERROR-NO
                 MOVE WS-TRAN-SEQ-NO TO WS-8020-TRAN-SEQ-NO
                 MOVE WS-LITERAL-NO TO WS-8020-ABORT-PROGRAM
                 MOVE 'WS-0707-ERROR-CODE' TO WS-8020-FIELD-NAME
                 MOVE WS-0707-ERROR-CODE TO WS-8020-BAD-DATA
                 MOVE WS-LITERAL-NO TO WS-8020-ABORT-PROGRAM
                 PERFORM 8020-RECORD-INT-ERROR
                    THRU 8020-RECORD-INT-ERROR-EXIT
                 MOVE 'Error Message not in Table!'
                   TO WS-0707-ERROR-MESSAGE
              ELSE
                 MOVE WS-7285-ERROR-MSG
                   TO WS-0707-ERROR-MESSAGE
              END-IF
              MOVE WS-0707-ERROR-LN2 TO ERROR-REPT-RECORD
              WRITE ERROR-REPT-RECORD
              ADD 1 TO WS-0707-CURRENT-LINE-COUNT
           END-IF.

       0707-WRITE-ERROR-EXIT.
           EXIT.


