      ***************************************************************
      * File:      M0100.CBL
      * Author:    Mike Ray
      * Date:      8/9/95
      * Purpose:
      *    This paragraph initializes working storage fields,
      *    gets parameters from the linkage section, gets system
      *    environment information, looks up das environment info
      *    from the database and opens all files by performing the
      *    appropriate setup paragraphs.
      * Contains:
      *    M0105.CBL  0105-INITIALIZE-STATS
      *    M0110.CBL  0110-INITIALIZE-TABLES
      *    M0115.CBL  0115-INITIALIZE-BATCH
      *    M0120.CBL  0120-INITIALIZE-POLICY
      *    M0125.CBL  0125-INITIALIZE-CROP-POL
      *    M0130.CBL  0130-INITIALIZE-TRAN
      *    M0135.CBL  0135-GET-PARAMETERS
      *    M0140.CBL  0140-GET-SYSTEM-DATA
      *    M0145.CBL  0145-GET-IP-DB-DATA
      *    M0155.CBL  0155-INIT-CROP-TABLES
      *    M0160.CBL  0160-INIT-POLICY-TABLES
      *    M0165.CBL  0165-SET-FILE-NAMES
      *    M0170.CBL  0170-MOVE-FILES-TO-TMP
      ***************************************************************

       0100-SETUP.

      $IF DEBUG-SW DEFINED
           DISPLAY 'BEGINNING 0100-SETUP'
           UPON CONSOLE
      $END

      *******************************************
      *    INITIALIZE WORKING STORAGE           *
      *******************************************
           PERFORM 0105-INITIALIZE-STATS
              THRU 0105-INITIALIZE-STATS-EXIT
           PERFORM 0110-INITIALIZE-TABLES
              THRU 0110-INITIALIZE-TABLES-EXIT
           PERFORM 0115-INITIALIZE-BATCH
              THRU 0115-INITIALIZE-BATCH-EXIT
           PERFORM 0120-INITIALIZE-POLICY
              THRU 0120-INITIALIZE-POLICY-EXIT
           PERFORM 0125-INITIALIZE-CROP-POL
              THRU 0125-INITIALIZE-CROP-POL-EXIT
           PERFORM 0130-INITIALIZE-TRAN
              THRU 0130-INITIALIZE-TRAN-EXIT

      $IF DEBUG-SW DEFINED
           DISPLAY 'INITIALIZATION COMPLETE'
           UPON CONSOLE
      $END

      *******************************************
      *    GET TIME & OTHER SYSTEM ENV DATA     *
      *******************************************
           PERFORM 0140-GET-SYSTEM-DATA
              THRU 0140-GET-SYSTEM-DATA-EXIT.

      *******************************************
      *       LOAD IP TABLE TO VAL PARAMETERS   *
      *******************************************
            PERFORM 7200-LOAD-IP-TBL
               THRU 7200-LOAD-IP-TBL-EXIT

      *******************************************
      *             GET PARAMETERS              *
      *******************************************
           PERFORM 0135-GET-PARAMETERS
              THRU 0135-GET-PARAMETERS-EXIT

      ************************************************
      *        SET BATCH ISAM FILE NAME              *
      ************************************************
           INITIALIZE WS-0565-INPUT
           STRING WS-0004-BATCH-INS-PROV
               DELIMITED BY SIZE
               WS-0004-REINS-SHORT-YR
               DELIMITED BY SIZE
               'BAT'
               DELIMITED BY SIZE
               INTO WS-0565-INPUT-FILE-NAME
           END-STRING
           MOVE 'ISAM/' TO WS-0565-INPUT-PATH
           MOVE 'ISM' TO WS-0565-INPUT-FILE-EXT
           PERFORM 0565-BUILD-FILE-NAME
              THRU 0565-BUILD-FILE-NAME-EXIT
           MOVE WS-0565-OUTPUT-FILE-NAME
             TO WS-0004-BATCH-FILE-NAME

      *******************************************
      *  OPEN BATCH ISAM TO GET BATCH NO INFO   *
      *******************************************
      $IF ISAM-SW DEFINED
           OPEN I-O BATCH-ISAM-FILE
           MOVE WS-LITERAL-YES TO WS-0900-INPUT-BATCH-OPEN
           ADD 1 TO WS-0004-FILES-OPEN
           IF WS-0004-FILES-OPEN > WS-0008-MAX-FILES-OPENED
              MOVE WS-0004-FILES-OPEN
                TO WS-0008-MAX-FILES-OPENED
           END-IF
      $END

      *******************************************
      *    LOOKUP BATCH NUMBER FOR RO           *
      *******************************************
           IF WS-0004-BATCH-NO = ZEROS
              MOVE WS-0004-REINS-YR TO WS-0952-INPUT-BATCH-YR
              MOVE WS-0004-BATCH-INS-PROV TO WS-0952-INPUT-BATCH-RO
              MOVE WS-0004-FILE-NAME TO WS-0952-FILE-NAME
              MOVE WS-0004-SYS-DATE TO WS-0952-SYS-DATE
              MOVE WS-0004-SYS-TIME TO WS-0952-SYS-TIME
              MOVE WS-0004-FCIC-PROC-DATE TO WS-0952-FCIC-CTRL-DT
              MOVE WS-0004-FCIC-PROC-TIME TO WS-0952-FCIC-CTRL-TIME
              PERFORM 0952-GET-NEXT-BATCH-NO
                 THRU 0952-GET-NEXT-BATCH-NO-EXIT

              MOVE WS-0952-BATCH-NO TO WS-0004-BATCH-NO
           END-IF

      *******************************************
      *            SET FILE NAMES               *
      *******************************************
           PERFORM 0165-SET-FILE-NAMES
              THRU 0165-SET-FILE-NAMES-EXIT

      ************************************************
      *    SEE IF T11 FILES EXIST                    *
      ************************************************
           MOVE SPACES TO WS-0165-ISAM-NAME
           MOVE 'T11' TO WS-0165-ISAM-NAME
           INITIALIZE WS-0565-INPUT
           STRING WS-0004-BATCH-INS-PROV
               DELIMITED BY SIZE
               WS-0004-REINS-SHORT-YR
               DELIMITED BY SIZE
               'T11'
               DELIMITED BY SIZE
               INTO WS-0565-INPUT-FILE-NAME
           END-STRING
           MOVE WS-0165-LOCAL-FILE-NAME TO WS-0565-INPUT-FILE-NAME
           MOVE '/tmp/' TO WS-0565-INPUT-PATH
           MOVE 'ISM' TO WS-0565-INPUT-FILE-EXT
           PERFORM 0565-BUILD-FILE-NAME
              THRU 0565-BUILD-FILE-NAME-EXIT
           MOVE WS-0565-OUTPUT-FILE-NAME
             TO WS-0004-OUT-T11-FILE-NAME
           MOVE WS-LITERAL-NO TO WS-0170-ISAM-FILE-EXISTS-FLG
           INITIALIZE WS-0575-INPUT
           MOVE WS-0004-OUT-T11-FILE-NAME
             TO WS-0575-INPUT-FILE-NAME
           PERFORM 0575-TEST-FILE-NAME
              THRU 0575-TEST-FILE-NAME-EXIT
           IF FILE-EXISTS-0575
              MOVE WS-LITERAL-NO TO WS-0004-USE-TMP-DIR-FLAG
      $IF DEBUG-SW DEFINED
           DISPLAY '0100-OUTPUT FILE: ' WS-0575-INPUT-FILE-NAME 
               ' EXISTS - ISAM FILES NOT COPIED '
           UPON CONSOLE
      $END
           END-IF

      **************************************************
      *    MOVE FILES TO TEMP DIRECTORY - IF NECESSARY *
      **************************************************
           IF WS-0004-USE-TMP-DIR-FLAG = WS-LITERAL-YES
              PERFORM 0170-MOVE-FILES-TO-TMP
                 THRU 0170-MOVE-FILES-TO-TMP-EXIT
           ELSE
      $IF DEBUG-SW DEFINED
               DISPLAY '0100-NOT MOVING FILES TO /tmp DIRECTORY'
      $END
               CONTINUE
           END-IF

      *******************************************
      *             OPEN FILES                  *
      *******************************************
           PERFORM 0910-OPEN-FILES
              THRU 0910-OPEN-FILES-EXIT

      *******************************************
      *    LOOKUP BOOK NUMBER FOR RO            *
      *******************************************
           MOVE 1 TO WS-0004-CURRENT-BOOK-NO

      $IF DATABASE-SW DEFINED

      $ELSE

      *******************************************
      *    DISPLAY MAX TABLE SIZES              *
      *******************************************
      $IF DEBUG-SW DEFINED
           DISPLAY '**** TABLE MAX SIZES ****'
           UPON CONSOLE
           DISPLAY 'T10 SBI MAX SIZE  = ', WS-0010-MAX-SIZE
           UPON CONSOLE
           DISPLAY 'T11 MAX SIZE      = ', WS-0011-MAX-SIZE
           UPON CONSOLE
           DISPLAY 'T12 MAX SIZE      = ', WS-0012-MAX-SIZE
           UPON CONSOLE
           DISPLAY 'T14 MAX SIZE      = ', WS-0014-MAX-SIZE
           UPON CONSOLE
           DISPLAY 'T15 MAX SIZE      = ', WS-0015-MAX-SIZE
           UPON CONSOLE
           DISPLAY 'T16 MAX SIZE      = ', WS-0016-MAX-SIZE
           UPON CONSOLE
           DISPLAY 'T20 MAX SIZE      = ', WS-0020-MAX-SIZE
           UPON CONSOLE
           DISPLAY 'T20 CLAIM MAX SIZE = ', WS-0020-CLAIM-MAX-SIZE
           UPON CONSOLE
           DISPLAY 'T21 MAX SIZE      = ', WS-0021-MAX-SIZE
           UPON CONSOLE
           DISPLAY 'T21 UNIT MAX SIZE = ', WS-0021-UNIT-MAX-SIZE
           UPON CONSOLE
           DISPLAY 'T21 CROP MAX SIZE = ', WS-0021-CROP-MAX-SIZE
           UPON CONSOLE
           DISPLAY 'T50 MAX SIZE     = ', WS-0050-MAX-SIZE
           UPON CONSOLE
           DISPLAY 'BUFFER MAX SIZE  = ', WS-0099-MAX-SIZE
           UPON CONSOLE
      $END
           PERFORM 7205-LOAD-COMPANY-TBL
              THRU 7205-LOAD-COMPANY-TBL-EXIT
           PERFORM 7210-LOAD-FIPS-ST-TBL
              THRU 7210-LOAD-FIPS-ST-TBL-EXIT
           PERFORM 7215-LOAD-COUNTY-TBL
              THRU 7215-LOAD-COUNTY-TBL-EXIT
           PERFORM 7220-LOAD-CROP-TBL
              THRU 7220-LOAD-CROP-TBL-EXIT
           PERFORM 7225-LOAD-CROP-TYPE-TBL
              THRU 7225-LOAD-CROP-TYPE-TBL-EXIT
           PERFORM 7230-LOAD-CROP-POL-TY-TBL
              THRU 7230-LOAD-CROP-POL-TY-TBL-EXIT
           PERFORM 7235-LOAD-ERROR-MSG-TBL
              THRU 7235-LOAD-ERROR-MSG-TBL-EXIT
           PERFORM 7240-LOAD-TXWA-FINAL-DATE-TBL
              THRU 7240-LOAD-TXWA-FINAL-DATE-EXIT
           PERFORM 7295-LOAD-UM-TBL
              THRU 7295-LOAD-UM-TBL-EXIT
           PERFORM 7300-LOAD-STAGE-CROP-TBL
              THRU 7300-LOAD-STAGE-CROP-TBL-EXIT
           PERFORM 7320-LOAD-LOSS-CAUSE-CROP
              THRU 7320-LOAD-LOSS-CAUSE-CROP-EXIT
           PERFORM 7360-LOAD-STAGE-TBL
              THRU 7360-LOAD-STAGE-TBL-EXIT
           PERFORM 7370-LOAD-LOSS-CAUSE-TBL
              THRU 7370-LOAD-LOSS-CAUSE-TBL-EXIT
           PERFORM 7325-LOAD-CROP-LIMIT-TBL
              THRU 7325-LOAD-CROP-LIMIT-TBL-EXIT
      $END

      *******************************************
      *          WRITE HEADER INFO              *
      *******************************************

           PERFORM 0935-WRITE-BATCH-HEADER
              THRU 0935-WRITE-BATCH-HEADER-EXIT.

       0100-SETUP-EXIT.
           EXIT.

       COPY 'SETUP/M0105.CBL'.
       COPY 'SETUP/M0110.CBL'.
       COPY 'SETUP/M0115.CBL'.
       COPY 'SETUP/M0120.CBL'.
       COPY 'SETUP/M0125.CBL'.
       COPY 'SETUP/M0130.CBL'.
       COPY 'SETUP/M0135.CBL'.
       COPY 'SETUP/M0140.CBL'.
       COPY 'SETUP/M0145.CBL'.
       COPY 'SETUP/M0155.CBL'.
       COPY 'SETUP/M0160.CBL'.
       COPY 'SETUP/M0165.CBL'.
       COPY 'SETUP/M0170.CBL'.
