      ***************************************************************
      * File:      M7010.CBL                                        *
      * Author:    Mike Ray and Cheryl D. Wood                      *
      * Date:      8/25/95                                          *
      * Purpose:                                                    *
      *    Adds a single T11 record to the T11 table.               *
      *    if the record exists, the new record replaces it and the *
      *    indicator is set to indicate where the record came from. *
      *                                                             *
      *    This module also creates/updates a table which stores    *
      *    Total Liability by crop unit.  This table is accessed by *
      *    Type 21 inter-record edits.                              *
      ***************************************************************

       7010-ADD-T11-RECORD.

      $IF DEBUG-SW DEFINED
           DISPLAY '7010-ADDING T11 RECORD'
           UPON CONSOLE
      $END

      ****************************************************************
      *   DISPLAY RECORD BEING ADDED                                 *
      ****************************************************************
      $IF DEBUG-SW DEFINED
           PERFORM 7010-DISPLAY-RECORD
              THRU 7010-DISPLAY-RECORD-EXIT
      $END

      ****************************************************************
      *  Check to make sure that the transaction sequence number     *
      *  is passed and that the other control flags are set.         *
      ****************************************************************

           IF WS-7010-TRAN-SEQ-NO IS NOT NUMERIC
              MOVE 7010 TO WS-8020-PARAGRAPH-NO
              MOVE 90001 TO WS-8020-INT-ERROR-NO
              MOVE 'WS-7010-TRAN-SEQ-NO' TO WS-8020-FIELD-NAME
              MOVE WS-7010-TRAN-SEQ-NO TO WS-8020-BAD-DATA
              MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
              PERFORM 8020-RECORD-INT-ERROR
                 THRU 8020-RECORD-INT-ERROR-EXIT
           END-IF

           IF WS-7010-TRAN-SEQ-NO = ZEROS
              MOVE 7010 TO WS-8020-PARAGRAPH-NO
              MOVE 90003 TO WS-8020-INT-ERROR-NO
              MOVE 'WS-7010-TRAN-SEQ-NO' TO WS-8020-FIELD-NAME
              MOVE WS-7010-TRAN-SEQ-NO TO WS-8020-BAD-DATA
              MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
              PERFORM 8020-RECORD-INT-ERROR
                 THRU 8020-RECORD-INT-ERROR-EXIT
           END-IF

           IF WS-7010-TRAN-SOURCE-FLAG = SPACES
              MOVE 7010 TO WS-8020-PARAGRAPH-NO
              MOVE 90003 TO WS-8020-INT-ERROR-NO
              MOVE 'WS-7010-TRAN-SOURCE-FLAG' TO WS-8020-FIELD-NAME
              MOVE WS-7010-TRAN-SOURCE-FLAG TO WS-8020-BAD-DATA
              MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
              PERFORM 8020-RECORD-INT-ERROR
                 THRU 8020-RECORD-INT-ERROR-EXIT
           END-IF

           IF WS-7010-GUARANTEE-PER-ACRE IS NOT NUMERIC
              MOVE 7010 TO WS-8020-PARAGRAPH-NO
              MOVE 90001 TO WS-8020-INT-ERROR-NO
              MOVE 'WS-7010-GUARANTEE-PER-ACRE' TO WS-8020-FIELD-NAME
              MOVE SPACES TO WS-8020-BAD-DATA
              MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
              PERFORM 8020-RECORD-INT-ERROR
                 THRU 8020-RECORD-INT-ERROR-EXIT
           END-IF


           IF WS-7010-TOTAL-GUARANTEE IS NOT NUMERIC
              MOVE 7010 TO WS-8020-PARAGRAPH-NO
              MOVE 90001 TO WS-8020-INT-ERROR-NO
              MOVE 'WS-7010-TOTAL-GUARANTEE' TO WS-8020-FIELD-NAME
              MOVE SPACES TO WS-8020-BAD-DATA
              MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
              PERFORM 8020-RECORD-INT-ERROR
                 THRU 8020-RECORD-INT-ERROR-EXIT
           END-IF


           IF WS-7010-LOW-YIELD IS NOT NUMERIC
              MOVE 7010 TO WS-8020-PARAGRAPH-NO
              MOVE 90001 TO WS-8020-INT-ERROR-NO
              MOVE 'WS-7010-LOW-YIELD' TO WS-8020-FIELD-NAME
              MOVE SPACES TO WS-8020-BAD-DATA
              MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
              PERFORM 8020-RECORD-INT-ERROR
                 THRU 8020-RECORD-INT-ERROR-EXIT
           END-IF


           IF WS-7010-HIGH-YIELD IS NOT NUMERIC
              MOVE 7010 TO WS-8020-PARAGRAPH-NO
              MOVE 90001 TO WS-8020-INT-ERROR-NO
              MOVE 'WS-7010-HIGH-YIELD' TO WS-8020-FIELD-NAME
              MOVE ZEROS TO WS-8020-BAD-DATA
              MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
              PERFORM 8020-RECORD-INT-ERROR
                 THRU 8020-RECORD-INT-ERROR-EXIT
           END-IF

           IF WS-7010-FCIC-CONTROL-TIME IS NOT NUMERIC
              MOVE 7010 TO WS-8020-PARAGRAPH-NO
              MOVE 90001 TO WS-8020-INT-ERROR-NO
              MOVE 'WS-7010-FCIC-CONTROL-TIME' TO WS-8020-FIELD-NAME
              MOVE WS-7010-FCIC-CONTROL-TIME TO WS-8020-BAD-DATA
              MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
              PERFORM 8020-RECORD-INT-ERROR
                 THRU 8020-RECORD-INT-ERROR-EXIT
           END-IF

           IF WS-7010-FCIC-CONTROL-TIME = ZEROS
              MOVE 7010 TO WS-8020-PARAGRAPH-NO
              MOVE 90003 TO WS-8020-INT-ERROR-NO
              MOVE 'WS-7010-FCIC-CONTROL-TIME' TO WS-8020-FIELD-NAME
              MOVE WS-7010-FCIC-CONTROL-TIME TO WS-8020-BAD-DATA
              MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
              PERFORM 8020-RECORD-INT-ERROR
                 THRU 8020-RECORD-INT-ERROR-EXIT
           END-IF

           IF WS-7010-FCIC-CONTROL-DATE IS NOT NUMERIC
              MOVE 7010 TO WS-8020-PARAGRAPH-NO
              MOVE 90001 TO WS-8020-INT-ERROR-NO
              MOVE 'WS-7010-FCIC-CONTROL-DATE' TO WS-8020-FIELD-NAME
              MOVE WS-7010-FCIC-CONTROL-DATE TO WS-8020-BAD-DATA
              MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
              PERFORM 8020-RECORD-INT-ERROR
                 THRU 8020-RECORD-INT-ERROR-EXIT
           END-IF

           IF WS-7010-FCIC-CONTROL-DATE IS EQUAL ZEROS
              MOVE 7010 TO WS-8020-PARAGRAPH-NO
              MOVE 90003 TO WS-8020-INT-ERROR-NO
              MOVE 'WS-7010-FCIC-CONTROL-DATE' TO WS-8020-FIELD-NAME
              MOVE WS-7010-FCIC-CONTROL-DATE TO WS-8020-BAD-DATA
              MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
              PERFORM 8020-RECORD-INT-ERROR
                 THRU 8020-RECORD-INT-ERROR-EXIT
           END-IF

           IF WS-7010-BATCH-NO IS NOT NUMERIC
              MOVE 7010 TO WS-8020-PARAGRAPH-NO
              MOVE 90001 TO WS-8020-INT-ERROR-NO
              MOVE 'WS-7010-BATCH-NO' TO WS-8020-FIELD-NAME
              MOVE WS-7010-BATCH-NO TO WS-8020-BAD-DATA
              MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
              PERFORM 8020-RECORD-INT-ERROR
                 THRU 8020-RECORD-INT-ERROR-EXIT
           END-IF

           IF WS-7010-BATCH-NO IS EQUAL ZEROS
              MOVE 7010 TO WS-8020-PARAGRAPH-NO
              MOVE 90003 TO WS-8020-INT-ERROR-NO
              MOVE 'WS-7010-BATCH-NO' TO WS-8020-FIELD-NAME
              MOVE WS-7010-BATCH-NO TO WS-8020-BAD-DATA
              MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
              PERFORM 8020-RECORD-INT-ERROR
                 THRU 8020-RECORD-INT-ERROR-EXIT
           END-IF

           IF WS-7010-WEEKS-LATE IS NOT NUMERIC
              MOVE 7010 TO WS-8020-PARAGRAPH-NO
              MOVE 90001 TO WS-8020-INT-ERROR-NO
              MOVE 'WS-7010-WEEKS-LATE' TO WS-8020-FIELD-NAME
              MOVE WS-7010-BATCH-NO TO WS-8020-BAD-DATA
              MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
              PERFORM 8020-RECORD-INT-ERROR
                 THRU 8020-RECORD-INT-ERROR-EXIT
           END-IF

      ****************************************************************
      *  Initialize local working storage                            *
      ****************************************************************
           INITIALIZE WS-7010-CROP-POLICY-TYPE

      ****************************************************************
      *  Look up Crop Policy Type for each crop/type combination     *
      *  so that these values can be placed in the table.            *
      ****************************************************************


      $IF ISAM-SW DEFINED

           IF ERROR-CROP-CD = WS-LITERAL-YES OR
              ERROR-RATE-STATE = WS-LITERAL-YES OR
              ERROR-CROP-TYPE = WS-LITERAL-YES
      **    ** SKIP THE CROP POLICY TYPE LOOKUP
      **    ** GIVE THE RECORD A DEFAULT VALUE-9997-FOR CROP POLICY TYPE
              MOVE '9997' TO WS-7010-CROP-POLICY-TYPE
           ELSE
              INITIALIZE WS-0211-PARAMETERS
              MOVE WS-7010-RATE-STATE TO WS-0211-STATE
              MOVE WS-7010-CROP-CD TO WS-0211-CROP-CD
              MOVE WS-7010-TYPE-CD TO WS-0211-CROP-TYPE

              PERFORM 0211-LOOKUP-CROP-POL-TYPE
                 THRU 0211-LOOKUP-CROP-POL-TYPE-EXIT

              IF WS-0211-CROP-POLICY-TYPE = SPACES
                 MOVE '9997' TO WS-7010-CROP-POLICY-TYPE
              ELSE
                 MOVE WS-0211-CROP-POLICY-TYPE
                   TO WS-7010-CROP-POLICY-TYPE
              END-IF
           END-IF
      $END

      ****************************************************************
      *  Display information.                                        *
      ****************************************************************
      $IF DEBUG-SW DEFINED
           DISPLAY 'REJECTION FLAG = ', WS-7010-TRAN-REJECTED-FLAG
           UPON CONSOLE
      $END

      ****************************************************************
      *  Do insertion logic.                                         *
      ****************************************************************
           SET WS-0011-T11-INDEX TO 1

           PERFORM 7010-ADD-RECORD
              THRU 7010-ADD-RECORD-EXIT

      ****************************************************************
      *  UPDATE REVENUE ASSURANCE FIELDS                             *
      ****************************************************************
           IF WS-7010-INSUR-PLAN-CD = WS-LITERAL-RA

              IF WS-7010-CROP-CD = WS-LITERAL-CORN
                 IF WS-7010-YIELD IS NUMERIC AND
                    WS-7010-PRICE-ELECTION IS NUMERIC
                    ADD WS-7010-REPORTED-ACRES
                     TO WS-0011-RA-CORN-ACRES
                    COMPUTE WS-0011-RA-CORN-YIELD-X-ACRES ROUNDED =
                       WS-0011-RA-CORN-YIELD-X-ACRES +
                       (WS-7010-REPORTED-ACRES * WS-7010-YIELD)
                    END-COMPUTE
                    IF WS-0011-RA-CORN-PRICE-ELECTION = ZERO
                       MOVE WS-7010-PRICE-ELECTION
                         TO WS-0011-RA-CORN-PRICE-ELECTION
                    END-IF
                 END-IF

                 IF WS-0011-RA-CORN-UNIT-ORG = SPACES
                    IF WS-7010-UNIT-OPT-CD = WS-LITERAL-OPT-UNIT
                       MOVE WS-LITERAL-BASIC-UNIT
                         TO WS-0011-RA-CORN-UNIT-ORG
                    ELSE
                       MOVE WS-7010-UNIT-OPT-CD
                         TO WS-0011-RA-CORN-UNIT-ORG
                    END-IF
                 END-IF

      *          *** IF THIS IS A BASIC OR OPTIONAL UNIT
      *          *** STORE THE MAXIMUM CALCULATED REV CVG %
                 IF WS-7010-UNIT-OPT-CD = WS-LITERAL-BASIC-UNIT
                    IF WS-7010-CALC-REV-CVG-PCT >
                       WS-0011-RA-CORN-CVG-LVL-PCT
                       MOVE WS-7010-CALC-REV-CVG-PCT
                         TO WS-0011-RA-CORN-CVG-LVL-PCT
                    END-IF
                 END-IF

      *          *** SEE IF THIS IS A CORN ENTERPRISE UNIT
                 IF WS-7010-UNIT-OPT-CD = WS-LITERAL-ENTERPRISE-UNIT
      *             *** IF IT IS THE FIRST ONE STORE THE RA CVG LVL
                    IF WS-0011-RA-CORN-CVG-LVL-PCT = ZERO
                       MOVE WS-7010-REVENUE-CVG-LVL-PCT
                         TO WS-0011-RA-CORN-CVG-LVL-PCT
                    END-IF
                 END-IF
              END-IF

              IF WS-7010-CROP-CD = WS-LITERAL-SOYBEANS
                 IF WS-7010-YIELD IS NUMERIC AND
                    WS-7010-PRICE-ELECTION IS NUMERIC
                    ADD WS-7010-REPORTED-ACRES
                     TO WS-0011-RA-SOY-ACRES
                    COMPUTE WS-0011-RA-SOY-YIELD-X-ACRES ROUNDED =
                       WS-0011-RA-SOY-YIELD-X-ACRES +
                       (WS-7010-REPORTED-ACRES * WS-7010-YIELD)
                    END-COMPUTE
                    IF WS-0011-RA-SOY-PRICE-ELECTION = ZERO
                       MOVE WS-7010-PRICE-ELECTION
                         TO WS-0011-RA-SOY-PRICE-ELECTION
                    END-IF
                 END-IF

                 IF WS-0011-RA-SOY-UNIT-ORG = SPACES
                    IF WS-7010-UNIT-OPT-CD = WS-LITERAL-OPT-UNIT
                       MOVE WS-LITERAL-BASIC-UNIT
                         TO WS-0011-RA-SOY-UNIT-ORG
                    ELSE
                       MOVE WS-7010-UNIT-OPT-CD
                         TO WS-0011-RA-SOY-UNIT-ORG
                    END-IF
                 END-IF

      *          *** IF THIS IS A BASIC OR OPTIONAL UNIT
      *          *** STORE THE MAXIMUM CALCULATED REV CVG %
                 IF WS-7010-UNIT-OPT-CD = WS-LITERAL-BASIC-UNIT
                    IF WS-7010-CALC-REV-CVG-PCT >
                       WS-0011-RA-SOY-CVG-LVL-PCT
                       MOVE WS-7010-CALC-REV-CVG-PCT
                         TO WS-0011-RA-SOY-CVG-LVL-PCT
                    END-IF
                 END-IF

      *          *** SEE IF THIS IS A SOYBEAN ENTERPRISE UNIT
                 IF WS-7010-UNIT-OPT-CD = WS-LITERAL-ENTERPRISE-UNIT
      *             *** IF IT IS THE FIRST ONE STORE THE RA CVG LVL
                    IF WS-0011-RA-SOY-CVG-LVL-PCT = ZERO
                       MOVE WS-7010-REVENUE-CVG-LVL-PCT
                         TO WS-0011-RA-SOY-CVG-LVL-PCT
                    END-IF
                 END-IF
              END-IF

              IF WS-7010-UNIT-OPT-CD = WS-LITERAL-WHOLE-FARM-UNIT
      *          *** IF IT IS THE FIRST ONE STORE THE RA CVG LVL
                 IF WS-0011-RA-WFARM-CVG-LVL-PCT = ZERO
                    MOVE WS-7010-REVENUE-CVG-LVL-PCT
                      TO WS-0011-RA-WFARM-CVG-LVL-PCT
                 END-IF
              END-IF
           END-IF


      ****************************************************************
      *  INSERTION LOGIC FOR THE TOTAL LIABILITY BY CROP-UNIT TABLE  *
      *  THIS TABLE IS LATER USED BY INTER RECORD EDITS FOR TYPE 21  *
      *  AND TYPE 21N RECORDS.                                       *
      ****************************************************************

           PERFORM 7010-UPDATE-UNIT-TBL
              THRU 7010-UPDATE-UNIT-TBL-EXIT

      ****************************************************************
      *  Initialize Input Fields                                     *
      ****************************************************************
           INITIALIZE WS-7010-INPUT
           INITIALIZE WS-7010-TYPE-11.


       7010-ADD-T11-RECORD-EXIT.
           EXIT.


      ****************************************************************
      *  THIS PARAGRAPH TEST THE TABLE SIZE LIMIT BEFORE ADDING AN   *
      *  ADDITIONAL RECORD. WHEN THE MAXIMUM TABLE SIZE IS REACHED,  *
      *  MESSAGES ARE DISPLAYED AND EXECUTION IS TERMINATED -        *
      *  OTHERWISE THE NEW TRANSACTION RECORD IS ADDED TO THE TABLE. *
      ****************************************************************

       7010-ADD-RECORD.

           IF WS-0011-T11-REC-COUNT >= WS-0011-MAX-SIZE
              DISPLAY 'REC TYPE 11 T11 TABLE LIMIT WILL BE EXCEEDED'
              UPON CONSOLE
              DISPLAY ' WITH THE ADDITION OF THIS RECORD'
              UPON CONSOLE
              DISPLAY '**********************************'
              UPON CONSOLE
              DISPLAY 'MAXIMUM TABLE SIZE IS ' WS-0011-MAX-SIZE
              ' RECORDS' UPON CONSOLE
              PERFORM 0800-ABORT-PROGRAM
                 THRU 0800-ABORT-PROGRAM-EXIT
           ELSE
              ADD 1 TO WS-0011-T11-REC-COUNT
              SET WS-0011-T11-INDEX TO WS-0011-T11-REC-COUNT
              MOVE WS-7010-CROP-POLICY-TYPE
                TO WS-0011-TBL-CROP-POLICY-TY(WS-0011-T11-INDEX)
              MOVE WS-7010-GUARANTEE-PER-ACRE
                TO WS-0011-TBL-GUAR-PER-ACRE(WS-0011-T11-INDEX)
              MOVE WS-7010-TOTAL-GUARANTEE
                TO WS-0011-TBL-TOTAL-GUARANTEE(WS-0011-T11-INDEX)
              MOVE WS-7010-LOW-YIELD
                TO WS-0011-TBL-LOW-YIELD(WS-0011-T11-INDEX)
              MOVE WS-7010-HIGH-YIELD
                TO WS-0011-TBL-HIGH-YIELD(WS-0011-T11-INDEX)
              MOVE WS-7010-TYPE-11
                TO WS-0011-TBL-TYPE-11(WS-0011-T11-INDEX)
              ADD 1 TO WS-0005-TYPE-11-COUNT

      *       *** UPDATE TABLE STATISTICS
              IF WS-0011-T11-REC-COUNT > WS-0008-T11-MAX-TABLE-SIZE
                 MOVE WS-0011-T11-REC-COUNT
                   TO WS-0008-T11-MAX-TABLE-SIZE
              END-IF
           END-IF.


       7010-ADD-RECORD-EXIT.
           EXIT.


       7010-UPDATE-UNIT-TBL.

      *****************************************************
      *              CHECK INPUT FIELDS                   *
      *****************************************************
           IF WS-7010-CROP-CD IS NOT NUMERIC
              MOVE 7010 TO WS-8020-PARAGRAPH-NO
              MOVE 90003 TO WS-8020-INT-ERROR-NO
              MOVE 'WS-7010-CROP-CD' TO WS-8020-FIELD-NAME
              MOVE WS-7010-CROP-CD TO WS-8020-BAD-DATA
              MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
              PERFORM 8020-RECORD-INT-ERROR
                 THRU 8020-RECORD-INT-ERROR-EXIT
              GO TO 7010-UPDATE-UNIT-TBL-EXIT
           END-IF

           IF WS-7010-LOCATION-COUNTY IS NOT NUMERIC
              MOVE 7010 TO WS-8020-PARAGRAPH-NO
              MOVE 90001 TO WS-8020-INT-ERROR-NO
              MOVE 'WS-7010-LOCATION-COUNTY' TO WS-8020-FIELD-NAME
              MOVE WS-7010-LOCATION-COUNTY TO WS-8020-BAD-DATA
              MOVE WS-LITERAL-NO TO WS-8020-ABORT-PROGRAM
              PERFORM 8020-RECORD-INT-ERROR
                 THRU 8020-RECORD-INT-ERROR-EXIT
              GO TO 7010-UPDATE-UNIT-TBL-EXIT
           END-IF

           IF WS-7010-OPTIONAL-UNIT IS NOT NUMERIC
              MOVE 7010 TO WS-8020-PARAGRAPH-NO
              MOVE 90003 TO WS-8020-INT-ERROR-NO
              MOVE 'WS-7010-OPTIONAL-UNIT' TO WS-8020-FIELD-NAME
              MOVE WS-7010-OPTIONAL-UNIT TO WS-8020-BAD-DATA
              MOVE WS-LITERAL-NO TO WS-8020-ABORT-PROGRAM
              PERFORM 8020-RECORD-INT-ERROR
                 THRU 8020-RECORD-INT-ERROR-EXIT
              GO TO 7010-UPDATE-UNIT-TBL-EXIT
           END-IF

           IF WS-7010-INSUR-PLAN-CD IS NOT NUMERIC
              MOVE 7010 TO WS-8020-PARAGRAPH-NO
              MOVE 90003 TO WS-8020-INT-ERROR-NO
              MOVE 'WS-7010-INSUR-PLAN-CD' TO WS-8020-FIELD-NAME
              MOVE WS-7010-INSUR-PLAN-CD TO WS-8020-BAD-DATA
              MOVE WS-LITERAL-NO TO WS-8020-ABORT-PROGRAM
              PERFORM 8020-RECORD-INT-ERROR
                 THRU 8020-RECORD-INT-ERROR-EXIT
              GO TO 7010-UPDATE-UNIT-TBL-EXIT
           END-IF

           IF WS-7010-LIABILITY IS NOT NUMERIC
              MOVE 7010 TO WS-8020-PARAGRAPH-NO
              MOVE 90003 TO WS-8020-INT-ERROR-NO
              MOVE 'WS-7010-LIABILITY' TO WS-8020-FIELD-NAME
              MOVE WS-7010-LIABILITY TO WS-8020-BAD-DATA
              MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
              PERFORM 8020-RECORD-INT-ERROR
                 THRU 8020-RECORD-INT-ERROR-EXIT
              GO TO 7010-UPDATE-UNIT-TBL-EXIT
           END-IF

           IF WS-7010-REPORTED-ACRES IS NOT NUMERIC
              MOVE 7010 TO WS-8020-PARAGRAPH-NO
              MOVE 90003 TO WS-8020-INT-ERROR-NO
              MOVE 'WS-7010-REPORTED-ACRES' TO WS-8020-FIELD-NAME
              MOVE SPACES TO WS-8020-BAD-DATA
              MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
              PERFORM 8020-RECORD-INT-ERROR
                 THRU 8020-RECORD-INT-ERROR-EXIT
              GO TO 7010-UPDATE-UNIT-TBL-EXIT
           END-IF

           IF WS-7010-GUARANTEE-PER-ACRE IS NOT NUMERIC
              MOVE 7010 TO WS-8020-PARAGRAPH-NO
              MOVE 90003 TO WS-8020-INT-ERROR-NO
              MOVE 'WS-7010-GPA' TO WS-8020-FIELD-NAME
              MOVE SPACES TO WS-8020-BAD-DATA
              MOVE WS-LITERAL-NO TO WS-8020-ABORT-PROGRAM
              PERFORM 8020-RECORD-INT-ERROR
                 THRU 8020-RECORD-INT-ERROR-EXIT
              GO TO 7010-UPDATE-UNIT-TBL-EXIT
           END-IF

           IF WS-7010-TOTAL-GUARANTEE IS NOT NUMERIC
              MOVE 7010 TO WS-8020-PARAGRAPH-NO
              MOVE 90003 TO WS-8020-INT-ERROR-NO
              MOVE 'WS-7010-TOTAL-GUARANTEE' TO WS-8020-FIELD-NAME
              MOVE SPACES TO WS-8020-BAD-DATA
              MOVE WS-LITERAL-NO TO WS-8020-ABORT-PROGRAM
              PERFORM 8020-RECORD-INT-ERROR
                 THRU 8020-RECORD-INT-ERROR-EXIT
              GO TO 7010-UPDATE-UNIT-TBL-EXIT
           END-IF


      ****************************************************************
      *  DO INSERTION LOGIC.                                         *
      ****************************************************************

           IF WS-0011-UNIT-REC-COUNT = ZEROS
              SET WS-0011-UNIT-INDEX TO 1
              PERFORM 7010-ADD-UNIT-RECORD
                 THRU 7010-ADD-UNIT-RECORD-EXIT
           ELSE
              PERFORM 7010-SEARCH-UNIT-TBL
                 THRU 7010-SEARCH-UNIT-TBL-EXIT
           END-IF.


       7010-UPDATE-UNIT-TBL-EXIT.
           EXIT.

      ****************************************************************
      *  THIS PARAGRAPH TESTS THE TABLE SIZE LIMIT BEFORE ADDING AN  *
      *  ADDITIONAL RECORD. WHEN THE MAXIMUM TABLE SIZE IS REACHED,  *
      *  MESSAGES ARE DISPLAYED AND EXECUTION IS TERMINATED -        *
      *  OTHERWISE THE NEW LIABILITY RECORD IS ADDED TO THE TABLE.   *
      *                                                              *
      *  IF THE RECORD IS UNDER A GROUP INSURANCE PLAN, THIS PLAN CD *
      *  IS ADDED TO THE RECORD.  OTHERWISE EACH NEW RECORD IS GIVEN *
      *  A PLAN CD = 98 (NOT APPLICABLE).                            *
      ****************************************************************

       7010-ADD-UNIT-RECORD.

           IF WS-0011-UNIT-REC-COUNT >= WS-0011-UNIT-MAX-SIZE
              DISPLAY 'REC T11 UNIT UNIT TABLE LIMIT WILL BE EXCEEDED'
              UPON CONSOLE
              DISPLAY ' WITH THE ADDITION OF THIS RECORD'
              UPON CONSOLE
              DISPLAY '**********************************'
              UPON CONSOLE
              DISPLAY 'MAXIMUM TABLE SIZE IS ' WS-0011-UNIT-MAX-SIZE
              ' RECORDS' UPON CONSOLE
              PERFORM 0800-ABORT-PROGRAM
                 THRU 0800-ABORT-PROGRAM-EXIT
           ELSE
              ADD 1 TO WS-0011-UNIT-REC-COUNT
              SET WS-0011-UNIT-INDEX TO WS-0011-UNIT-REC-COUNT
              MOVE WS-7010-TYPE-CD
                TO WS-0011-UNIT-TBL-CROP-TYPE(WS-0011-UNIT-INDEX)
              MOVE WS-7010-LOCATION-COUNTY
                TO WS-0011-UNIT-TBL-LOC-COUNTY(WS-0011-UNIT-INDEX)
              MOVE WS-7010-BASIC-UNIT-NUM
                TO WS-0011-UNIT-TBL-BASIC-UNIT(WS-0011-UNIT-INDEX)
              MOVE WS-7010-OPTIONAL-UNIT
                TO WS-0011-UNIT-TBL-OPTIONAL-UNIT(WS-0011-UNIT-INDEX)
              IF WS-7010-INSUR-PLAN-CD = WS-LITERAL-GRP
                 MOVE WS-7010-INSUR-PLAN-CD
                   TO WS-0011-UNIT-TBL-INS-PLAN-CD(WS-0011-UNIT-INDEX)
              ELSE
                 MOVE 98
                   TO WS-0011-UNIT-TBL-INS-PLAN-CD(WS-0011-UNIT-INDEX)
              END-IF
              MOVE WS-7010-LIABILITY
                TO WS-0011-UNIT-TBL-TOT-LIABILITY(WS-0011-UNIT-INDEX)
              MOVE WS-7010-REPORTED-ACRES
                TO WS-0011-UNIT-TBL-TOT-RPT-ACRES(WS-0011-UNIT-INDEX)
              MOVE WS-7010-GUARANTEE-PER-ACRE
                TO WS-0011-UNIT-TBL-GUAR-PER-ACRE(WS-0011-UNIT-INDEX)
              MOVE WS-7010-TOTAL-GUARANTEE
                TO WS-0011-UNIT-TBL-TOT-GUARANTEE(WS-0011-UNIT-INDEX)

      *            UPDATE TABLE STATISTICS
              IF WS-0011-UNIT-REC-COUNT > WS-0008-T11-UNIT-MAX-TBL-SIZE
                 MOVE WS-0011-UNIT-REC-COUNT
                   TO WS-0008-T11-UNIT-MAX-TBL-SIZE
              END-IF
           END-IF.


       7010-ADD-UNIT-RECORD-EXIT.
           EXIT.


      ****************************************************************
      *  THIS PARAGRAPH DOES A SEARCH OF THE TYPE 11 LIABILITY TABLE.*
      *  WHEN A MATCH IS FOUND, THE TOTAL LIABILITY & TOTAL REPORTED *
      *  ACRES ARE INCREMENTED.                                      *
      *                                                              *
      *  IF THE INCOMING GUARANTEE PER ACRE FOR THE UNIT             *
      *  IS GREATER THAN THE ONE STORED IN TABLE, REPLACE THE TABLE  *
      *  VALUE.                                                      *
      *                                                              *
      *  IF THE INCOMING TOTAL GUARANTEE FOR THE UNIT IS GREATER THAN*
      *  THE ONE STORED IN THE TABLE, REPLACE THE TABLE VALUE.       *

      ****************************************************************

       7010-SEARCH-UNIT-TBL.

           SET WS-0011-UNIT-INDEX TO 1.

           SEARCH WS-0011-UNIT-RECORD VARYING WS-0011-UNIT-INDEX
                AT END
                    PERFORM 7010-ADD-UNIT-RECORD
                       THRU 7010-ADD-UNIT-RECORD-EXIT
                    GO TO 7010-SEARCH-UNIT-TBL-EXIT
                WHEN (WS-0011-UNIT-TBL-CROP-TYPE(WS-0011-UNIT-INDEX)
                     IS EQUAL WS-7010-TYPE-CD)
                 AND (WS-0011-UNIT-TBL-LOC-COUNTY(WS-0011-UNIT-INDEX)
                     IS EQUAL WS-7010-LOCATION-COUNTY)
                 AND (WS-0011-UNIT-TBL-BASIC-UNIT(WS-0011-UNIT-INDEX)
                     IS EQUAL WS-7010-BASIC-UNIT-NUM)
                 AND (WS-0011-UNIT-TBL-OPTIONAL-UNIT
                     (WS-0011-UNIT-INDEX)
                     IS EQUAL WS-7010-OPTIONAL-UNIT)
      $IF DEBUG-SW DEFINED
           DISPLAY 'UPDATING TYPE 11 LIABILITY RECORD' UPON CONSOLE
      $END
                 ADD WS-7010-LIABILITY
                   TO WS-0011-UNIT-TBL-TOT-LIABILITY
                      (WS-0011-UNIT-INDEX)

                 ADD WS-7010-REPORTED-ACRES
                   TO WS-0011-UNIT-TBL-TOT-RPT-ACRES
                      (WS-0011-UNIT-INDEX)

                 IF WS-7010-GUARANTEE-PER-ACRE >
                    WS-0011-UNIT-TBL-GUAR-PER-ACRE(WS-0011-UNIT-INDEX)
                    MOVE WS-7010-GUARANTEE-PER-ACRE
                      TO WS-0011-UNIT-TBL-GUAR-PER-ACRE
                         (WS-0011-UNIT-INDEX)
                 END-IF

                 IF WS-7010-TOTAL-GUARANTEE >
                    WS-0011-UNIT-TBL-TOT-GUARANTEE(WS-0011-UNIT-INDEX)
                    MOVE WS-7010-TOTAL-GUARANTEE
                      TO WS-0011-UNIT-TBL-TOT-GUARANTEE
                         (WS-0011-UNIT-INDEX)
                 END-IF

           END-SEARCH.

       7010-SEARCH-UNIT-TBL-EXIT.
           EXIT.

      $IF DEBUG-SW DEFINED

       7010-DISPLAY-RECORD.

           DISPLAY '7010-TYPE 11 RECORD BEING ADDED TO THE T11 TABLE'
           UPON CONSOLE
           DISPLAY 'RECORD TYPE        : ',
           WS-7010-RECORD-TYPE UPON CONSOLE
           DISPLAY 'REPORTING ORG      : ',
           WS-7010-REPORTING-ORG UPON CONSOLE
           DISPLAY 'LOCATION STATE     : ',
           WS-7010-LOC-STATE UPON CONSOLE
           DISPLAY 'COMPANY            : ',
           WS-7010-COMPANY-COUNTY UPON CONSOLE
           DISPLAY 'POLICY NUMBER      : ',
           WS-7010-POLICY-NUM UPON CONSOLE
           DISPLAY 'CROP YEAR          : ',
           WS-7010-CROP-YEAR UPON CONSOLE
           DISPLAY '--------------------------------'
           UPON CONSOLE
           DISPLAY 'CROP CODE          : ',
           WS-7010-CROP-CD UPON CONSOLE
           DISPLAY 'INSURANCE PLAN CD  : ',
           WS-7010-INSUR-PLAN-CD UPON CONSOLE
           DISPLAY 'LOCATION COUNTY    : ',
           WS-7010-LOCATION-COUNTY UPON CONSOLE
           DISPLAY 'UNIT NUMBER        : ',
           WS-7010-UNIT-NUM UPON CONSOLE
           DISPLAY 'TYPE CODE          : ',
           WS-7010-TYPE-CD UPON CONSOLE
           DISPLAY 'PRACTICE CODE      : ',
           WS-7010-PRACTICE-CD UPON CONSOLE
           DISPLAY 'COVERAGE FLAG      : ',
           WS-7010-COVERAGE-FLG UPON CONSOLE
           DISPLAY '--------------------------------'
           UPON CONSOLE
           DISPLAY 'KEY RESERVE          : ',
           WS-7010-KEY-RESERVE UPON CONSOLE
           DISPLAY 'FILLER 01 (02)       : ',
           WS-7010-FILLER-1 UPON CONSOLE
           DISPLAY 'RECORD NUMBER        : ',
           WS-7010-RECORD-NUM UPON CONSOLE
           DISPLAY 'TYPE 15 RECORD NUM   : ',
           WS-7010-TYPE15-REC-NO UPON CONSOLE
           DISPLAY 'AGENT ID CODE        : ',
           WS-7010-AGENT-ID-CODE UPON CONSOLE
           DISPLAY 'RATE CLASSIFICATION  : ',
           WS-7010-RATE-CLASS UPON CONSOLE
           DISPLAY 'MAP AREA             : ',
           WS-7010-MAP-AREA UPON CONSOLE
           DISPLAY 'CRUSH DISTRICT       : ',
           WS-7010-CRUSH-DISTRICT UPON CONSOLE
           DISPLAY 'REFERENCE CROP YEAR  : ',
           WS-7010-REFERENCE-CROP-YR UPON CONSOLE
           DISPLAY 'NCS/FCIC-2 FLAG      : ',
           WS-7010-NCS-FCIC-2-FL UPON CONSOLE
           DISPLAY 'DATE PLANTED         : ',
           WS-7010-DATE-PLANTED UPON CONSOLE
           DISPLAY 'GUAR REDUCTION FLAG  : ',
           WS-7010-GUARANTEE-REDUCT-FLG UPON CONSOLE
           DISPLAY 'YIELD                : ',
           WS-7010-YIELD UPON CONSOLE
           DISPLAY 'DOLLAR AMT OF INS    : ',
           WS-7010-DOLLAR-AMT-INSUR UPON CONSOLE
           DISPLAY 'QUOTA                : ',
           WS-7010-QUOTA UPON CONSOLE
           DISPLAY 'COVERAGE LEVEL %     : ',
           WS-7010-COVERAGE-LEVEL-PCT UPON CONSOLE
           DISPLAY 'GUARANTEE PER ACRE   : ',
           WS-7010-GUARANTEE-PER-ACRE UPON CONSOLE
           DISPLAY 'GUARANTEE REDUCTION% : ',
           WS-7010-GUARANTEE-RED-PCT UPON CONSOLE
           DISPLAY 'REPORTED ACRES       : ',
           WS-7010-REPORTED-ACRES UPON CONSOLE
           DISPLAY 'TOTAL GUARANTEE      : ',
           WS-7010-TOTAL-GUARANTEE UPON CONSOLE
           DISPLAY 'PRICE ELECTION       : ',
           WS-7010-PRICE-ELECTION UPON CONSOLE
           DISPLAY 'INSURED SHARE        : ',
           WS-7010-INSURED-SHARE UPON CONSOLE
           DISPLAY 'LIABILITY            : ',
           WS-7010-LIABILITY UPON CONSOLE
           DISPLAY 'PERCENT ELECTION     : ',
           WS-7010-PERCENT-ELECTION UPON CONSOLE
           DISPLAY 'BASE PREMIUM RATE    : ',
           WS-7010-BASE-PREM-RATE UPON CONSOLE
           DISPLAY 'UNIT OPTION CODE     : ',
           WS-7010-UNIT-OPT-CD UPON CONSOLE
           DISPLAY 'ADDITIONAL OPT CODE  : ',
           WS-7010-ADD-OPT-CD UPON CONSOLE
           DISPLAY 'TYPE/PRACTICE OPT CD : ',
           WS-7010-TYPE-PRAC-OPT-CD UPON CONSOLE
           DISPLAY 'EXPERIENCE FACTOR    : ',
           WS-7010-EXPERIENCE-FACTOR UPON CONSOLE
           DISPLAY 'PREMIUM RATE SURCHG  : ',
           WS-7010-PREM-RATE-SURCHARGE UPON CONSOLE
           DISPLAY 'TOTAL PREMIUM        : ',
           WS-7010-TOTAL-PREMIUM UPON CONSOLE
           DISPLAY 'PRODUCER PREMIUM     : ',
           WS-7010-PRODUCER-PREMIUM UPON CONSOLE
           DISPLAY 'PRIVATE POLICY CODE  : ',
           WS-7010-PRIVATE-POLICY-CD UPON CONSOLE
           DISPLAY 'INTENDED ACREAGE FLG : ',
           WS-7010-INTENDED-ACREAGE-FLAG UPON CONSOLE
           DISPLAY 'SEED COMPANY CODE    : ',
           WS-7010-SEED-COMPANY-CD UPON CONSOLE
           DISPLAY 'RATE STATE           : ',
           WS-7010-RATE-STATE UPON CONSOLE
           DISPLAY 'RATE COUNTY          : ',
           WS-7010-RATE-COUNTY UPON CONSOLE
           DISPLAY 'FARM SERIAL NUMBER   : ',
           WS-7010-FARM-SERIAL-NUM UPON CONSOLE
           DISPLAY 'REVENUE CVG LVL %    : ',
           WS-7010-REVENUE-CVG-LVL-PCT UPON CONSOLE
           DISPLAY 'NUMBER OF SECTIONS   : ',
           WS-7010-NBR-OF-SECTIONS UPON CONSOLE
           DISPLAY 'UNIT PREMIUM ADJ FCTR: ',
           WS-7010-UNIT-PREM-ADJ-FCTR UPON CONSOLE
           DISPLAY 'PARTIAL PREV PLANTING: ',
           WS-7010-PARTIAL-PP-FLAG UPON CONSOLE
           DISPLAY 'IP COUNTY AVERAGE YLD: ',
           WS-7010-IP-COUNTY-AVERAGE-YLD UPON CONSOLE
           DISPLAY 'WHOLE FARM DISC FCTR : ',
           WS-7010-WFARM-DISCOUNT-FCTR UPON CONSOLE
           DISPLAY '--------------------------------'
           UPON CONSOLE
           DISPLAY 'FILLER 02 (28)       : ',
           WS-7010-FILLER-2 UPON CONSOLE
           DISPLAY 'SEED CYCLE CODE      : ',
           WS-7010-SEED-CYCLE-CD UPON CONSOLE
           DISPLAY 'CRC APH PREMIUM      : ',
           WS-7010-CRC-APH-PREMIUM UPON CONSOLE
           DISPLAY 'CAT 65/100 PREMIUM   : ',
           WS-7010-CAT-65-100-PREMIUM UPON CONSOLE
           DISPLAY '1996 CROP CODE       : ',
           WS-7010-1996-CROP-CODE UPON CONSOLE
           DISPLAY '1996 TYPE CODE       : ',
           WS-7010-1996-TYPE-CODE UPON CONSOLE
           DISPLAY 'RM DATA RECEIPT DATE : ',
           WS-7010-RM-DATA-RECEIPT-DATE UPON CONSOLE
           DISPLAY 'FILLER 03 (02)       : ',
           WS-7010-FILLER-3 UPON CONSOLE
           DISPLAY 'WEEKS LATE           : ',
           WS-7010-WEEKS-LATE UPON CONSOLE
           DISPLAY 'FIRST SUBMISSION FLG : ',
           WS-7010-FIRST-SUBMISSION-FLG UPON CONSOLE
           DISPLAY 'FILLER 04 (02)       : ',
           WS-7010-FILLER-4 UPON CONSOLE
           DISPLAY 'FSA CONTROL DATE     : ',
           WS-7010-FSA-CONTROL-DATE UPON CONSOLE
           DISPLAY '--------------------------------'
           UPON CONSOLE
           DISPLAY 'FCIC CONTROL TIME    : ',
           WS-7010-FCIC-CONTROL-TIME UPON CONSOLE
           DISPLAY 'FCIC CONTROL DATE    : ',
           WS-7010-FCIC-CONTROL-DATE UPON CONSOLE
           DISPLAY 'REINSURANCE YEAR     : ',
           WS-7010-REINS-YR UPON CONSOLE
           DISPLAY 'BATCH NUMBER         : ',
           WS-7010-BATCH-NO UPON CONSOLE
           DISPLAY 'TRANS SEQUENCE NUM   : ',
           WS-7010-TRAN-SEQ-NO UPON CONSOLE
           DISPLAY 'TRANS REJECTED FLAG  : ',
           WS-7010-TRAN-REJECTED-FLAG UPON CONSOLE
           DISPLAY 'TRANS SOURCE FLAG    : ',
           WS-7010-TRAN-SOURCE-FLAG UPON CONSOLE
           DISPLAY 'MDAS PROCESS NUMBER  : ',
           WS-7010-MDAS-PROCESS-NO UPON CONSOLE
           DISPLAY 'FILLER 5 (14)        : ',
           WS-7010-FILLER-5 UPON CONSOLE.


       7010-DISPLAY-RECORD-EXIT.
           EXIT.

      $END

