      ***************************************************************
      * File:      M7012.CBL                                        *
      * Author:    Mike Ray and Cheryl D. Wood                      *
      * Date:      8/25/95                                          *
      * Purpose:                                                    *
      *    Adds a single T12 record to the T12 table.               *
      *    if the record exists, the new record replaces it and the *
      *    indicator is set to indicate where the record came from. *
      ***************************************************************

       7012-ADD-T12-RECORD.

      $IF DEBUG-SW DEFINED
           DISPLAY '7012-ADDING T12 RECORD'
           UPON CONSOLE
      $END

      ****************************************************************
      *   DISPLAY RECORD BEING ADDED                                 *
      ****************************************************************
      $IF DEBUG-SW DEFINED
           PERFORM 7012-DISPLAY-RECORD
              THRU 7012-DISPLAY-RECORD-EXIT
      $END

      ****************************************************************
      *  Check to make sure that the transaction sequence number     *
      *  is passed and that the other control flags are set.         *
      ****************************************************************

           IF WS-7012-TRAN-SEQ-NO IS NOT NUMERIC
              MOVE 7012 TO WS-8020-PARAGRAPH-NO
              MOVE 90001 TO WS-8020-INT-ERROR-NO
              MOVE 'WS-7012-TRAN-SEQ-NO' TO WS-8020-FIELD-NAME
              MOVE WS-7012-TRAN-SEQ-NO TO WS-8020-BAD-DATA
              MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
              PERFORM 8020-RECORD-INT-ERROR
                 THRU 8020-RECORD-INT-ERROR-EXIT
           END-IF

           IF WS-7012-TRAN-SEQ-NO = ZEROS
              MOVE 7012 TO WS-8020-PARAGRAPH-NO
              MOVE 90003 TO WS-8020-INT-ERROR-NO
              MOVE 'WS-7012-TRAN-SEQ-NO' TO WS-8020-FIELD-NAME
              MOVE WS-7012-TRAN-SEQ-NO TO WS-8020-BAD-DATA
              MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
              PERFORM 8020-RECORD-INT-ERROR
                 THRU 8020-RECORD-INT-ERROR-EXIT
           END-IF

           IF WS-7012-TRAN-SOURCE-FLAG = SPACES
              MOVE 7012 TO WS-8020-PARAGRAPH-NO
              MOVE 90003 TO WS-8020-INT-ERROR-NO
              MOVE 'WS-7012-TRAN-SOURCE-FLAG' TO WS-8020-FIELD-NAME
              MOVE WS-7012-TRAN-SOURCE-FLAG TO WS-8020-BAD-DATA
              MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
              PERFORM 8020-RECORD-INT-ERROR
                 THRU 8020-RECORD-INT-ERROR-EXIT
           END-IF

      ****************************************************************
      *  Do insertion logic                                          *
      ****************************************************************

           IF WS-0012-T12-REC-COUNT = ZEROS
              SET WS-0012-T12-INDEX TO 1
              PERFORM 7012-ADD-RECORD
                 THRU 7012-ADD-RECORD-EXIT
           ELSE
      *
      *       TYPE 12 RECORDS ARE NOT UNIQUE, SO REPLACE ONLY IF
      *       THE INPUT RECORD IS COMING FROM THE DATABASE.
      *
              IF WS-7012-TRAN-SOURCE-FLAG = WS-LITERAL-DATABASE
                 PERFORM 7012-SEARCH-T12-TBL
                    THRU 7012-SEARCH-T12-TBL-EXIT
              ELSE
                 PERFORM 7012-ADD-RECORD
                    THRU 7012-ADD-RECORD-EXIT
              END-IF
           END-IF


      ****************************************************************
      *  Initialize Input Fields                                     *
      ****************************************************************

           INITIALIZE WS-7012-TRAN-REJECTED-FLAG
           INITIALIZE WS-7012-TRAN-SOURCE-FLAG
           INITIALIZE WS-7012-TYPE-12.



       7012-ADD-T12-RECORD-EXIT.
           EXIT.

      ****************************************************************
      *  THIS PARAGRAPH DOES A SEARCH OF THE RECORD TYPE 12          *
      *  RECORDS TABLE. WHEN A MATCH IS FOUND, THE TABLE IS UPDATED  *
      *  WITH THE NEW TRANSACTION RECORD CONTENTS.                   *
      ****************************************************************

       7012-SEARCH-T12-TBL.

           SET WS-0012-T12-INDEX TO 1

           SEARCH WS-0012-T12-RECORD VARYING WS-0012-T12-INDEX
                AT END
                    PERFORM 7012-ADD-RECORD
                       THRU 7012-ADD-RECORD-EXIT
                    GO TO 7012-SEARCH-T12-TBL-EXIT
                WHEN (WS-0012-TBL-POLICY-NO (WS-0012-T12-INDEX)
                     IS EQUAL WS-7012-POLICY-NO)
                 AND (WS-0012-TBL-RECORD-NUM (WS-0012-T12-INDEX)
                     IS EQUAL WS-7012-RECORD-NUM)

      $IF DEBUG-SW DEFINED
           DISPLAY 'REPLACING TYPE 12 RECORD' UPON CONSOLE
      $END
                     MOVE WS-7012-TRAN-REJECTED-FLAG
                       TO WS-0012-TBL-TRAN-REJECTED-FLAG
                          (WS-0012-T12-INDEX)
                     MOVE WS-7012-TRAN-SOURCE-FLAG
                       TO WS-0012-TBL-TRAN-SOURCE-FL
                          (WS-0012-T12-INDEX)
                     MOVE WS-7012-TYPE-12
                       TO WS-0012-TBL-TYPE-12 (WS-0012-T12-INDEX)
           END-SEARCH.

       7012-SEARCH-T12-TBL-EXIT.
           EXIT.

      ****************************************************************
      *  THIS PARAGRAPH TEST THE TABLE SIZE LIMIT BEFORE ADDING AN   *
      *  ADDITIONAL RECORD. WHEN THE MAXIMUM TABLE SIZE IS REACHED,  *
      *  MESSAGES ARE DISPLAYED AND EXECUTION IS TERMINATED -        *
      *  OTHERWISE THE NEW TRANSACTION RECORD IS ADDED TO THE TABLE. *
      ****************************************************************

       7012-ADD-RECORD.

           IF WS-0012-T12-REC-COUNT >= WS-0012-MAX-SIZE
              DISPLAY 'REC TYPE 12 T12 TABLE LIMIT WILL BE EXCEEDED'
              UPON CONSOLE
              DISPLAY ' WITH THE ADDITION OF THIS RECORD'
              UPON CONSOLE
              DISPLAY '**********************************'
              UPON CONSOLE
              DISPLAY 'MAXIMUM TABLE SIZE IS ' WS-0012-MAX-SIZE
                      ' RECORDS' UPON CONSOLE
              PERFORM 0800-ABORT-PROGRAM
                 THRU 0800-ABORT-PROGRAM-EXIT
           ELSE
              ADD 1 TO WS-0012-T12-REC-COUNT
              SET WS-0012-T12-INDEX TO WS-0012-T12-REC-COUNT
              MOVE WS-7012-TRAN-REJECTED-FLAG
                TO WS-0012-TBL-TRAN-REJECTED-FLAG(WS-0012-T12-INDEX)
              MOVE WS-7012-TRAN-SOURCE-FLAG
                TO WS-0012-TBL-TRAN-SOURCE-FL(WS-0012-T12-INDEX)
              MOVE WS-7012-TYPE-12
                TO WS-0012-TBL-TYPE-12 (WS-0012-T12-INDEX)

      *            UPDATE TABLE STATISTICS
              IF WS-0012-T12-REC-COUNT > WS-0008-T12-MAX-TABLE-SIZE
                 MOVE WS-0012-T12-REC-COUNT
                   TO WS-0008-T12-MAX-TABLE-SIZE
              END-IF
           END-IF.

       7012-ADD-RECORD-EXIT.
           EXIT.


      $IF DEBUG-SW DEFINED

       7012-DISPLAY-RECORD.

           DISPLAY '7012-TYPE 12 RECORD BEING ADDED TO THE T12 TABLE'
           UPON CONSOLE
           DISPLAY 'RECORD TYPE        : ',
           WS-7012-RECORD-TYPE UPON CONSOLE
           DISPLAY 'REPORTING ORG      : ',
           WS-7012-REPORTING-ORG UPON CONSOLE
           DISPLAY 'LOCATION STATE     : ',
           WS-7012-LOC-STATE UPON CONSOLE
           DISPLAY 'COMPANY            : ',
           WS-7012-COMPANY-COUNTY UPON CONSOLE
           DISPLAY 'POLICY NUMBER      : ',
           WS-7012-POLICY-NUM UPON CONSOLE
           DISPLAY 'CROP YEAR          : ',
           WS-7012-CROP-YEAR UPON CONSOLE
           DISPLAY 'KEY RESERVE        : ',
           WS-7012-KEY-RESERVE UPON CONSOLE
           DISPLAY '--------------------------------'
           UPON CONSOLE
           DISPLAY 'RECORD NUMBER      : ',
           WS-7012-RECORD-NUM UPON CONSOLE
           DISPLAY 'PAYMENT TYPE       : ',
           WS-7012-PAYMENT-TYPE UPON CONSOLE
           DISPLAY 'PAID AMOUNT        : ',
           WS-7012-PAID-AMOUNT UPON CONSOLE
           DISPLAY 'PREPAYMENT FLAG    : ',
           WS-7012-PREPAYMENT-FLG UPON CONSOLE
           DISPLAY 'PAID DATE          : ',
           WS-7012-PAID-DATE UPON CONSOLE
           DISPLAY 'FILLER 01 (209)    : ',
           WS-7012-FILLER-1 UPON CONSOLE
           DISPLAY 'PARENT T20 SEQ NO  : ',
           WS-7012-PMEMO-PARENT-TSEQ-NO UPON CONSOLE
           DISPLAY 'PARENT T20 POLICY  : ',
           WS-7012-PMEMO-CONTRACT-NUMBER UPON CONSOLE
           DISPLAY 'RM DATA RECEIPT DT : ',
           WS-7012-RM-DATA-RECEIPT-DATE UPON CONSOLE
           DISPLAY 'FILLER 02 (08)     : ',
           WS-7012-FILLER-2 UPON CONSOLE
           DISPLAY '--------------------------------'
           UPON CONSOLE
           DISPLAY 'FCIC CONTROL TIME    : ',
           WS-7012-FCIC-CONTROL-TIME UPON CONSOLE
           DISPLAY 'FCIC CONTROL DATE    : ',
           WS-7012-FCIC-CONTROL-DATE UPON CONSOLE
           DISPLAY 'REINSURANCE YEAR     : ',
           WS-7012-REINS-YR UPON CONSOLE
           DISPLAY 'BATCH NUMBER         : ',
           WS-7012-BATCH-NO UPON CONSOLE
           DISPLAY 'TRANS SEQUENCE NUM   : ',
           WS-7012-TRAN-SEQ-NO UPON CONSOLE
           DISPLAY 'TRANS REJECTED FLAG  : ',
           WS-7012-TRAN-REJECTED-FLAG UPON CONSOLE
           DISPLAY 'TRANS SOURCE FLAG    : ',
           WS-7012-TRAN-SOURCE-FLAG UPON CONSOLE
           DISPLAY 'MDAS PROCESS NUMBER  : ',
           WS-7012-MDAS-PROCESS-NO UPON CONSOLE
           DISPLAY 'FILLER 03  (14)      : ',
           WS-7012-FILLER-3 UPON CONSOLE.

       7012-DISPLAY-RECORD-EXIT.
           EXIT.

      $END
