      ***************************************************************
      * File:      M7020.CBL                                        *
      * Author:    Mike Ray and Cheryl D. Wood                      *
      * Date:      8/25/95                                          *
      * Purpose:                                                    *
      *    Adds a single T15 record to the T15 table.               *
      *    if the record exists, the new record replaces it and the *
      *    indicator is set to indicate where the record came from. *
      ***************************************************************

       7020-ADD-T15-RECORD.

      $IF DEBUG-SW DEFINED
           DISPLAY '7020-ADDING T15 RECORD'
           UPON CONSOLE
      $END

      ****************************************************************
      *   DISPLAY RECORD BEING ADDED                                 *
      ****************************************************************
      $IF DEBUG-SW DEFINED
           PERFORM 7020-DISPLAY-RECORD
              THRU 7020-DISPLAY-RECORD-EXIT
      $END

      ****************************************************************
      *  Check to make sure that the transaction sequence number     *
      *  is passed and that the other control flags are set.         *
      ****************************************************************

           IF WS-7020-TRAN-SEQ-NO IS NOT NUMERIC
              MOVE 7020 TO WS-8020-PARAGRAPH-NO
              MOVE 90001 TO WS-8020-INT-ERROR-NO
              MOVE 'WS-7020-TRAN-SEQ-NO' TO WS-8020-FIELD-NAME
              MOVE WS-7020-TRAN-SEQ-NO TO WS-8020-BAD-DATA
              MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
              PERFORM 8020-RECORD-INT-ERROR
                 THRU 8020-RECORD-INT-ERROR-EXIT
           END-IF

           IF WS-7020-TRAN-SEQ-NO = ZEROS
              MOVE 7020 TO WS-8020-PARAGRAPH-NO
              MOVE 90003 TO WS-8020-INT-ERROR-NO
              MOVE 'WS-7020-TRAN-SEQ-NO' TO WS-8020-FIELD-NAME
              MOVE WS-7020-TRAN-SEQ-NO TO WS-8020-BAD-DATA
              MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
              PERFORM 8020-RECORD-INT-ERROR
                 THRU 8020-RECORD-INT-ERROR-EXIT
           END-IF

           IF WS-7020-TRAN-SOURCE-FLAG = SPACES
              MOVE 7020 TO WS-8020-PARAGRAPH-NO
              MOVE 90003 TO WS-8020-INT-ERROR-NO
              MOVE 'WS-7020-TRAN-SOURCE-FLAG' TO WS-8020-FIELD-NAME
              MOVE WS-7020-TRAN-SOURCE-FLAG TO WS-8020-BAD-DATA
              MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
              PERFORM 8020-RECORD-INT-ERROR
                 THRU 8020-RECORD-INT-ERROR-EXIT
           END-IF

           IF WS-7020-AVG-APH-YIELD IS NOT NUMERIC
              MOVE 7020 TO WS-8020-PARAGRAPH-NO
              MOVE 90001 TO WS-8020-INT-ERROR-NO
              MOVE 'WS-7020-AVG-APH-YIELD' TO WS-8020-FIELD-NAME
              MOVE SPACES TO WS-8020-BAD-DATA
              MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
              PERFORM 8020-RECORD-INT-ERROR
                 THRU 8020-RECORD-INT-ERROR-EXIT
           END-IF

      ****************************************************************
      *  Initialize local working storage                            *
      ****************************************************************
           INITIALIZE WS-7020-CROP-POLICY-TYPE

      ****************************************************************
      *  Look up Crop Policy Type for each crop/type combination     *
      *  so that these values can be placed in the table.            *
      ****************************************************************

      $IF DATABASE-SW DEFINED
           INITIALIZE WS-6280-INPUT
           MOVE WS-7020-RATE-STATE TO WS-6280-STATE-CD
           MOVE WS-7020-TYPE-CD TO WS-6280-TYPE-CD
           MOVE WS-7020-CROP-YR TO WS-6280-CROP-YR-YY
           PERFORM 6280-LOOKUP-CPT
              THRU 6280-LOOKUP-CPT-EXIT

           MOVE WS-6280-CPT TO WS-7020-CROP-POLICY-TYPE
      $END

      ****************************************************************
      *  NEITHER OF THESE TWO LOOKUPS HAS PROCESSING FOR WHEN A      *
      *  CROP POLICY TYPE IS NOT FOUND.  WILL IT BE AN INTERNAL      *
      *  ERROR????                                                   *
      ****************************************************************

      $IF ISAM-SW DEFINED
           IF ERROR-CROP-CD = WS-LITERAL-YES
              OR ERROR-RATE-STATE = WS-LITERAL-YES
              OR ERROR-CROP-TYPE = WS-LITERAL-YES
      **    ** SKIP THE CROP POLICY TYPE LOOKUP
      **    ** GIVE THE RECORD A DEFAULT VALUE-9997-FOR CROP POLICY TYPE
              MOVE '9997' TO WS-7020-CROP-POLICY-TYPE
           ELSE
              INITIALIZE WS-0211-PARAMETERS
              MOVE WS-7020-RATE-STATE TO WS-0211-STATE
              MOVE WS-7020-CROP-CD TO WS-0211-CROP-CD
              MOVE WS-7020-TYPE-CD TO WS-0211-CROP-TYPE

              PERFORM 0211-LOOKUP-CROP-POL-TYPE
                 THRU 0211-LOOKUP-CROP-POL-TYPE-EXIT

              IF WS-0211-CROP-POLICY-TYPE = SPACES
                 MOVE '9997' TO WS-7020-CROP-POLICY-TYPE
              ELSE
                 MOVE WS-0211-CROP-POLICY-TYPE
                   TO WS-7020-CROP-POLICY-TYPE
              END-IF
           END-IF
      $END

      ****************************************************************
      *  Display Status                                              *
      ****************************************************************
      $IF DEBUG-SW DEFINED
           DISPLAY 'REJECTION FLAG = ', WS-7020-TRAN-REJECTED-FLAG
           UPON CONSOLE
      $END
      ****************************************************************
      *  Do insertion logic                                          *
      ****************************************************************

           IF WS-0015-T15-REC-COUNT = ZEROS
              PERFORM 7020-ADD-RECORD
                 THRU 7020-ADD-RECORD-EXIT
           ELSE
      *       *** REPLACEMENT LOGIC IS NOT NEEDED UNTIL
      *       *** WE ACCEPT INCOMPLETE POLICIES
      *       PERFORM 7020-SEARCH-T15-TBL
      *          THRU 7020-SEARCH-T15-TBL-EXIT
              PERFORM 7020-ADD-RECORD
                 THRU 7020-ADD-RECORD-EXIT
           END-IF

      ****************************************************************
      *  Initialize Input Fields                                     *
      ****************************************************************
           INITIALIZE WS-7020-INPUT
           INITIALIZE WS-7020-FARM-APR-AVG-REV
           INITIALIZE WS-7020-TYPE-15.



       7020-ADD-T15-RECORD-EXIT.
           EXIT.

      ****************************************************************
      *  THIS PARAGRAPH DOES A SEARCH OF THE RECORD TYPE 15          *
      *  RECORDS TABLE. WHEN A MATCH IS FOUND, THE TABLE IS UPDATED  *
      *  WITH THE NEW TRANSACTION RECORD CONTENTS.                   *
      ****************************************************************

       7020-SEARCH-T15-TBL.

           SET WS-0015-T15-INDEX TO 1

           SEARCH WS-0015-T15-RECORD VARYING WS-0015-T15-INDEX
                AT END
                    PERFORM 7020-ADD-RECORD
                       THRU 7020-ADD-RECORD-EXIT
                    GO TO 7020-SEARCH-T15-TBL-EXIT
                WHEN (WS-0015-TBL-POLICY-NO (WS-0015-T15-INDEX)
                     IS EQUAL WS-7020-POLICY-NO)
                 AND (WS-0015-TBL-CROP-CD (WS-0015-T15-INDEX)
                     IS EQUAL WS-7020-CROP-CD)
                 AND (WS-0015-TBL-TYPE-CD (WS-0015-T15-INDEX)
                     IS EQUAL WS-7020-TYPE-CD)
                 AND (WS-0015-TBL-PRACTICE-CD (WS-0015-T15-INDEX)
                     IS EQUAL WS-7020-PRACTICE-CD)
                 AND (WS-0015-TBL-BASIC-UNIT-NUM (WS-0015-T15-INDEX)
                     IS EQUAL WS-7020-BASIC-UNIT-NUM)
                 AND (WS-0015-TBL-OPTIONAL-UNIT (WS-0015-T15-INDEX)
                     IS EQUAL WS-7020-OPTIONAL-UNIT)
                 AND (WS-0015-TBL-APPROVED-YIELD (WS-0015-T15-INDEX)
                     IS EQUAL WS-7020-APPROVED-YIELD)
      *************************************************************
      *  Approved Yield is currently included as part of the      *
      *  replacement key.  This may need to change in the future. *
      *************************************************************
      $IF DEBUG-SW DEFINED
           DISPLAY 'REPLACING TYPE 15 RECORD' UPON CONSOLE
      $END
                     MOVE WS-7020-TRAN-REJECTED-FLAG TO
                     WS-0015-TBL-TRAN-REJECTED-FLAG (WS-0015-T15-INDEX)

                     MOVE WS-7020-TRAN-SOURCE-FLAG
                     TO WS-0015-TBL-TRAN-SOURCE-FLAG(WS-0015-T15-INDEX)

                     MOVE WS-7020-AVG-APH-YIELD
                     TO WS-0015-TBL-AVG-APH-YIELD(WS-0015-T15-INDEX)

                     MOVE WS-7020-CROP-POLICY-TYPE
                     TO WS-0015-TBL-CROP-POLICY-TY(WS-0015-T15-INDEX)

                     MOVE WS-7020-TYPE-15
                     TO WS-0015-TBL-TYPE-15 (WS-0015-T15-INDEX).

       7020-SEARCH-T15-TBL-EXIT.
           EXIT.

      ****************************************************************
      *  THIS PARAGRAPH TEST THE TABLE SIZE LIMIT BEFORE ADDING AN   *
      *  ADDITIONAL RECORD. WHEN THE MAXIMUM TABLE SIZE IS REACHED,  *
      *  MESSAGES ARE DISPLAYED AND EXECUTION IS TERMINATED -        *
      *  OTHERWISE THE NEW TRANSACTION RECORD IS ADDED TO THE TABLE. *
      ****************************************************************

       7020-ADD-RECORD.

           IF WS-0015-T15-REC-COUNT >= WS-0015-MAX-SIZE
              DISPLAY 'REC TYPE 15 T15 TABLE LIMIT WILL BE EXCEEDED'
              UPON CONSOLE
              DISPLAY ' WITH THE ADDITION OF THIS RECORD'
              UPON CONSOLE
              DISPLAY '**********************************'
              UPON CONSOLE
              DISPLAY 'MAXIMUM TABLE SIZE IS ' WS-0015-MAX-SIZE
                      ' RECORDS' UPON CONSOLE
              PERFORM 0800-ABORT-PROGRAM
                 THRU 0800-ABORT-PROGRAM-EXIT
           ELSE
              ADD 1 TO WS-0015-T15-REC-COUNT
              SET WS-0015-T15-INDEX TO WS-0015-T15-REC-COUNT
              MOVE WS-7020-TRAN-REJECTED-FLAG
                TO WS-0015-TBL-TRAN-REJECTED-FLAG(WS-0015-T15-INDEX)
              MOVE WS-7020-TRAN-SOURCE-FLAG
                TO WS-0015-TBL-TRAN-SOURCE-FLAG(WS-0015-T15-INDEX)
              MOVE WS-7020-AVG-APH-YIELD
                TO WS-0015-TBL-AVG-APH-YIELD(WS-0015-T15-INDEX)
              MOVE WS-7020-ACTUAL-YEARS
                TO WS-0015-TBL-ACTUAL-YEARS(WS-0015-T15-INDEX)
              MOVE WS-7020-REF-YEARS-REQ
                TO WS-0015-TBL-REF-YEARS-REQ(WS-0015-T15-INDEX)
              MOVE WS-7020-CROP-POLICY-TYPE
                TO WS-0015-TBL-CROP-POLICY-TY(WS-0015-T15-INDEX)
              MOVE WS-7020-TYPE-15
                TO WS-0015-TBL-TYPE-15(WS-0015-T15-INDEX)

      $IF DEBUG-SW DEFINED
           DISPLAY 'ADDED T15 TABLE REC # ', WS-0015-T15-REC-COUNT
           UPON CONSOLE
      $END

      *            UPDATE TABLE STATISTICS
              IF WS-0015-T15-REC-COUNT > WS-0008-T15-MAX-TABLE-SIZE
                 MOVE WS-0015-T15-REC-COUNT
                   TO WS-0008-T15-MAX-TABLE-SIZE
              END-IF
           END-IF.

       7020-ADD-RECORD-EXIT.
           EXIT.


      $IF DEBUG-SW DEFINED

       7020-DISPLAY-RECORD.

           DISPLAY '7020-TYPE 15 RECORD BEING ADDED TO THE T15 TABLE'
           UPON CONSOLE
           DISPLAY 'RECORD TYPE        : ',
           WS-7020-RECORD-TYPE UPON CONSOLE
           DISPLAY 'REPORTING ORG      : ',
           WS-7020-REPORTING-ORG UPON CONSOLE
           DISPLAY 'LOCATION STATE     : ',
           WS-7020-LOC-STATE UPON CONSOLE
           DISPLAY 'COMPANY            : ',
           WS-7020-COMPANY-COUNTY UPON CONSOLE
           DISPLAY 'POLICY NUMBER      : ',
           WS-7020-POLICY-NUM UPON CONSOLE
           DISPLAY 'CROP YEAR          : ',
           WS-7020-CROP-YEAR UPON CONSOLE
           DISPLAY '--------------------------------'
           UPON CONSOLE
           DISPLAY 'CROP CODE          : ',
           WS-7020-CROP-CD UPON CONSOLE
           DISPLAY 'INSURANCE PLAN CD  : ',
           WS-7020-INS-PLAN-CD UPON CONSOLE
           DISPLAY 'LOCATION COUNTY    : ',
           WS-7020-LOCATION-COUNTY UPON CONSOLE
           DISPLAY 'UNIT NUMBER        : ',
           WS-7020-UNIT-NUMBER UPON CONSOLE
           DISPLAY 'TYPE CODE          : ',
           WS-7020-TYPE-CD UPON CONSOLE
           DISPLAY 'PRACTICE CODE      : ',
           WS-7020-PRACTICE-CD UPON CONSOLE
           DISPLAY 'COVERAGE FLAG      : ',
           WS-7020-COVERAGE-FLG UPON CONSOLE
           DISPLAY '--------------------------------'
           UPON CONSOLE
           DISPLAY 'KEY RESERVE          : ',
           WS-7020-KEY-RESERVE UPON CONSOLE
           DISPLAY 'FILLER 01 (02)       : ',
           WS-7020-FILLER-1 UPON CONSOLE
           DISPLAY 'RECORD NUMBER        : ',
           WS-7020-RECORD-NUMBER UPON CONSOLE
           DISPLAY 'MAP AREA             : ',
           WS-7020-MAP-AREA UPON CONSOLE
           DISPLAY 'NCS EXCEPTION FLAG   : ',
           WS-7020-NCS-EXCEPTION-FLAG UPON CONSOLE
           DISPLAY 'NCS YIELD FACTOR     : ',
           WS-7020-NCS-YIELD-FACTOR UPON CONSOLE
           DISPLAY 'REVIEW FLAG          : ',
           WS-7020-REVIEW-FLG UPON CONSOLE
           DISPLAY 'YIELD INDICATOR      : ',
           WS-7020-YIELD-INDICATOR UPON CONSOLE
           DISPLAY 'TRANSITIONAL YIELD   : ',
           WS-7020-TRANSITIONAL-YIELD UPON CONSOLE
           DISPLAY 'CFSA YIELD           : ',
           WS-7020-CFSA-YIELD UPON CONSOLE
           DISPLAY 'APPROVED YIELD       : ',
           WS-7020-APPROVED-YIELD UPON CONSOLE
           DISPLAY 'PREVIOUS APPROVED YLD: ',
           WS-7020-PREV-APPROV-YIELD UPON CONSOLE
           DISPLAY 'YIELD YEAR 01        : ',
           WS-7020-YIELD-YEAR1 UPON CONSOLE
           DISPLAY 'YIELD TYPE 01        : ',
           WS-7020-YIELD-TYPE-YEAR1 UPON CONSOLE
           DISPLAY 'ANNUAL YIELD 01      : ',
           WS-7020-ANNUAL-YIELD1 UPON CONSOLE
           DISPLAY 'YIELD ACRES 01       : ',
           WS-7020-YIELD-ACRE1 UPON CONSOLE
           DISPLAY 'YIELD YEAR 02        : ',
           WS-7020-YIELD-YEAR2 UPON CONSOLE
           DISPLAY 'YIELD TYPE 02        : ',
           WS-7020-YIELD-TYPE-YEAR2 UPON CONSOLE
           DISPLAY 'ANNUAL YIELD 02      : ',
           WS-7020-ANNUAL-YIELD2 UPON CONSOLE
           DISPLAY 'YIELD ACRES 02       : ',
           WS-7020-YIELD-ACRE2 UPON CONSOLE
           DISPLAY 'YIELD YEAR 03        : ',
           WS-7020-YIELD-YEAR3 UPON CONSOLE
           DISPLAY 'YIELD TYPE 03        : ',
           WS-7020-YIELD-TYPE-YEAR3 UPON CONSOLE
           DISPLAY 'ANNUAL YIELD 03      : ',
           WS-7020-ANNUAL-YIELD3 UPON CONSOLE
           DISPLAY 'YIELD ACRES 03       : ',
           WS-7020-YIELD-ACRE3 UPON CONSOLE
           DISPLAY 'YIELD YEAR 04        : ',
           WS-7020-YIELD-YEAR4 UPON CONSOLE
           DISPLAY 'YIELD TYPE 04        : ',
           WS-7020-YIELD-TYPE-YEAR4 UPON CONSOLE
           DISPLAY 'ANNUAL YIELD 04      : ',
           WS-7020-ANNUAL-YIELD4 UPON CONSOLE
           DISPLAY 'YIELD ACRES 04       : ',
           WS-7020-YIELD-ACRE4 UPON CONSOLE
           DISPLAY 'YIELD YEAR 05        : ',
           WS-7020-YIELD-YEAR5 UPON CONSOLE
           DISPLAY 'YIELD TYPE 05        : ',
           WS-7020-YIELD-TYPE-YEAR5 UPON CONSOLE
           DISPLAY 'ANNUAL YIELD 05      : ',
           WS-7020-ANNUAL-YIELD5 UPON CONSOLE
           DISPLAY 'YIELD ACRES 05       : ',
           WS-7020-YIELD-ACRE5 UPON CONSOLE
           DISPLAY 'YIELD YEAR 06        : ',
           WS-7020-YIELD-YEAR6 UPON CONSOLE
           DISPLAY 'YIELD TYPE 06        : ',
           WS-7020-YIELD-TYPE-YEAR6 UPON CONSOLE
           DISPLAY 'ANNUAL YIELD 06      : ',
           WS-7020-ANNUAL-YIELD6 UPON CONSOLE
           DISPLAY 'YIELD ACRES 06       : ',
           WS-7020-YIELD-ACRE6 UPON CONSOLE
           DISPLAY 'YIELD YEAR 07        : ',
           WS-7020-YIELD-YEAR7 UPON CONSOLE
           DISPLAY 'YIELD TYPE 07        : ',
           WS-7020-YIELD-TYPE-YEAR7 UPON CONSOLE
           DISPLAY 'ANNUAL YIELD 07      : ',
           WS-7020-ANNUAL-YIELD7 UPON CONSOLE
           DISPLAY 'YIELD ACRES 07       : ',
           WS-7020-YIELD-ACRE7 UPON CONSOLE
           DISPLAY 'YIELD YEAR 08        : ',
           WS-7020-YIELD-YEAR8 UPON CONSOLE
           DISPLAY 'YIELD TYPE 08        : ',
           WS-7020-YIELD-TYPE-YEAR8 UPON CONSOLE
           DISPLAY 'ANNUAL YIELD 08      : ',
           WS-7020-ANNUAL-YIELD8 UPON CONSOLE
           DISPLAY 'YIELD ACRES 08       : ',
           WS-7020-YIELD-ACRE8 UPON CONSOLE
           DISPLAY 'YIELD YEAR 09        : ',
           WS-7020-YIELD-YEAR9 UPON CONSOLE
           DISPLAY 'YIELD TYPE 09        : ',
           WS-7020-YIELD-TYPE-YEAR9 UPON CONSOLE
           DISPLAY 'ANNUAL YIELD 09      : ',
           WS-7020-ANNUAL-YIELD9 UPON CONSOLE
           DISPLAY 'YIELD ACRES 09       : ',
           WS-7020-YIELD-ACRE9 UPON CONSOLE
           DISPLAY 'YIELD YEAR 10        : ',
           WS-7020-YIELD-YEAR10 UPON CONSOLE
           DISPLAY 'YIELD TYPE 10        : ',
           WS-7020-YIELD-TYPE-YEAR10 UPON CONSOLE
           DISPLAY 'ANNUAL YIELD 10      : ',
           WS-7020-ANNUAL-YIELD10 UPON CONSOLE
           DISPLAY 'YIELD ACRES 10       : ',
           WS-7020-YIELD-ACRE10 UPON CONSOLE
           DISPLAY 'RATE STATE           : ',
           WS-7020-RATE-STATE UPON CONSOLE
           DISPLAY 'RATE COUNTY          : ',
           WS-7020-RATE-COUNTY UPON CONSOLE
           DISPLAY 'FARM SERIAL NUMBER   : ',
           WS-7020-FARM-SERIAL-NUM UPON CONSOLE
           DISPLAY 'YIELD LIMITATION FLG : ',
           WS-7020-YIELD-LIM-FLAG UPON CONSOLE
           DISPLAY 'FILLER 02 (65)       : ',
           WS-7020-FILLER-2 UPON CONSOLE
           DISPLAY '--------------------------------'
           UPON CONSOLE
           DISPLAY 'FCIC CONTROL TIME    : ',
           WS-7020-FCIC-CONTROL-TIME UPON CONSOLE
           DISPLAY 'FCIC CONTROL DATE    : ',
           WS-7020-FCIC-CONTROL-DATE UPON CONSOLE
           DISPLAY 'REINSURANCE YEAR     : ',
           WS-7020-REINS-YR UPON CONSOLE
           DISPLAY 'BATCH NUMBER         : ',
           WS-7020-BATCH-NO UPON CONSOLE
           DISPLAY 'TRANS SEQUENCE NUM   : ',
           WS-7020-TRAN-SEQ-NO UPON CONSOLE
           DISPLAY 'TRANS REJECTED FLAG  : ',
           WS-7020-TRAN-REJECTED-FLAG UPON CONSOLE
           DISPLAY 'TRANS SOURCE FLAG    : ',
           WS-7020-TRAN-SOURCE-FLAG UPON CONSOLE
           DISPLAY 'MDAS PROCESS NUMBER  : ',
           WS-7020-MDAS-PROCESS-NO UPON CONSOLE
           DISPLAY 'FILLER 3 (14)        : ',
           WS-7020-FILLER-3 UPON CONSOLE
           DISPLAY '--------------------------------'
           UPON CONSOLE
           DISPLAY 'AVERAGE APH YIELD    : ',
           WS-7020-AVG-APH-YIELD UPON CONSOLE
           DISPLAY 'ACTUAL YIELD YEARS   : ',
           WS-7020-ACTUAL-YEARS UPON CONSOLE
           DISPLAY 'REFERENCE YEARS REQ  : ',
           WS-7020-REF-YEARS-REQ UPON CONSOLE.

       7020-DISPLAY-RECORD-EXIT.
           EXIT.

      $END

