      ***************************************************************
      ***************************************************************
      * File:      M7025.CBL                                        *
      * Author:    Mike Ray and Cheryl D. Wood                      *
      * Date:      8/25/95                                          *
      * Purpose:                                                    *
      *    Adds a single T16 record to the T16 table.               *
      *    if the record exists, the new record replaces it and the *
      *    indicator is set to indicate where the record came from. *
      ***************************************************************

       7025-ADD-T16-RECORD.

      $IF DEBUG-SW DEFINED
           DISPLAY '7025-ADDING T16 RECORD'
           UPON CONSOLE
      $END

      ****************************************************************
      *  Check to make sure that the transaction sequence number     *
      *  is passed and that the other control flags are set.         *
      ****************************************************************

           IF WS-7025-TRAN-SEQ-NO IS NOT NUMERIC
              MOVE 7025 TO WS-8020-PARAGRAPH-NO
              MOVE 90001 TO WS-8020-INT-ERROR-NO
              MOVE 'WS-7025-TRAN-SEQ-NO' TO WS-8020-FIELD-NAME
              MOVE WS-7025-TRAN-SEQ-NO TO WS-8020-BAD-DATA
              MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
              PERFORM 8020-RECORD-INT-ERROR
                 THRU 8020-RECORD-INT-ERROR-EXIT
           END-IF

           IF WS-7025-TRAN-SEQ-NO = ZEROS
              MOVE 7025 TO WS-8020-PARAGRAPH-NO
              MOVE 90003 TO WS-8020-INT-ERROR-NO
              MOVE 'WS-7025-TRAN-SEQ-NO' TO WS-8020-FIELD-NAME
              MOVE WS-7025-TRAN-SEQ-NO TO WS-8020-BAD-DATA
              MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
              PERFORM 8020-RECORD-INT-ERROR
                 THRU 8020-RECORD-INT-ERROR-EXIT
           END-IF

           IF WS-7025-TRAN-SOURCE-FLAG = SPACES
              MOVE 7025 TO WS-8020-PARAGRAPH-NO
              MOVE 90003 TO WS-8020-INT-ERROR-NO
              MOVE 'WS-7025-TRAN-SOURCE-FLAG' TO WS-8020-FIELD-NAME
              MOVE WS-7025-TRAN-SOURCE-FLAG TO WS-8020-BAD-DATA
              MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
              PERFORM 8020-RECORD-INT-ERROR
                 THRU 8020-RECORD-INT-ERROR-EXIT
           END-IF

      ****************************************************************
      *  Do insertion logic                                          *
      ****************************************************************

           IF WS-0016-T16-REC-COUNT = ZEROS
              SET WS-0016-T16-INDEX TO 1
              PERFORM 7025-ADD-RECORD
                 THRU 7025-ADD-RECORD-EXIT
           ELSE
              PERFORM 7025-SEARCH-T16-TBL
                 THRU 7025-SEARCH-T16-TBL-EXIT
           END-IF

      ****************************************************************
      *  Initialize Input Fields                                     *
      ****************************************************************

           INITIALIZE WS-7025-TRAN-REJECTED-FLAG
           INITIALIZE WS-7025-TRAN-SOURCE-FLAG
           INITIALIZE WS-7025-TYPE-16.


       7025-ADD-T16-RECORD-EXIT.
           EXIT.

      ****************************************************************
      *  THIS PARAGRAPH DOES A SEARCH OF THE RECORD TYPE 16          *
      *  RECORDS TABLE. WHEN A MATCH IS FOUND, THE TABLE IS UPDATED  *
      *  WITH THE NEW TRANSACTION RECORD CONTENTS.                   *
      ****************************************************************

       7025-SEARCH-T16-TBL.

           SET WS-0016-T16-INDEX TO 1.

           SEARCH WS-0016-T16-RECORD VARYING WS-0016-T16-INDEX
                AT END
                    PERFORM 7025-ADD-RECORD
                       THRU 7025-ADD-RECORD-EXIT
                    GO TO 7025-SEARCH-T16-TBL-EXIT
                WHEN (WS-0016-TBL-POLICY-NO (WS-0016-T16-INDEX)
                     IS EQUAL WS-7025-POLICY-NO)
                 AND (WS-0016-TBL-PAYMENT-CROP-UNIT (WS-0016-T16-INDEX)
                     IS EQUAL WS-7025-PAYMENT-CROP-UNIT)
                 AND (WS-0016-TBL-PAYMENT-CROP-CODE (WS-0016-T16-INDEX)
                     IS EQUAL WS-7025-PAYMENT-CROP-CODE)

      $IF DEBUG-SW DEFINED
           DISPLAY 'REPLACING TYPE 16 RECORD' UPON CONSOLE
      $END
                     MOVE WS-7025-TRAN-REJECTED-FLAG TO
                     WS-0016-TBL-TRAN-REJECTED-FLAG (WS-0016-T16-INDEX)

                     MOVE WS-7025-TRAN-SOURCE-FLAG TO
                     WS-0016-TBL-TRAN-SOURCE-FLAG (WS-0016-T16-INDEX)

                     MOVE WS-7025-TYPE-16 TO
                     WS-0016-TBL-TYPE-16 (WS-0016-T16-INDEX).

       7025-SEARCH-T16-TBL-EXIT.
           EXIT.

      ****************************************************************
      *  THIS PARAGRAPH TEST THE TABLE SIZE LIMIT BEFORE ADDING AN   *
      *  ADDITIONAL RECORD. WHEN THE MAXIMUM TABLE SIZE IS REACHED,  *
      *  MESSAGES ARE DISPLAYED AND EXECUTION IS TERMINATED -        *
      *  OTHERWISE THE NEW TRANSACTION RECORD IS ADDED TO THE TABLE. *
      ****************************************************************

       7025-ADD-RECORD.

           IF WS-0016-T16-REC-COUNT = WS-0016-MAX-SIZE
              DISPLAY 'REC TYPE 16 T16 TABLE LIMIT WILL BE EXCEEDED'
              UPON CONSOLE
              DISPLAY ' WITH THE ADDITION OF THIS RECORD'
              UPON CONSOLE
              DISPLAY '**********************************'
              UPON CONSOLE
              DISPLAY 'MAXIMUM TABLE SIZE IS ' WS-0016-MAX-SIZE
                      ' RECORDS' UPON CONSOLE
              PERFORM 0800-ABORT-PROGRAM
                 THRU 0800-ABORT-PROGRAM-EXIT
           ELSE
              ADD 1 TO WS-0016-T16-REC-COUNT
              MOVE WS-7025-TRAN-REJECTED-FLAG
                TO WS-0016-TBL-TRAN-REJECTED-FLAG (WS-0016-T16-INDEX)
              MOVE WS-7025-TRAN-SOURCE-FLAG
                TO WS-0016-TBL-TRAN-SOURCE-FLAG (WS-0016-T16-INDEX)
              MOVE WS-7025-TYPE-16
                TO WS-0016-TBL-TYPE-16 (WS-0016-T16-INDEX)

      *            UPDATE TABLE STATISTICS
              IF WS-0016-T16-REC-COUNT > WS-0008-T16-MAX-TABLE-SIZE
                 MOVE WS-0016-T16-REC-COUNT
                   TO WS-0008-T16-MAX-TABLE-SIZE
              END-IF
           END-IF.

       7025-ADD-RECORD-EXIT.
           EXIT.
