      ***************************************************************
      * File:      M7030.CBL                                        *
      * Author:    Mike Ray and Cheryl D. Wood                      *
      * Date:      8/25/95                                          *
      * Purpose:                                                    *
      *    Adds a single T20 record to the T20 table.               *
      *    if the record exists, the new record replaces it and the *
      *    indicator is set to indicate where the record came from. *
      ***************************************************************

       7030-ADD-T20-RECORD.

      $IF DEBUG-SW DEFINED
           DISPLAY '7030-ADDING T20 RECORD'
           UPON CONSOLE
      $END

      ****************************************************************
      *   DISPLAY RECORD BEING ADDED                                 *
      ****************************************************************
      $IF DEBUG-SW DEFINED
           PERFORM 7030-DISPLAY-RECORD
              THRU 7030-DISPLAY-RECORD-EXIT
      $END

      ****************************************************************
      *  Check to make sure that the transaction sequence number     *
      *  is passed and that the other control flags are set.         *
      ****************************************************************

           IF WS-7030-TRAN-SEQ-NO IS NOT NUMERIC
              MOVE 7030 TO WS-8020-PARAGRAPH-NO
              MOVE 90001 TO WS-8020-INT-ERROR-NO
              MOVE 'WS-7030-TRAN-SEQ-NO' TO WS-8020-FIELD-NAME
              MOVE WS-7030-TRAN-SEQ-NO TO WS-8020-BAD-DATA
              MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
              PERFORM 8020-RECORD-INT-ERROR
                 THRU 8020-RECORD-INT-ERROR-EXIT
           END-IF

           IF WS-7030-TRAN-SEQ-NO = ZEROS
              MOVE 7030 TO WS-8020-PARAGRAPH-NO
              MOVE 90003 TO WS-8020-INT-ERROR-NO
              MOVE 'WS-7030-TRAN-SEQ-NO' TO WS-8020-FIELD-NAME
              MOVE WS-7030-TRAN-SEQ-NO TO WS-8020-BAD-DATA
              MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
              PERFORM 8020-RECORD-INT-ERROR
                 THRU 8020-RECORD-INT-ERROR-EXIT
           END-IF

           IF WS-7030-TRAN-SOURCE-FLAG = SPACES
              MOVE 7030 TO WS-8020-PARAGRAPH-NO
              MOVE 90003 TO WS-8020-INT-ERROR-NO
              MOVE 'WS-7030-TRAN-SOURCE-FLAG' TO WS-8020-FIELD-NAME
              MOVE WS-7030-TRAN-SOURCE-FLAG TO WS-8020-BAD-DATA
              MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
              PERFORM 8020-RECORD-INT-ERROR
                 THRU 8020-RECORD-INT-ERROR-EXIT
           END-IF

      ****************************************************************
      *  Do insertion logic                                          *
      ****************************************************************

           IF WS-0020-T20-REC-COUNT = ZEROS
              SET WS-0020-T20-INDEX TO 1
              PERFORM 7030-ADD-RECORD
                 THRU 7030-ADD-RECORD-EXIT
           ELSE
      *       **** THERE IS CURRENTLY NO NEED FOR REPLACEMENT LOGIC
      *       **** THIS MAY BE NEEDED IF WE GO BACK TO ACCEPTING
      *       **** INCOMPLETE POLICIES.
      *       PERFORM 7030-SEARCH-T20-TBL
      *          THRU 7030-SEARCH-T20-TBL-EXIT
              PERFORM 7030-ADD-RECORD
                 THRU 7030-ADD-RECORD-EXIT
           END-IF

      ****************************************************************
      *  Insertion logic for the Claim Total Indemnity Table.        *
      *  This table is later used by inter record edits              *
      *  to determine whether the total indemnity specified on the   *
      *  Type 20(s) equals the sum of the Type 21 line indemnities.  *
      *                                                              *
      *  This same table is used to ensure that Type 21 records      *
      *  in the policy buffer are correctly written to the Rejected  *
      *  or Accepted files.  If the Claim Number has been rejected,  *
      *  all of the associated Type 21 records must also be rejected.*
      ****************************************************************

           PERFORM 7030-UPDATE-CLAIM-TBL
              THRU 7030-UPDATE-CLAIM-TBL-EXIT


      ****************************************************************
      *  Initialize Input Fields                                     *
      ****************************************************************
           INITIALIZE WS-7030-TYPE-20.


       7030-ADD-T20-RECORD-EXIT.
           EXIT.

      ****************************************************************
      *  THIS PARAGRAPH DOES A SEARCH OF THE RECORD TYPE 20          *
      *  RECORDS TABLE. WHEN A MATCH IS FOUND, THE TABLE IS UPDATED  *
      *  WITH THE NEW TRANSACTION RECORD CONTENTS.                   *
      ****************************************************************

       7030-SEARCH-T20-TBL.

           SET WS-0020-T20-INDEX TO 1.

           SEARCH WS-0020-T20-RECORD VARYING WS-0020-T20-INDEX
                AT END
                    PERFORM 7030-ADD-RECORD
                       THRU 7030-ADD-RECORD-EXIT
                    GO TO 7030-SEARCH-T20-TBL-EXIT
                WHEN (WS-0020-TBL-POLICY-NO (WS-0020-T20-INDEX)
                     IS EQUAL WS-7030-POLICY-NO)
                 AND (WS-0020-TBL-CLAIM-NUM (WS-0020-T20-INDEX)
                     IS EQUAL WS-7030-CLAIM-NUM)

      $IF DEBUG-SW DEFINED
           DISPLAY 'REPLACING TYPE 20 RECORD' UPON CONSOLE
      $END
                     MOVE WS-7030-TYPE-20
                       TO WS-0020-TBL-TYPE-20 (WS-0020-T20-INDEX)
           END-SEARCH.

       7030-SEARCH-T20-TBL-EXIT.
           EXIT.

      ****************************************************************
      *  THIS PARAGRAPH TEST THE TABLE SIZE LIMIT BEFORE ADDING AN   *
      *  ADDITIONAL RECORD. WHEN THE MAXIMUM TABLE SIZE IS REACHED,  *
      *  MESSAGES ARE DISPLAYED AND EXECUTION IS TERMINATED -        *
      *  OTHERWISE THE NEW TRANSACTION RECORD IS ADDED TO THE TABLE. *
      ****************************************************************

       7030-ADD-RECORD.

           IF WS-0020-T20-REC-COUNT >= WS-0020-MAX-SIZE
              DISPLAY 'REC TYPE 20 T20 TABLE LIMIT WILL BE EXCEEDED'
              UPON CONSOLE
              DISPLAY ' WITH THE ADDITION OF THIS RECORD'
              UPON CONSOLE
              DISPLAY '**********************************'
              UPON CONSOLE
              DISPLAY 'MAXIMUM TABLE SIZE IS ' WS-0020-MAX-SIZE
                      ' RECORDS' UPON CONSOLE
              PERFORM 0800-ABORT-PROGRAM
                 THRU 0800-ABORT-PROGRAM-EXIT
           ELSE
              ADD 1 TO WS-0020-T20-REC-COUNT
              SET WS-0020-T20-INDEX TO WS-0020-T20-REC-COUNT
              MOVE WS-7030-TYPE-20
                TO WS-0020-TBL-TYPE-20(WS-0020-T20-INDEX)

      *          UPDATE TABLE STATISTICS
              IF WS-0020-T20-REC-COUNT > WS-0008-T20-MAX-TABLE-SIZE
                 MOVE WS-0020-T20-REC-COUNT
                   TO WS-0008-T20-MAX-TABLE-SIZE
              END-IF
           END-IF.

       7030-ADD-RECORD-EXIT.
           EXIT.


       7030-UPDATE-CLAIM-TBL.

      *****************************************************
      *              CHECK INPUT FIELDS                   *
      *****************************************************

           IF WS-7030-CLAIM-NUM IS NOT NUMERIC
              GO TO 7030-UPDATE-CLAIM-TBL-EXIT
           END-IF

           IF WS-7030-1ST-TOTAL-AMOUNT IS NOT NUMERIC
              GO TO 7030-UPDATE-CLAIM-TBL-EXIT
           END-IF

           IF WS-7030-2ND-TOTAL-AMOUNT IS NOT NUMERIC
              GO TO 7030-UPDATE-CLAIM-TBL-EXIT
           END-IF

           IF WS-7030-3RD-TOTAL-AMOUNT IS NOT NUMERIC
              GO TO 7030-UPDATE-CLAIM-TBL-EXIT
           END-IF

           IF WS-7030-4TH-TOTAL-AMOUNT IS NOT NUMERIC
              GO TO 7030-UPDATE-CLAIM-TBL-EXIT
           END-IF

           INITIALIZE WS-7030-TOT-T20-INDEMNITY

      ****************************************************************
      *  DO INSERTION LOGIC.                                         *
      ****************************************************************

           IF WS-0020-CLAIM-REC-COUNT = ZEROS
              SET WS-0020-CLAIM-INDEX TO 1
              PERFORM 7030-ADD-CLAIM-RECORD
                 THRU 7030-ADD-CLAIM-RECORD-EXIT
           ELSE
              PERFORM 7030-SEARCH-CLAIM-TBL
                 THRU 7030-SEARCH-CLAIM-TBL-EXIT
           END-IF.


       7030-UPDATE-CLAIM-TBL-EXIT.
           EXIT.


      ****************************************************************
      *  THIS PARAGRAPH TESTS THE TABLE SIZE LIMIT BEFORE ADDING AN  *
      *  ADDITIONAL RECORD. WHEN THE MAXIMUM TABLE SIZE IS REACHED,  *
      *  MESSAGES ARE DISPLAYED AND EXECUTION IS TERMINATED -        *
      *  OTHERWISE THE NEW INDEMNITY RECORD IS ADDED TO THE TABLE.   *
      *                                                              *
      *  THE FOUR TOTAL AMOUNTS ARE SUMMED AND PLACED IN             *
      *  WS-0020-CLAIM-TBL-T20-TOT.                              *
      ****************************************************************

       7030-ADD-CLAIM-RECORD.

           IF WS-0020-CLAIM-REC-COUNT >= WS-0020-CLAIM-MAX-SIZE
              DISPLAY
              'REC 20 TOTAL INDEMNITY TABLE LIMIT WILL BE EXCEEDED'
              UPON CONSOLE
              DISPLAY ' WITH THE ADDITION OF THIS RECORD'
              UPON CONSOLE
              DISPLAY '**********************************'
              UPON CONSOLE
              DISPLAY 'MAXIMUM TABLE SIZE IS '
              WS-0020-CLAIM-MAX-SIZE
              ' RECORDS' UPON CONSOLE
              PERFORM 0800-ABORT-PROGRAM
                 THRU 0800-ABORT-PROGRAM-EXIT
           ELSE
              ADD 1 TO WS-0020-CLAIM-REC-COUNT
              SET WS-0020-CLAIM-INDEX TO WS-0020-CLAIM-REC-COUNT
              MOVE WS-7030-CLAIM-NUM
                TO WS-0020-CLAIM-TBL-CLAIM-NO(WS-0020-CLAIM-INDEX)

      *****   ADD THE FOUR TOTAL AMOUNT FIELDS TO DERIVE T20 TOTAL AMT
              COMPUTE WS-7030-TOT-T20-INDEMNITY ROUNDED =
                 WS-7030-1ST-TOTAL-AMOUNT + WS-7030-2ND-TOTAL-AMOUNT +
                 WS-7030-3RD-TOTAL-AMOUNT + WS-7030-4TH-TOTAL-AMOUNT
                 ON SIZE ERROR
                    MOVE 7030 TO WS-8020-PARAGRAPH-NO
                    MOVE 90017 TO WS-8020-INT-ERROR-NO
                    MOVE 'SUM T20 TOT AMTS' TO WS-8020-FIELD-NAME
                    MOVE WS-7030-TOT-T20-INDEMNITY
                      TO WS-8020-BAD-DATA
                    MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                    PERFORM 8020-RECORD-INT-ERROR
                       THRU 8020-RECORD-INT-ERROR-EXIT
              END-COMPUTE

              MOVE WS-7030-TOT-T20-INDEMNITY
                TO WS-0020-CLAIM-TBL-T20-TOT-AMT(WS-0020-CLAIM-INDEX)
              MOVE WS-7030-TRAN-REJ-FLAG
                TO WS-0020-CLAIM-TBL-TRAN-REJ-FL(WS-0020-CLAIM-INDEX)
              MOVE WS-7030-VALID-FOR-ESCROW
                TO WS-0020-CLAIM-TBL-ESCROW-FLAG(WS-0020-CLAIM-INDEX)
              MOVE ZEROS
                TO WS-0020-CLAIM-TBL-LOSS-TOT(WS-0020-CLAIM-INDEX)

      *            UPDATE TABLE STATISTICS
              IF WS-0020-CLAIM-REC-COUNT
                 > WS-0008-T20-CLAIM-MAX-TBL-SIZE
                 MOVE WS-0020-CLAIM-REC-COUNT
                   TO WS-0008-T20-CLAIM-MAX-TBL-SIZE
              END-IF
           END-IF.


       7030-ADD-CLAIM-RECORD-EXIT.
           EXIT.


      ****************************************************************
      *  THIS PARAGRAPH DOES A SEARCH OF THE CLAIM TOTAL INDEMNITY   *
      *  TABLE.  WHEN A MATCH IS FOUND, THE TOTAL TYPE 20 INDEMNITY  *
      *  IS INCREMENTED.                                             *
      ****************************************************************

       7030-SEARCH-CLAIM-TBL.

           SET WS-0020-CLAIM-INDEX TO 1.

           SEARCH WS-0020-CLAIM-RECORD
                VARYING WS-0020-CLAIM-INDEX
                AT END
                    PERFORM 7030-ADD-CLAIM-RECORD
                       THRU 7030-ADD-CLAIM-RECORD-EXIT
                    GO TO 7030-SEARCH-CLAIM-TBL-EXIT
                WHEN (WS-0020-CLAIM-TBL-CLAIM-NO
                     (WS-0020-CLAIM-INDEX)
                     IS EQUAL WS-7030-CLAIM-NUM)
      $IF DEBUG-SW DEFINED
           DISPLAY 'UPDATING CLAIM TOTAL INDEMNITY RECORD'
           UPON CONSOLE
      $END
                 COMPUTE WS-7030-TOT-T20-INDEMNITY ROUNDED =
                   WS-7030-1ST-TOTAL-AMOUNT + WS-7030-2ND-TOTAL-AMOUNT +
                   WS-7030-3RD-TOTAL-AMOUNT + WS-7030-4TH-TOTAL-AMOUNT
                   ON SIZE ERROR
                      MOVE 7030 TO WS-8020-PARAGRAPH-NO
                      MOVE 90017 TO WS-8020-INT-ERROR-NO
                      MOVE 'SUM T20 TOT AMTS' TO WS-8020-FIELD-NAME
                      MOVE WS-7030-TOT-T20-INDEMNITY
                        TO WS-8020-BAD-DATA
                      MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                      PERFORM 8020-RECORD-INT-ERROR
                         THRU 8020-RECORD-INT-ERROR-EXIT
                 END-COMPUTE

                 ADD WS-7030-TOT-T20-INDEMNITY
                   TO WS-0020-CLAIM-TBL-T20-TOT-AMT
                      (WS-0020-CLAIM-INDEX)
                 IF WS-7030-TRAN-REJ-FLAG = WS-LITERAL-YES
                    MOVE WS-LITERAL-YES
                      TO WS-0020-CLAIM-TBL-TRAN-REJ-FL
                         (WS-0020-CLAIM-INDEX)

                 END-IF
                 IF WS-7030-VALID-FOR-ESCROW = WS-LITERAL-NO
                    MOVE WS-LITERAL-NO
                      TO WS-0020-CLAIM-TBL-ESCROW-FLAG
                         (WS-0020-CLAIM-INDEX)
                 END-IF
           END-SEARCH.

       7030-SEARCH-CLAIM-TBL-EXIT.
           EXIT.

      $IF DEBUG-SW DEFINED

       7030-DISPLAY-RECORD.

           DISPLAY '7030-TYPE 20 RECORD BEING ADDED TO T20 TABLE'
           UPON CONSOLE
           DISPLAY 'RECORD TYPE        : ',
           WS-7030-RECORD-TYPE UPON CONSOLE
           DISPLAY 'REPORTING ORG      : ',
           WS-7030-REPORTING-ORG UPON CONSOLE
           DISPLAY 'LOCATION STATE     : ',
           WS-7030-LOC-STATE UPON CONSOLE
           DISPLAY 'COMPANY            : ',
           WS-7030-COMPANY-COUNTY UPON CONSOLE
           DISPLAY 'POLICY NUMBER      : ',
           WS-7030-POLICY-NUM UPON CONSOLE
           DISPLAY 'CROP YEAR          : ',
           WS-7030-CROP-YEAR UPON CONSOLE
           DISPLAY '--------------------------------'
           UPON CONSOLE
           DISPLAY 'KEY RESERVE 01 (21)  : ',
           WS-7030-KEY-RESERVE-01 UPON CONSOLE
           DISPLAY 'CLAIM NUMBER         : ',
           WS-7030-CLAIM-NUM UPON CONSOLE
           DISPLAY 'REINSURANCE YEAR     : ',
           WS-7030-REINSURE-YR UPON CONSOLE
           DISPLAY 'KEY RESERVE 02 (20)  : ',
           WS-7030-KEY-RESERVE-02 UPON CONSOLE
           DISPLAY '--------------------------------'
           UPON CONSOLE
           DISPLAY 'FILLER 01 (02)       : ',
           WS-7030-FILLER-1 UPON CONSOLE
           DISPLAY 'RECORD NUMBER        : ',
           WS-7030-RECORD-NUM UPON CONSOLE
           DISPLAY '1ST TOTAL REINSURANCE YEAR  : ',
           WS-7030-1ST-TOT-REINS-YR UPON CONSOLE
           DISPLAY '1ST TOTAL P/CR MEMO COMPANY : ',
           WS-7030-1ST-TOT-P-CR-MEMO-CO UPON CONSOLE
           DISPLAY '1ST TOTAL                   : ',
           WS-7030-1ST-TOTAL UPON CONSOLE
           DISPLAY '1ST ESCROW CHECK            : ',
           WS-7030-1ST-ESCROW-CHK UPON CONSOLE
           DISPLAY '1ST TOTAL DATE DRAFT ISSUED : ',
           WS-7030-1ST-TOT-DATE-DRAFT-ISU UPON CONSOLE
           DISPLAY '1ST TOTAL AMOUNT            : ',
           WS-7030-1ST-TOTAL-AMOUNT UPON CONSOLE
           DISPLAY '---------------------------------------------'
           UPON CONSOLE
           DISPLAY '2ND TOTAL REINSURANCE YEAR  : ',
           WS-7030-2ND-TOT-REINS-YR UPON CONSOLE
           DISPLAY '2ND TOTAL P/CR MEMO COMPANY : ',
           WS-7030-2ND-TOT-P-CR-MEMO-CO UPON CONSOLE
           DISPLAY '2ND TOTAL                   : ',
           WS-7030-2ND-TOTAL UPON CONSOLE
           DISPLAY '2ND ESCROW CHECK            : ',
           WS-7030-2ND-ESCROW-CHK UPON CONSOLE
           DISPLAY '2ND TOTAL DATE DRAFT ISSUED : ',
           WS-7030-2ND-TOT-DATE-DRAFT-ISU UPON CONSOLE
           DISPLAY '2ND TOTAL AMOUNT            : ',
           WS-7030-2ND-TOTAL-AMOUNT UPON CONSOLE
           DISPLAY '---------------------------------------------'
           UPON CONSOLE
           DISPLAY '3RD TOTAL REINSURANCE YEAR  : ',
           WS-7030-3RD-TOT-REINS-YR UPON CONSOLE
           DISPLAY '3RD TOTAL P/CR MEMO COMPANY : ',
           WS-7030-3RD-TOT-P-CR-MEMO-CO UPON CONSOLE
           DISPLAY '3RD TOTAL                   : ',
           WS-7030-3RD-TOTAL UPON CONSOLE
           DISPLAY '3RD ESCROW CHECK            : ',
           WS-7030-3RD-ESCROW-CHK UPON CONSOLE
           DISPLAY '3RD TOTAL DATE DRAFT ISSUED : ',
           WS-7030-3RD-TOT-DATE-DRAFT-ISU UPON CONSOLE
           DISPLAY '3RD TOTAL AMOUNT            : ',
           WS-7030-3RD-TOTAL-AMOUNT UPON CONSOLE
           DISPLAY '---------------------------------------------'
           UPON CONSOLE
           DISPLAY '4TH TOTAL REINSURANCE YEAR  : ',
           WS-7030-4TH-TOT-REINS-YR UPON CONSOLE
           DISPLAY '4TH TOTAL P/CR MEMO COMPANY : ',
           WS-7030-4TH-TOT-P-CR-MEMO-CO UPON CONSOLE
           DISPLAY '4TH TOTAL                   : ',
           WS-7030-4TH-TOTAL UPON CONSOLE
           DISPLAY '4TH ESCROW CHECK            : ',
           WS-7030-4TH-ESCROW-CHK UPON CONSOLE
           DISPLAY '4TH TOTAL DATE DRAFT ISSUED : ',
           WS-7030-4TH-TOT-DATE-DRAFT-ISU UPON CONSOLE
           DISPLAY '4TH TOTAL AMOUNT            : ',
           WS-7030-4TH-TOTAL-AMOUNT UPON CONSOLE
           DISPLAY '---------------------------------------------'
           UPON CONSOLE
           DISPLAY 'FILLER 02 (123)             : ',
           WS-7030-FILLER-2 UPON CONSOLE
           DISPLAY '---------------------------------------------'
           UPON CONSOLE
           DISPLAY 'VALID FOR ESCROW FLAG       : ',
           WS-7030-VALID-FOR-ESCROW UPON CONSOLE
           DISPLAY 'RM DATA RECEIPT DATE        : ',
           WS-7030-RM-DATA-RECEIPT-DATE UPON CONSOLE
           DISPLAY 'FSA CONTROL DATE            : ',
           WS-7030-FSA-CONTROL-DATE UPON CONSOLE
           DISPLAY '--------------------------------'
           UPON CONSOLE
           DISPLAY 'FCIC CONTROL TIME    : ',
           WS-7030-FCIC-CONTROL-TIME UPON CONSOLE
           DISPLAY 'FCIC CONTROL DATE    : ',
           WS-7030-FCIC-CONTROL-DATE UPON CONSOLE
           DISPLAY 'REINSURANCE YEAR     : ',
           WS-7030-REINS-YR UPON CONSOLE
           DISPLAY 'BATCH NUMBER         : ',
           WS-7030-BATCH-NO UPON CONSOLE
           DISPLAY 'TRANS SEQUENCE NUM   : ',
           WS-7030-TRAN-SEQ-NO UPON CONSOLE
           DISPLAY 'TRANS REJECTED FLAG  : ',
           WS-7030-TRAN-REJ-FLAG UPON CONSOLE
           DISPLAY 'TRANS SOURCE FLAG    : ',
           WS-7030-TRAN-SOURCE-FLAG UPON CONSOLE
           DISPLAY 'MDAS PROCESS NUMBER  : ',
           WS-7030-MDAS-PROCESS-NO UPON CONSOLE
           DISPLAY 'FILLER 03 (14)       : ',
           WS-7030-FILLER-3 UPON CONSOLE.


       7030-DISPLAY-RECORD-EXIT.
           EXIT.

      $END

