      ***************************************************************
      * File:      M7035.CBL                                        *
      * Author:    Mike Ray and Cheryl D. Wood                      *
      * Date:      8/25/95                                          *
      * Purpose:                                                    *
      *    Adds a single T21 record to the T21 table.               *
      *    if the record exists, the new record replaces it and the *
      *    indicator is set to indicate where the record came from. *
      ***************************************************************

       7035-ADD-T21-RECORD.

      $IF DEBUG-SW DEFINED
           DISPLAY '7035-ADDING T21 RECORD'
           UPON CONSOLE
      $END


      ****************************************************************
      *   INITIALIZE LOCAL WORKING STORAGE                           *
      ****************************************************************
           INITIALIZE WS-7035-WORK

      ****************************************************************
      *   DISPLAY RECORD BEING ADDED                                 *
      ****************************************************************
      $IF DEBUG-SW DEFINED
           PERFORM 7035-DISPLAY-RECORD
              THRU 7035-DISPLAY-RECORD-EXIT
      $END


      ****************************************************************
      *  Check to make sure that the transaction sequence number     *
      *  is passed and that the other control flags are set.         *
      ****************************************************************

           IF WS-7035-TRAN-SEQ-NO IS NOT NUMERIC
              MOVE 7035 TO WS-8020-PARAGRAPH-NO
              MOVE 90001 TO WS-8020-INT-ERROR-NO
              MOVE 'WS-7035-TRAN-SEQ-NO' TO WS-8020-FIELD-NAME
              MOVE SPACES TO WS-8020-BAD-DATA
              MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
              PERFORM 8020-RECORD-INT-ERROR
                 THRU 8020-RECORD-INT-ERROR-EXIT
           END-IF

           IF WS-7035-TRAN-SEQ-NO = ZEROS
              MOVE 7035 TO WS-8020-PARAGRAPH-NO
              MOVE 90003 TO WS-8020-INT-ERROR-NO
              MOVE 'WS-7035-TRAN-SEQ-NO' TO WS-8020-FIELD-NAME
              MOVE WS-7035-TRAN-SEQ-NO TO WS-8020-BAD-DATA
              MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
              PERFORM 8020-RECORD-INT-ERROR
                 THRU 8020-RECORD-INT-ERROR-EXIT
           END-IF

           IF WS-7035-TRAN-SOURCE-FLAG = SPACES
              MOVE 7035 TO WS-8020-PARAGRAPH-NO
              MOVE 90003 TO WS-8020-INT-ERROR-NO
              MOVE 'WS-7035-TRAN-SOURCE-FLAG' TO WS-8020-FIELD-NAME
              MOVE WS-7035-TRAN-SOURCE-FLAG TO WS-8020-BAD-DATA
              MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
              PERFORM 8020-RECORD-INT-ERROR
                 THRU 8020-RECORD-INT-ERROR-EXIT
           END-IF


      ****************************************************************
      *  Look up Crop Policy Type for each crop/type combination     *
      *  so that these values can be placed in the table.            *
      ****************************************************************

      $IF ISAM-SW DEFINED
           IF ERROR-CROP-CD = WS-LITERAL-YES
              OR ERROR-LOC-STATE = WS-LITERAL-YES
              OR ERROR-CROP-TYPE = WS-LITERAL-YES
      **    ** SKIP THE CROP POLICY TYPE LOOKUP
      **    ** GIVE THE RECORD A DEFAULT VALUE-9997-FOR CROP POLICY TYPE
              MOVE '9997' TO WS-7020-CROP-POLICY-TYPE
           ELSE
              INITIALIZE WS-0211-PARAMETERS
              MOVE WS-7035-LOC-STATE TO WS-0211-STATE
              MOVE WS-7035-CROP-CD TO WS-0211-CROP-CD
              MOVE WS-7035-TYPE-CD TO WS-0211-CROP-TYPE

              PERFORM 0211-LOOKUP-CROP-POL-TYPE
                 THRU 0211-LOOKUP-CROP-POL-TYPE-EXIT

              IF WS-0211-CROP-POLICY-TYPE = SPACES
                 MOVE '9997' TO WS-7035-CROP-POLICY-TYPE
              ELSE
                 MOVE WS-0211-CROP-POLICY-TYPE
                   TO WS-7035-CROP-POLICY-TYPE
              END-IF
           END-IF
      $END

      ****************************************************************
      *  Do insertion logic                                          *
      ****************************************************************

           IF WS-0021-T21-REC-COUNT = ZEROS
              SET WS-0021-T21-INDEX TO 1
              PERFORM 7035-ADD-RECORD
                 THRU 7035-ADD-RECORD-EXIT
           ELSE
      *       **** THERE IS CURRENTLY NO NEED FOR REPLACEMENT LOGIC
      *       **** THIS MAY BE NEEDED IF WE GO BACK TO ACCEPTING
      *       **** INCOMPLETE POLICIES.
      *       PERFORM 7035-SEARCH-T21-TBL
      *          THRU 7035-SEARCH-T21-TBL-EXIT
              PERFORM 7035-ADD-RECORD
                 THRU 7035-ADD-RECORD-EXIT
           END-IF

      ****************************************************************
      *  Insertion logic for the Type 21 Unit Table.                 *
      *  This table is later used by inter record edits for Type 21  *
      *  and Type 21N records.                                       *
      ****************************************************************

           PERFORM 7035-UPDATE-UNIT-TBL
              THRU 7035-UPDATE-UNIT-TBL-EXIT

      ****************************************************************
      *  Insertion logic for the Type 21 Crop Table.                 *
      *  This table is later used by inter record edits for Type 21  *
      *  records.                                                    *
      ****************************************************************

           PERFORM 7035-UPDATE-CROP-TBL
              THRU 7035-UPDATE-CROP-TBL-EXIT

      ****************************************************************
      *  Update logic for the Total Indemnity for Claim Table.       *
      *  This table is later used by an inter record edit for        *
      *  Type 20 records.  This logic tallies the total line item    *
      *  indemnity.                                                  *
      ****************************************************************

           PERFORM 7035-UPDATE-CLAIM-TBL
              THRU 7035-UPDATE-CLAIM-TBL-EXIT

      ****************************************************************
      *  Initialize Input Fields                                     *
      ****************************************************************

           INITIALIZE WS-7035-CROP-POLICY-TYPE
           INITIALIZE WS-7035-INSURANCE-PLAN-CD
           INITIALIZE WS-7035-TYPE-21.


       7035-ADD-T21-RECORD-EXIT.
           EXIT.

      ****************************************************************
      *  THIS PARAGRAPH DOES A SEARCH OF THE RECORD TYPE 21          *
      *  RECORDS TABLE. WHEN A MATCH IS FOUND, THE TABLE IS UPDATED  *
      *  WITH THE NEW TRANSACTION RECORD CONTENTS.                   *
      ****************************************************************

       7035-SEARCH-T21-TBL.

           SET WS-0021-T21-INDEX TO 1.

           SEARCH WS-0021-T21-RECORD VARYING WS-0021-T21-INDEX
                AT END
                    PERFORM 7035-ADD-RECORD
                       THRU 7035-ADD-RECORD-EXIT
                    GO TO 7035-SEARCH-T21-TBL-EXIT
                WHEN (WS-0021-TBL-POLICY-NO (WS-0021-T21-INDEX)
                     IS EQUAL WS-7035-POLICY-NO)
                 AND (WS-0021-TBL-CLAIM-NUM (WS-0021-T21-INDEX)
                     IS EQUAL WS-7035-CLAIM-NUM)
                 AND (WS-0021-TBL-CROP-CD (WS-0021-T21-INDEX)
                     IS EQUAL WS-7035-CROP-CD)
                 AND (WS-0021-TBL-TYPE-CD (WS-0021-T21-INDEX)
                     IS EQUAL WS-7035-TYPE-CD)
                 AND (WS-0021-TBL-PRACTICE-CD (WS-0021-T21-INDEX)
                     IS EQUAL WS-7035-PRACTICE-CD)
      $IF DEBUG-SW DEFINED
           DISPLAY 'REPLACING TYPE 21 RECORD' UPON CONSOLE
      $END
                     MOVE WS-7035-CROP-POLICY-TYPE
                       TO WS-0021-TBL-CROP-POLICY-TY(WS-0021-T21-INDEX)
                     MOVE WS-7035-TYPE-21
                       TO WS-0021-TBL-TYPE-21 (WS-0021-T21-INDEX)
           END-SEARCH.

       7035-SEARCH-T21-TBL-EXIT.
           EXIT.

      ****************************************************************
      *  THIS PARAGRAPH TEST THE TABLE SIZE LIMIT BEFORE ADDING AN   *
      *  ADDITIONAL RECORD. WHEN THE MAXIMUM TABLE SIZE IS REACHED,  *
      *  MESSAGES ARE DISPLAYED AND EXECUTION IS TERMINATED -        *
      *  OTHERWISE THE NEW TRANSACTION RECORD IS ADDED TO THE TABLE. *
      ****************************************************************

       7035-ADD-RECORD.

           IF WS-0021-T21-REC-COUNT >= WS-0021-MAX-SIZE
              DISPLAY 'REC TYPE 21 T21 TABLE LIMIT WILL BE EXCEEDED'
              UPON CONSOLE
              DISPLAY ' WITH THE ADDITION OF THIS RECORD'
              UPON CONSOLE
              DISPLAY '**********************************'
              UPON CONSOLE
              DISPLAY 'MAXIMUM TABLE SIZE IS ' WS-0021-MAX-SIZE
                      ' RECORDS' UPON CONSOLE
              PERFORM 0800-ABORT-PROGRAM
                 THRU 0800-ABORT-PROGRAM-EXIT
           ELSE
              ADD 1 TO WS-0021-T21-REC-COUNT
              SET WS-0021-T21-INDEX TO WS-0021-T21-REC-COUNT
              MOVE WS-7035-CROP-POLICY-TYPE
                TO WS-0021-TBL-CROP-POLICY-TY(WS-0021-T21-INDEX)
              MOVE WS-7035-TYPE-21
                TO WS-0021-TBL-TYPE-21(WS-0021-T21-INDEX)

      *            UPDATE TABLE STATISTICS
              IF WS-0021-T21-REC-COUNT > WS-0008-T21-MAX-TABLE-SIZE
                 MOVE WS-0021-T21-REC-COUNT
                   TO WS-0008-T21-MAX-TABLE-SIZE
              END-IF
           END-IF.

       7035-ADD-RECORD-EXIT.
           EXIT.


       7035-UPDATE-UNIT-TBL.

      *****************************************************
      *              CHECK INPUT FIELDS                   *
      *****************************************************

           IF WS-7035-CLAIM-NUM IS NOT NUMERIC
              GO TO 7035-UPDATE-UNIT-TBL-EXIT
           END-IF

           IF WS-7035-CROP-CD IS NOT NUMERIC
              GO TO 7035-UPDATE-UNIT-TBL-EXIT
           END-IF

           IF WS-7035-LOCATION-COUNTY IS NOT NUMERIC
              GO TO 7035-UPDATE-UNIT-TBL-EXIT
           END-IF

           IF WS-7035-OPTIONAL-UNIT IS NOT NUMERIC
              GO TO 7035-UPDATE-UNIT-TBL-EXIT
           END-IF

           IF WS-7035-INSURANCE-PLAN-CD IS NOT NUMERIC
              GO TO 7035-UPDATE-UNIT-TBL-EXIT
           END-IF

           IF WS-7035-INDEMNITY IS NOT NUMERIC
              GO TO 7035-UPDATE-UNIT-TBL-EXIT
           END-IF

           IF WS-7035-DETERMINED-ACRES IS NOT NUMERIC
              GO TO 7035-UPDATE-UNIT-TBL-EXIT
           END-IF

           IF WS-7035-STAGE-GUARANTEE IS NOT NUMERIC
              GO TO 7035-UPDATE-UNIT-TBL-EXIT
           END-IF

           IF WS-7035-LOSS-GUARANTEE IS NOT NUMERIC
              GO TO 7035-UPDATE-UNIT-TBL-EXIT
           END-IF


      ****************************************************************
      *  DO INSERTION LOGIC.                                         *
      ****************************************************************

           IF WS-0021-UNIT-REC-COUNT = ZEROS
              SET WS-0021-UNIT-INDEX TO 1
              PERFORM 7035-ADD-UNIT-RECORD
                 THRU 7035-ADD-UNIT-RECORD-EXIT
           ELSE
              MOVE WS-LITERAL-NO TO WS-7035-MATCH-FOUND
              PERFORM 7035-SEARCH-UNIT-TBL
                 THRU 7035-SEARCH-UNIT-TBL-EXIT
                 WITH TEST AFTER
              VARYING WS-0021-UNIT-INT-INDEX FROM 1 BY 1
              UNTIL WS-0021-UNIT-INT-INDEX = WS-0021-UNIT-REC-COUNT
               OR WS-7035-MATCH-FOUND = WS-LITERAL-YES
              IF WS-7035-MATCH-FOUND = WS-LITERAL-YES
                PERFORM 7035-ADD-UNIT-RECORD
                  THRU 7035-ADD-UNIT-RECORD-EXIT
              END-IF
           END-IF.


       7035-UPDATE-UNIT-TBL-EXIT.
           EXIT.

      ****************************************************************
      *  THIS PARAGRAPH TESTS THE TABLE SIZE LIMIT BEFORE ADDING AN  *
      *  ADDITIONAL RECORD. WHEN THE MAXIMUM TABLE SIZE IS REACHED,  *
      *  MESSAGES ARE DISPLAYED AND EXECUTION IS TERMINATED -        *
      *  OTHERWISE THE NEW UNIT RECORD IS ADDED TO THE TABLE.        *
      *                                                              *
      *  IF THE RECORD IS UNDER A GROUP INSURANCE PLAN, THIS PLAN CD *
      *  IS ADDED TO THE RECORD.  OTHERWISE EACH NEW RECORD IS GIVEN *
      *  A PLAN CD = 98 (NOT APPLICABLE).                            *
      ****************************************************************

       7035-ADD-UNIT-RECORD.

      $IF DEBUG-SW DEFINED
           DISPLAY '7035-ADDING TO T21 UNIT TABLE'
           UPON CONSOLE
      $END
           IF WS-0021-UNIT-REC-COUNT >= WS-0021-UNIT-MAX-SIZE
              DISPLAY 'REC T21 UNIT TABLE LIMIT WILL BE EXCEEDED'
              UPON CONSOLE
              DISPLAY ' WITH THE ADDITION OF THIS RECORD'
              UPON CONSOLE
              DISPLAY '**********************************'
              UPON CONSOLE
              DISPLAY 'MAXIMUM TABLE SIZE IS ' WS-0021-UNIT-MAX-SIZE
              ' RECORDS' UPON CONSOLE
              PERFORM 0800-ABORT-PROGRAM
                 THRU 0800-ABORT-PROGRAM-EXIT
           ELSE
              ADD 1 TO WS-0021-UNIT-REC-COUNT
              SET WS-0021-UNIT-INDEX TO WS-0021-UNIT-REC-COUNT
              MOVE WS-7035-CLAIM-NUM
                TO WS-0021-UNIT-TBL-CLAIM-NUMBER(WS-0021-UNIT-INDEX)
              MOVE WS-7035-CROP-CD
                TO WS-0021-UNIT-TBL-CROP(WS-0021-UNIT-INDEX)
              MOVE WS-7035-TYPE-CD
                TO WS-0021-UNIT-TBL-CROP-TYPE(WS-0021-UNIT-INDEX)
              MOVE WS-7035-LOCATION-COUNTY
                TO WS-0021-UNIT-TBL-LOC-COUNTY(WS-0021-UNIT-INDEX)
              MOVE WS-7035-BASIC-UNIT-NUM
                TO WS-0021-UNIT-TBL-BASIC-UNIT(WS-0021-UNIT-INDEX)
              MOVE WS-7035-OPTIONAL-UNIT
                TO WS-0021-UNIT-TBL-OPTIONAL-UNIT(WS-0021-UNIT-INDEX)
              MOVE WS-7035-SIMPLIFIED-CLM-FLG
                TO WS-0021-UNIT-TBL-SIMPLE-CLAIM(WS-0021-UNIT-INDEX)
              IF WS-7035-INSURANCE-PLAN-CD = WS-LITERAL-GRP
                 MOVE WS-7035-INSURANCE-PLAN-CD
                   TO WS-0021-UNIT-TBL-INS-PLAN-CD(WS-0021-UNIT-INDEX)
              ELSE
                 MOVE 98
                   TO WS-0021-UNIT-TBL-INS-PLAN-CD(WS-0021-UNIT-INDEX)
              END-IF
              MOVE WS-7035-INDEMNITY
                TO WS-0021-UNIT-TBL-TOT-INDEMNITY(WS-0021-UNIT-INDEX)
              MOVE WS-7035-DETERMINED-ACRES
                TO WS-0021-UNIT-TBL-TOT-DET-ACRE(WS-0021-UNIT-INDEX)
              IF WS-7035-STAGE-CD = WS-LITERAL-REPLANTED
                 MOVE WS-7035-DETERMINED-ACRES
                   TO WS-0021-UNIT-TBL-REPLANT-ACRES(WS-0021-UNIT-INDEX)
              ELSE
                 MOVE ZEROS
                   TO WS-0021-UNIT-TBL-REPLANT-ACRES(WS-0021-UNIT-INDEX)
              END-IF
              MOVE WS-7035-STAGE-GUARANTEE
                TO WS-0021-UNIT-TBL-STAGE-GUAR(WS-0021-UNIT-INDEX)
              MOVE WS-7035-LOSS-GUARANTEE
                TO WS-0021-UNIT-TBL-LOSS-GUAR(WS-0021-UNIT-INDEX)

      *            UPDATE TABLE STATISTICS
              IF WS-0021-UNIT-REC-COUNT >
                 WS-0008-T21-UNIT-MAX-TBL-SIZE
                 MOVE WS-0021-UNIT-REC-COUNT
                   TO WS-0008-T21-UNIT-MAX-TBL-SIZE
              END-IF
           END-IF.


       7035-ADD-UNIT-RECORD-EXIT.
           EXIT.


      ****************************************************************
      *  THIS PARAGRAPH DOES A SEARCH OF THE TYPE 21 UNIT TABLE.     *
      *  WHEN A MATCH IS FOUND, THE TOTAL INDEMNITY AND TOTAL        *
      *  DETERMINED ACRES ARE INCREMENTED.                           *
      *                                                              *
      *  IF THE INCOMING STAGE GUARANTEE FOR THE UNIT                *
      *  IS GREATER THAN THE ONE STORED IN TABLE, REPLACE THE TABLE  *
      *  VALUE.                                                      *
      *                                                              *
      *  IF THE INCOMING LOSS GUARANTEE FOR THE UNIT IS GREATER THAN *
      *  THE ONE STORED IN THE TABLE, REPLACE THE TABLE VALUE.       *
      ****************************************************************

       7035-SEARCH-UNIT-TBL.

           SET WS-0021-UNIT-INDEX TO WS-0021-UNIT-INT-INDEX

           IF (WS-0021-UNIT-TBL-CLAIM-NUMBER(WS-0021-UNIT-INDEX)
              = WS-7035-CLAIM-NUM) AND
              (WS-0021-UNIT-TBL-CROP(WS-0021-UNIT-INDEX)
              = WS-7035-CROP-CD) AND
              (WS-0021-UNIT-TBL-CROP-TYPE(WS-0021-UNIT-INDEX)
              = WS-7035-TYPE-CD) AND
              (WS-0021-UNIT-TBL-LOC-COUNTY(WS-0021-UNIT-INDEX)
              = WS-7035-LOCATION-COUNTY) AND
              (WS-0021-UNIT-TBL-BASIC-UNIT(WS-0021-UNIT-INDEX)
              = WS-7035-BASIC-UNIT-NUM) AND
              (WS-0021-UNIT-TBL-OPTIONAL-UNIT(WS-0021-UNIT-INDEX)
              = WS-7035-OPTIONAL-UNIT)
              MOVE WS-LITERAL-YES TO WS-7035-MATCH-FOUND

      $IF DEBUG-SW DEFINED
           DISPLAY 'UPDATING TYPE 21 UNIT TABLE'
           UPON CONSOLE
      $END
              ADD WS-7035-INDEMNITY
               TO WS-0021-UNIT-TBL-TOT-INDEMNITY
                  (WS-0021-UNIT-INDEX)

              ADD WS-7035-DETERMINED-ACRES
               TO WS-0021-UNIT-TBL-TOT-DET-ACRE(WS-0021-UNIT-INDEX)

              IF WS-7035-STAGE-CD = WS-LITERAL-REPLANTED
                 ADD WS-7035-DETERMINED-ACRES
                  TO WS-0021-UNIT-TBL-REPLANT-ACRES
                     (WS-0021-UNIT-INDEX)
              END-IF

              IF WS-7035-STAGE-GUARANTEE >
                 WS-0021-UNIT-TBL-STAGE-GUAR(WS-0021-UNIT-INDEX)
                 MOVE WS-7035-STAGE-GUARANTEE
                   TO WS-0021-UNIT-TBL-STAGE-GUAR
                      (WS-0021-UNIT-INDEX)
              END-IF

              IF WS-7035-LOSS-GUARANTEE >
                 WS-0021-UNIT-TBL-LOSS-GUAR(WS-0021-UNIT-INDEX)
                 MOVE WS-7035-LOSS-GUARANTEE
                   TO WS-0021-UNIT-TBL-LOSS-GUAR(WS-0021-UNIT-INDEX)
              END-IF
           END-IF.

       7035-SEARCH-UNIT-TBL-EXIT.
           EXIT.


       7035-UPDATE-CROP-TBL.

      *****************************************************
      *              CHECK INPUT FIELDS                   *
      *****************************************************

           IF WS-7035-CLAIM-NUM IS NOT NUMERIC
              MOVE 7035 TO WS-8020-PARAGRAPH-NO
              MOVE 90003 TO WS-8020-INT-ERROR-NO
              MOVE 'WS-7035-CLAIM-NUM' TO WS-8020-FIELD-NAME
              MOVE WS-7035-CLAIM-NUM TO WS-8020-BAD-DATA
              MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
              PERFORM 8020-RECORD-INT-ERROR
                 THRU 8020-RECORD-INT-ERROR-EXIT
              GO TO 7035-UPDATE-CROP-TBL-EXIT
           END-IF

           IF WS-7035-CROP-CD IS NOT NUMERIC
              MOVE 7035 TO WS-8020-PARAGRAPH-NO
              MOVE 90001 TO WS-8020-INT-ERROR-NO
              MOVE 'WS-7035-CROP-CD' TO WS-8020-FIELD-NAME
              MOVE WS-7035-CROP-CD TO WS-8020-BAD-DATA
              MOVE WS-LITERAL-NO TO WS-8020-ABORT-PROGRAM
              PERFORM 8020-RECORD-INT-ERROR
                 THRU 8020-RECORD-INT-ERROR-EXIT
              GO TO 7035-UPDATE-CROP-TBL-EXIT
           END-IF

           IF WS-7035-INDEMNITY IS NOT NUMERIC
              MOVE 7035 TO WS-8020-PARAGRAPH-NO
              MOVE 90003 TO WS-8020-INT-ERROR-NO
              MOVE 'WS-7035-INDEMNITY' TO WS-8020-FIELD-NAME
              MOVE WS-7035-INDEMNITY TO WS-8020-BAD-DATA
              MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
              PERFORM 8020-RECORD-INT-ERROR
                 THRU 8020-RECORD-INT-ERROR-EXIT
              GO TO 7035-UPDATE-CROP-TBL-EXIT
           END-IF

           IF WS-7035-DETERMINED-ACRES IS NOT NUMERIC
              MOVE 7035 TO WS-8020-PARAGRAPH-NO
              MOVE 90003 TO WS-8020-INT-ERROR-NO
              MOVE 'WS-7035-DETERMINED-ACRES' TO WS-8020-FIELD-NAME
              MOVE SPACES TO WS-8020-BAD-DATA
              MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
              PERFORM 8020-RECORD-INT-ERROR
                 THRU 8020-RECORD-INT-ERROR-EXIT
              GO TO 7035-UPDATE-CROP-TBL-EXIT
           END-IF


      ****************************************************************
      *  DO INSERTION LOGIC.                                         *
      ****************************************************************

           IF WS-0021-CROP-REC-COUNT = ZEROS
              SET WS-0021-CROP-INDEX TO 1
              PERFORM 7035-ADD-CROP-RECORD
                 THRU 7035-ADD-CROP-RECORD-EXIT
           ELSE
              MOVE WS-LITERAL-NO TO WS-7035-MATCH-FOUND
              PERFORM 7035-SEARCH-CROP-TBL
                 THRU 7035-SEARCH-CROP-TBL-EXIT
                 WITH TEST AFTER
              VARYING WS-0021-CROP-INT-INDEX FROM 1 BY 1
                 UNTIL WS-0021-CROP-INT-INDEX = WS-0021-CROP-REC-COUNT
                 OR WS-7035-MATCH-FOUND = WS-LITERAL-YES
              IF WS-7035-MATCH-FOUND = WS-LITERAL-NO
                 PERFORM 7035-ADD-CROP-RECORD
                 THRU 7035-ADD-CROP-RECORD-EXIT
              END-IF

           END-IF.


       7035-UPDATE-CROP-TBL-EXIT.
           EXIT.

      ****************************************************************
      *  THIS PARAGRAPH TESTS THE TABLE SIZE LIMIT BEFORE ADDING AN  *
      *  ADDITIONAL RECORD. WHEN THE MAXIMUM TABLE SIZE IS REACHED,  *
      *  MESSAGES ARE DISPLAYED AND EXECUTION IS TERMINATED -        *
      *  OTHERWISE THE NEW CROP RECORD IS ADDED TO THE TABLE.        *
      ****************************************************************

       7035-ADD-CROP-RECORD.

      $IF DEBUG-SW DEFINED
           DISPLAY '7035-ADDING TO T21 CROP TABLE'
           UPON CONSOLE
      $END

           IF WS-0021-CROP-REC-COUNT >= WS-0021-CROP-MAX-SIZE
              DISPLAY 'REC T21 CROP TABLE LIMIT WILL BE EXCEEDED'
              UPON CONSOLE
              DISPLAY ' WITH THE ADDITION OF THIS RECORD'
              UPON CONSOLE
              DISPLAY '**********************************'
              UPON CONSOLE
              DISPLAY 'MAXIMUM TABLE SIZE IS ' WS-0021-CROP-MAX-SIZE
              ' RECORDS' UPON CONSOLE
              PERFORM 0800-ABORT-PROGRAM
                 THRU 0800-ABORT-PROGRAM-EXIT
           ELSE
              ADD 1 TO WS-0021-CROP-REC-COUNT
              SET WS-0021-CROP-INDEX TO WS-0021-CROP-REC-COUNT
              MOVE WS-7035-CLAIM-NUM
                TO WS-0021-CROP-TBL-CLAIM-NUMBER(WS-0021-CROP-INDEX)
              MOVE WS-7035-CROP-CD
                TO WS-0021-CROP-TBL-CROP(WS-0021-CROP-INDEX)
              MOVE WS-7035-SIMPLIFIED-CLM-FLG
                TO WS-0021-CROP-TBL-SIMPLE-CLAIM(WS-0021-CROP-INDEX)
              MOVE WS-7035-INDEMNITY
                TO WS-0021-CROP-TBL-TOT-INDEMNITY(WS-0021-CROP-INDEX)
              MOVE WS-7035-DETERMINED-ACRES
                TO WS-0021-CROP-TBL-TOT-DET-ACRE(WS-0021-CROP-INDEX)

      *            UPDATE TABLE STATISTICS
              IF WS-0021-CROP-REC-COUNT >
                 WS-0008-T21-CROP-MAX-TBL-SIZE
                 MOVE WS-0021-CROP-REC-COUNT
                   TO WS-0008-T21-CROP-MAX-TBL-SIZE
              END-IF
           END-IF.


       7035-ADD-CROP-RECORD-EXIT.
           EXIT.


      ****************************************************************
      *  THIS PARAGRAPH DOES A SEARCH OF THE TYPE 21 CROP TABLE.     *
      *  WHEN A MATCH IS FOUND, THE TOTAL INDEMNITY AND TOTAL        *
      *  DETERMINED ACRES ARE INCREMENTED.                           *
      ****************************************************************

       7035-SEARCH-CROP-TBL.

           SET WS-0021-CROP-INDEX TO WS-0021-CROP-INT-INDEX

           IF WS-0021-CROP-TBL-CLAIM-NUMBER(WS-0021-CROP-INDEX)
              = WS-7035-CLAIM-NUM
              MOVE WS-LITERAL-YES TO WS-7035-MATCH-FOUND
      $IF DEBUG-SW DEFINED
           DISPLAY 'UPDATING TYPE 21 CROP TABLE'
           UPON CONSOLE
      $END
              ADD WS-7035-INDEMNITY
               TO WS-0021-CROP-TBL-TOT-INDEMNITY
                  (WS-0021-CROP-INDEX)
              ADD WS-7035-DETERMINED-ACRES
               TO WS-0021-CROP-TBL-TOT-DET-ACRE(WS-0021-CROP-INDEX)
           END-IF.

       7035-SEARCH-CROP-TBL-EXIT.
           EXIT.


       7035-UPDATE-CLAIM-TBL.

      *****************************************************
      *              CHECK INPUT FIELDS                   *
      *****************************************************

           IF WS-7035-CLAIM-NUM IS NOT NUMERIC
              MOVE 7035 TO WS-8020-PARAGRAPH-NO
              MOVE 90003 TO WS-8020-INT-ERROR-NO
              MOVE 'WS-7035-CLAIM-NUM' TO WS-8020-FIELD-NAME
              MOVE WS-7035-CLAIM-NUM TO WS-8020-BAD-DATA
              MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
              PERFORM 8020-RECORD-INT-ERROR
                 THRU 8020-RECORD-INT-ERROR-EXIT
              GO TO 7035-UPDATE-CLAIM-TBL-EXIT
           END-IF

           IF WS-7035-INDEMNITY IS NOT NUMERIC
              MOVE 7035 TO WS-8020-PARAGRAPH-NO
              MOVE 90003 TO WS-8020-INT-ERROR-NO
              MOVE 'WS-7035-INDEMNITY' TO WS-8020-FIELD-NAME
              MOVE WS-7035-INDEMNITY TO WS-8020-BAD-DATA
              MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
              PERFORM 8020-RECORD-INT-ERROR
                 THRU 8020-RECORD-INT-ERROR-EXIT
              GO TO 7035-UPDATE-CLAIM-TBL-EXIT
           END-IF


      ****************************************************************
      *  DO INSERTION LOGIC.                                         *
      ****************************************************************

           IF WS-0020-CLAIM-REC-COUNT = ZEROS
      *    ** THIS SHOULD NOT HAPPEN.  IT MEANS THAT THERE ARE NO
      *    ** TYPE 20 RECORDS ASSOCIATED WITH THE TYPE 21S
      *    ** THIS ERROR IS RECORDED IN IR3400-VAL-RELATED-TYPE-20
              CONTINUE
           ELSE
              MOVE WS-LITERAL-NO TO WS-7035-MATCH-FOUND
              PERFORM 7035-SEARCH-CLAIM-TBL
                 THRU 7035-SEARCH-CLAIM-TBL-EXIT
                 WITH TEST AFTER
              VARYING WS-0020-CLAIM-INT-INDEX FROM 1 BY 1
                UNTIL WS-0020-CLAIM-INT-INDEX = WS-0020-CLAIM-REC-COUNT
                OR WS-7035-MATCH-FOUND = WS-LITERAL-YES
           END-IF.


       7035-UPDATE-CLAIM-TBL-EXIT.
           EXIT.


       7035-SEARCH-CLAIM-TBL.
      ****************************************************************
      *  THIS PARAGRAPH DOES A SEARCH OF THE CLAIM TOTAL INDEMNITY   *
      *  TABLE.  WHEN A MATCH IS FOUND, THE TOTAL LOSS LINE INDEMNITY*
      *  IS INCREMENTED.                                             *
      ****************************************************************

           SET WS-0020-CLAIM-INDEX TO WS-0020-CLAIM-INT-INDEX.

           IF (WS-0020-CLAIM-TBL-CLAIM-NO(WS-0020-CLAIM-INDEX)
              = WS-7035-CLAIM-NUM)
              MOVE WS-LITERAL-YES TO WS-7035-MATCH-FOUND
      $IF DEBUG-SW DEFINED
           DISPLAY 'UPDATING CLAIM TOTAL INDEMNITY RECORD'
           UPON CONSOLE
      $END
              ADD WS-7035-INDEMNITY
               TO WS-0020-CLAIM-TBL-LOSS-TOT(WS-0020-CLAIM-INDEX)
              IF WS-7035-TRAN-REJECTED-FLAG = WS-LITERAL-YES
                 MOVE WS-LITERAL-YES
                   TO WS-0020-CLAIM-TBL-TRAN-REJ-FL
                      (WS-0020-CLAIM-INDEX)
              END-IF
              IF WS-7035-VALID-FOR-ESCROW = WS-LITERAL-NO
                 MOVE WS-LITERAL-NO
                   TO WS-0020-CLAIM-TBL-ESCROW-FLAG
                      (WS-0020-CLAIM-INDEX)
              END-IF
           END-IF.

       7035-SEARCH-CLAIM-TBL-EXIT.
           EXIT.

      $IF DEBUG-SW DEFINED

       7035-DISPLAY-RECORD.

           DISPLAY '7035-TYPE 21 RECORD BEING ADDED TO THE T21 TABLE'
           UPON CONSOLE
           DISPLAY 'RECORD TYPE        : ',
           WS-7035-RECORD-TYPE UPON CONSOLE
           DISPLAY 'REPORTING ORG      : ',
           WS-7035-REPORTING-ORG UPON CONSOLE
           DISPLAY 'LOCATION STATE     : ',
           WS-7035-LOC-STATE UPON CONSOLE
           DISPLAY 'COMPANY            : ',
           WS-7035-COMPANY-COUNTY UPON CONSOLE
           DISPLAY 'POLICY NUMBER      : ',
           WS-7035-POLICY-NUM UPON CONSOLE
           DISPLAY 'CROP YEAR          : ',
           WS-7035-CROP-YEAR UPON CONSOLE
           DISPLAY '--------------------------------'
           UPON CONSOLE
           DISPLAY 'CROP CODE          : ',
           WS-7035-CROP-CD UPON CONSOLE
           DISPLAY 'INSURANCE PLAN CD  : ',
           WS-7035-INSURANCE-PLAN-CD UPON CONSOLE
           DISPLAY 'LOCATION COUNTY    : ',
           WS-7035-LOCATION-COUNTY UPON CONSOLE
           DISPLAY 'UNIT NUMBER        : ',
           WS-7035-UNIT-NUMBER UPON CONSOLE
           DISPLAY 'TYPE CODE          : ',
           WS-7035-TYPE-CD UPON CONSOLE
           DISPLAY 'PRACTICE CODE      : ',
           WS-7035-PRACTICE-CD UPON CONSOLE
           DISPLAY 'COVERAGE FLAG      : ',
           WS-7035-COVERAGE-FLG UPON CONSOLE
           DISPLAY 'CLAIM NUMBER       : ',
           WS-7035-CLAIM-NUM UPON CONSOLE
           DISPLAY '--------------------------------'
           UPON CONSOLE
           DISPLAY 'KEY RESERVE          : ',
           WS-7035-KEY-RESERVE UPON CONSOLE
           DISPLAY 'FILLER 01 (02)       : ',
           WS-7035-FILLER-1 UPON CONSOLE
           DISPLAY 'RECORD NUMBER        : ',
           WS-7035-RECORD-NUM UPON CONSOLE
           DISPLAY 'TYPE 11 RECORD NUM   : ',
           WS-7035-TYPE-11-REC-NUM UPON CONSOLE
           DISPLAY 'ADJUSTER ID CODE     : ',
           WS-7035-ADJUSTER-ID-CD UPON CONSOLE
           DISPLAY 'RATE CLASSIFICATION  : ',
           WS-7035-RATE-CLASS UPON CONSOLE
           DISPLAY 'STAGE CODE           : ',
           WS-7035-STAGE-CD UPON CONSOLE
           DISPLAY '100% REPLANT FLAG    : ',
           WS-7035-100-PCT-REPLANT-FL UPON CONSOLE
           DISPLAY 'STAGE GUARANTEE/ACRE : ',
           WS-7035-STAGE-GUAR-PER-ACRE UPON CONSOLE
           DISPLAY 'DETERMINED ACRES     : ',
           WS-7035-DETERMINED-ACRES UPON CONSOLE
           DISPLAY 'LIABILITY FACTOR     : ',
           WS-7035-LIABILITY-FACTOR UPON CONSOLE
           DISPLAY 'LOSS GUARANTEE       : ',
           WS-7035-LOSS-GUARANTEE UPON CONSOLE
           DISPLAY 'PRODUCTION TO COUNT  : ',
           WS-7035-PROD-TO-CNT UPON CONSOLE
           DISPLAY 'FARM UNIT DEFICIENCY : ',
           WS-7035-FARM-UNIT-DEFIC UPON CONSOLE
           DISPLAY 'INSURED SHARE        : ',
           WS-7035-INSURED-SHARE UPON CONSOLE
           DISPLAY 'GRP PAYMENT CALC FCTR: ',
           WS-7035-GRP-PMT-CALC-FCTR UPON CONSOLE
           DISPLAY 'INDEMNITY            : ',
           WS-7035-INDEMNITY UPON CONSOLE
           DISPLAY 'HARVESTED PRODUCTION : ',
           WS-7035-HARVEST-PROD UPON CONSOLE
           DISPLAY 'SUGAR FACTOR         : ',
           WS-7035-SUGAR-FCTR UPON CONSOLE
           DISPLAY 'AUDIT CORRECTION     : ',
           WS-7035-AUDIT-CORR UPON CONSOLE
           DISPLAY 'PRIMARY MONTH        : ',
           WS-7035-PRIMARY-MONTH UPON CONSOLE
           DISPLAY 'SECONDARY MONTH      : ',
           WS-7035-SECONDARY-MONTH UPON CONSOLE
           DISPLAY 'PRIMARY CAUSE        : ',
           WS-7035-PRIMARY-CAUSE UPON CONSOLE
           DISPLAY 'PRIMARY PERCENT      : ',
           WS-7035-PRIMARY-PCT UPON CONSOLE
           DISPLAY 'SECONDARY CAUSE      : ',
           WS-7035-SECONDARY-CAUSE UPON CONSOLE
           DISPLAY 'SIMPLIFIED CLAIM FLG : ',
           WS-7035-SIMPLIFIED-CLM-FLG UPON CONSOLE
           DISPLAY 'FARM SERIAL NUMBER   : ',
           WS-7035-FARM-SERIAL-NUM UPON CONSOLE
           DISPLAY 'REVENUE CVG LEVEL %  : ',
           WS-7035-REVENUE-CVG-LEVEL-PCT UPON CONSOLE
           DISPLAY 'GUARANTEE RED PCT    : ',
           WS-7035-GUARANTEE-RED-PCT UPON CONSOLE
           DISPLAY 'DOLLAR AMT INS       : ',
           WS-7035-DOLLAR-AMT-INSUR UPON CONSOLE
           DISPLAY '--------------------------------'
           UPON CONSOLE
           DISPLAY 'FILLER 02 (59)       : ',
           WS-7035-FILLER-2 UPON CONSOLE
           DISPLAY 'VALID FOR ESCROW     : ',
           WS-7035-VALID-FOR-ESCROW UPON CONSOLE
           DISPLAY '1996 CROP CODE       : ',
           WS-7035-1996-CROP-CODE UPON CONSOLE
           DISPLAY '1996 TYPE CODE       : ',
           WS-7035-1996-TYPE-CODE UPON CONSOLE
           DISPLAY 'RM DATA RECEIPT DATE : ',
           WS-7035-RM-DATA-RECEIPT-DATE UPON CONSOLE
           DISPLAY 'YIELD                : ',
           WS-7035-YIELD UPON CONSOLE
           DISPLAY 'QUOTA                : ',
           WS-7035-QUOTA UPON CONSOLE
           DISPLAY 'COVERAGE LEVEL PCT   : ',
           WS-7035-COVERAGE-LEVEL-PCT UPON CONSOLE
           DISPLAY 'PRICE ELECTION       : ',
           WS-7035-PRICE-ELECTION UPON CONSOLE
           DISPLAY 'FILLER 3 (28)        : ',
           WS-7035-FILLER-3 UPON CONSOLE.
           DISPLAY 'FSA CONTROL DATE     : ',
           WS-7035-FSA-CONTROL-DATE UPON CONSOLE
           DISPLAY '--------------------------------'
           UPON CONSOLE
           DISPLAY 'FCIC CONTROL TIME    : ',
           WS-7035-FCIC-CONTROL-TIME UPON CONSOLE
           DISPLAY 'FCIC CONTROL DATE    : ',
           WS-7035-FCIC-CONTROL-DATE UPON CONSOLE
           DISPLAY 'REINSURANCE YEAR     : ',
           WS-7035-REINS-YR UPON CONSOLE
           DISPLAY 'BATCH NUMBER         : ',
           WS-7035-BATCH-NO UPON CONSOLE
           DISPLAY 'TRANS SEQUENCE NUM   : ',
           WS-7035-TRAN-SEQ-NO UPON CONSOLE
           DISPLAY 'TRANS REJECTED FLAG  : ',
           WS-7035-TRAN-REJECTED-FLAG UPON CONSOLE
           DISPLAY 'TRANS SOURCE FLAG    : ',
           WS-7035-TRAN-SOURCE-FLAG UPON CONSOLE
           DISPLAY 'MDAS PROCESS NUMBER  : ',
           WS-7035-MDAS-PROCESS-NO UPON CONSOLE
           DISPLAY 'FILLER 4 (14)        : ',
           WS-7035-FILLER-4 UPON CONSOLE.


       7035-DISPLAY-RECORD-EXIT.
           EXIT.

      $END

