      ***************************************************************
      ***************************************************************
      * File:      M7040.CBL                                        *
      * Author:    Mike Ray and Cheryl D. Wood                      *
      * Date:      8/25/95                                          *
      * Purpose:                                                    *
      *    Adds a single T50 record to the T50 table.               *
      *    if the record exists, the new record replaces it and the *
      *    indicator is set to indicate where the record came from. *
      ***************************************************************

       7040-ADD-T50-RECORD.

      $IF DEBUG-SW DEFINED
           DISPLAY '7040-ADDING T50 RECORD'
           UPON CONSOLE
      $END

      ****************************************************************
      *  Check to make sure that the transaction sequence number     *
      *  is passed and that the other control flags are set.         *
      ****************************************************************

           IF WS-7040-TRAN-SEQ-NO IS NOT NUMERIC
              MOVE 7040 TO WS-8020-PARAGRAPH-NO
              MOVE 90001 TO WS-8020-INT-ERROR-NO
              MOVE 'WS-7040-TRAN-SEQ-NO' TO WS-8020-FIELD-NAME
              MOVE WS-7040-TRAN-SEQ-NO TO WS-8020-BAD-DATA
              MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
              PERFORM 8020-RECORD-INT-ERROR
                 THRU 8020-RECORD-INT-ERROR-EXIT
           END-IF

           IF WS-7040-TRAN-SEQ-NO = ZEROS
              MOVE 7040 TO WS-8020-PARAGRAPH-NO
              MOVE 90003 TO WS-8020-INT-ERROR-NO
              MOVE 'WS-7040-TRAN-SEQ-NO' TO WS-8020-FIELD-NAME
              MOVE WS-7040-TRAN-SEQ-NO TO WS-8020-BAD-DATA
              MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
              PERFORM 8020-RECORD-INT-ERROR
                 THRU 8020-RECORD-INT-ERROR-EXIT
           END-IF

           IF WS-7040-TRAN-SOURCE-FLAG = SPACES
              MOVE 7040 TO WS-8020-PARAGRAPH-NO
              MOVE 90003 TO WS-8020-INT-ERROR-NO
              MOVE 'WS-7040-TRAN-SOURCE-FLAG' TO WS-8020-FIELD-NAME
              MOVE WS-7040-TRAN-SOURCE-FLAG TO WS-8020-BAD-DATA
              MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
              PERFORM 8020-RECORD-INT-ERROR
                 THRU 8020-RECORD-INT-ERROR-EXIT
           END-IF

      ****************************************************************
      *  Do insertion logic                                          *
      ****************************************************************

           IF WS-0050-T50-REC-COUNT = ZEROS
              SET WS-0050-T50-INDEX TO 1
              PERFORM 7040-ADD-RECORD
                 THRU 7040-ADD-RECORD-EXIT
           ELSE
              PERFORM 7040-SEARCH-T50-TBL
                 THRU 7040-SEARCH-T50-TBL-EXIT
           END-IF

      ****************************************************************
      *  Initialize Input Fields                                     *
      ****************************************************************

           INITIALIZE WS-7040-TRAN-REJECTED-FLAG
           INITIALIZE WS-7040-TRAN-SOURCE-FLAG
           INITIALIZE WS-7040-TYPE-50.


       7040-ADD-T50-RECORD-EXIT.
           EXIT.

      ****************************************************************
      *  THIS PARAGRAPH DOES A SEARCH OF THE RECORD TYPE 50          *
      *  RECORDS TABLE. WHEN A MATCH IS FOUND, THE TABLE IS UPDATED  *
      *  WITH THE NEW TRANSACTION RECORD CONTENTS.                   *
      ****************************************************************

       7040-SEARCH-T50-TBL.

           SET WS-0050-T50-INDEX TO 1

           SEARCH WS-0050-T50-RECORD VARYING WS-0050-T50-INDEX
                AT END
                    PERFORM 7040-ADD-RECORD
                       THRU 7040-ADD-RECORD-EXIT
                    GO TO 7040-SEARCH-T50-TBL-EXIT
                WHEN (WS-0050-TBL-POLICY-NO (WS-0050-T50-INDEX)
                     EQUAL WS-7040-POLICY-NO)
                 AND (WS-0050-TBL-CROP-CD (WS-0050-T50-INDEX)
                     IS EQUAL WS-7040-CROP-CD)

      $IF DEBUG-SW DEFINED
           DISPLAY 'REPLACING TYPE 50 RECORD' UPON CONSOLE
      $END
                     MOVE WS-7040-TRAN-REJECTED-FLAG
                       TO WS-0050-TBL-TRAN-REJECTED-FLAG
                       (WS-0050-T50-INDEX)
                     MOVE WS-7040-TRAN-SOURCE-FLAG
                       TO WS-0050-TBL-TRAN-SOURCE-FLAG
                       (WS-0050-T50-INDEX)
                     MOVE WS-7040-TYPE-50
                       TO WS-0050-TBL-TYPE-50 (WS-0050-T50-INDEX)
           END-SEARCH.

       7040-SEARCH-T50-TBL-EXIT.
           EXIT.

      ****************************************************************
      *  THIS PARAGRAPH TEST THE TABLE SIZE LIMIT BEFORE ADDING AN   *
      *  ADDITIONAL RECORD. WHEN THE MAXIMUM TABLE SIZE IS REACHED,  *
      *  MESSAGES ARE DISPLAYED AND EXECUTION IS TERMINATED -        *
      *  OTHERWISE THE NEW TRANSACTION RECORD IS ADDED TO THE TABLE. *
      ****************************************************************

       7040-ADD-RECORD.

           IF WS-0050-T50-REC-COUNT >= WS-0050-MAX-SIZE
              DISPLAY 'REC TYPE 50 T50 TABLE LIMIT WILL BE EXCEEDED'
              UPON CONSOLE
              DISPLAY ' WITH THE ADDITION OF THIS RECORD'
              UPON CONSOLE
              DISPLAY '**********************************'
              UPON CONSOLE
              DISPLAY 'MAXIMUM TABLE SIZE IS ' WS-0050-MAX-SIZE
                      ' RECORDS' UPON CONSOLE
              PERFORM 0800-ABORT-PROGRAM
                 THRU 0800-ABORT-PROGRAM-EXIT
           ELSE
              ADD 1 TO WS-0050-T50-REC-COUNT
              MOVE WS-7040-TRAN-REJECTED-FLAG
                TO WS-0050-TBL-TRAN-REJECTED-FLAG (WS-0050-T50-INDEX)
              MOVE WS-7040-TRAN-SOURCE-FLAG
                TO WS-0050-TBL-TRAN-SOURCE-FLAG (WS-0050-T50-INDEX)
              MOVE WS-7040-TYPE-50
                TO WS-0050-TBL-TYPE-50 (WS-0050-T50-INDEX)

      *            UPDATE TABLE STATISTICS
              IF WS-0050-T50-REC-COUNT > WS-0008-T50-MAX-TABLE-SIZE
                 MOVE WS-0050-T50-REC-COUNT
                   TO WS-0008-T50-MAX-TABLE-SIZE
              END-IF
           END-IF.

       7040-ADD-RECORD-EXIT.
           EXIT.
