      *****************************************************************
      * File:      M7330.CBL                                          *
      * Author:    Laura Dittamo                                      *
      * Date:      06/19/96                                           *
      * Purpose:                                                      *
      *    This routine uses a serial search against the              *
      *    WS-7010-CROP-LIMIT-TBL to look up the maximum limit set    *
      *    for a crop.                                                *
      *                                                               *
      * Special Notes:                                                *
      *    Where a Stage code applies to all types the type code      *
      *    will be 998.  Where it applies to all plan codes the plan  *
      *    code will be 98.                                           *
      *                                                               *
      * Example:                                                      *
      *    Fresh Market Tomatoes under Dollar Amount of Insurance     *
      *      Crop = 086; Type = 998; Plan = 50                        *
      *****************************************************************

       7330-LOOKUP-CROP-LIMIT.

      $IF DEBUG-SW DEFINED
           DISPLAY '7330-LOOKING UP CROP MAXIMUM LIMIT'
           UPON CONSOLE
      $END

      *****************************************************
      *    INITIALIZE LOCAL WORKING STORAGE               *
      *****************************************************

           MOVE WS-LITERAL-NO TO WS-7330-FOUND-FLG
           INITIALIZE WS-7330-O-CROP-LIMIT-AREA
           SET WS-7010-CROP-LIMIT-INDEX TO 1

      *****************************************************
      *    CHECK INPUT VALUES                             *
      *****************************************************
           IF WS-7330-I-INSURANCE-PLAN = ZEROS
              MOVE 7330 TO WS-8020-PARAGRAPH-NO
              MOVE 90003 TO WS-8020-INT-ERROR-NO
              MOVE 'WS-7330-I-INS-PLAN' TO WS-8020-FIELD-NAME
              MOVE WS-7330-I-INSURANCE-PLAN TO WS-8020-BAD-DATA
              MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
              PERFORM 8020-RECORD-INT-ERROR
                 THRU 8020-RECORD-INT-ERROR-EXIT
           END-IF

           IF WS-7330-I-CROP = ZEROS
              MOVE 7330 TO WS-8020-PARAGRAPH-NO
              MOVE 90003 TO WS-8020-INT-ERROR-NO
              MOVE 'WS-7330-I-CROP' TO WS-8020-FIELD-NAME
              MOVE WS-7330-I-CROP TO WS-8020-BAD-DATA
              MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
              PERFORM 8020-RECORD-INT-ERROR
                 THRU 8020-RECORD-INT-ERROR-EXIT
           END-IF

           IF WS-7330-I-CROP-TYPE = SPACES
              MOVE 7330 TO WS-8020-PARAGRAPH-NO
              MOVE 90003 TO WS-8020-INT-ERROR-NO
              MOVE 'WS-7330-I-CROP-TYPE' TO WS-8020-FIELD-NAME
              MOVE WS-7330-I-CROP-TYPE TO WS-8020-BAD-DATA
              MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
              PERFORM 8020-RECORD-INT-ERROR
                 THRU 8020-RECORD-INT-ERROR-EXIT
           END-IF

      *****************************************************
      *    SEARCH TABLE                                   *
      *****************************************************

           SET WS-7010-CROP-LIMIT-INDEX TO 1
           SEARCH WS-7010-CROP-LIMIT-REC
              VARYING WS-7010-CROP-LIMIT-INDEX
              AT END CONTINUE
              WHEN  (WS-7330-I-CROP
                    = WS-7010-CROP(WS-7010-CROP-LIMIT-INDEX))
               AND  (WS-7330-I-CROP-TYPE
                    = WS-7010-CROP-TYPE(WS-7010-CROP-LIMIT-INDEX))
               AND  (WS-7330-I-INSURANCE-PLAN
                    = WS-7010-INSURANCE-PLAN(WS-7010-CROP-LIMIT-INDEX))
                    MOVE WS-LITERAL-YES TO WS-7330-FOUND-FLG
                    MOVE WS-7010-CROP(WS-7010-CROP-LIMIT-INDEX)
                      TO WS-7330-O-CROP
                    MOVE WS-7010-CROP-TYPE(WS-7010-CROP-LIMIT-INDEX)
                      TO WS-7330-O-CROP-TYPE
                    MOVE WS-7010-INSURANCE-PLAN
                      (WS-7010-CROP-LIMIT-INDEX)
                      TO WS-7330-O-INSURANCE-PLAN
                    MOVE WS-7010-CROP-MAX-LIMIT
                      (WS-7010-CROP-LIMIT-INDEX)
                      TO WS-7330-O-CROP-MAX-LIMIT
                    INITIALIZE WS-7330-I-CROP-LIMIT-AREA
           END-SEARCH.

      $IF DEBUG-SW DEFINED
           IF NOT MATCH-FOUND-7330
              DISPLAY 'MAX CROP LIMIT NOT FOUND!'
              UPON CONSOLE
              DISPLAY 'INS PLAN  = ', WS-7330-I-INSURANCE-PLAN
              UPON CONSOLE
              DISPLAY 'CROP      = ', WS-7330-I-CROP
              UPON CONSOLE
              DISPLAY 'CROP TYPE = ', WS-7330-I-CROP-TYPE
              UPON CONSOLE
           END-IF.
      $END

      *****************************************************
      *    INITIALIZE INPUT FIELDS                        *
      *****************************************************
           INITIALIZE WS-7330-I-CROP-LIMIT-AREA.


       7330-LOOKUP-CROP-LIMIT-EXIT.
           EXIT.

