      *****************************************************************
      * File:      M7505.CBL                                          *
      * Author:    Mike Ray                                           *
      * Date:      10/25/95                                           *
      * Purpose:                                                      *
      *    This module validates the lookup parameters passed in and  *
      *    looks up values in the ADM record type 1 ISAM file.        *
      *    The ADM record contains:                                   *
      *        YIELD/$AMT/GUARANTEE/RATE DATA FOR ALL NON-GRP CROPS   *
      *****************************************************************

       7505-LOOKUP-ADM1.

      $IF DEBUG-SW DEFINED
           DISPLAY '7505-LOOKING UP ADM TYPE 1 REC (YIELD/$/RATE DATA)'
           UPON CONSOLE
      $END

      ************************************************
      *       INITIALIZE OUTPUT FIELDS               *
      ************************************************
           MOVE WS-LITERAL-NO TO WS-7505-FOUND-FLG
           MOVE WS-LITERAL-NO TO WS-7505-INPUT-ERROR

      ************************************************
      *         VALIDATE INPUT FIELDS                *
      ************************************************
           IF WS-7505-INPUT-CROP-YR = ZEROS
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 043 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-7505-INPUT-ERROR
              MOVE WS-LITERAL-CROP-YR TO WS-8000-FIELD-NAME1
              MOVE ZEROS TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 7505 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-7505-INPUT-STATE-CD = ZEROS
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 043 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-7505-INPUT-ERROR
              MOVE 'WS-7505-INPUT-STATE-CD' TO WS-8000-FIELD-NAME1
              MOVE WS-7505-INPUT-STATE-CD TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 7505 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-7505-INPUT-COUNTY-CD = ZEROS
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 043 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-7505-INPUT-ERROR
              MOVE 'WS-7505-INPUT-COUNTY-CD' TO WS-8000-FIELD-NAME1
              MOVE WS-7505-INPUT-COUNTY-CD TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 7505 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-7505-INPUT-INSURANCE-PLAN = ZERO
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 043 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-7505-INPUT-ERROR
              MOVE WS-LITERAL-INSURE-PLAN-CD TO WS-8000-FIELD-NAME1
              MOVE WS-7505-INPUT-INSURANCE-PLAN TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 7505 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-7505-INPUT-CROP-CD = ZERO
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 043 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-7505-INPUT-ERROR
              MOVE 'WS-7505-INPUT-COUNTY-CD' TO WS-8000-FIELD-NAME1
              MOVE WS-7505-INPUT-COUNTY-CD TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 7505 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

           IF WS-7505-INPUT-PRACTICE-CD = SPACES
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 043 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO WS-7505-INPUT-ERROR
              MOVE 'WS-7505-INPUT-PRACTICE-CD' TO WS-8000-FIELD-NAME1
              MOVE WS-7505-INPUT-PRACTICE-CD TO WS-8000-BAD-DATA1
              MOVE 'NOT BLANK' TO WS-8000-CORR-DATA1
              MOVE 7505 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF

      *    *** ADM HAS SPACES, NOT ZEROS FOR CASES WHERE
      *    *** NO RATE CLASS APPLIES
           IF WS-7505-INPUT-RATE-CLASS = '000'
              MOVE SPACES TO WS-7505-INPUT-RATE-CLASS
           END-IF

           IF WS-7505-INPUT-ERROR = WS-LITERAL-YES
              GO TO 7505-LOOKUP-ADM1-EXIT
           END-IF

           IF WS-7505-INPUT-TYPE-CD IS EQUAL SPACES
              MOVE '997' TO WS-7505-INPUT-TYPE-CD
           END-IF

      ************************************************
      *            EXCEPTIONS BY INS PLAN            *
      ************************************************
           EVALUATE WS-7505-INPUT-INSURANCE-PLAN
              WHEN WS-LITERAL-CRC
                MOVE WS-LITERAL-APH TO WS-7505-INPUT-INSURANCE-PLAN
              WHEN WS-LITERAL-RA
                MOVE WS-LITERAL-APH TO WS-7505-INPUT-INSURANCE-PLAN
              WHEN OTHER
                CONTINUE
           END-EVALUATE

      ************************************************
      *            EXCEPTIONS BY CROP                *
      ************************************************
           EVALUATE WS-7505-INPUT-CROP-CD
               WHEN WS-LITERAL-NURSERY
                      MOVE '998' TO WS-7505-INPUT-COUNTY-CD
               WHEN WS-LITERAL-POTATOES
                  IF WS-7505-INPUT-TYPE-CD = '997'
                     MOVE '000' TO WS-7505-INPUT-TYPE-CD
                  END-IF
               WHEN OTHER
                  CONTINUE
           END-EVALUATE.

      ************************************************
      *         READ RECORD FROM ISAM FILE           *
      ************************************************
       M7505-REREAD.

      $IF DEBUG-SW DEFINED
         DISPLAY 'ADM TYPE 1 KEY = '
           WS-7505-INPUT-KEY
         UPON CONSOLE
      $END

           IF ADM1-FILE-OPEN
              IF WS-7505-INPUT-KEY = WS-7505-ADM1-KEY
                 MOVE WS-LITERAL-YES TO WS-7505-FOUND-FLG
              ELSE
                 INITIALIZE WS-7505-ADM1-REC
                 MOVE WS-7505-INPUT-KEY TO ADM1-REC-KEY
                 READ ADM1-FILE
                    INVALID KEY
                       IF WS-7505-INPUT-CROP-CD =
                          WS-LITERAL-POTATOES
                         IF WS-7505-INPUT-TYPE-CD = '000'
                            MOVE '997' TO WS-7505-INPUT-TYPE-CD
                            GO TO M7505-REREAD
                         ELSE
                           if WS-7505-INPUT-RATE-CLASS = '000'
                            move spaces to WS-7505-INPUT-RATE-CLASS
                            GO TO M7505-REREAD
                            END-IF
                         END-IF
                        ELSE
                          if WS-7505-INPUT-RATE-CLASS = '000'
                           move spaces to WS-7505-INPUT-RATE-CLASS
                           GO TO M7505-REREAD
                          else
                           GO TO 7505-LOOKUP-ADM1-EXIT
                          end-if
                        END-IF
                    NOT INVALID KEY
                       MOVE ADM1-RECORD TO WS-7505-ADM1-REC
                       MOVE WS-LITERAL-YES TO WS-7505-FOUND-FLG
                 END-READ
              END-IF
           ELSE
              MOVE 7505 TO WS-8020-PARAGRAPH-NO
              MOVE 90013 TO WS-8020-INT-ERROR-NO
              MOVE 'ADM1 FILE' TO WS-8020-FIELD-NAME
              MOVE SPACES TO WS-8020-BAD-DATA
              MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
              PERFORM 8020-RECORD-INT-ERROR
                 THRU 8020-RECORD-INT-ERROR-EXIT
           END-IF

      $IF DEBUG-SW DEFINED
           PERFORM 7505-DISPLAY-RECORD
              THRU 7505-DISPLAY-RECORD-EXIT
      $END

      ************************************************
      *         INITIALIZE INPUT FIELDS              *
      ************************************************
           INITIALIZE WS-7505-INPUT-KEY.


       7505-LOOKUP-ADM1-EXIT.
           EXIT.


      $IF DEBUG-SW DEFINED

       7505-DISPLAY-RECORD.

           DISPLAY 'ADM1 RECORD'
           UPON CONSOLE
           DISPLAY 'RECORD TYPE CODE: ',
           WS-7505-RECORD-TYPE-CD UPON CONSOLE
           DISPLAY 'CROP YEAR       : ',
           WS-7505-CROP-YEAR UPON CONSOLE
           DISPLAY 'STATE CODE      : ',
           WS-7505-STATE-CD UPON CONSOLE
           DISPLAY 'COUNTY CODE     : ',
           WS-7505-COUNTY-CD UPON CONSOLE
           DISPLAY 'CROP CODE       : ',
           WS-7505-CROP-CD UPON CONSOLE
           DISPLAY 'INSURANCE PLAN  : ',
           WS-7505-INSURANCE-PLAN-ID UPON CONSOLE
           DISPLAY 'PRACTICE CODE   : ',
           WS-7505-PRACTICE-CD UPON CONSOLE
           DISPLAY 'TYPE CODE       : ',
           WS-7505-TYPE-CD UPON CONSOLE
           DISPLAY 'RATE CLASS      : ',
           WS-7505-RATE-CLASS UPON CONSOLE
           DISPLAY '---------------------------'
           UPON CONSOLE
           DISPLAY 'RECORD TYPE SFX : ',
           WS-7505-RECORD-TYPE-SFX UPON CONSOLE
           DISPLAY 'LOW/HIGH YIELD  : ',
           WS-7505-LOW-YIELD, ' - ',
           WS-7505-HIGH-YIELD UPON CONSOLE
           DISPLAY 'LOW/HIGH TREES  : ',
           WS-7505-LOW-TREES, ' - ',
           WS-7505-HIGH-TREES UPON CONSOLE
           DISPLAY 'GROWTH STAGE    : ',
           WS-7505-GROWTH-STAGE UPON CONSOLE
           DISPLAY '---------------------------'
             UPON CONSOLE
           DISPLAY 'CAT/MIN/MAX $AMT INS: ',
           WS-7505-CAT-DOLLAR-AMT-INS, ' / ',
           WS-7505-MIN-DOLLAR-AMT-INS, ' / ',
           WS-7505-MAX-DOLLAR-AMT-INS UPON CONSOLE
           DISPLAY 'REF MAX $AMT INS    : ',
           WS-7505-REF-MAX-DOLLAR-AMT-INS UPON CONSOLE
           DISPLAY 'REF MAX PRICE       : ',
           WS-7505-REF-MAX-PRICE UPON CONSOLE
           DISPLAY '---------------------------'
             UPON CONSOLE
           DISPLAY 'COVERAGE LEVEL/RATE 01 : ',
             WS-7505-COVERAGE-LEVEL-01, ' - ',
             WS-7505-BASE-PREMIUM-RATE-01 UPON CONSOLE
           DISPLAY 'COVERAGE LEVEL/RATE 02 : ',
             WS-7505-COVERAGE-LEVEL-02, ' - ',
             WS-7505-BASE-PREMIUM-RATE-02 UPON CONSOLE
           DISPLAY 'COVERAGE LEVEL/RATE 03 : ',
             WS-7505-COVERAGE-LEVEL-03, ' - ',
             WS-7505-BASE-PREMIUM-RATE-03 UPON CONSOLE
           DISPLAY 'COVERAGE LEVEL/RATE 04 : ',
             WS-7505-COVERAGE-LEVEL-04, ' - ',
             WS-7505-BASE-PREMIUM-RATE-04 UPON CONSOLE
           DISPLAY 'COVERAGE LEVEL/RATE 05 : ',
             WS-7505-COVERAGE-LEVEL-05, ' - ',
             WS-7505-BASE-PREMIUM-RATE-05 UPON CONSOLE
           DISPLAY 'COVERAGE LEVEL/RATE 06 : ',
             WS-7505-COVERAGE-LEVEL-06, ' - ',
             WS-7505-BASE-PREMIUM-RATE-06 UPON CONSOLE
           DISPLAY 'COVERAGE LEVEL/RATE 07 : ',
             WS-7505-COVERAGE-LEVEL-07, ' - ',
             WS-7505-BASE-PREMIUM-RATE-07 UPON CONSOLE
           DISPLAY 'COVERAGE LEVEL/RATE 08 : ',
             WS-7505-COVERAGE-LEVEL-08, ' - ',
             WS-7505-BASE-PREMIUM-RATE-08 UPON CONSOLE
           DISPLAY 'COVERAGE LEVEL/RATE 09 : ',
             WS-7505-COVERAGE-LEVEL-09, ' - ',
             WS-7505-BASE-PREMIUM-RATE-09 UPON CONSOLE
           DISPLAY 'COVERAGE LEVEL/RATE 10 : ',
             WS-7505-COVERAGE-LEVEL-10, ' - ',
             WS-7505-BASE-PREMIUM-RATE-10 UPON CONSOLE
           DISPLAY 'COVERAGE LEVEL/RATE 11 : ',
             WS-7505-COVERAGE-LEVEL-11, ' - ',
             WS-7505-BASE-PREMIUM-RATE-11 UPON CONSOLE
           DISPLAY 'COVERAGE LEVEL/RATE 12 : ',
             WS-7505-COVERAGE-LEVEL-12, ' - ',
             WS-7505-BASE-PREMIUM-RATE-12 UPON CONSOLE
           DISPLAY 'COVERAGE LEVEL/RATE 13 : ',
             WS-7505-COVERAGE-LEVEL-13, ' - ',
             WS-7505-BASE-PREMIUM-RATE-13 UPON CONSOLE
           DISPLAY 'COVERAGE LEVEL/RATE 14 : ',
             WS-7505-COVERAGE-LEVEL-14, ' - ',
             WS-7505-BASE-PREMIUM-RATE-14 UPON CONSOLE
           DISPLAY 'COVERAGE LEVEL/RATE 15 : ',
             WS-7505-COVERAGE-LEVEL-15, ' - ',
             WS-7505-BASE-PREMIUM-RATE-15 UPON CONSOLE
           DISPLAY 'COVERAGE LEVEL/RATE 16 : ',
             WS-7505-COVERAGE-LEVEL-16, ' - ',
             WS-7505-BASE-PREMIUM-RATE-16 UPON CONSOLE
           DISPLAY 'CRC APH FLAG         : ',
             WS-7505-CRC-APH-FLAG UPON CONSOLE
           DISPLAY '---------------------------'
             UPON CONSOLE
           DISPLAY 'DATE RELEASED/UPDATED/FILED : ',
           WS-7505-DATE-LAST-RELEASED, '/',
           WS-7505-DATE-LAST-UPDATED, '/',
           WS-7505-DATE-FILED UPON CONSOLE
           DISPLAY ' ' UPON CONSOLE.

       7505-DISPLAY-RECORD-EXIT.
           EXIT.

      $END
